%%% Unicode to TeX mapping, file uni-205.def, U+CD00..U+CDFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-205.def}[2013/05/13 UCS: Unicode data U+CD00..U+CDFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{52481}{cjkhangul}{\u@cjk@hangul13A4}%
\uc@dclc{52488}{cjkhangul}{\u@cjk@hangul13A5}%
\uc@dclc{52489}{cjkhangul}{\u@cjk@hangul13A6}%
\uc@dclc{52492}{cjkhangul}{\u@cjk@hangul13A7}%
\uc@dclc{52496}{cjkhangul}{\u@cjk@hangul13A8}%
\uc@dclc{52504}{cjkhangul}{\u@cjk@hangul13A9}%
\uc@dclc{52505}{cjkhangul}{\u@cjk@hangul13AA}%
\uc@dclc{52507}{cjkhangul}{\u@cjk@hangul13AB}%
\uc@dclc{52509}{cjkhangul}{\u@cjk@hangul13AC}%
\uc@dclc{52516}{cjkhangul}{\u@cjk@hangul13AD}%
\uc@dclc{52520}{cjkhangul}{\u@cjk@hangul13AE}%
\uc@dclc{52524}{cjkhangul}{\u@cjk@hangul13AF}%
\uc@dclc{52537}{cjkhangul}{\u@cjk@hangul13B0}%
\uc@dclc{52572}{cjkhangul}{\u@cjk@hangul13B1}%
\uc@dclc{52576}{cjkhangul}{\u@cjk@hangul13B2}%
\uc@dclc{52580}{cjkhangul}{\u@cjk@hangul13B3}%
\uc@dclc{52588}{cjkhangul}{\u@cjk@hangul13B4}%
\uc@dclc{52589}{cjkhangul}{\u@cjk@hangul13B5}%
\uc@dclc{52591}{cjkhangul}{\u@cjk@hangul13B6}%
\uc@dclc{52593}{cjkhangul}{\u@cjk@hangul13B7}%
\uc@dclc{52600}{cjkhangul}{\u@cjk@hangul13B8}%
\uc@dclc{52616}{cjkhangul}{\u@cjk@hangul13B9}%
\uc@dclc{52628}{cjkhangul}{\u@cjk@hangul13BA}%
\uc@dclc{52629}{cjkhangul}{\u@cjk@hangul13BB}%
\uc@dclc{52632}{cjkhangul}{\u@cjk@hangul13BC}%
\uc@dclc{52636}{cjkhangul}{\u@cjk@hangul13BD}%
\uc@dclc{52644}{cjkhangul}{\u@cjk@hangul13BE}%
\uc@dclc{52645}{cjkhangul}{\u@cjk@hangul13BF}%
\uc@dclc{52647}{cjkhangul}{\u@cjk@hangul13C0}%
\uc@dclc{52649}{cjkhangul}{\u@cjk@hangul13C1}%
\uc@dclc{52656}{cjkhangul}{\u@cjk@hangul13C2}%
\uc@dclc{52676}{cjkhangul}{\u@cjk@hangul13C3}%
\uc@dclc{52684}{cjkhangul}{\u@cjk@hangul13C4}%
\uc@dclc{52688}{cjkhangul}{\u@cjk@hangul13C5}%
\uc@dclc{52712}{cjkhangul}{\u@cjk@hangul13C6}%
\uc@dclc{52716}{cjkhangul}{\u@cjk@hangul13C7}%
\uc@dclc{52720}{cjkhangul}{\u@cjk@hangul13C8}%
\uc@dclc{52728}{cjkhangul}{\u@cjk@hangul13C9}%
\uc@dclc{52729}{cjkhangul}{\u@cjk@hangul13CA}%
\uc@dclc{52731}{cjkhangul}{\u@cjk@hangul13CB}%
\uc@dclc{52733}{cjkhangul}{\u@cjk@hangul13CC}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
