%%% Unicode to TeX mapping, file uni-201.def, U+C900..U+C9FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-201.def}[2013/05/13 UCS: Unicode data U+C900..U+C9FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{51456}{cjkhangul}{\u@cjk@hangul12F7}%
\uc@dclc{51460}{cjkhangul}{\u@cjk@hangul12F8}%
\uc@dclc{51461}{cjkhangul}{\u@cjk@hangul12F9}%
\uc@dclc{51462}{cjkhangul}{\u@cjk@hangul12FA}%
\uc@dclc{51468}{cjkhangul}{\u@cjk@hangul12FB}%
\uc@dclc{51469}{cjkhangul}{\u@cjk@hangul12FC}%
\uc@dclc{51471}{cjkhangul}{\u@cjk@hangul12FD}%
\uc@dclc{51473}{cjkhangul}{\u@cjk@hangul12FE}%
\uc@dclc{51480}{cjkhangul}{\u@cjk@hangul12FF}%
\uc@dclc{51500}{cjkhangul}{\u@cjk@hangul1300}%
\uc@dclc{51508}{cjkhangul}{\u@cjk@hangul1301}%
\uc@dclc{51536}{cjkhangul}{\u@cjk@hangul1302}%
\uc@dclc{51537}{cjkhangul}{\u@cjk@hangul1303}%
\uc@dclc{51540}{cjkhangul}{\u@cjk@hangul1304}%
\uc@dclc{51544}{cjkhangul}{\u@cjk@hangul1305}%
\uc@dclc{51552}{cjkhangul}{\u@cjk@hangul1306}%
\uc@dclc{51553}{cjkhangul}{\u@cjk@hangul1307}%
\uc@dclc{51555}{cjkhangul}{\u@cjk@hangul1308}%
\uc@dclc{51564}{cjkhangul}{\u@cjk@hangul1309}%
\uc@dclc{51568}{cjkhangul}{\u@cjk@hangul130A}%
\uc@dclc{51572}{cjkhangul}{\u@cjk@hangul130B}%
\uc@dclc{51580}{cjkhangul}{\u@cjk@hangul130C}%
\uc@dclc{51592}{cjkhangul}{\u@cjk@hangul130D}%
\uc@dclc{51593}{cjkhangul}{\u@cjk@hangul130E}%
\uc@dclc{51596}{cjkhangul}{\u@cjk@hangul130F}%
\uc@dclc{51600}{cjkhangul}{\u@cjk@hangul1310}%
\uc@dclc{51608}{cjkhangul}{\u@cjk@hangul1311}%
\uc@dclc{51609}{cjkhangul}{\u@cjk@hangul1312}%
\uc@dclc{51611}{cjkhangul}{\u@cjk@hangul1313}%
\uc@dclc{51613}{cjkhangul}{\u@cjk@hangul1314}%
\uc@dclc{51648}{cjkhangul}{\u@cjk@hangul1315}%
\uc@dclc{51649}{cjkhangul}{\u@cjk@hangul1316}%
\uc@dclc{51652}{cjkhangul}{\u@cjk@hangul1317}%
\uc@dclc{51655}{cjkhangul}{\u@cjk@hangul1318}%
\uc@dclc{51656}{cjkhangul}{\u@cjk@hangul1319}%
\uc@dclc{51658}{cjkhangul}{\u@cjk@hangul131A}%
\uc@dclc{51664}{cjkhangul}{\u@cjk@hangul131B}%
\uc@dclc{51665}{cjkhangul}{\u@cjk@hangul131C}%
\uc@dclc{51667}{cjkhangul}{\u@cjk@hangul131D}%
\uc@dclc{51669}{cjkhangul}{\u@cjk@hangul131E}%
\uc@dclc{51670}{cjkhangul}{\u@cjk@hangul131F}%
\uc@dclc{51673}{cjkhangul}{\u@cjk@hangul1320}%
\uc@dclc{51674}{cjkhangul}{\u@cjk@hangul1321}%
\uc@dclc{51676}{cjkhangul}{\u@cjk@hangul1322}%
\uc@dclc{51677}{cjkhangul}{\u@cjk@hangul1323}%
\uc@dclc{51680}{cjkhangul}{\u@cjk@hangul1324}%
\uc@dclc{51682}{cjkhangul}{\u@cjk@hangul1325}%
\uc@dclc{51684}{cjkhangul}{\u@cjk@hangul1326}%
\uc@dclc{51687}{cjkhangul}{\u@cjk@hangul1327}%
\uc@dclc{51692}{cjkhangul}{\u@cjk@hangul1328}%
\uc@dclc{51693}{cjkhangul}{\u@cjk@hangul1329}%
\uc@dclc{51695}{cjkhangul}{\u@cjk@hangul132A}%
\uc@dclc{51696}{cjkhangul}{\u@cjk@hangul132B}%
\uc@dclc{51697}{cjkhangul}{\u@cjk@hangul132C}%
\uc@dclc{51704}{cjkhangul}{\u@cjk@hangul132D}%
\uc@dclc{51705}{cjkhangul}{\u@cjk@hangul132E}%
\uc@dclc{51708}{cjkhangul}{\u@cjk@hangul132F}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
