%%% Unicode to TeX mapping, file uni-211.def, U+D300..U+D3FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-211.def}[2013/05/13 UCS: Unicode data U+D300..U+D3FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{54016}{cjkhangul}{\u@cjk@hangul14B5}%
\uc@dclc{54017}{cjkhangul}{\u@cjk@hangul14B6}%
\uc@dclc{54019}{cjkhangul}{\u@cjk@hangul14B7}%
\uc@dclc{54021}{cjkhangul}{\u@cjk@hangul14B8}%
\uc@dclc{54028}{cjkhangul}{\u@cjk@hangul14B9}%
\uc@dclc{54029}{cjkhangul}{\u@cjk@hangul14BA}%
\uc@dclc{54030}{cjkhangul}{\u@cjk@hangul14BB}%
\uc@dclc{54032}{cjkhangul}{\u@cjk@hangul14BC}%
\uc@dclc{54036}{cjkhangul}{\u@cjk@hangul14BD}%
\uc@dclc{54038}{cjkhangul}{\u@cjk@hangul14BE}%
\uc@dclc{54044}{cjkhangul}{\u@cjk@hangul14BF}%
\uc@dclc{54045}{cjkhangul}{\u@cjk@hangul14C0}%
\uc@dclc{54047}{cjkhangul}{\u@cjk@hangul14C1}%
\uc@dclc{54048}{cjkhangul}{\u@cjk@hangul14C2}%
\uc@dclc{54049}{cjkhangul}{\u@cjk@hangul14C3}%
\uc@dclc{54053}{cjkhangul}{\u@cjk@hangul14C4}%
\uc@dclc{54056}{cjkhangul}{\u@cjk@hangul14C5}%
\uc@dclc{54057}{cjkhangul}{\u@cjk@hangul14C6}%
\uc@dclc{54060}{cjkhangul}{\u@cjk@hangul14C7}%
\uc@dclc{54064}{cjkhangul}{\u@cjk@hangul14C8}%
\uc@dclc{54072}{cjkhangul}{\u@cjk@hangul14C9}%
\uc@dclc{54073}{cjkhangul}{\u@cjk@hangul14CA}%
\uc@dclc{54075}{cjkhangul}{\u@cjk@hangul14CB}%
\uc@dclc{54076}{cjkhangul}{\u@cjk@hangul14CC}%
\uc@dclc{54077}{cjkhangul}{\u@cjk@hangul14CD}%
\uc@dclc{54084}{cjkhangul}{\u@cjk@hangul14CE}%
\uc@dclc{54085}{cjkhangul}{\u@cjk@hangul14CF}%
\uc@dclc{54140}{cjkhangul}{\u@cjk@hangul14D0}%
\uc@dclc{54141}{cjkhangul}{\u@cjk@hangul14D1}%
\uc@dclc{54144}{cjkhangul}{\u@cjk@hangul14D2}%
\uc@dclc{54148}{cjkhangul}{\u@cjk@hangul14D3}%
\uc@dclc{54156}{cjkhangul}{\u@cjk@hangul14D4}%
\uc@dclc{54157}{cjkhangul}{\u@cjk@hangul14D5}%
\uc@dclc{54159}{cjkhangul}{\u@cjk@hangul14D6}%
\uc@dclc{54160}{cjkhangul}{\u@cjk@hangul14D7}%
\uc@dclc{54161}{cjkhangul}{\u@cjk@hangul14D8}%
\uc@dclc{54168}{cjkhangul}{\u@cjk@hangul14D9}%
\uc@dclc{54169}{cjkhangul}{\u@cjk@hangul14DA}%
\uc@dclc{54172}{cjkhangul}{\u@cjk@hangul14DB}%
\uc@dclc{54176}{cjkhangul}{\u@cjk@hangul14DC}%
\uc@dclc{54184}{cjkhangul}{\u@cjk@hangul14DD}%
\uc@dclc{54185}{cjkhangul}{\u@cjk@hangul14DE}%
\uc@dclc{54187}{cjkhangul}{\u@cjk@hangul14DF}%
\uc@dclc{54189}{cjkhangul}{\u@cjk@hangul14E0}%
\uc@dclc{54196}{cjkhangul}{\u@cjk@hangul14E1}%
\uc@dclc{54200}{cjkhangul}{\u@cjk@hangul14E2}%
\uc@dclc{54204}{cjkhangul}{\u@cjk@hangul14E3}%
\uc@dclc{54212}{cjkhangul}{\u@cjk@hangul14E4}%
\uc@dclc{54213}{cjkhangul}{\u@cjk@hangul14E5}%
\uc@dclc{54216}{cjkhangul}{\u@cjk@hangul14E6}%
\uc@dclc{54217}{cjkhangul}{\u@cjk@hangul14E7}%
\uc@dclc{54224}{cjkhangul}{\u@cjk@hangul14E8}%
\uc@dclc{54232}{cjkhangul}{\u@cjk@hangul14E9}%
\uc@dclc{54241}{cjkhangul}{\u@cjk@hangul14EA}%
\uc@dclc{54243}{cjkhangul}{\u@cjk@hangul14EB}%
\uc@dclc{54252}{cjkhangul}{\u@cjk@hangul14EC}%
\uc@dclc{54253}{cjkhangul}{\u@cjk@hangul14ED}%
\uc@dclc{54256}{cjkhangul}{\u@cjk@hangul14EE}%
\uc@dclc{54260}{cjkhangul}{\u@cjk@hangul14EF}%
\uc@dclc{54268}{cjkhangul}{\u@cjk@hangul14F0}%
\uc@dclc{54269}{cjkhangul}{\u@cjk@hangul14F1}%
\uc@dclc{54271}{cjkhangul}{\u@cjk@hangul14F2}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
