%%% Unicode to TeX mapping, file uni-50.def, U+3200..U+32FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-50.def}[2013/05/13 UCS: Unicode data U+3200..U+32FF]%
\fi
\uc@dclc{12832}{autogenerated}{\unichar{40}\unichar{19968}\unichar{41}}%
\uc@dclc{12833}{autogenerated}{\unichar{40}\unichar{20108}\unichar{41}}%
\uc@dclc{12834}{autogenerated}{\unichar{40}\unichar{19977}\unichar{41}}%
\uc@dclc{12835}{autogenerated}{\unichar{40}\unichar{22235}\unichar{41}}%
\uc@dclc{12836}{autogenerated}{\unichar{40}\unichar{20116}\unichar{41}}%
\uc@dclc{12837}{autogenerated}{\unichar{40}\unichar{20845}\unichar{41}}%
\uc@dclc{12838}{autogenerated}{\unichar{40}\unichar{19971}\unichar{41}}%
\uc@dclc{12839}{autogenerated}{\unichar{40}\unichar{20843}\unichar{41}}%
\uc@dclc{12840}{autogenerated}{\unichar{40}\unichar{20061}\unichar{41}}%
\uc@dclc{12841}{autogenerated}{\unichar{40}\unichar{21313}\unichar{41}}%
\uc@dclc{12842}{autogenerated}{\unichar{40}\unichar{26376}\unichar{41}}%
\uc@dclc{12843}{autogenerated}{\unichar{40}\unichar{28779}\unichar{41}}%
\uc@dclc{12844}{autogenerated}{\unichar{40}\unichar{27700}\unichar{41}}%
\uc@dclc{12845}{autogenerated}{\unichar{40}\unichar{26408}\unichar{41}}%
\uc@dclc{12846}{autogenerated}{\unichar{40}\unichar{37329}\unichar{41}}%
\uc@dclc{12847}{autogenerated}{\unichar{40}\unichar{22303}\unichar{41}}%
\uc@dclc{12848}{autogenerated}{\unichar{40}\unichar{26085}\unichar{41}}%
\uc@dclc{12849}{autogenerated}{\unichar{40}\unichar{26666}\unichar{41}}%
\uc@dclc{12850}{autogenerated}{\unichar{40}\unichar{26377}\unichar{41}}%
\uc@dclc{12851}{autogenerated}{\unichar{40}\unichar{31038}\unichar{41}}%
\uc@dclc{12852}{autogenerated}{\unichar{40}\unichar{21517}\unichar{41}}%
\uc@dclc{12853}{autogenerated}{\unichar{40}\unichar{29305}\unichar{41}}%
\uc@dclc{12854}{autogenerated}{\unichar{40}\unichar{36001}\unichar{41}}%
\uc@dclc{12855}{autogenerated}{\unichar{40}\unichar{31069}\unichar{41}}%
\uc@dclc{12856}{autogenerated}{\unichar{40}\unichar{21172}\unichar{41}}%
\uc@dclc{12857}{autogenerated}{\unichar{40}\unichar{20195}\unichar{41}}%
\uc@dclc{12858}{autogenerated}{\unichar{40}\unichar{21628}\unichar{41}}%
\uc@dclc{12859}{autogenerated}{\unichar{40}\unichar{23398}\unichar{41}}%
\uc@dclc{12860}{autogenerated}{\unichar{40}\unichar{30435}\unichar{41}}%
\uc@dclc{12861}{autogenerated}{\unichar{40}\unichar{20225}\unichar{41}}%
\uc@dclc{12862}{autogenerated}{\unichar{40}\unichar{36039}\unichar{41}}%
\uc@dclc{12863}{autogenerated}{\unichar{40}\unichar{21332}\unichar{41}}%
\uc@dclc{12864}{autogenerated}{\unichar{40}\unichar{31085}\unichar{41}}%
\uc@dclc{12865}{autogenerated}{\unichar{40}\unichar{20241}\unichar{41}}%
\uc@dclc{12866}{autogenerated}{\unichar{40}\unichar{33258}\unichar{41}}%
\uc@dclc{12867}{autogenerated}{\unichar{40}\unichar{33267}\unichar{41}}%
\uc@dclc{12868}{autogenerated}{\unicodecircle{\unichar{21839}}}%
\uc@dclc{12869}{autogenerated}{\unicodecircle{\unichar{24188}}}%
\uc@dclc{12870}{autogenerated}{\unicodecircle{\unichar{25991}}}%
\uc@dclc{12871}{autogenerated}{\unicodecircle{\unichar{31631}}}%
\uc@dclc{12880}{autogenerated}{\unicodesquare{\unichar{80}\unichar{84}\unichar{69}}}%
\uc@dclc{12881}{autogenerated}{\unicodecircle{\unichar{50}\unichar{49}}}%
\uc@dclc{12882}{autogenerated}{\unicodecircle{\unichar{50}\unichar{50}}}%
\uc@dclc{12883}{autogenerated}{\unicodecircle{\unichar{50}\unichar{51}}}%
\uc@dclc{12884}{autogenerated}{\unicodecircle{\unichar{50}\unichar{52}}}%
\uc@dclc{12885}{autogenerated}{\unicodecircle{\unichar{50}\unichar{53}}}%
\uc@dclc{12886}{autogenerated}{\unicodecircle{\unichar{50}\unichar{54}}}%
\uc@dclc{12887}{autogenerated}{\unicodecircle{\unichar{50}\unichar{55}}}%
\uc@dclc{12888}{autogenerated}{\unicodecircle{\unichar{50}\unichar{56}}}%
\uc@dclc{12889}{autogenerated}{\unicodecircle{\unichar{50}\unichar{57}}}%
\uc@dclc{12890}{autogenerated}{\unicodecircle{\unichar{51}\unichar{48}}}%
\uc@dclc{12891}{autogenerated}{\unicodecircle{\unichar{51}\unichar{49}}}%
\uc@dclc{12892}{autogenerated}{\unicodecircle{\unichar{51}\unichar{50}}}%
\uc@dclc{12893}{autogenerated}{\unicodecircle{\unichar{51}\unichar{51}}}%
\uc@dclc{12894}{autogenerated}{\unicodecircle{\unichar{51}\unichar{52}}}%
\uc@dclc{12895}{autogenerated}{\unicodecircle{\unichar{51}\unichar{53}}}%
\uc@dclc{12928}{autogenerated}{\unicodecircle{\unichar{19968}}}%
\uc@dclc{12929}{autogenerated}{\unicodecircle{\unichar{20108}}}%
\uc@dclc{12930}{autogenerated}{\unicodecircle{\unichar{19977}}}%
\uc@dclc{12931}{autogenerated}{\unicodecircle{\unichar{22235}}}%
\uc@dclc{12932}{autogenerated}{\unicodecircle{\unichar{20116}}}%
\uc@dclc{12933}{autogenerated}{\unicodecircle{\unichar{20845}}}%
\uc@dclc{12934}{autogenerated}{\unicodecircle{\unichar{19971}}}%
\uc@dclc{12935}{autogenerated}{\unicodecircle{\unichar{20843}}}%
\uc@dclc{12936}{autogenerated}{\unicodecircle{\unichar{20061}}}%
\uc@dclc{12937}{autogenerated}{\unicodecircle{\unichar{21313}}}%
\uc@dclc{12938}{autogenerated}{\unicodecircle{\unichar{26376}}}%
\uc@dclc{12939}{autogenerated}{\unicodecircle{\unichar{28779}}}%
\uc@dclc{12940}{autogenerated}{\unicodecircle{\unichar{27700}}}%
\uc@dclc{12941}{autogenerated}{\unicodecircle{\unichar{26408}}}%
\uc@dclc{12942}{autogenerated}{\unicodecircle{\unichar{37329}}}%
\uc@dclc{12943}{autogenerated}{\unicodecircle{\unichar{22303}}}%
\uc@dclc{12944}{autogenerated}{\unicodecircle{\unichar{26085}}}%
\uc@dclc{12945}{autogenerated}{\unicodecircle{\unichar{26666}}}%
\uc@dclc{12946}{autogenerated}{\unicodecircle{\unichar{26377}}}%
\uc@dclc{12947}{autogenerated}{\unicodecircle{\unichar{31038}}}%
\uc@dclc{12948}{autogenerated}{\unicodecircle{\unichar{21517}}}%
\uc@dclc{12949}{autogenerated}{\unicodecircle{\unichar{29305}}}%
\uc@dclc{12950}{autogenerated}{\unicodecircle{\unichar{36001}}}%
\uc@dclc{12951}{autogenerated}{\unicodecircle{\unichar{31069}}}%
\uc@dclc{12952}{autogenerated}{\unicodecircle{\unichar{21172}}}%
\uc@dclc{12953}{autogenerated}{\unicodecircle{\unichar{31192}}}%
\uc@dclc{12954}{autogenerated}{\unicodecircle{\unichar{30007}}}%
\uc@dclc{12955}{autogenerated}{\unicodecircle{\unichar{22899}}}%
\uc@dclc{12956}{autogenerated}{\unicodecircle{\unichar{36969}}}%
\uc@dclc{12957}{autogenerated}{\unicodecircle{\unichar{20778}}}%
\uc@dclc{12958}{autogenerated}{\unicodecircle{\unichar{21360}}}%
\uc@dclc{12959}{autogenerated}{\unicodecircle{\unichar{27880}}}%
\uc@dclc{12960}{autogenerated}{\unicodecircle{\unichar{38917}}}%
\uc@dclc{12961}{autogenerated}{\unicodecircle{\unichar{20241}}}%
\uc@dclc{12962}{autogenerated}{\unicodecircle{\unichar{20889}}}%
\gdef\u@cjk@Bgv#1#2#3#4{{\fontencoding{C00}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{12963}{cjkbg5}{\u@cjk@Bgv015E}%
\uc@dclc{12964}{autogenerated}{\unicodecircle{\unichar{19978}}}%
\uc@dclc{12965}{autogenerated}{\unicodecircle{\unichar{20013}}}%
\uc@dclc{12966}{autogenerated}{\unicodecircle{\unichar{19979}}}%
\uc@dclc{12967}{autogenerated}{\unicodecircle{\unichar{24038}}}%
\uc@dclc{12968}{autogenerated}{\unicodecircle{\unichar{21491}}}%
\uc@dclc{12969}{autogenerated}{\unicodecircle{\unichar{21307}}}%
\uc@dclc{12970}{autogenerated}{\unicodecircle{\unichar{23447}}}%
\uc@dclc{12971}{autogenerated}{\unicodecircle{\unichar{23398}}}%
\uc@dclc{12972}{autogenerated}{\unicodecircle{\unichar{30435}}}%
\uc@dclc{12973}{autogenerated}{\unicodecircle{\unichar{20225}}}%
\uc@dclc{12974}{autogenerated}{\unicodecircle{\unichar{36039}}}%
\uc@dclc{12975}{autogenerated}{\unicodecircle{\unichar{21332}}}%
\uc@dclc{12976}{autogenerated}{\unicodecircle{\unichar{22812}}}%
\uc@dclc{12977}{autogenerated}{\unicodecircle{\unichar{51}\unichar{54}}}%
\uc@dclc{12978}{autogenerated}{\unicodecircle{\unichar{51}\unichar{55}}}%
\uc@dclc{12979}{autogenerated}{\unicodecircle{\unichar{51}\unichar{56}}}%
\uc@dclc{12980}{autogenerated}{\unicodecircle{\unichar{51}\unichar{57}}}%
\uc@dclc{12981}{autogenerated}{\unicodecircle{\unichar{52}\unichar{48}}}%
\uc@dclc{12982}{autogenerated}{\unicodecircle{\unichar{52}\unichar{49}}}%
\uc@dclc{12983}{autogenerated}{\unicodecircle{\unichar{52}\unichar{50}}}%
\uc@dclc{12984}{autogenerated}{\unicodecircle{\unichar{52}\unichar{51}}}%
\uc@dclc{12985}{autogenerated}{\unicodecircle{\unichar{52}\unichar{52}}}%
\uc@dclc{12986}{autogenerated}{\unicodecircle{\unichar{52}\unichar{53}}}%
\uc@dclc{12987}{autogenerated}{\unicodecircle{\unichar{52}\unichar{54}}}%
\uc@dclc{12988}{autogenerated}{\unicodecircle{\unichar{52}\unichar{55}}}%
\uc@dclc{12989}{autogenerated}{\unicodecircle{\unichar{52}\unichar{56}}}%
\uc@dclc{12990}{autogenerated}{\unicodecircle{\unichar{52}\unichar{57}}}%
\uc@dclc{12991}{autogenerated}{\unicodecircle{\unichar{53}\unichar{48}}}%
\uc@dclc{12992}{autogenerated}{\unichar{49}\unichar{26376}}%
\uc@dclc{12993}{autogenerated}{\unichar{50}\unichar{26376}}%
\uc@dclc{12994}{autogenerated}{\unichar{51}\unichar{26376}}%
\uc@dclc{12995}{autogenerated}{\unichar{52}\unichar{26376}}%
\uc@dclc{12996}{autogenerated}{\unichar{53}\unichar{26376}}%
\uc@dclc{12997}{autogenerated}{\unichar{54}\unichar{26376}}%
\uc@dclc{12998}{autogenerated}{\unichar{55}\unichar{26376}}%
\uc@dclc{12999}{autogenerated}{\unichar{56}\unichar{26376}}%
\uc@dclc{13000}{autogenerated}{\unichar{57}\unichar{26376}}%
\uc@dclc{13001}{autogenerated}{\unichar{49}\unichar{48}\unichar{26376}}%
\uc@dclc{13002}{autogenerated}{\unichar{49}\unichar{49}\unichar{26376}}%
\uc@dclc{13003}{autogenerated}{\unichar{49}\unichar{50}\unichar{26376}}%
\uc@dclc{13004}{autogenerated}{\unicodesquare{\unichar{72}\unichar{103}}}%
\uc@dclc{13005}{autogenerated}{\unicodesquare{\unichar{101}\unichar{114}\unichar{103}}}%
\uc@dclc{13006}{autogenerated}{\unicodesquare{\unichar{101}\unichar{86}}}%
\uc@dclc{13007}{autogenerated}{\unicodesquare{\unichar{76}\unichar{84}\unichar{68}}}%
\uc@dclc{13008}{autogenerated}{\unicodecircle{\unichar{12450}}}%
\uc@dclc{13009}{autogenerated}{\unicodecircle{\unichar{12452}}}%
\uc@dclc{13010}{autogenerated}{\unicodecircle{\unichar{12454}}}%
\uc@dclc{13011}{autogenerated}{\unicodecircle{\unichar{12456}}}%
\uc@dclc{13012}{autogenerated}{\unicodecircle{\unichar{12458}}}%
\uc@dclc{13013}{autogenerated}{\unicodecircle{\unichar{12459}}}%
\uc@dclc{13014}{autogenerated}{\unicodecircle{\unichar{12461}}}%
\uc@dclc{13015}{autogenerated}{\unicodecircle{\unichar{12463}}}%
\uc@dclc{13016}{autogenerated}{\unicodecircle{\unichar{12465}}}%
\uc@dclc{13017}{autogenerated}{\unicodecircle{\unichar{12467}}}%
\uc@dclc{13018}{autogenerated}{\unicodecircle{\unichar{12469}}}%
\uc@dclc{13019}{autogenerated}{\unicodecircle{\unichar{12471}}}%
\uc@dclc{13020}{autogenerated}{\unicodecircle{\unichar{12473}}}%
\uc@dclc{13021}{autogenerated}{\unicodecircle{\unichar{12475}}}%
\uc@dclc{13022}{autogenerated}{\unicodecircle{\unichar{12477}}}%
\uc@dclc{13023}{autogenerated}{\unicodecircle{\unichar{12479}}}%
\uc@dclc{13024}{autogenerated}{\unicodecircle{\unichar{12481}}}%
\uc@dclc{13025}{autogenerated}{\unicodecircle{\unichar{12484}}}%
\uc@dclc{13026}{autogenerated}{\unicodecircle{\unichar{12486}}}%
\uc@dclc{13027}{autogenerated}{\unicodecircle{\unichar{12488}}}%
\uc@dclc{13028}{autogenerated}{\unicodecircle{\unichar{12490}}}%
\uc@dclc{13029}{autogenerated}{\unicodecircle{\unichar{12491}}}%
\uc@dclc{13030}{autogenerated}{\unicodecircle{\unichar{12492}}}%
\uc@dclc{13031}{autogenerated}{\unicodecircle{\unichar{12493}}}%
\uc@dclc{13032}{autogenerated}{\unicodecircle{\unichar{12494}}}%
\uc@dclc{13033}{autogenerated}{\unicodecircle{\unichar{12495}}}%
\uc@dclc{13034}{autogenerated}{\unicodecircle{\unichar{12498}}}%
\uc@dclc{13035}{autogenerated}{\unicodecircle{\unichar{12501}}}%
\uc@dclc{13036}{autogenerated}{\unicodecircle{\unichar{12504}}}%
\uc@dclc{13037}{autogenerated}{\unicodecircle{\unichar{12507}}}%
\uc@dclc{13038}{autogenerated}{\unicodecircle{\unichar{12510}}}%
\uc@dclc{13039}{autogenerated}{\unicodecircle{\unichar{12511}}}%
\uc@dclc{13040}{autogenerated}{\unicodecircle{\unichar{12512}}}%
\uc@dclc{13041}{autogenerated}{\unicodecircle{\unichar{12513}}}%
\uc@dclc{13042}{autogenerated}{\unicodecircle{\unichar{12514}}}%
\uc@dclc{13043}{autogenerated}{\unicodecircle{\unichar{12516}}}%
\uc@dclc{13044}{autogenerated}{\unicodecircle{\unichar{12518}}}%
\uc@dclc{13045}{autogenerated}{\unicodecircle{\unichar{12520}}}%
\uc@dclc{13046}{autogenerated}{\unicodecircle{\unichar{12521}}}%
\uc@dclc{13047}{autogenerated}{\unicodecircle{\unichar{12522}}}%
\uc@dclc{13048}{autogenerated}{\unicodecircle{\unichar{12523}}}%
\uc@dclc{13049}{autogenerated}{\unicodecircle{\unichar{12524}}}%
\uc@dclc{13050}{autogenerated}{\unicodecircle{\unichar{12525}}}%
\uc@dclc{13051}{autogenerated}{\unicodecircle{\unichar{12527}}}%
\uc@dclc{13052}{autogenerated}{\unicodecircle{\unichar{12528}}}%
\uc@dclc{13053}{autogenerated}{\unicodecircle{\unichar{12529}}}%
\uc@dclc{13054}{autogenerated}{\unicodecircle{\unichar{12530}}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
