%%% Unicode to TeX mapping, file uni-34.def, U+2200..U+22FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-34.def}[2013/05/13 UCS: Unicode data U+2200..U+22FF]%
\fi
\uc@dclc{8704}{default}{\ensuremath{\forall}}%
\uc@dclc{8704}{postscript}{\Pisymbol{psy}{"22}}%
\uc@dclc{8705}{default}{\ensuremath\complement}%
\uc@dclc{8706}{default}{\ensuremath{\partial}}%
\uc@dclc{8706}{postscript}{\Pisymbol{psy}{"B6}}%
\uc@dclc{8707}{default}{\ensuremath{\exists}}%
\uc@dclc{8707}{postscript}{\Pisymbol{psy}{"24}}%
\uc@dclc{8708}{default}{\ensuremath\nexists}%
\uc@dclc{8709}{default}{\ensuremath{\emptyset}}%
\uc@dclc{8709}{postscript}{\Pisymbol{psy}{"C6}}%
\uc@dclc{8710}{default}{\ensuremath{\Delta}}%
\uc@dclc{8710}{postscript}{\Pisymbol{psy}{"44}}%
\uc@dclc{8711}{default}{\ensuremath{\nabla}}%
\uc@dclc{8711}{postscript}{\Pisymbol{psy}{"D1}}%
\uc@dclc{8712}{default}{\ensuremath{\in}}%
\uc@dclc{8712}{postscript}{\Pisymbol{psy}{"CE}}%
\uc@dclc{8713}{default}{\ensuremath{\notin}}%
\uc@dclc{8713}{postscript}{\Pisymbol{psy}{"CF}}%
\uc@dclc{8715}{default}{\ensuremath{\ni}}%
\uc@dclc{8715}{postscript}{\Pisymbol{psy}{"27}}%
\uc@dclc{8716}{default}{\ensuremath{\not\ni}}%
\uc@dclc{8719}{default}{\ensuremath{\prod}}%
\uc@dclc{8719}{postscript}{\Pisymbol{psy}{"D5}}%
\uc@dclc{8720}{default}{\ensuremath{\coprod}}%
\uc@dclc{8721}{default}{\ensuremath{\sum}}%
\uc@dclc{8721}{postscript}{\Pisymbol{psy}{"E5}}%
\uc@dclc{8722}{default}{\ensuremath{-}}%
\uc@dclc{8722}{postscript}{\Pisymbol{psy}{"2D}}%
\uc@dclc{8723}{default}{\ensuremath{\mp}}%
\uc@dclc{8724}{default}{\ensuremath\dotplus}%
\uc@dclc{8725}{default}{\ensuremath{/}}%
\uc@dclc{8726}{default}{\ensuremath{\setminus}}%
\uc@dclc{8727}{default}{\ensuremath{\ast}}%
\uc@dclc{8727}{postscript}{\Pisymbol{psy}{"2A}}%
\uc@dclc{8728}{default}{\ensuremath{\circ}}%
\uc@dclc{8729}{default}{\ensuremath{\bullet}}%
\uc@dclc{8730}{default}{\ensuremath{\surd}}%
\uc@dclc{8730}{postscript}{\Pisymbol{psy}{"D6}}%
\uc@dclc{8733}{default}{\ensuremath{\propto}}%
\uc@dclc{8733}{postscript}{\Pisymbol{psy}{"B5}}%
\uc@dclc{8734}{default}{\ensuremath{\infty}}%
\uc@dclc{8734}{postscript}{\Pisymbol{psy}{"A5}}%
\uc@dclc{8736}{default}{\ensuremath{\angle}}%
\uc@dclc{8736}{postscript}{\Pisymbol{psy}{"D0}}%
\uc@dclc{8737}{default}{\ensuremath\measuredangle}%
\uc@dclc{8738}{default}{\ensuremath\sphericalangle}%
\uc@dclc{8739}{default}{\ensuremath{\mid}}%
\uc@dclc{8740}{default}{\ensuremath\nmid}%
\uc@dclc{8741}{default}{\ensuremath{\parallel}}%
\uc@dclc{8742}{default}{\ensuremath\nparallel}%
\uc@dclc{8743}{default}{\ensuremath{\wedge}}%
\uc@dclc{8743}{postscript}{\Pisymbol{psy}{"D9}}%
\uc@dclc{8744}{default}{\ensuremath{\vee}}%
\uc@dclc{8744}{postscript}{\Pisymbol{psy}{"DA}}%
\uc@dclc{8745}{default}{\ensuremath{\cap}}%
\uc@dclc{8745}{postscript}{\Pisymbol{psy}{"C7}}%
\uc@dclc{8746}{default}{\ensuremath{\cup}}%
\uc@dclc{8746}{postscript}{\Pisymbol{psy}{"C8}}%
\uc@dclc{8747}{default}{\ensuremath{\int}}%
\uc@dclc{8747}{postscript}{\Pisymbol{psy}{"F2}}%
\uc@dclc{8748}{default}{\ensuremath\iint}%
\uc@dclc{8749}{default}{\ensuremath\iiint}%
\uc@dclc{8750}{default}{\ensuremath{\oint}}%
\uc@dclc{8751}{autogenerated}{\unichar{8750}\unichar{8750}}%
\uc@dclc{8752}{autogenerated}{\unichar{8750}\unichar{8750}\unichar{8750}}%
\uc@dclc{8756}{default}{\ensuremath\therefore}%
\uc@dclc{8756}{postscript}{\Pisymbol{psy}{"5C}}%
\uc@dclc{8757}{default}{\ensuremath\because}%
\uc@dclc{8758}{default}{\ensuremath{:}}%
\uc@dclc{8764}{default}{\ensuremath{\sim}}%
\uc@dclc{8764}{postscript}{\Pisymbol{psy}{"7E}}%
\uc@dclc{8765}{default}{\ensuremath\backsim}%
\uc@dclc{8768}{default}{\ensuremath{\wr}}%
\uc@dclc{8769}{default}{\ensuremath\nsim}%
\uc@dclc{8771}{default}{\ensuremath{\simeq}}%
\uc@dclc{8772}{default}{\ensuremath{\not\simeq}}%
\uc@dclc{8773}{default}{\ensuremath{\cong}}%
\uc@dclc{8773}{postscript}{\Pisymbol{psy}{"40}}%
\uc@dclc{8775}{default}{\ensuremath\ncong}%
\uc@dclc{8776}{default}{\ensuremath{\approx}}%
\uc@dclc{8776}{postscript}{\Pisymbol{psy}{"BB}}%
\uc@dclc{8777}{default}{\ensuremath{\not\approx}}%
\uc@dclc{8778}{default}{\ensuremath\approxeq}%
\uc@dclc{8781}{default}{\ensuremath{\asymp}}%
\uc@dclc{8782}{default}{\ensuremath\Bumpeq}%
\uc@dclc{8783}{default}{\ensuremath\bumpeq}%
\uc@dclc{8784}{default}{\ensuremath{\doteq}}%
\uc@dclc{8785}{default}{\ensuremath\doteqdot}%
\uc@dclc{8786}{default}{\ensuremath\fallingdotseq}%
\uc@dclc{8787}{default}{\ensuremath\risingdotseq}%
\uc@dclc{8790}{default}{\ensuremath\eqcirc}%
\uc@dclc{8791}{default}{\ensuremath\circeq}%
\uc@dclc{8796}{default}{\ensuremath\triangleq}%
\uc@dclc{8800}{default}{\ensuremath{\neq}}%
\uc@dclc{8800}{postscript}{\Pisymbol{psy}{"B9}}%
\uc@dclc{8801}{default}{\ensuremath{\equiv}}%
\uc@dclc{8801}{postscript}{\Pisymbol{psy}{"BA}}%
\uc@dclc{8802}{default}{\ensuremath{\not\equiv}}%
\uc@dclc{8804}{default}{\ensuremath{\leq}}%
\uc@dclc{8804}{postscript}{\Pisymbol{psy}{"A3}}%
\uc@dclc{8805}{default}{\ensuremath{\geq}}%
\uc@dclc{8805}{postscript}{\Pisymbol{psy}{"B3}}%
\uc@dclc{8806}{default}{\ensuremath\leqq}%
\uc@dclc{8807}{default}{\ensuremath\geqq}%
\uc@dclc{8808}{default}{\ensuremath\lneqq}%
\uc@dclc{8809}{default}{\ensuremath\gneqq}%
\uc@dclc{8810}{default}{\ensuremath{\ll}}%
\uc@dclc{8811}{default}{\ensuremath{\gg}}%
\uc@dclc{8812}{default}{\ensuremath\between}%
\uc@dclc{8813}{default}{\ensuremath{\not\asymp}}%
\uc@dclc{8814}{default}{\ensuremath\nless}%
\uc@dclc{8815}{default}{\ensuremath\ngtr}%
\uc@dclc{8816}{default}{\ensuremath\nleq}%
\uc@dclc{8817}{default}{\ensuremath\ngeq}%
\uc@dclc{8818}{default}{\ensuremath\lesssim}%
\uc@dclc{8819}{default}{\ensuremath\gtrsim}%
\uc@dclc{8820}{default}{\ensuremath{\not\lesssim}}%
\uc@dclc{8821}{default}{\ensuremath{\not\gtrsim}}%
\uc@dclc{8822}{default}{\ensuremath\lessgtr}%
\uc@dclc{8823}{default}{\ensuremath\gtrless}%
\uc@dclc{8826}{default}{\ensuremath{\prec}}%
\uc@dclc{8827}{default}{\ensuremath{\succ}}%
\uc@dclc{8828}{default}{\ensuremath\preccurlyeq}%
\uc@dclc{8829}{default}{\ensuremath\succcurlyeq}%
\uc@dclc{8830}{default}{\ensuremath\precsim}%
\uc@dclc{8831}{default}{\ensuremath\succsim}%
\uc@dclc{8832}{default}{\ensuremath\nprec}%
\uc@dclc{8833}{default}{\ensuremath\nsucc}%
\uc@dclc{8834}{default}{\ensuremath{\subset}}%
\uc@dclc{8834}{postscript}{\Pisymbol{psy}{"CC}}%
\uc@dclc{8835}{default}{\ensuremath{\supset}}%
\uc@dclc{8835}{postscript}{\Pisymbol{psy}{"C9}}%
\uc@dclc{8836}{default}{\ensuremath{\not\subset}}%
\uc@dclc{8836}{postscript}{\Pisymbol{psy}{"CB}}%
\uc@dclc{8837}{default}{\ensuremath{\not\supset}}%
\uc@dclc{8838}{default}{\ensuremath{\subseteq}}%
\uc@dclc{8838}{postscript}{\Pisymbol{psy}{"CD}}%
\uc@dclc{8839}{default}{\ensuremath{\supseteq}}%
\uc@dclc{8839}{postscript}{\Pisymbol{psy}{"CA}}%
\uc@dclc{8840}{default}{\ensuremath\nsubseteq}%
\uc@dclc{8841}{default}{\ensuremath\nsupseteq}%
\uc@dclc{8842}{default}{\ensuremath\subsetneq}%
\uc@dclc{8843}{default}{\ensuremath\supsetneq}%
\uc@dclc{8846}{default}{\ensuremath{\uplus}}%
\uc@dclc{8847}{default}{\ensuremath\sqsubset}%
\uc@dclc{8848}{default}{\ensuremath\sqsupset}%
\uc@dclc{8849}{default}{\ensuremath{\sqsubseteq}}%
\uc@dclc{8850}{default}{\ensuremath{\sqsupseteq}}%
\uc@dclc{8851}{default}{\ensuremath{\sqcap}}%
\uc@dclc{8852}{default}{\ensuremath{\sqcup}}%
\uc@dclc{8853}{default}{\ensuremath{\oplus}}%
\uc@dclc{8853}{postscript}{\Pisymbol{psy}{"C5}}%
\uc@dclc{8854}{default}{\ensuremath{\ominus}}%
\uc@dclc{8855}{default}{\ensuremath{\otimes}}%
\uc@dclc{8855}{postscript}{\Pisymbol{psy}{"C4}}%
\uc@dclc{8856}{default}{\ensuremath{\oslash}}%
\uc@dclc{8857}{default}{\ensuremath{\odot}}%
\uc@dclc{8858}{default}{\ensuremath\circledcirc}%
\uc@dclc{8859}{default}{\ensuremath\circledast}%
\uc@dclc{8861}{default}{\ensuremath\circleddash}%
\uc@dclc{8862}{default}{\ensuremath\boxplus}%
\uc@dclc{8863}{default}{\ensuremath\boxminus}%
\uc@dclc{8864}{default}{\ensuremath\boxtimes}%
\uc@dclc{8865}{default}{\ensuremath\boxdot}%
\uc@dclc{8866}{default}{\ensuremath{\vdash}}%
\uc@dclc{8867}{default}{\ensuremath{\dashv}}%
\uc@dclc{8868}{default}{\ensuremath{\top}}%
\uc@dclc{8869}{default}{\ensuremath{\bot}}%
\uc@dclc{8869}{postscript}{\Pisymbol{psy}{"5E}}%
\uc@dclc{8873}{default}{\ensuremath\Vdash}%
\uc@dclc{8874}{default}{\ensuremath\Vvdash}%
\uc@dclc{8878}{default}{\ensuremath\nVdash}%
\uc@dclc{8882}{default}{\ensuremath\lhd}%
\uc@dclc{8883}{default}{\ensuremath\rhd}%
\uc@dclc{8884}{default}{\ensuremath\unlhd}%
\uc@dclc{8885}{default}{\ensuremath\unrhd}%
\uc@dclc{8888}{default}{\ensuremath\multimap}%
\uc@dclc{8890}{default}{\ensuremath\intercal}%
\uc@dclc{8891}{default}{\ensuremath\veebar}%
\uc@dclc{8892}{default}{\ensuremath\barwedge}%
\uc@dclc{8896}{default}{\ensuremath{\bigwedge}}%
\uc@dclc{8897}{default}{\ensuremath{\bigvee}}%
\uc@dclc{8898}{default}{\ensuremath{\bigcap}}%
\uc@dclc{8899}{default}{\ensuremath{\bigcup}}%
\uc@dclc{8900}{default}{\ensuremath{\diamond}}%
\uc@dclc{8901}{default}{\ensuremath{\cdot}}%
\uc@dclc{8901}{postscript}{\Pisymbol{psy}{"D7}}%
\uc@dclc{8902}{default}{\ensuremath{\star}}%
\uc@dclc{8903}{default}{\ensuremath\divideontimes}%
\uc@dclc{8904}{default}{\ensuremath{\bowtie}}%
\uc@dclc{8905}{default}{\ensuremath\ltimes}%
\uc@dclc{8906}{default}{\ensuremath\rtimes}%
\uc@dclc{8907}{default}{\ensuremath\leftthreetimes}%
\uc@dclc{8908}{default}{\ensuremath\rightthreetimes}%
\uc@dclc{8909}{default}{\ensuremath\backsimeq}%
\uc@dclc{8910}{default}{\ensuremath\curlyvee}%
\uc@dclc{8911}{default}{\ensuremath\curlywedge}%
\uc@dclc{8912}{default}{\ensuremath\Subset}%
\uc@dclc{8913}{default}{\ensuremath\Supset}%
\uc@dclc{8914}{default}{\ensuremath\Cap}%
\uc@dclc{8915}{default}{\ensuremath\Cup}%
\uc@dclc{8916}{default}{\ensuremath\pitchfork}%
\uc@dclc{8918}{default}{\ensuremath\lessdot}%
\uc@dclc{8919}{default}{\ensuremath\gtrdot}%
\uc@dclc{8920}{default}{\ensuremath\lll}%
\uc@dclc{8921}{default}{\ensuremath\ggg}%
\uc@dclc{8922}{default}{\ensuremath\lesseqgtr}%
\uc@dclc{8923}{default}{\ensuremath\gtreqless}%
\uc@dclc{8926}{default}{\ensuremath\curlyeqprec}%
\uc@dclc{8927}{default}{\ensuremath\curlyeqsucc}%
\uc@dclc{8928}{default}{\ensuremath{\not\preccurlyeq}}%
\uc@dclc{8929}{default}{\ensuremath{\not\succcurlyeq}}%
\uc@dclc{8930}{default}{\ensuremath{\not\sqsubseteq}}%
\uc@dclc{8931}{default}{\ensuremath{\not\sqsupseteq}}%
\uc@dclc{8934}{default}{\ensuremath\lnsim}%
\uc@dclc{8935}{default}{\ensuremath\gnsim}%
\uc@dclc{8936}{default}{\ensuremath\precnsim}%
\uc@dclc{8937}{default}{\ensuremath\succnsim}%
\uc@dclc{8938}{default}{\ensuremath\ntriangleleft}%
\uc@dclc{8939}{default}{\ensuremath\ntriangleright}%
\uc@dclc{8940}{default}{\ensuremath\ntrianglelefteq}%
\uc@dclc{8941}{default}{\ensuremath\ntrianglerighteq}%
\uc@dclc{8942}{default}{\ensuremath{\vdots}}%
\uc@dclc{8943}{default}{\ensuremath{\cdots}}%
\uc@dclc{8945}{default}{\ensuremath{\ddots}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
