%%% Unicode to TeX mapping, file uni-35.def, U+2300..U+23FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-35.def}[2013/05/13 UCS: Unicode data U+2300..U+23FF]%
\fi
\uc@dclc{8968}{default}{\ensuremath{\lceil}}%
\uc@dclc{8969}{default}{\ensuremath{\rceil}}%
\uc@dclc{8970}{default}{\ensuremath{\lfloor}}%
\uc@dclc{8971}{default}{\ensuremath{\rfloor}}%
\uc@dclc{8992}{postscript}{\Pisymbol{psy}{"F3}}%
\uc@dclc{8993}{postscript}{\Pisymbol{psy}{"F5}}%
\uc@dclc{9001}{postscript}{\Pisymbol{psy}{"E1}}%
\uc@dclc{9002}{postscript}{\Pisymbol{psy}{"F1}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
