%%% Unicode to TeX mapping, file uni-19.def, U+1300..U+13FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-19.def}[2013/05/13 UCS: Unicode data U+1300..U+13FF]%
\fi
\uc@dclc{4864}{default}{\textethiopicja}%
\uc@dclc{4865}{default}{\textethiopicju}%
\uc@dclc{4866}{default}{\textethiopicji}%
\uc@dclc{4867}{default}{\textethiopicjaa}%
\uc@dclc{4868}{default}{\textethiopicjee}%
\uc@dclc{4869}{default}{\textethiopicje}%
\uc@dclc{4870}{default}{\textethiopicjo}%
\uc@dclc{4871}{default}{\textethiopicjwa}%
\uc@dclc{4872}{default}{\textethiopicga}%
\uc@dclc{4873}{default}{\textethiopicgu}%
\uc@dclc{4874}{default}{\textethiopicgi}%
\uc@dclc{4875}{default}{\textethiopicgaa}%
\uc@dclc{4876}{default}{\textethiopicgee}%
\uc@dclc{4877}{default}{\textethiopicge}%
\uc@dclc{4878}{default}{\textethiopicgo}%
\uc@dclc{4880}{default}{\textethiopicgwa}%
\uc@dclc{4882}{default}{\textethiopicgwi}%
\uc@dclc{4883}{default}{\textethiopicgwaa}%
\uc@dclc{4884}{default}{\textethiopicgwee}%
\uc@dclc{4885}{default}{\textethiopicgwe}%
\uc@dclc{4888}{default}{\textethiopicgga}%
\uc@dclc{4889}{default}{\textethiopicggu}%
\uc@dclc{4890}{default}{\textethiopicggi}%
\uc@dclc{4891}{default}{\textethiopicggaa}%
\uc@dclc{4892}{default}{\textethiopicggee}%
\uc@dclc{4893}{default}{\textethiopicgge}%
\uc@dclc{4894}{default}{\textethiopicggo}%
\uc@dclc{4896}{default}{\textethiopictha}%
\uc@dclc{4897}{default}{\textethiopicthu}%
\uc@dclc{4898}{default}{\textethiopicthi}%
\uc@dclc{4899}{default}{\textethiopicthaa}%
\uc@dclc{4900}{default}{\textethiopicthee}%
\uc@dclc{4901}{default}{\textethiopicthe}%
\uc@dclc{4902}{default}{\textethiopictho}%
\uc@dclc{4903}{default}{\textethiopicthwa}%
\uc@dclc{4904}{default}{\textethiopiccha}%
\uc@dclc{4905}{default}{\textethiopicchu}%
\uc@dclc{4906}{default}{\textethiopicchi}%
\uc@dclc{4907}{default}{\textethiopicchaa}%
\uc@dclc{4908}{default}{\textethiopicchee}%
\uc@dclc{4909}{default}{\textethiopicche}%
\uc@dclc{4910}{default}{\textethiopiccho}%
\uc@dclc{4911}{default}{\textethiopicchwa}%
\uc@dclc{4912}{default}{\textethiopicpha}%
\uc@dclc{4913}{default}{\textethiopicphu}%
\uc@dclc{4914}{default}{\textethiopicphi}%
\uc@dclc{4915}{default}{\textethiopicphaa}%
\uc@dclc{4916}{default}{\textethiopicphee}%
\uc@dclc{4917}{default}{\textethiopicphe}%
\uc@dclc{4918}{default}{\textethiopicpho}%
\uc@dclc{4919}{default}{\textethiopicphwa}%
\uc@dclc{4920}{default}{\textethiopictsa}%
\uc@dclc{4921}{default}{\textethiopictsu}%
\uc@dclc{4922}{default}{\textethiopictsi}%
\uc@dclc{4923}{default}{\textethiopictsaa}%
\uc@dclc{4924}{default}{\textethiopictsee}%
\uc@dclc{4925}{default}{\textethiopictse}%
\uc@dclc{4926}{default}{\textethiopictso}%
\uc@dclc{4927}{default}{\textethiopictswa}%
\uc@dclc{4928}{default}{\textethiopictza}%
\uc@dclc{4929}{default}{\textethiopictzu}%
\uc@dclc{4930}{default}{\textethiopictzi}%
\uc@dclc{4931}{default}{\textethiopictzaa}%
\uc@dclc{4932}{default}{\textethiopictzee}%
\uc@dclc{4933}{default}{\textethiopictze}%
\uc@dclc{4934}{default}{\textethiopictzo}%
\uc@dclc{4936}{default}{\textethiopicfa}%
\uc@dclc{4937}{default}{\textethiopicfu}%
\uc@dclc{4938}{default}{\textethiopicfi}%
\uc@dclc{4939}{default}{\textethiopicfaa}%
\uc@dclc{4940}{default}{\textethiopicfee}%
\uc@dclc{4941}{default}{\textethiopicfe}%
\uc@dclc{4942}{default}{\textethiopicfo}%
\uc@dclc{4943}{default}{\textethiopicfwa}%
\uc@dclc{4944}{default}{\textethiopicpa}%
\uc@dclc{4945}{default}{\textethiopicpu}%
\uc@dclc{4946}{default}{\textethiopicpi}%
\uc@dclc{4947}{default}{\textethiopicpaa}%
\uc@dclc{4948}{default}{\textethiopicpee}%
\uc@dclc{4949}{default}{\textethiopicpe}%
\uc@dclc{4950}{default}{\textethiopicpo}%
\uc@dclc{4951}{default}{\textethiopicpwa}%
\uc@dclc{4952}{default}{\textethiopicrya}%
\uc@dclc{4953}{default}{\textethiopicmya}%
\uc@dclc{4954}{default}{\textethiopicfya}%
\uc@dclc{4961}{default}{\textethiopicwordspace}%
\uc@dclc{4962}{default}{\textethiopicfullstop}%
\uc@dclc{4963}{default}{\textethiopiccomma}%
\uc@dclc{4964}{default}{\textethiopicsemicolon}%
\uc@dclc{4965}{default}{\textethiopiccolon}%
\uc@dclc{4966}{default}{\textethiopicprefacecolon}%
\uc@dclc{4967}{default}{\textethiopicquestionmark}%
\uc@dclc{4968}{default}{\textethiopicparagraph}%
\uc@dclc{4969}{default}{\textethiopicone}%
\uc@dclc{4970}{default}{\textethiopictwo}%
\uc@dclc{4971}{default}{\textethiopicthree}%
\uc@dclc{4972}{default}{\textethiopicfour}%
\uc@dclc{4973}{default}{\textethiopicfive}%
\uc@dclc{4974}{default}{\textethiopicsix}%
\uc@dclc{4975}{default}{\textethiopicseven}%
\uc@dclc{4976}{default}{\textethiopiceight}%
\uc@dclc{4977}{default}{\textethiopicnine}%
\uc@dclc{4978}{default}{\textethiopicten}%
\uc@dclc{4979}{default}{\textethiopictwenty}%
\uc@dclc{4980}{default}{\textethiopicthirty}%
\uc@dclc{4981}{default}{\textethiopicforty}%
\uc@dclc{4982}{default}{\textethiopicfifty}%
\uc@dclc{4983}{default}{\textethiopicsixty}%
\uc@dclc{4984}{default}{\textethiopicseventy}%
\uc@dclc{4985}{default}{\textethiopiceighty}%
\uc@dclc{4986}{default}{\textethiopicninety}%
\uc@dclc{4987}{default}{\textethiopichundred}%
\uc@dclc{4988}{default}{\textethiopictenthousand}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
