%%% Unicode to TeX mapping, file uni-250.def, U+FA00..U+FAFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-250.def}[2013/05/13 UCS: Unicode data U+FA00..U+FAFF]%
\fi
\uc@dclc{64000}{autogenerated}{\unichar{20999}}%
\uc@dclc{64001}{autogenerated}{\unichar{24230}}%
\uc@dclc{64002}{autogenerated}{\unichar{25299}}%
\uc@dclc{64003}{autogenerated}{\unichar{31958}}%
\uc@dclc{64004}{autogenerated}{\unichar{23429}}%
\uc@dclc{64005}{autogenerated}{\unichar{27934}}%
\uc@dclc{64006}{autogenerated}{\unichar{26292}}%
\uc@dclc{64007}{autogenerated}{\unichar{36667}}%
\uc@dclc{64008}{autogenerated}{\unichar{34892}}%
\uc@dclc{64009}{autogenerated}{\unichar{38477}}%
\uc@dclc{64010}{autogenerated}{\unichar{35211}}%
\uc@dclc{64011}{autogenerated}{\unichar{24275}}%
\gdef\u@cjk@Bgv#1#2#3#4{{\fontencoding{C00}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{64012}{cjkbg5}{\u@cjk@Bgv2592}%
\uc@dclc{64013}{cjkbg5}{\u@cjk@Bgv3866}%
\uc@dclc{64016}{autogenerated}{\unichar{22618}}%
\uc@dclc{64018}{autogenerated}{\unichar{26228}}%
\uc@dclc{64021}{autogenerated}{\unichar{20958}}%
\uc@dclc{64022}{autogenerated}{\unichar{29482}}%
\uc@dclc{64023}{autogenerated}{\unichar{30410}}%
\uc@dclc{64024}{autogenerated}{\unichar{31036}}%
\uc@dclc{64025}{autogenerated}{\unichar{31070}}%
\uc@dclc{64026}{autogenerated}{\unichar{31077}}%
\uc@dclc{64027}{autogenerated}{\unichar{31119}}%
\uc@dclc{64028}{autogenerated}{\unichar{38742}}%
\uc@dclc{64029}{autogenerated}{\unichar{31934}}%
\uc@dclc{64030}{autogenerated}{\unichar{32701}}%
\uc@dclc{64034}{autogenerated}{\unichar{35576}}%
\uc@dclc{64037}{autogenerated}{\unichar{36920}}%
\uc@dclc{64038}{autogenerated}{\unichar{37117}}%
\uc@dclc{64042}{autogenerated}{\unichar{39151}}%
\uc@dclc{64043}{autogenerated}{\unichar{39164}}%
\uc@dclc{64044}{autogenerated}{\unichar{39208}}%
\uc@dclc{64045}{autogenerated}{\unichar{40372}}%
\uc@dclc{64047}{autogenerated}{\unichar{38583}}%
\uc@dclc{64048}{autogenerated}{\unichar{20398}}%
\uc@dclc{64049}{autogenerated}{\unichar{20711}}%
\uc@dclc{64050}{autogenerated}{\unichar{20813}}%
\uc@dclc{64051}{autogenerated}{\unichar{21193}}%
\uc@dclc{64052}{autogenerated}{\unichar{21220}}%
\uc@dclc{64053}{autogenerated}{\unichar{21329}}%
\uc@dclc{64054}{autogenerated}{\unichar{21917}}%
\uc@dclc{64055}{autogenerated}{\unichar{22022}}%
\uc@dclc{64056}{autogenerated}{\unichar{22120}}%
\uc@dclc{64057}{autogenerated}{\unichar{22592}}%
\uc@dclc{64058}{autogenerated}{\unichar{22696}}%
\uc@dclc{64059}{autogenerated}{\unichar{23652}}%
\uc@dclc{64060}{autogenerated}{\unichar{23662}}%
\uc@dclc{64061}{autogenerated}{\unichar{24724}}%
\uc@dclc{64062}{autogenerated}{\unichar{24936}}%
\uc@dclc{64063}{autogenerated}{\unichar{24974}}%
\uc@dclc{64064}{autogenerated}{\unichar{25074}}%
\uc@dclc{64065}{autogenerated}{\unichar{25935}}%
\uc@dclc{64066}{autogenerated}{\unichar{26082}}%
\uc@dclc{64067}{autogenerated}{\unichar{26257}}%
\uc@dclc{64068}{autogenerated}{\unichar{26757}}%
\uc@dclc{64069}{autogenerated}{\unichar{28023}}%
\uc@dclc{64070}{autogenerated}{\unichar{28186}}%
\uc@dclc{64071}{autogenerated}{\unichar{28450}}%
\uc@dclc{64072}{autogenerated}{\unichar{29038}}%
\uc@dclc{64074}{autogenerated}{\unichar{29730}}%
\uc@dclc{64075}{autogenerated}{\unichar{30865}}%
\uc@dclc{64076}{autogenerated}{\unichar{31038}}%
\uc@dclc{64077}{autogenerated}{\unichar{31049}}%
\uc@dclc{64078}{autogenerated}{\unichar{31048}}%
\uc@dclc{64079}{autogenerated}{\unichar{31056}}%
\uc@dclc{64080}{autogenerated}{\unichar{31062}}%
\uc@dclc{64081}{autogenerated}{\unichar{31069}}%
\uc@dclc{64082}{autogenerated}{\unichar{31117}}%
\uc@dclc{64083}{autogenerated}{\unichar{31118}}%
\uc@dclc{64084}{autogenerated}{\unichar{31296}}%
\uc@dclc{64085}{autogenerated}{\unichar{31361}}%
\uc@dclc{64086}{autogenerated}{\unichar{31680}}%
\uc@dclc{64087}{autogenerated}{\unichar{32244}}%
\uc@dclc{64088}{autogenerated}{\unichar{32265}}%
\uc@dclc{64089}{autogenerated}{\unichar{32321}}%
\uc@dclc{64090}{autogenerated}{\unichar{32626}}%
\uc@dclc{64091}{autogenerated}{\unichar{32773}}%
\uc@dclc{64092}{autogenerated}{\unichar{33261}}%
\uc@dclc{64093}{autogenerated}{\unichar{33401}}%
\uc@dclc{64094}{autogenerated}{\unichar{33401}}%
\uc@dclc{64095}{autogenerated}{\unichar{33879}}%
\uc@dclc{64096}{autogenerated}{\unichar{35088}}%
\uc@dclc{64097}{autogenerated}{\unichar{35222}}%
\uc@dclc{64098}{autogenerated}{\unichar{35585}}%
\uc@dclc{64099}{autogenerated}{\unichar{35641}}%
\uc@dclc{64100}{autogenerated}{\unichar{36051}}%
\uc@dclc{64101}{autogenerated}{\unichar{36104}}%
\uc@dclc{64102}{autogenerated}{\unichar{36790}}%
\uc@dclc{64103}{autogenerated}{\unichar{36920}}%
\uc@dclc{64104}{autogenerated}{\unichar{38627}}%
\uc@dclc{64105}{autogenerated}{\unichar{38911}}%
\uc@dclc{64106}{autogenerated}{\unichar{38971}}%
\uc@dclc{64107}{autogenerated}{\unichar{24693}}%
\uc@dclc{64109}{autogenerated}{\unichar{33304}}%
\uc@dclc{64112}{autogenerated}{\unichar{20006}}%
\uc@dclc{64113}{autogenerated}{\unichar{20917}}%
\uc@dclc{64114}{autogenerated}{\unichar{20840}}%
\uc@dclc{64115}{autogenerated}{\unichar{20352}}%
\uc@dclc{64116}{autogenerated}{\unichar{20805}}%
\uc@dclc{64117}{autogenerated}{\unichar{20864}}%
\uc@dclc{64118}{autogenerated}{\unichar{21191}}%
\uc@dclc{64119}{autogenerated}{\unichar{21242}}%
\uc@dclc{64120}{autogenerated}{\unichar{21917}}%
\uc@dclc{64121}{autogenerated}{\unichar{21845}}%
\uc@dclc{64122}{autogenerated}{\unichar{21913}}%
\uc@dclc{64123}{autogenerated}{\unichar{21986}}%
\uc@dclc{64124}{autogenerated}{\unichar{22618}}%
\uc@dclc{64125}{autogenerated}{\unichar{22707}}%
\uc@dclc{64126}{autogenerated}{\unichar{22852}}%
\uc@dclc{64127}{autogenerated}{\unichar{22868}}%
\uc@dclc{64128}{autogenerated}{\unichar{23138}}%
\uc@dclc{64129}{autogenerated}{\unichar{23336}}%
\uc@dclc{64130}{autogenerated}{\unichar{24274}}%
\uc@dclc{64131}{autogenerated}{\unichar{24281}}%
\uc@dclc{64132}{autogenerated}{\unichar{24425}}%
\uc@dclc{64133}{autogenerated}{\unichar{24493}}%
\uc@dclc{64134}{autogenerated}{\unichar{24792}}%
\uc@dclc{64135}{autogenerated}{\unichar{24910}}%
\uc@dclc{64136}{autogenerated}{\unichar{24840}}%
\uc@dclc{64137}{autogenerated}{\unichar{24974}}%
\uc@dclc{64139}{autogenerated}{\unichar{25074}}%
\uc@dclc{64140}{autogenerated}{\unichar{25140}}%
\uc@dclc{64141}{autogenerated}{\unichar{25540}}%
\uc@dclc{64142}{autogenerated}{\unichar{25628}}%
\uc@dclc{64143}{autogenerated}{\unichar{25682}}%
\uc@dclc{64144}{autogenerated}{\unichar{25942}}%
\uc@dclc{64145}{autogenerated}{\unichar{26228}}%
\uc@dclc{64146}{autogenerated}{\unichar{26391}}%
\uc@dclc{64147}{autogenerated}{\unichar{26395}}%
\uc@dclc{64148}{autogenerated}{\unichar{26454}}%
\uc@dclc{64149}{autogenerated}{\unichar{27513}}%
\uc@dclc{64150}{autogenerated}{\unichar{27578}}%
\uc@dclc{64151}{autogenerated}{\unichar{27969}}%
\uc@dclc{64153}{autogenerated}{\unichar{28363}}%
\uc@dclc{64154}{autogenerated}{\unichar{28450}}%
\uc@dclc{64155}{autogenerated}{\unichar{28702}}%
\uc@dclc{64156}{autogenerated}{\unichar{29038}}%
\uc@dclc{64157}{autogenerated}{\unichar{30631}}%
\uc@dclc{64158}{autogenerated}{\unichar{29237}}%
\uc@dclc{64159}{autogenerated}{\unichar{29359}}%
\uc@dclc{64160}{autogenerated}{\unichar{29482}}%
\uc@dclc{64161}{autogenerated}{\unichar{29809}}%
\uc@dclc{64163}{autogenerated}{\unichar{30011}}%
\uc@dclc{64164}{autogenerated}{\unichar{30237}}%
\uc@dclc{64165}{autogenerated}{\unichar{30239}}%
\uc@dclc{64166}{autogenerated}{\unichar{30410}}%
\uc@dclc{64167}{autogenerated}{\unichar{30427}}%
\uc@dclc{64168}{autogenerated}{\unichar{30452}}%
\uc@dclc{64169}{autogenerated}{\unichar{30538}}%
\uc@dclc{64170}{autogenerated}{\unichar{30528}}%
\uc@dclc{64171}{autogenerated}{\unichar{30924}}%
\uc@dclc{64172}{autogenerated}{\unichar{31409}}%
\uc@dclc{64173}{autogenerated}{\unichar{31680}}%
\uc@dclc{64174}{autogenerated}{\unichar{31867}}%
\uc@dclc{64175}{autogenerated}{\unichar{32091}}%
\uc@dclc{64176}{autogenerated}{\unichar{32244}}%
\uc@dclc{64177}{autogenerated}{\unichar{32574}}%
\uc@dclc{64178}{autogenerated}{\unichar{32773}}%
\uc@dclc{64179}{autogenerated}{\unichar{33618}}%
\uc@dclc{64180}{autogenerated}{\unichar{33775}}%
\uc@dclc{64181}{autogenerated}{\unichar{34681}}%
\uc@dclc{64182}{autogenerated}{\unichar{35137}}%
\uc@dclc{64183}{autogenerated}{\unichar{35206}}%
\uc@dclc{64184}{autogenerated}{\unichar{35222}}%
\uc@dclc{64185}{autogenerated}{\unichar{35519}}%
\uc@dclc{64186}{autogenerated}{\unichar{35576}}%
\uc@dclc{64187}{autogenerated}{\unichar{35531}}%
\uc@dclc{64188}{autogenerated}{\unichar{35585}}%
\uc@dclc{64189}{autogenerated}{\unichar{35582}}%
\uc@dclc{64190}{autogenerated}{\unichar{35565}}%
\uc@dclc{64191}{autogenerated}{\unichar{35641}}%
\uc@dclc{64192}{autogenerated}{\unichar{35722}}%
\uc@dclc{64193}{autogenerated}{\unichar{36104}}%
\uc@dclc{64194}{autogenerated}{\unichar{36664}}%
\uc@dclc{64195}{autogenerated}{\unichar{36978}}%
\uc@dclc{64196}{autogenerated}{\unichar{37273}}%
\uc@dclc{64197}{autogenerated}{\unichar{37494}}%
\uc@dclc{64198}{autogenerated}{\unichar{38524}}%
\uc@dclc{64199}{autogenerated}{\unichar{38627}}%
\uc@dclc{64200}{autogenerated}{\unichar{38742}}%
\uc@dclc{64202}{autogenerated}{\unichar{38911}}%
\uc@dclc{64204}{autogenerated}{\unichar{38971}}%
\uc@dclc{64205}{autogenerated}{\unichar{39698}}%
\uc@dclc{64206}{autogenerated}{\unichar{40860}}%
\uc@dclc{64216}{autogenerated}{\unichar{40771}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
