%%% Unicode to TeX mapping, file uni-195.def, U+C300..U+C3FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-195.def}[2013/05/13 UCS: Unicode data U+C300..U+C3FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{49920}{cjkhangul}{\u@cjk@hangul1179}%
\uc@dclc{49928}{cjkhangul}{\u@cjk@hangul117A}%
\uc@dclc{49929}{cjkhangul}{\u@cjk@hangul117B}%
\uc@dclc{49932}{cjkhangul}{\u@cjk@hangul117C}%
\uc@dclc{49933}{cjkhangul}{\u@cjk@hangul117D}%
\uc@dclc{49939}{cjkhangul}{\u@cjk@hangul117E}%
\uc@dclc{49940}{cjkhangul}{\u@cjk@hangul117F}%
\uc@dclc{49941}{cjkhangul}{\u@cjk@hangul1180}%
\uc@dclc{49944}{cjkhangul}{\u@cjk@hangul1181}%
\uc@dclc{49948}{cjkhangul}{\u@cjk@hangul1182}%
\uc@dclc{49956}{cjkhangul}{\u@cjk@hangul1183}%
\uc@dclc{49957}{cjkhangul}{\u@cjk@hangul1184}%
\uc@dclc{49960}{cjkhangul}{\u@cjk@hangul1185}%
\uc@dclc{49961}{cjkhangul}{\u@cjk@hangul1186}%
\uc@dclc{49989}{cjkhangul}{\u@cjk@hangul1187}%
\uc@dclc{50024}{cjkhangul}{\u@cjk@hangul1188}%
\uc@dclc{50025}{cjkhangul}{\u@cjk@hangul1189}%
\uc@dclc{50028}{cjkhangul}{\u@cjk@hangul118A}%
\uc@dclc{50032}{cjkhangul}{\u@cjk@hangul118B}%
\uc@dclc{50034}{cjkhangul}{\u@cjk@hangul118C}%
\uc@dclc{50040}{cjkhangul}{\u@cjk@hangul118D}%
\uc@dclc{50041}{cjkhangul}{\u@cjk@hangul118E}%
\uc@dclc{50044}{cjkhangul}{\u@cjk@hangul118F}%
\uc@dclc{50045}{cjkhangul}{\u@cjk@hangul1190}%
\uc@dclc{50052}{cjkhangul}{\u@cjk@hangul1191}%
\uc@dclc{50056}{cjkhangul}{\u@cjk@hangul1192}%
\uc@dclc{50060}{cjkhangul}{\u@cjk@hangul1193}%
\uc@dclc{50112}{cjkhangul}{\u@cjk@hangul1194}%
\uc@dclc{50136}{cjkhangul}{\u@cjk@hangul1195}%
\uc@dclc{50137}{cjkhangul}{\u@cjk@hangul1196}%
\uc@dclc{50140}{cjkhangul}{\u@cjk@hangul1197}%
\uc@dclc{50143}{cjkhangul}{\u@cjk@hangul1198}%
\uc@dclc{50144}{cjkhangul}{\u@cjk@hangul1199}%
\uc@dclc{50146}{cjkhangul}{\u@cjk@hangul119A}%
\uc@dclc{50152}{cjkhangul}{\u@cjk@hangul119B}%
\uc@dclc{50153}{cjkhangul}{\u@cjk@hangul119C}%
\uc@dclc{50157}{cjkhangul}{\u@cjk@hangul119D}%
\uc@dclc{50164}{cjkhangul}{\u@cjk@hangul119E}%
\uc@dclc{50165}{cjkhangul}{\u@cjk@hangul119F}%
\uc@dclc{50168}{cjkhangul}{\u@cjk@hangul11A0}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
