%%% Unicode to TeX mapping, file uni-29.def, U+1D00..U+1DFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-29.def}[2013/05/13 UCS: Unicode data U+1D00..U+1DFF]%
\fi
\uc@dclc{7468}{autogenerated}{\unicodesuper{\unichar{65}}}%
\uc@dclc{7469}{autogenerated}{\unicodesuper{\unichar{198}}}%
\uc@dclc{7470}{autogenerated}{\unicodesuper{\unichar{66}}}%
\uc@dclc{7472}{autogenerated}{\unicodesuper{\unichar{68}}}%
\uc@dclc{7473}{autogenerated}{\unicodesuper{\unichar{69}}}%
\uc@dclc{7474}{autogenerated}{\unicodesuper{\unichar{398}}}%
\uc@dclc{7475}{autogenerated}{\unicodesuper{\unichar{71}}}%
\uc@dclc{7476}{autogenerated}{\unicodesuper{\unichar{72}}}%
\uc@dclc{7477}{autogenerated}{\unicodesuper{\unichar{73}}}%
\uc@dclc{7478}{autogenerated}{\unicodesuper{\unichar{74}}}%
\uc@dclc{7479}{autogenerated}{\unicodesuper{\unichar{75}}}%
\uc@dclc{7480}{autogenerated}{\unicodesuper{\unichar{76}}}%
\uc@dclc{7481}{autogenerated}{\unicodesuper{\unichar{77}}}%
\uc@dclc{7482}{autogenerated}{\unicodesuper{\unichar{78}}}%
\uc@dclc{7484}{autogenerated}{\unicodesuper{\unichar{79}}}%
\uc@dclc{7486}{autogenerated}{\unicodesuper{\unichar{80}}}%
\uc@dclc{7487}{autogenerated}{\unicodesuper{\unichar{82}}}%
\uc@dclc{7488}{autogenerated}{\unicodesuper{\unichar{84}}}%
\uc@dclc{7489}{autogenerated}{\unicodesuper{\unichar{85}}}%
\uc@dclc{7490}{autogenerated}{\unicodesuper{\unichar{87}}}%
\uc@dclc{7491}{autogenerated}{\unicodesuper{\unichar{97}}}%
\uc@dclc{7492}{autogenerated}{\unicodesuper{\unichar{592}}}%
\uc@dclc{7493}{autogenerated}{\unicodesuper{\unichar{593}}}%
\uc@dclc{7495}{autogenerated}{\unicodesuper{\unichar{98}}}%
\uc@dclc{7496}{autogenerated}{\unicodesuper{\unichar{100}}}%
\uc@dclc{7497}{autogenerated}{\unicodesuper{\unichar{101}}}%
\uc@dclc{7498}{autogenerated}{\unicodesuper{\unichar{601}}}%
\uc@dclc{7499}{autogenerated}{\unicodesuper{\unichar{603}}}%
\uc@dclc{7500}{autogenerated}{\unicodesuper{\unichar{604}}}%
\uc@dclc{7501}{autogenerated}{\unicodesuper{\unichar{103}}}%
\uc@dclc{7503}{autogenerated}{\unicodesuper{\unichar{107}}}%
\uc@dclc{7504}{autogenerated}{\unicodesuper{\unichar{109}}}%
\uc@dclc{7505}{autogenerated}{\unicodesuper{\unichar{331}}}%
\uc@dclc{7506}{autogenerated}{\unicodesuper{\unichar{111}}}%
\uc@dclc{7507}{autogenerated}{\unicodesuper{\unichar{596}}}%
\uc@dclc{7510}{autogenerated}{\unicodesuper{\unichar{112}}}%
\uc@dclc{7511}{autogenerated}{\unicodesuper{\unichar{116}}}%
\uc@dclc{7512}{autogenerated}{\unicodesuper{\unichar{117}}}%
\uc@dclc{7514}{autogenerated}{\unicodesuper{\unichar{623}}}%
\uc@dclc{7515}{autogenerated}{\unicodesuper{\unichar{118}}}%
\uc@dclc{7517}{autogenerated}{\unicodesuper{\unichar{946}}}%
\uc@dclc{7518}{autogenerated}{\unicodesuper{\unichar{947}}}%
\uc@dclc{7519}{autogenerated}{\unicodesuper{\unichar{948}}}%
\uc@dclc{7520}{autogenerated}{\unicodesuper{\unichar{966}}}%
\uc@dclc{7521}{autogenerated}{\unicodesuper{\unichar{967}}}%
\uc@dclc{7522}{autogenerated}{\unicodesub{\unichar{105}}}%
\uc@dclc{7523}{autogenerated}{\unicodesub{\unichar{114}}}%
\uc@dclc{7524}{autogenerated}{\unicodesub{\unichar{117}}}%
\uc@dclc{7525}{autogenerated}{\unicodesub{\unichar{118}}}%
\uc@dclc{7526}{autogenerated}{\unicodesub{\unichar{946}}}%
\uc@dclc{7527}{autogenerated}{\unicodesub{\unichar{947}}}%
\uc@dclc{7528}{autogenerated}{\unicodesub{\unichar{961}}}%
\uc@dclc{7529}{autogenerated}{\unicodesub{\unichar{966}}}%
\uc@dclc{7530}{autogenerated}{\unicodesub{\unichar{967}}}%
\uc@dclc{7544}{autogenerated}{\unicodesuper{\unichar{1085}}}%
\uc@dclc{7579}{autogenerated}{\unicodesuper{\unichar{594}}}%
\uc@dclc{7580}{autogenerated}{\unicodesuper{\unichar{99}}}%
\uc@dclc{7581}{autogenerated}{\unicodesuper{\unichar{597}}}%
\uc@dclc{7582}{autogenerated}{\unicodesuper{\unichar{240}}}%
\uc@dclc{7583}{autogenerated}{\unicodesuper{\unichar{604}}}%
\uc@dclc{7584}{autogenerated}{\unicodesuper{\unichar{102}}}%
\uc@dclc{7585}{autogenerated}{\unicodesuper{\unichar{607}}}%
\uc@dclc{7586}{autogenerated}{\unicodesuper{\unichar{609}}}%
\uc@dclc{7587}{autogenerated}{\unicodesuper{\unichar{613}}}%
\uc@dclc{7588}{autogenerated}{\unicodesuper{\unichar{616}}}%
\uc@dclc{7589}{autogenerated}{\unicodesuper{\unichar{617}}}%
\uc@dclc{7590}{autogenerated}{\unicodesuper{\unichar{618}}}%
\uc@dclc{7592}{autogenerated}{\unicodesuper{\unichar{669}}}%
\uc@dclc{7593}{autogenerated}{\unicodesuper{\unichar{621}}}%
\uc@dclc{7595}{autogenerated}{\unicodesuper{\unichar{671}}}%
\uc@dclc{7596}{autogenerated}{\unicodesuper{\unichar{625}}}%
\uc@dclc{7597}{autogenerated}{\unicodesuper{\unichar{624}}}%
\uc@dclc{7598}{autogenerated}{\unicodesuper{\unichar{626}}}%
\uc@dclc{7599}{autogenerated}{\unicodesuper{\unichar{627}}}%
\uc@dclc{7600}{autogenerated}{\unicodesuper{\unichar{628}}}%
\uc@dclc{7601}{autogenerated}{\unicodesuper{\unichar{629}}}%
\uc@dclc{7602}{autogenerated}{\unicodesuper{\unichar{632}}}%
\uc@dclc{7603}{autogenerated}{\unicodesuper{\unichar{642}}}%
\uc@dclc{7604}{autogenerated}{\unicodesuper{\unichar{643}}}%
\uc@dclc{7606}{autogenerated}{\unicodesuper{\unichar{649}}}%
\uc@dclc{7607}{autogenerated}{\unicodesuper{\unichar{650}}}%
\uc@dclc{7609}{autogenerated}{\unicodesuper{\unichar{651}}}%
\uc@dclc{7610}{autogenerated}{\unicodesuper{\unichar{652}}}%
\uc@dclc{7611}{autogenerated}{\unicodesuper{\unichar{122}}}%
\uc@dclc{7612}{autogenerated}{\unicodesuper{\unichar{656}}}%
\uc@dclc{7613}{autogenerated}{\unicodesuper{\unichar{657}}}%
\uc@dclc{7614}{autogenerated}{\unicodesuper{\unichar{658}}}%
\uc@dclc{7615}{autogenerated}{\unicodesuper{\unichar{952}}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
