%%% Unicode to TeX mapping, file uni-254.def, U+FE00..U+FEFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-254.def}[2013/05/13 UCS: Unicode data U+FE00..U+FEFF]%
\fi
\uc@dclc{65040}{autogenerated}{\unicodevertical{\unichar{44}}}%
\uc@dclc{65041}{autogenerated}{\unicodevertical{\unichar{12289}}}%
\uc@dclc{65042}{autogenerated}{\unicodevertical{\unichar{12290}}}%
\uc@dclc{65043}{autogenerated}{\unicodevertical{\unichar{58}}}%
\uc@dclc{65044}{autogenerated}{\unicodevertical{\unichar{59}}}%
\uc@dclc{65045}{autogenerated}{\unicodevertical{\unichar{33}}}%
\uc@dclc{65046}{autogenerated}{\unicodevertical{\unichar{63}}}%
\uc@dclc{65049}{autogenerated}{\unicodevertical{\unichar{8230}}}%
\gdef\u@cjk@Bgv#1#2#3#4{{\fontencoding{C00}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{65072}{cjkbg5}{\u@cjk@Bgv010A}%
\uc@dclc{65073}{cjkbg5}{\u@cjk@Bgv0117}%
\uc@dclc{65074}{autogenerated}{\unicodevertical{\unichar{8211}}}%
\uc@dclc{65075}{cjkbg5}{\u@cjk@Bgv0119}%
\uc@dclc{65076}{cjkbg5}{\u@cjk@Bgv011B}%
\uc@dclc{65077}{cjkbg5}{\u@cjk@Bgv011F}%
\uc@dclc{65078}{cjkbg5}{\u@cjk@Bgv0120}%
\uc@dclc{65079}{cjkbg5}{\u@cjk@Bgv0123}%
\uc@dclc{65080}{cjkbg5}{\u@cjk@Bgv0124}%
\uc@dclc{65081}{cjkbg5}{\u@cjk@Bgv0127}%
\uc@dclc{65082}{cjkbg5}{\u@cjk@Bgv0128}%
\uc@dclc{65083}{cjkbg5}{\u@cjk@Bgv012B}%
\uc@dclc{65084}{cjkbg5}{\u@cjk@Bgv012C}%
\uc@dclc{65085}{cjkbg5}{\u@cjk@Bgv012F}%
\uc@dclc{65086}{cjkbg5}{\u@cjk@Bgv0130}%
\uc@dclc{65087}{cjkbg5}{\u@cjk@Bgv0133}%
\uc@dclc{65088}{cjkbg5}{\u@cjk@Bgv0134}%
\uc@dclc{65089}{cjkbg5}{\u@cjk@Bgv0137}%
\uc@dclc{65090}{cjkbg5}{\u@cjk@Bgv0138}%
\uc@dclc{65091}{cjkbg5}{\u@cjk@Bgv013B}%
\uc@dclc{65092}{cjkbg5}{\u@cjk@Bgv013C}%
\uc@dclc{65095}{autogenerated}{\unicodevertical{\unichar{91}}}%
\uc@dclc{65096}{autogenerated}{\unicodevertical{\unichar{93}}}%
\uc@dclc{65097}{cjkbg5}{\u@cjk@Bgv0164}%
\uc@dclc{65098}{cjkbg5}{\u@cjk@Bgv0165}%
\uc@dclc{65099}{cjkbg5}{\u@cjk@Bgv0168}%
\uc@dclc{65100}{cjkbg5}{\u@cjk@Bgv0169}%
\uc@dclc{65101}{cjkbg5}{\u@cjk@Bgv0166}%
\uc@dclc{65102}{cjkbg5}{\u@cjk@Bgv0167}%
\uc@dclc{65103}{cjkbg5}{\u@cjk@Bgv011C}%
\uc@dclc{65104}{autogenerated}{\unicodesmall{\unichar{44}}}%
\uc@dclc{65105}{autogenerated}{\unicodesmall{\unichar{12289}}}%
\uc@dclc{65106}{autogenerated}{\unicodesmall{\unichar{46}}}%
\uc@dclc{65108}{autogenerated}{\unicodesmall{\unichar{59}}}%
\uc@dclc{65109}{autogenerated}{\unicodesmall{\unichar{58}}}%
\uc@dclc{65110}{autogenerated}{\unicodesmall{\unichar{63}}}%
\uc@dclc{65111}{autogenerated}{\unicodesmall{\unichar{33}}}%
\uc@dclc{65112}{autogenerated}{\unicodesmall{\unichar{8212}}}%
\uc@dclc{65113}{autogenerated}{\unicodesmall{\unichar{40}}}%
\uc@dclc{65114}{autogenerated}{\unicodesmall{\unichar{41}}}%
\uc@dclc{65115}{autogenerated}{\unicodesmall{\unichar{123}}}%
\uc@dclc{65116}{autogenerated}{\unicodesmall{\unichar{125}}}%
\uc@dclc{65117}{autogenerated}{\unicodesmall{\unichar{12308}}}%
\uc@dclc{65118}{autogenerated}{\unicodesmall{\unichar{12309}}}%
\uc@dclc{65119}{autogenerated}{\unicodesmall{\unichar{35}}}%
\uc@dclc{65120}{autogenerated}{\unicodesmall{\unichar{38}}}%
\uc@dclc{65121}{autogenerated}{\unicodesmall{\unichar{42}}}%
\uc@dclc{65122}{autogenerated}{\unicodesmall{\unichar{43}}}%
\uc@dclc{65123}{autogenerated}{\unicodesmall{\unichar{45}}}%
\uc@dclc{65124}{autogenerated}{\unicodesmall{\unichar{60}}}%
\uc@dclc{65125}{autogenerated}{\unicodesmall{\unichar{62}}}%
\uc@dclc{65126}{autogenerated}{\unicodesmall{\unichar{61}}}%
\uc@dclc{65128}{autogenerated}{\unicodesmall{\unichar{92}}}%
\uc@dclc{65129}{autogenerated}{\unicodesmall{\unichar{36}}}%
\uc@dclc{65130}{autogenerated}{\unicodesmall{\unichar{37}}}%
\uc@dclc{65131}{autogenerated}{\unicodesmall{\unichar{64}}}%
\uc@dclc{65279}{default}{{}}%
\gdef\uc@controlbox#1{{\fboxsep=1pt\fbox{\tabcolsep=0pt\ttfamily\tiny\begin{tabular}{c}#1\end{tabular}}}}%
\uc@dclc{65279}{ctrlglyphs}{\uc@controlbox{BOM}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
