%%% Unicode to TeX mapping, file uni-184.def, U+B800..U+B8FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-184.def}[2013/05/13 UCS: Unicode data U+B800..U+B8FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{47104}{cjkhangul}{\u@cjk@hangul0929}%
\uc@dclc{47105}{cjkhangul}{\u@cjk@hangul092A}%
\uc@dclc{47111}{cjkhangul}{\u@cjk@hangul092B}%
\uc@dclc{47112}{cjkhangul}{\u@cjk@hangul092C}%
\uc@dclc{47113}{cjkhangul}{\u@cjk@hangul092D}%
\uc@dclc{47116}{cjkhangul}{\u@cjk@hangul092E}%
\uc@dclc{47120}{cjkhangul}{\u@cjk@hangul092F}%
\uc@dclc{47128}{cjkhangul}{\u@cjk@hangul0930}%
\uc@dclc{47129}{cjkhangul}{\u@cjk@hangul0931}%
\uc@dclc{47131}{cjkhangul}{\u@cjk@hangul0932}%
\uc@dclc{47133}{cjkhangul}{\u@cjk@hangul0933}%
\uc@dclc{47140}{cjkhangul}{\u@cjk@hangul0934}%
\uc@dclc{47141}{cjkhangul}{\u@cjk@hangul0935}%
\uc@dclc{47144}{cjkhangul}{\u@cjk@hangul0936}%
\uc@dclc{47148}{cjkhangul}{\u@cjk@hangul0937}%
\uc@dclc{47156}{cjkhangul}{\u@cjk@hangul0938}%
\uc@dclc{47157}{cjkhangul}{\u@cjk@hangul0939}%
\uc@dclc{47159}{cjkhangul}{\u@cjk@hangul093A}%
\uc@dclc{47160}{cjkhangul}{\u@cjk@hangul093B}%
\uc@dclc{47161}{cjkhangul}{\u@cjk@hangul093C}%
\uc@dclc{47168}{cjkhangul}{\u@cjk@hangul093D}%
\uc@dclc{47172}{cjkhangul}{\u@cjk@hangul093E}%
\uc@dclc{47185}{cjkhangul}{\u@cjk@hangul093F}%
\uc@dclc{47187}{cjkhangul}{\u@cjk@hangul0940}%
\uc@dclc{47196}{cjkhangul}{\u@cjk@hangul0941}%
\uc@dclc{47197}{cjkhangul}{\u@cjk@hangul0942}%
\uc@dclc{47200}{cjkhangul}{\u@cjk@hangul0943}%
\uc@dclc{47204}{cjkhangul}{\u@cjk@hangul0944}%
\uc@dclc{47212}{cjkhangul}{\u@cjk@hangul0945}%
\uc@dclc{47213}{cjkhangul}{\u@cjk@hangul0946}%
\uc@dclc{47215}{cjkhangul}{\u@cjk@hangul0947}%
\uc@dclc{47217}{cjkhangul}{\u@cjk@hangul0948}%
\uc@dclc{47224}{cjkhangul}{\u@cjk@hangul0949}%
\uc@dclc{47228}{cjkhangul}{\u@cjk@hangul094A}%
\uc@dclc{47245}{cjkhangul}{\u@cjk@hangul094B}%
\uc@dclc{47272}{cjkhangul}{\u@cjk@hangul094C}%
\uc@dclc{47280}{cjkhangul}{\u@cjk@hangul094D}%
\uc@dclc{47284}{cjkhangul}{\u@cjk@hangul094E}%
\uc@dclc{47288}{cjkhangul}{\u@cjk@hangul094F}%
\uc@dclc{47296}{cjkhangul}{\u@cjk@hangul0950}%
\uc@dclc{47297}{cjkhangul}{\u@cjk@hangul0951}%
\uc@dclc{47299}{cjkhangul}{\u@cjk@hangul0952}%
\uc@dclc{47301}{cjkhangul}{\u@cjk@hangul0953}%
\uc@dclc{47308}{cjkhangul}{\u@cjk@hangul0954}%
\uc@dclc{47312}{cjkhangul}{\u@cjk@hangul0955}%
\uc@dclc{47316}{cjkhangul}{\u@cjk@hangul0956}%
\uc@dclc{47325}{cjkhangul}{\u@cjk@hangul0957}%
\uc@dclc{47327}{cjkhangul}{\u@cjk@hangul0958}%
\uc@dclc{47329}{cjkhangul}{\u@cjk@hangul0959}%
\uc@dclc{47336}{cjkhangul}{\u@cjk@hangul095A}%
\uc@dclc{47337}{cjkhangul}{\u@cjk@hangul095B}%
\uc@dclc{47340}{cjkhangul}{\u@cjk@hangul095C}%
\uc@dclc{47344}{cjkhangul}{\u@cjk@hangul095D}%
\uc@dclc{47352}{cjkhangul}{\u@cjk@hangul095E}%
\uc@dclc{47353}{cjkhangul}{\u@cjk@hangul095F}%
\uc@dclc{47355}{cjkhangul}{\u@cjk@hangul0960}%
\uc@dclc{47357}{cjkhangul}{\u@cjk@hangul0961}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
