%%
%% This is file `c42enc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ucs.dtx  (with options: `c42enc.def')
%% 
%% Copyright 2001 Dominique Unruh  <unruh@ut.ee>
%% Copyright 2013 Wolfgang Jeltsch <wolfgang@cs.ioc.ee>
%% 
%% This program is provided under the terms of the LaTeX Project Public License with some
%% modifications. See the file LICENSE for information.
%% 
\ProvidesFile{c42enc.def}[2002/11/25 Fontencoding C42 (JISdnp)]%
\DeclareFontEncoding{C42}{}{}%
\DeclareFontSubstitution{C42}{song}{m}{n}%
\input{cenccmn.tex}%
\expandafter\let\csname C42/song/m/n\endcsname\undefined
\def\cjk@Cfrttw@#1#2#3{%
  \advance\count1 by#3
  \ifnum\count1>256\advance\count1by-256\def\temp@a{#2}\else\def\temp@a{#1}\fi
  %\typeout{#1/#2/#3, \meaning\temp@a, \number\count1}%
}
\def\cjk@Cfrttw#1#2#3#4{% Takes JIS0208 codepos in hex
  %\typeout{JIS: #1#2#3#4}%
  {%
    \count0="#1#2 \count1="#3#4
    \advance\count0by-33
    \expandafter\cjk@Cfrttw@
    \ifcase\count0
    {sy}{err}{-32}\or % 0
    {sy}{err}{68}\or % 1
    {roma}{err}{0}\or % 2
    {hira}{err}{-32}\or % 3
    {kata}{err}{-32}\or % 4
    {greek}{err}{-32}\or % 5
    {russian}{err}{-32}\or % 6
    {keisen}{err}{-32}\or % 7
    {err}{err}{128}\or % 8
    {err}{err}{128}\or % 9
    {err}{err}{128}\or % 10
    {err}{err}{128}\or % 11
    {err}{err}{128}\or % 12
    {err}{err}{128}\or % 13
    {err}{err}{128}\or % 14
    {ka}{err}{-33}\or % 15
    {ka}{err}{61}\or % 16
    {ka}{kb}{155}\or % 17
    {kb}{err}{-7}\or % 18
    {kb}{err}{87}\or % 19
    {kb}{kc}{181}\or % 20
    {kc}{err}{19}\or % 21
    {kc}{err}{113}\or % 22
    {kc}{kd}{207}\or % 23
    {kd}{err}{45}\or % 24
    {kd}{ke}{139}\or % 25
    {ke}{err}{-23}\or % 26
    {ke}{err}{71}\or % 27
    {ke}{kf}{165}\or % 28
    {kf}{err}{3}\or % 29
    {kf}{err}{97}\or % 30
    {kf}{kg}{191}\or % 31
    {kg}{err}{29}\or % 32
    {kg}{err}{123}\or % 33
    {kg}{kh}{217}\or % 34
    {kh}{err}{55}\or % 35
    {kh}{ki}{149}\or % 36
    {ki}{err}{-13}\or % 37
    {ki}{err}{81}\or % 38
    {ki}{kj}{175}\or % 39
    {kj}{err}{13}\or % 40
    {kj}{err}{107}\or % 41
    {kj}{kk}{201}\or % 42
    {kk}{err}{39}\or % 43
    {kk}{kl}{133}\or % 44
    {kl}{err}{-29}\or % 45
    {kl}{err}{65}\or % 46
    {km}{err}{-33}\or % 47
    {km}{err}{61}\or % 48
    {km}{kn}{155}\or % 49
    {kn}{err}{-7}\or % 50
    {kn}{err}{87}\or % 51
    {kn}{ko}{181}\or % 52
    {ko}{err}{19}\or % 53
    {ko}{err}{113}\or % 54
    {ko}{kp}{207}\or % 55
    {kp}{err}{45}\or % 56
    {kp}{kq}{139}\or % 57
    {kq}{err}{-23}\or % 58
    {kq}{err}{71}\or % 59
    {kq}{kr}{165}\or % 60
    {kr}{err}{3}\or % 61
    {kr}{err}{97}\or % 62
    {kr}{ks}{191}\or % 63
    {ks}{err}{29}\or % 64
    {ks}{err}{123}\or % 65
    {ks}{kt}{217}\or % 66
    {kt}{err}{55}\or % 67
    {kt}{ku}{149}\or % 68
    {ku}{err}{-13}\or % 69
    {ku}{err}{81}\or % 70
    {ku}{kv}{175}\or % 71
    {kv}{err}{13}\or % 72
    {kv}{err}{107}\or % 73
    {kv}{kw}{201}\or % 74
    {kw}{err}{39}\or % 75
    {kw}{kx}{133}\or % 76
    {kx}{err}{-29}\or % 77
    {kx}{err}{65}\or % 78
    {kx}{ky}{159}\or % 79
    {ky}{err}{-3}\or % 80
    {ky}{err}{91}\or % 81
    {ky}{kz}{185}\or % 82
    {kz}{err}{23}\else % 83
    {err}{err}0\fi
    \edef\temp@b{\ifx\temp@a\CJK@plane\else
      \def\noexpand\CJK@plane{\temp@a}\noexpand\selectfont\fi
      \char\number\count\@ne\space}%
    %\typeout{C42: \meaning\temp@b}%
    \expandafter}\temp@b%
  }%
\DeclareTextCommand\jischar{C42}[1]{\cjk@Cfrttw#1}
\DeclareTextCommandDefault\jischar[1]{{\fontencoding{C42}%
    \let\CJK@plane\undefined\cjk@Cfrttw#1}}
