%%% Unicode to TeX mapping, file uni-3.def, U+0300..U+03FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-3.def}[2013/05/13 UCS: Unicode data U+0300..U+03FF]%
\fi
\uc@dclc{768}{default}{\uc@cmb\@tabacckludge`{#1}}%
\uc@dclc{769}{default}{\uc@cmb\@tabacckludge'{#1}}%
\uc@dclc{770}{default}{\uc@cmb\^{#1}}%
\uc@dclc{771}{default}{\uc@cmb\~{#1}}%
\uc@dclc{772}{default}{\uc@cmb\@tabacckludge={#1}}%
\uc@dclc{774}{default}{\uc@cmb\u{#1}}%
\uc@dclc{775}{default}{\uc@cmb\.{#1}}%
\uc@dclc{776}{default}{\uc@cmb\"{#1}}%
\uc@dclc{777}{default}{\uc@cmb\h{#1}}%
\uc@dclc{778}{default}{\uc@cmb\r{#1}}%
\uc@dclc{779}{default}{\uc@cmb\H{#1}}%
\uc@dclc{780}{default}{\uc@cmb\v{#1}}%
\uc@dclc{781}{tipa}{\uc@cmb\textvbaraccent{#1}}%
\uc@dclc{782}{tipa}{\uc@cmb\textdoublevbaraccent{#1}}%
\uc@dclc{783}{default}{\uc@cmb\textdblgravecmb{#1}}%
\uc@dclc{783}{tipa}{\uc@cmb\textdoublegrave{#1}}%
\uc@dclc{784}{tipa}{\uc@cmb\textdotbreve{#1}}%
\uc@dclc{785}{tipa}{\uc@cmb\textroundcap{#1}}%
\uc@dclc{790}{tipa}{\uc@cmb\textsubgrave{#1}}%
\uc@dclc{791}{tipa}{\uc@cmb\textsubacute{#1}}%
\uc@dclc{792}{tipa}{\uc@cmb\textadvancing{#1}}%
\uc@dclc{793}{tipa}{\uc@cmb\textretracting{#1}}%
\uc@dclc{796}{tipa}{\uc@cmb\textsublhalfring{#1}}%
\uc@dclc{797}{tipa}{\uc@cmb\textraising{#1}}%
\uc@dclc{798}{tipa}{\uc@cmb\textlowering{#1}}%
\uc@dclc{799}{tipa}{\uc@cmb\textsubplus{#1}}%
\uc@dclc{800}{tipa}{\uc@cmb\textsubbar{#1}}%
\uc@dclc{803}{default}{\uc@cmb\d{#1}}%
\uc@dclc{803}{tipa}{\uc@cmb\textsubdot{#1}}%
\uc@dclc{804}{tipa}{\uc@cmb\textsubumlaut{#1}}%
\uc@dclc{805}{tipa}{\uc@cmb\textsubring{#1}}%
\uc@dclc{807}{default}{\uc@cmb\c{#1}}%
\uc@dclc{808}{default}{\uc@cmb\k{#1}}%
\uc@dclc{808}{tipa}{\uc@cmb\textpolhook{#1}}%
\uc@dclc{809}{tipa}{\uc@cmb\textsyllabic{#1}}%
\uc@dclc{810}{tipa}{\uc@cmb\textsubbridge{#1}}%
\uc@dclc{811}{tipa}{\uc@cmb\textsubw{#1}}%
\uc@dclc{812}{tipa}{\uc@cmb\textsubwedge{#1}}%
\gdef \charettesubbreve#1{\oalign{#1\crcr\hidewidth% BREVE BELOW U+032E
   \vbox to.2ex{\hbox{\ifnum\fontdimen1\font=0%
     \kern-0.0em\else\kern-0.40em\fi\u{}}\vss}\hidewidth}}%
\uc@dclc{814}{default}{\uc@cmb\charettesubbreve{#1}}%
\uc@dclc{815}{tipa}{\uc@cmb\textsubarch{#1}}%
\uc@dclc{816}{tipa}{\uc@cmb\textsubtilde{#1}}%
\uc@dclc{817}{default}{\uc@cmb\b{#1}}%
\uc@dclc{820}{tipa}{\uc@cmb\textsuperimposetilde{#1}}%
\uc@dclc{825}{tipa}{\uc@cmb\textsubrhalfring{#1}}%
\uc@dclc{826}{tipa}{\uc@cmb\textinvsubbridge{#1}}%
\uc@dclc{827}{tipa}{\uc@cmb\textsubsquare{#1}}%
\uc@dclc{828}{tipa}{\uc@cmb\textseagull{#1}}%
\uc@dclc{829}{tipa}{\uc@cmb\textovercross{#1}}%
\uc@dclc{832}{default}{\uc@cmb\PackageWarning{ucs}{U+0340 (COMBINING GRAVE TONE MARK) is deprecated}\`{#1}}%
\uc@dclc{833}{default}{\uc@cmb\PackageWarning{ucs}{U+0341 (COMBINING ACUTE TONE MARK) is deprecated}\'{#1}}%
\uc@dclc{836}{autogenerated}{\unichar{776}\unichar{769}}%
\uc@dclc{838}{tipa}{\uc@cmb\overbridge{#1}}%
\uc@dclc{839}{tipa}{\uc@cmb\subdoublebar{#1}}%
\uc@dclc{840}{tipa}{\uc@cmb\subdoublevert{#1}}%
\uc@dclc{841}{tipa}{\uc@cmb\subcorner{#1}}%
\uc@dclc{842}{tipa}{\uc@cmb\crtilde{#1}}%
\uc@dclc{843}{tipa}{\uc@cmb\dottedtilde{#1}}%
\uc@dclc{844}{tipa}{\uc@cmb\doubletilde{#1}}%
\uc@dclc{845}{tipa}{\uc@cmb\spreadlips{#1}}%
\uc@dclc{846}{tipa}{\uc@cmb\whistle{#1}}%
\uc@dclc{884}{default}{\textdexiakeraia}%
\uc@dclc{885}{default}{\textaristerikeraia}%
\uc@dclc{890}{default}{\textsubiota{\empty}}%
\uc@dclc{894}{default}{\textquestion}%
\uc@dclc{900}{default}{\@tabacckludge'{\empty}}%
\uc@dclc{901}{default}{\textdialytikatonos{\empty}}%
\uc@dclc{902}{default}{\@tabacckludge'\textAlpha}%
\uc@dclc{903}{default}{\textanoteleia}%
\uc@dclc{904}{default}{\@tabacckludge'\textEpsilon}%
\uc@dclc{905}{default}{\@tabacckludge'\textEta}%
\uc@dclc{906}{default}{\@tabacckludge'\textIota}%
\uc@dclc{908}{default}{\@tabacckludge'\textOmicron}%
\uc@dclc{910}{default}{\@tabacckludge'\textUpsilon}%
\uc@dclc{911}{default}{\@tabacckludge'\textOmega}%
\uc@dclc{912}{default}{\textdialytikatonos\textiota}%
\uc@dclc{913}{default}{\textAlpha}%
\uc@dclc{913}{mathletters}{\ensuremath{\mathrm A}}%
\uc@dclc{913}{postscript}{\Pisymbol{psy}{"41}}%
\uc@dclc{914}{default}{\textBeta}%
\uc@dclc{914}{mathletters}{\ensuremath{\mathrm B}}%
\uc@dclc{914}{postscript}{\Pisymbol{psy}{"42}}%
\uc@dclc{915}{default}{\textGamma}%
\uc@dclc{915}{mathletters}{\ensuremath{\Gamma}}%
\uc@dclc{915}{postscript}{\Pisymbol{psy}{"47}}%
\uc@dclc{916}{default}{\textDelta}%
\uc@dclc{916}{mathletters}{\ensuremath{\Delta}}%
\uc@dclc{917}{default}{\textEpsilon}%
\uc@dclc{917}{mathletters}{\ensuremath{\mathrm E}}%
\uc@dclc{917}{postscript}{\Pisymbol{psy}{"45}}%
\uc@dclc{918}{default}{\textZeta}%
\uc@dclc{918}{mathletters}{\ensuremath{\mathrm Z}}%
\uc@dclc{918}{postscript}{\Pisymbol{psy}{"5A}}%
\uc@dclc{919}{default}{\textEta}%
\uc@dclc{919}{mathletters}{\ensuremath{\mathrm H}}%
\uc@dclc{919}{postscript}{\Pisymbol{psy}{"48}}%
\uc@dclc{920}{default}{\textTheta}%
\uc@dclc{920}{mathletters}{\ensuremath{\Theta}}%
\uc@dclc{920}{postscript}{\Pisymbol{psy}{"51}}%
\uc@dclc{921}{default}{\textIota}%
\uc@dclc{921}{mathletters}{\ensuremath{\mathrm I}}%
\uc@dclc{921}{postscript}{\Pisymbol{psy}{"49}}%
\uc@dclc{922}{default}{\textKappa}%
\uc@dclc{922}{mathletters}{\ensuremath{\mathrm K}}%
\uc@dclc{922}{postscript}{\Pisymbol{psy}{"4B}}%
\uc@dclc{923}{default}{\textLambda}%
\uc@dclc{923}{mathletters}{\ensuremath{\Lambda}}%
\uc@dclc{923}{postscript}{\Pisymbol{psy}{"4C}}%
\uc@dclc{924}{default}{\textMu}%
\uc@dclc{924}{mathletters}{\ensuremath{\mathrm M}}%
\uc@dclc{924}{postscript}{\Pisymbol{psy}{"4D}}%
\uc@dclc{925}{default}{\textNu}%
\uc@dclc{925}{mathletters}{\ensuremath{\mathrm N}}%
\uc@dclc{925}{postscript}{\Pisymbol{psy}{"4E}}%
\uc@dclc{926}{default}{\textXi}%
\uc@dclc{926}{mathletters}{\ensuremath{\Xi}}%
\uc@dclc{926}{postscript}{\Pisymbol{psy}{"58}}%
\uc@dclc{927}{default}{\textOmicron}%
\uc@dclc{927}{mathletters}{\ensuremath{\mathrm O}}%
\uc@dclc{927}{postscript}{\Pisymbol{psy}{"4F}}%
\uc@dclc{928}{default}{\textPi}%
\uc@dclc{928}{mathletters}{\ensuremath{\Pi}}%
\uc@dclc{928}{postscript}{\Pisymbol{psy}{"50}}%
\uc@dclc{929}{default}{\textRho}%
\uc@dclc{929}{mathletters}{\ensuremath{\mathrm P}}%
\uc@dclc{929}{postscript}{\Pisymbol{psy}{"52}}%
\uc@dclc{931}{default}{\textSigma}%
\uc@dclc{931}{mathletters}{\ensuremath{\Sigma}}%
\uc@dclc{931}{postscript}{\Pisymbol{psy}{"53}}%
\uc@dclc{932}{default}{\textTau}%
\uc@dclc{932}{mathletters}{\ensuremath{\mathrm T}}%
\uc@dclc{932}{postscript}{\Pisymbol{psy}{"54}}%
\uc@dclc{933}{default}{\textUpsilon}%
\uc@dclc{933}{mathletters}{\ensuremath{\Upsilon}}%
\uc@dclc{933}{postscript}{\Pisymbol{psy}{"55}}%
\uc@dclc{934}{default}{\textPhi}%
\uc@dclc{934}{mathletters}{\ensuremath{\Phi}}%
\uc@dclc{934}{postscript}{\Pisymbol{psy}{"46}}%
\uc@dclc{935}{default}{\textChi}%
\uc@dclc{935}{mathletters}{\ensuremath{\mathrm X}}%
\uc@dclc{935}{postscript}{\Pisymbol{psy}{"43}}%
\uc@dclc{936}{default}{\textPsi}%
\uc@dclc{936}{mathletters}{\ensuremath{\Psi}}%
\uc@dclc{936}{postscript}{\Pisymbol{psy}{"59}}%
\uc@dclc{937}{default}{\textOmega}%
\uc@dclc{937}{mathletters}{\ensuremath{\Omega}}%
\uc@dclc{937}{postscript}{\Pisymbol{psy}{"57}}%
\uc@dclc{938}{default}{\"\textIota}%
\uc@dclc{939}{default}{\"\textUpsilon}%
\uc@dclc{940}{default}{\@tabacckludge'\textalpha}%
\uc@dclc{941}{default}{\@tabacckludge'\textepsilon}%
\uc@dclc{942}{default}{\@tabacckludge'\texteta}%
\uc@dclc{943}{default}{\@tabacckludge'\textiota}%
\uc@dclc{944}{default}{\textdialytikatonos\textupsilon}%
\uc@dclc{945}{default}{\textalpha}%
\uc@dclc{945}{mathletters}{\ensuremath{\alpha}}%
\uc@dclc{945}{postscript}{\Pisymbol{psy}{"61}}%
\uc@dclc{946}{default}{\textbeta}%
\uc@dclc{946}{mathletters}{\ensuremath{\beta}}%
\uc@dclc{946}{postscript}{\Pisymbol{psy}{"62}}%
\uc@dclc{947}{default}{\textgamma}%
\uc@dclc{947}{mathletters}{\ensuremath{\gamma}}%
\uc@dclc{947}{postscript}{\Pisymbol{psy}{"67}}%
\uc@dclc{948}{default}{\textdelta}%
\uc@dclc{948}{mathletters}{\ensuremath{\delta}}%
\uc@dclc{948}{postscript}{\Pisymbol{psy}{"64}}%
\uc@dclc{949}{default}{\textepsilon}%
\uc@dclc{949}{mathletters}{\ensuremath{\varepsilon}}%
\uc@dclc{949}{postscript}{\Pisymbol{psy}{"65}}%
\uc@dclc{950}{default}{\textzeta}%
\uc@dclc{950}{mathletters}{\ensuremath{\zeta}}%
\uc@dclc{950}{postscript}{\Pisymbol{psy}{"7A}}%
\uc@dclc{951}{default}{\texteta}%
\uc@dclc{951}{mathletters}{\ensuremath{\eta}}%
\uc@dclc{951}{postscript}{\Pisymbol{psy}{"68}}%
\uc@dclc{952}{default}{\texttheta}%
\uc@dclc{952}{mathletters}{\ensuremath{\theta}}%
\uc@dclc{952}{postscript}{\Pisymbol{psy}{"71}}%
\uc@dclc{953}{default}{\textiota}%
\uc@dclc{953}{mathletters}{\ensuremath{\iota}}%
\uc@dclc{953}{postscript}{\Pisymbol{psy}{"69}}%
\uc@dclc{954}{default}{\textkappa}%
\uc@dclc{954}{mathletters}{\ensuremath{\kappa}}%
\uc@dclc{954}{postscript}{\Pisymbol{psy}{"6B}}%
\uc@dclc{955}{default}{\textlambda}%
\uc@dclc{955}{mathletters}{\ensuremath{\lambda}}%
\uc@dclc{955}{postscript}{\Pisymbol{psy}{"6C}}%
\uc@dclc{956}{default}{\textmu}%
\uc@dclc{956}{mathletters}{\ensuremath{\mu}}%
\uc@dclc{956}{postscript}{\Pisymbol{psy}{"6D}}%
\uc@dclc{957}{default}{\textnu}%
\uc@dclc{957}{mathletters}{\ensuremath{\nu}}%
\uc@dclc{957}{postscript}{\Pisymbol{psy}{"6E}}%
\uc@dclc{958}{default}{\textxi}%
\uc@dclc{958}{mathletters}{\ensuremath{\xi}}%
\uc@dclc{958}{postscript}{\Pisymbol{psy}{"78}}%
\uc@dclc{959}{default}{\textomicron}%
\uc@dclc{959}{mathletters}{\ensuremath{o}}%
\uc@dclc{959}{postscript}{\Pisymbol{psy}{"6F}}%
\uc@dclc{960}{default}{\textpi}%
\uc@dclc{960}{mathletters}{\ensuremath{\pi}}%
\uc@dclc{960}{postscript}{\Pisymbol{psy}{"70}}%
\uc@dclc{961}{default}{\textrho}%
\uc@dclc{961}{mathletters}{\ensuremath{\rho}}%
\uc@dclc{961}{postscript}{\Pisymbol{psy}{"72}}%
\uc@dclc{962}{default}{\textvarsigma}%
\uc@dclc{962}{mathletters}{\ensuremath{\varsigma}}%
\uc@dclc{962}{postscript}{\Pisymbol{psy}{"56}}%
\uc@dclc{963}{default}{\textsigma}%
\uc@dclc{963}{mathletters}{\ensuremath{\sigma}}%
\uc@dclc{963}{postscript}{\Pisymbol{psy}{"73}}%
\uc@dclc{964}{default}{\texttau}%
\uc@dclc{964}{mathletters}{\ensuremath{\tau}}%
\uc@dclc{964}{postscript}{\Pisymbol{psy}{"74}}%
\uc@dclc{965}{default}{\textupsilon}%
\uc@dclc{965}{mathletters}{\ensuremath{\upsilon}}%
\uc@dclc{965}{postscript}{\Pisymbol{psy}{"75}}%
\uc@dclc{966}{default}{\textphi}%
\uc@dclc{966}{mathletters}{\ensuremath{\varphi}}%
\uc@dclc{966}{postscript}{\Pisymbol{psy}{"66}}%
\uc@dclc{967}{default}{\textchi}%
\uc@dclc{967}{mathletters}{\ensuremath{\chi}}%
\uc@dclc{967}{postscript}{\Pisymbol{psy}{"63}}%
\uc@dclc{968}{default}{\textpsi}%
\uc@dclc{968}{mathletters}{\ensuremath{\psi}}%
\uc@dclc{968}{postscript}{\Pisymbol{psy}{"79}}%
\uc@dclc{969}{default}{\textomega}%
\uc@dclc{969}{mathletters}{\ensuremath{\omega}}%
\uc@dclc{969}{postscript}{\Pisymbol{psy}{"77}}%
\uc@dclc{970}{default}{\"\textiota}%
\uc@dclc{971}{default}{\"\textupsilon}%
\uc@dclc{972}{default}{\@tabacckludge'\textomicron}%
\uc@dclc{973}{default}{\@tabacckludge'\textupsilon}%
\uc@dclc{974}{default}{\@tabacckludge'\textomega}%
\uc@dclc{976}{autogenerated}{\unichar{946}}%
\uc@dclc{977}{mathletters}{\ensuremath{\vartheta}}%
\uc@dclc{977}{postscript}{\Pisymbol{psy}{"4A}}%
\uc@dclc{978}{postscript}{\Pisymbol{psy}{"A1}}%
\uc@dclc{979}{autogenerated}{\unichar{978}\unichar{769}}%
\uc@dclc{980}{autogenerated}{\unichar{978}\unichar{776}}%
\uc@dclc{981}{mathletters}{\ensuremath{\phi}}%
\uc@dclc{981}{postscript}{\Pisymbol{psy}{"6A}}%
\uc@dclc{982}{mathletters}{\ensuremath{\varpi}}%
\uc@dclc{982}{postscript}{\Pisymbol{psy}{"76}}%
\uc@dclc{987}{default}{\textstigma}%
\uc@dclc{988}{default}{\textDigamma}%
\uc@dclc{989}{default}{\textdigamma}%
\uc@dclc{991}{default}{\textqoppa}%
\uc@dclc{993}{default}{\textsanpi}%
\uc@dclc{1008}{mathletters}{\ensuremath{\varkappa}}%
\uc@dclc{1009}{mathletters}{\ensuremath{\varrho}}%
\uc@dclc{1010}{autogenerated}{\unichar{962}}%
\uc@dclc{1012}{autogenerated}{\unichar{920}}%
\uc@dclc{1013}{mathletters}{\ensuremath{\epsilon}}%
\uc@dclc{1017}{autogenerated}{\unichar{931}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
