%%% Unicode to TeX mapping, file uni-762.def, U+2FA00..U+2FAFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-762.def}[2013/05/13 UCS: Unicode data U+2FA00..U+2FAFF]%
\fi
\uc@dclc{195072}{autogenerated}{\unichar{38953}}%
\uc@dclc{195074}{autogenerated}{\unichar{39138}}%
\uc@dclc{195076}{autogenerated}{\unichar{39209}}%
\uc@dclc{195077}{autogenerated}{\unichar{39335}}%
\uc@dclc{195078}{autogenerated}{\unichar{39362}}%
\uc@dclc{195079}{autogenerated}{\unichar{39422}}%
\uc@dclc{195082}{autogenerated}{\unichar{39698}}%
\uc@dclc{195083}{autogenerated}{\unichar{40000}}%
\uc@dclc{195084}{autogenerated}{\unichar{40189}}%
\uc@dclc{195087}{autogenerated}{\unichar{40295}}%
\uc@dclc{195093}{autogenerated}{\unichar{40635}}%
\uc@dclc{195095}{autogenerated}{\unichar{40697}}%
\uc@dclc{195096}{autogenerated}{\unichar{40702}}%
\uc@dclc{195098}{autogenerated}{\unichar{40719}}%
\uc@dclc{195099}{autogenerated}{\unichar{40726}}%
\uc@dclc{195100}{autogenerated}{\unichar{40763}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
