%%% Unicode to TeX mapping, file uni-173.def, U+AD00..U+ADFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-173.def}[2013/05/13 UCS: Unicode data U+AD00..U+ADFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{44288}{cjkhangul}{\u@cjk@hangul06DD}%
\uc@dclc{44292}{cjkhangul}{\u@cjk@hangul06DE}%
\uc@dclc{44294}{cjkhangul}{\u@cjk@hangul06DF}%
\uc@dclc{44300}{cjkhangul}{\u@cjk@hangul06E0}%
\uc@dclc{44301}{cjkhangul}{\u@cjk@hangul06E1}%
\uc@dclc{44303}{cjkhangul}{\u@cjk@hangul06E2}%
\uc@dclc{44305}{cjkhangul}{\u@cjk@hangul06E3}%
\uc@dclc{44312}{cjkhangul}{\u@cjk@hangul06E4}%
\uc@dclc{44316}{cjkhangul}{\u@cjk@hangul06E5}%
\uc@dclc{44320}{cjkhangul}{\u@cjk@hangul06E6}%
\uc@dclc{44329}{cjkhangul}{\u@cjk@hangul06E7}%
\uc@dclc{44332}{cjkhangul}{\u@cjk@hangul06E8}%
\uc@dclc{44333}{cjkhangul}{\u@cjk@hangul06E9}%
\uc@dclc{44340}{cjkhangul}{\u@cjk@hangul06EA}%
\uc@dclc{44341}{cjkhangul}{\u@cjk@hangul06EB}%
\uc@dclc{44344}{cjkhangul}{\u@cjk@hangul06EC}%
\uc@dclc{44348}{cjkhangul}{\u@cjk@hangul06ED}%
\uc@dclc{44356}{cjkhangul}{\u@cjk@hangul06EE}%
\uc@dclc{44357}{cjkhangul}{\u@cjk@hangul06EF}%
\uc@dclc{44359}{cjkhangul}{\u@cjk@hangul06F0}%
\uc@dclc{44361}{cjkhangul}{\u@cjk@hangul06F1}%
\uc@dclc{44368}{cjkhangul}{\u@cjk@hangul06F2}%
\uc@dclc{44372}{cjkhangul}{\u@cjk@hangul06F3}%
\uc@dclc{44376}{cjkhangul}{\u@cjk@hangul06F4}%
\uc@dclc{44385}{cjkhangul}{\u@cjk@hangul06F5}%
\uc@dclc{44387}{cjkhangul}{\u@cjk@hangul06F6}%
\uc@dclc{44396}{cjkhangul}{\u@cjk@hangul06F7}%
\uc@dclc{44397}{cjkhangul}{\u@cjk@hangul06F8}%
\uc@dclc{44400}{cjkhangul}{\u@cjk@hangul06F9}%
\uc@dclc{44403}{cjkhangul}{\u@cjk@hangul06FA}%
\uc@dclc{44404}{cjkhangul}{\u@cjk@hangul06FB}%
\uc@dclc{44405}{cjkhangul}{\u@cjk@hangul06FC}%
\uc@dclc{44406}{cjkhangul}{\u@cjk@hangul06FD}%
\uc@dclc{44411}{cjkhangul}{\u@cjk@hangul06FE}%
\uc@dclc{44412}{cjkhangul}{\u@cjk@hangul06FF}%
\uc@dclc{44413}{cjkhangul}{\u@cjk@hangul0700}%
\uc@dclc{44415}{cjkhangul}{\u@cjk@hangul0701}%
\uc@dclc{44417}{cjkhangul}{\u@cjk@hangul0702}%
\uc@dclc{44418}{cjkhangul}{\u@cjk@hangul0703}%
\uc@dclc{44424}{cjkhangul}{\u@cjk@hangul0704}%
\uc@dclc{44425}{cjkhangul}{\u@cjk@hangul0705}%
\uc@dclc{44428}{cjkhangul}{\u@cjk@hangul0706}%
\uc@dclc{44432}{cjkhangul}{\u@cjk@hangul0707}%
\uc@dclc{44444}{cjkhangul}{\u@cjk@hangul0708}%
\uc@dclc{44445}{cjkhangul}{\u@cjk@hangul0709}%
\uc@dclc{44452}{cjkhangul}{\u@cjk@hangul070A}%
\uc@dclc{44471}{cjkhangul}{\u@cjk@hangul070B}%
\uc@dclc{44480}{cjkhangul}{\u@cjk@hangul070C}%
\uc@dclc{44481}{cjkhangul}{\u@cjk@hangul070D}%
\uc@dclc{44484}{cjkhangul}{\u@cjk@hangul070E}%
\uc@dclc{44488}{cjkhangul}{\u@cjk@hangul070F}%
\uc@dclc{44496}{cjkhangul}{\u@cjk@hangul0710}%
\uc@dclc{44497}{cjkhangul}{\u@cjk@hangul0711}%
\uc@dclc{44499}{cjkhangul}{\u@cjk@hangul0712}%
\uc@dclc{44508}{cjkhangul}{\u@cjk@hangul0713}%
\uc@dclc{44512}{cjkhangul}{\u@cjk@hangul0714}%
\uc@dclc{44516}{cjkhangul}{\u@cjk@hangul0715}%
\uc@dclc{44536}{cjkhangul}{\u@cjk@hangul0716}%
\uc@dclc{44537}{cjkhangul}{\u@cjk@hangul0717}%
\uc@dclc{44540}{cjkhangul}{\u@cjk@hangul0718}%
\uc@dclc{44543}{cjkhangul}{\u@cjk@hangul0719}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
