%%% Unicode to TeX mapping, file uni-194.def, U+C200..U+C2FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-194.def}[2013/05/13 UCS: Unicode data U+C200..U+C2FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{49664}{cjkhangul}{\u@cjk@hangul1139}%
\uc@dclc{49668}{cjkhangul}{\u@cjk@hangul113A}%
\uc@dclc{49676}{cjkhangul}{\u@cjk@hangul113B}%
\uc@dclc{49677}{cjkhangul}{\u@cjk@hangul113C}%
\uc@dclc{49679}{cjkhangul}{\u@cjk@hangul113D}%
\uc@dclc{49681}{cjkhangul}{\u@cjk@hangul113E}%
\uc@dclc{49688}{cjkhangul}{\u@cjk@hangul113F}%
\uc@dclc{49689}{cjkhangul}{\u@cjk@hangul1140}%
\uc@dclc{49692}{cjkhangul}{\u@cjk@hangul1141}%
\uc@dclc{49695}{cjkhangul}{\u@cjk@hangul1142}%
\uc@dclc{49696}{cjkhangul}{\u@cjk@hangul1143}%
\uc@dclc{49704}{cjkhangul}{\u@cjk@hangul1144}%
\uc@dclc{49705}{cjkhangul}{\u@cjk@hangul1145}%
\uc@dclc{49707}{cjkhangul}{\u@cjk@hangul1146}%
\uc@dclc{49709}{cjkhangul}{\u@cjk@hangul1147}%
\uc@dclc{49711}{cjkhangul}{\u@cjk@hangul1148}%
\uc@dclc{49713}{cjkhangul}{\u@cjk@hangul1149}%
\uc@dclc{49714}{cjkhangul}{\u@cjk@hangul114A}%
\uc@dclc{49716}{cjkhangul}{\u@cjk@hangul114B}%
\uc@dclc{49736}{cjkhangul}{\u@cjk@hangul114C}%
\uc@dclc{49744}{cjkhangul}{\u@cjk@hangul114D}%
\uc@dclc{49745}{cjkhangul}{\u@cjk@hangul114E}%
\uc@dclc{49748}{cjkhangul}{\u@cjk@hangul114F}%
\uc@dclc{49752}{cjkhangul}{\u@cjk@hangul1150}%
\uc@dclc{49760}{cjkhangul}{\u@cjk@hangul1151}%
\uc@dclc{49765}{cjkhangul}{\u@cjk@hangul1152}%
\uc@dclc{49772}{cjkhangul}{\u@cjk@hangul1153}%
\uc@dclc{49773}{cjkhangul}{\u@cjk@hangul1154}%
\uc@dclc{49776}{cjkhangul}{\u@cjk@hangul1155}%
\uc@dclc{49780}{cjkhangul}{\u@cjk@hangul1156}%
\uc@dclc{49788}{cjkhangul}{\u@cjk@hangul1157}%
\uc@dclc{49789}{cjkhangul}{\u@cjk@hangul1158}%
\uc@dclc{49791}{cjkhangul}{\u@cjk@hangul1159}%
\uc@dclc{49793}{cjkhangul}{\u@cjk@hangul115A}%
\uc@dclc{49800}{cjkhangul}{\u@cjk@hangul115B}%
\uc@dclc{49801}{cjkhangul}{\u@cjk@hangul115C}%
\uc@dclc{49808}{cjkhangul}{\u@cjk@hangul115D}%
\uc@dclc{49816}{cjkhangul}{\u@cjk@hangul115E}%
\uc@dclc{49819}{cjkhangul}{\u@cjk@hangul115F}%
\uc@dclc{49821}{cjkhangul}{\u@cjk@hangul1160}%
\uc@dclc{49828}{cjkhangul}{\u@cjk@hangul1161}%
\uc@dclc{49829}{cjkhangul}{\u@cjk@hangul1162}%
\uc@dclc{49832}{cjkhangul}{\u@cjk@hangul1163}%
\uc@dclc{49836}{cjkhangul}{\u@cjk@hangul1164}%
\uc@dclc{49837}{cjkhangul}{\u@cjk@hangul1165}%
\uc@dclc{49844}{cjkhangul}{\u@cjk@hangul1166}%
\uc@dclc{49845}{cjkhangul}{\u@cjk@hangul1167}%
\uc@dclc{49847}{cjkhangul}{\u@cjk@hangul1168}%
\uc@dclc{49849}{cjkhangul}{\u@cjk@hangul1169}%
\uc@dclc{49884}{cjkhangul}{\u@cjk@hangul116A}%
\uc@dclc{49885}{cjkhangul}{\u@cjk@hangul116B}%
\uc@dclc{49888}{cjkhangul}{\u@cjk@hangul116C}%
\uc@dclc{49891}{cjkhangul}{\u@cjk@hangul116D}%
\uc@dclc{49892}{cjkhangul}{\u@cjk@hangul116E}%
\uc@dclc{49899}{cjkhangul}{\u@cjk@hangul116F}%
\uc@dclc{49900}{cjkhangul}{\u@cjk@hangul1170}%
\uc@dclc{49901}{cjkhangul}{\u@cjk@hangul1171}%
\uc@dclc{49903}{cjkhangul}{\u@cjk@hangul1172}%
\uc@dclc{49905}{cjkhangul}{\u@cjk@hangul1173}%
\uc@dclc{49910}{cjkhangul}{\u@cjk@hangul1174}%
\uc@dclc{49912}{cjkhangul}{\u@cjk@hangul1175}%
\uc@dclc{49913}{cjkhangul}{\u@cjk@hangul1176}%
\uc@dclc{49915}{cjkhangul}{\u@cjk@hangul1177}%
\uc@dclc{49916}{cjkhangul}{\u@cjk@hangul1178}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
