%%% Unicode to TeX mapping, file uni-200.def, U+C800..U+C8FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-200.def}[2013/05/13 UCS: Unicode data U+C800..U+C8FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{51200}{cjkhangul}{\u@cjk@hangul12BB}%
\uc@dclc{51201}{cjkhangul}{\u@cjk@hangul12BC}%
\uc@dclc{51204}{cjkhangul}{\u@cjk@hangul12BD}%
\uc@dclc{51208}{cjkhangul}{\u@cjk@hangul12BE}%
\uc@dclc{51210}{cjkhangul}{\u@cjk@hangul12BF}%
\uc@dclc{51216}{cjkhangul}{\u@cjk@hangul12C0}%
\uc@dclc{51217}{cjkhangul}{\u@cjk@hangul12C1}%
\uc@dclc{51219}{cjkhangul}{\u@cjk@hangul12C2}%
\uc@dclc{51221}{cjkhangul}{\u@cjk@hangul12C3}%
\uc@dclc{51222}{cjkhangul}{\u@cjk@hangul12C4}%
\uc@dclc{51228}{cjkhangul}{\u@cjk@hangul12C5}%
\uc@dclc{51229}{cjkhangul}{\u@cjk@hangul12C6}%
\uc@dclc{51232}{cjkhangul}{\u@cjk@hangul12C7}%
\uc@dclc{51236}{cjkhangul}{\u@cjk@hangul12C8}%
\uc@dclc{51244}{cjkhangul}{\u@cjk@hangul12C9}%
\uc@dclc{51245}{cjkhangul}{\u@cjk@hangul12CA}%
\uc@dclc{51247}{cjkhangul}{\u@cjk@hangul12CB}%
\uc@dclc{51249}{cjkhangul}{\u@cjk@hangul12CC}%
\uc@dclc{51256}{cjkhangul}{\u@cjk@hangul12CD}%
\uc@dclc{51260}{cjkhangul}{\u@cjk@hangul12CE}%
\uc@dclc{51264}{cjkhangul}{\u@cjk@hangul12CF}%
\uc@dclc{51272}{cjkhangul}{\u@cjk@hangul12D0}%
\uc@dclc{51273}{cjkhangul}{\u@cjk@hangul12D1}%
\uc@dclc{51276}{cjkhangul}{\u@cjk@hangul12D2}%
\uc@dclc{51277}{cjkhangul}{\u@cjk@hangul12D3}%
\uc@dclc{51284}{cjkhangul}{\u@cjk@hangul12D4}%
\uc@dclc{51312}{cjkhangul}{\u@cjk@hangul12D5}%
\uc@dclc{51313}{cjkhangul}{\u@cjk@hangul12D6}%
\uc@dclc{51316}{cjkhangul}{\u@cjk@hangul12D7}%
\uc@dclc{51320}{cjkhangul}{\u@cjk@hangul12D8}%
\uc@dclc{51322}{cjkhangul}{\u@cjk@hangul12D9}%
\uc@dclc{51328}{cjkhangul}{\u@cjk@hangul12DA}%
\uc@dclc{51329}{cjkhangul}{\u@cjk@hangul12DB}%
\uc@dclc{51331}{cjkhangul}{\u@cjk@hangul12DC}%
\uc@dclc{51333}{cjkhangul}{\u@cjk@hangul12DD}%
\uc@dclc{51334}{cjkhangul}{\u@cjk@hangul12DE}%
\uc@dclc{51335}{cjkhangul}{\u@cjk@hangul12DF}%
\uc@dclc{51339}{cjkhangul}{\u@cjk@hangul12E0}%
\uc@dclc{51340}{cjkhangul}{\u@cjk@hangul12E1}%
\uc@dclc{51341}{cjkhangul}{\u@cjk@hangul12E2}%
\uc@dclc{51348}{cjkhangul}{\u@cjk@hangul12E3}%
\uc@dclc{51357}{cjkhangul}{\u@cjk@hangul12E4}%
\uc@dclc{51359}{cjkhangul}{\u@cjk@hangul12E5}%
\uc@dclc{51361}{cjkhangul}{\u@cjk@hangul12E6}%
\uc@dclc{51368}{cjkhangul}{\u@cjk@hangul12E7}%
\uc@dclc{51388}{cjkhangul}{\u@cjk@hangul12E8}%
\uc@dclc{51389}{cjkhangul}{\u@cjk@hangul12E9}%
\uc@dclc{51396}{cjkhangul}{\u@cjk@hangul12EA}%
\uc@dclc{51400}{cjkhangul}{\u@cjk@hangul12EB}%
\uc@dclc{51404}{cjkhangul}{\u@cjk@hangul12EC}%
\uc@dclc{51412}{cjkhangul}{\u@cjk@hangul12ED}%
\uc@dclc{51413}{cjkhangul}{\u@cjk@hangul12EE}%
\uc@dclc{51415}{cjkhangul}{\u@cjk@hangul12EF}%
\uc@dclc{51417}{cjkhangul}{\u@cjk@hangul12F0}%
\uc@dclc{51424}{cjkhangul}{\u@cjk@hangul12F1}%
\uc@dclc{51425}{cjkhangul}{\u@cjk@hangul12F2}%
\uc@dclc{51428}{cjkhangul}{\u@cjk@hangul12F3}%
\uc@dclc{51445}{cjkhangul}{\u@cjk@hangul12F4}%
\uc@dclc{51452}{cjkhangul}{\u@cjk@hangul12F5}%
\uc@dclc{51453}{cjkhangul}{\u@cjk@hangul12F6}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
