%%% Unicode to TeX mapping, file uni-39.def, U+2700..U+27FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-39.def}[2013/05/13 UCS: Unicode data U+2700..U+27FF]%
\fi
\uc@dclc{9985}{postscript}{\ding{"21}}%
\uc@dclc{9986}{postscript}{\ding{"22}}%
\uc@dclc{9987}{postscript}{\ding{"23}}%
\uc@dclc{9988}{postscript}{\ding{"24}}%
\uc@dclc{9990}{postscript}{\ding{"26}}%
\uc@dclc{9991}{postscript}{\ding{"27}}%
\uc@dclc{9992}{postscript}{\ding{"28}}%
\uc@dclc{9993}{postscript}{\ding{"29}}%
\uc@dclc{9996}{postscript}{\ding{"2C}}%
\uc@dclc{9997}{postscript}{\ding{"2D}}%
\uc@dclc{9998}{postscript}{\ding{"2E}}%
\uc@dclc{9999}{postscript}{\ding{"2F}}%
\uc@dclc{10000}{postscript}{\ding{"30}}%
\uc@dclc{10001}{postscript}{\ding{"31}}%
\uc@dclc{10002}{postscript}{\ding{"32}}%
\uc@dclc{10003}{postscript}{\ding{"33}}%
\uc@dclc{10004}{postscript}{\ding{"34}}%
\uc@dclc{10005}{postscript}{\ding{"35}}%
\uc@dclc{10006}{postscript}{\ding{"36}}%
\uc@dclc{10007}{postscript}{\ding{"37}}%
\uc@dclc{10008}{postscript}{\ding{"38}}%
\uc@dclc{10009}{postscript}{\ding{"39}}%
\uc@dclc{10010}{postscript}{\ding{"3A}}%
\uc@dclc{10011}{postscript}{\ding{"3B}}%
\uc@dclc{10012}{postscript}{\ding{"3C}}%
\uc@dclc{10013}{postscript}{\ding{"3D}}%
\uc@dclc{10014}{postscript}{\ding{"3E}}%
\uc@dclc{10015}{postscript}{\ding{"3F}}%
\uc@dclc{10016}{postscript}{\ding{"40}}%
\uc@dclc{10017}{postscript}{\ding{"41}}%
\uc@dclc{10018}{postscript}{\ding{"42}}%
\uc@dclc{10019}{postscript}{\ding{"43}}%
\uc@dclc{10020}{postscript}{\ding{"44}}%
\uc@dclc{10021}{postscript}{\ding{"45}}%
\uc@dclc{10022}{postscript}{\ding{"46}}%
\uc@dclc{10023}{postscript}{\ding{"47}}%
\uc@dclc{10025}{postscript}{\ding{"49}}%
\uc@dclc{10026}{postscript}{\ding{"4A}}%
\uc@dclc{10027}{postscript}{\ding{"4B}}%
\uc@dclc{10028}{postscript}{\ding{"4C}}%
\uc@dclc{10029}{postscript}{\ding{"4D}}%
\uc@dclc{10030}{postscript}{\ding{"4E}}%
\uc@dclc{10031}{postscript}{\ding{"4F}}%
\uc@dclc{10032}{postscript}{\ding{"50}}%
\uc@dclc{10033}{postscript}{\ding{"51}}%
\uc@dclc{10034}{postscript}{\ding{"52}}%
\uc@dclc{10035}{postscript}{\ding{"53}}%
\uc@dclc{10036}{postscript}{\ding{"54}}%
\uc@dclc{10037}{postscript}{\ding{"55}}%
\uc@dclc{10038}{postscript}{\ding{"56}}%
\uc@dclc{10039}{postscript}{\ding{"57}}%
\uc@dclc{10040}{postscript}{\ding{"58}}%
\uc@dclc{10041}{postscript}{\ding{"59}}%
\uc@dclc{10042}{postscript}{\ding{"5A}}%
\uc@dclc{10043}{postscript}{\ding{"5B}}%
\uc@dclc{10044}{postscript}{\ding{"5C}}%
\uc@dclc{10045}{postscript}{\ding{"5D}}%
\uc@dclc{10046}{postscript}{\ding{"5E}}%
\uc@dclc{10047}{postscript}{\ding{"5F}}%
\uc@dclc{10048}{postscript}{\ding{"60}}%
\uc@dclc{10049}{postscript}{\ding{"61}}%
\uc@dclc{10050}{postscript}{\ding{"62}}%
\uc@dclc{10051}{postscript}{\ding{"63}}%
\uc@dclc{10052}{postscript}{\ding{"64}}%
\uc@dclc{10053}{postscript}{\ding{"65}}%
\uc@dclc{10054}{postscript}{\ding{"66}}%
\uc@dclc{10055}{postscript}{\ding{"67}}%
\uc@dclc{10056}{postscript}{\ding{"68}}%
\uc@dclc{10057}{postscript}{\ding{"69}}%
\uc@dclc{10058}{postscript}{\ding{"6A}}%
\uc@dclc{10059}{postscript}{\ding{"6B}}%
\uc@dclc{10061}{postscript}{\ding{"6D}}%
\uc@dclc{10063}{postscript}{\ding{"6F}}%
\uc@dclc{10064}{postscript}{\ding{"70}}%
\uc@dclc{10065}{postscript}{\ding{"71}}%
\uc@dclc{10066}{postscript}{\ding{"72}}%
\uc@dclc{10070}{postscript}{\ding{"76}}%
\uc@dclc{10072}{postscript}{\ding{"78}}%
\uc@dclc{10073}{postscript}{\ding{"79}}%
\uc@dclc{10074}{postscript}{\ding{"7A}}%
\uc@dclc{10075}{postscript}{\ding{"7B}}%
\uc@dclc{10076}{postscript}{\ding{"7C}}%
\uc@dclc{10077}{postscript}{\ding{"7D}}%
\uc@dclc{10078}{postscript}{\ding{"7E}}%
\uc@dclc{10081}{postscript}{\ding{"A1}}%
\uc@dclc{10082}{postscript}{\ding{"A2}}%
\uc@dclc{10083}{postscript}{\ding{"A3}}%
\uc@dclc{10084}{postscript}{\ding{"A4}}%
\uc@dclc{10085}{postscript}{\ding{"A5}}%
\uc@dclc{10086}{postscript}{\ding{"A6}}%
\uc@dclc{10087}{postscript}{\ding{"A7}}%
\uc@dclc{10102}{postscript}{\ding{"B6}}%
\uc@dclc{10103}{postscript}{\ding{"B7}}%
\uc@dclc{10104}{postscript}{\ding{"B8}}%
\uc@dclc{10105}{postscript}{\ding{"B9}}%
\uc@dclc{10106}{postscript}{\ding{"BA}}%
\uc@dclc{10107}{postscript}{\ding{"BB}}%
\uc@dclc{10108}{postscript}{\ding{"BC}}%
\uc@dclc{10109}{postscript}{\ding{"BD}}%
\uc@dclc{10110}{postscript}{\ding{"BE}}%
\uc@dclc{10111}{postscript}{\ding{"BF}}%
\uc@dclc{10112}{postscript}{\ding{"C0}}%
\uc@dclc{10113}{postscript}{\ding{"C1}}%
\uc@dclc{10114}{postscript}{\ding{"C2}}%
\uc@dclc{10115}{postscript}{\ding{"C3}}%
\uc@dclc{10116}{postscript}{\ding{"C4}}%
\uc@dclc{10117}{postscript}{\ding{"C5}}%
\uc@dclc{10118}{postscript}{\ding{"C6}}%
\uc@dclc{10119}{postscript}{\ding{"C7}}%
\uc@dclc{10120}{postscript}{\ding{"C8}}%
\uc@dclc{10121}{postscript}{\ding{"C9}}%
\uc@dclc{10122}{postscript}{\ding{"CA}}%
\uc@dclc{10123}{postscript}{\ding{"CB}}%
\uc@dclc{10124}{postscript}{\ding{"CC}}%
\uc@dclc{10125}{postscript}{\ding{"CD}}%
\uc@dclc{10126}{postscript}{\ding{"CE}}%
\uc@dclc{10127}{postscript}{\ding{"CF}}%
\uc@dclc{10128}{postscript}{\ding{"D0}}%
\uc@dclc{10129}{postscript}{\ding{"D1}}%
\uc@dclc{10130}{postscript}{\ding{"D2}}%
\uc@dclc{10131}{postscript}{\ding{"D3}}%
\uc@dclc{10132}{postscript}{\ding{"D4}}%
\uc@dclc{10136}{postscript}{\ding{"D8}}%
\uc@dclc{10137}{postscript}{\ding{"D9}}%
\uc@dclc{10138}{postscript}{\ding{"DA}}%
\uc@dclc{10139}{postscript}{\ding{"DB}}%
\uc@dclc{10140}{postscript}{\ding{"DC}}%
\uc@dclc{10141}{postscript}{\ding{"DD}}%
\uc@dclc{10142}{postscript}{\ding{"DE}}%
\uc@dclc{10143}{postscript}{\ding{"DF}}%
\uc@dclc{10144}{postscript}{\ding{"E0}}%
\uc@dclc{10145}{postscript}{\ding{"E1}}%
\uc@dclc{10146}{postscript}{\ding{"E2}}%
\uc@dclc{10147}{postscript}{\ding{"E3}}%
\uc@dclc{10148}{postscript}{\ding{"E4}}%
\uc@dclc{10149}{postscript}{\ding{"E5}}%
\uc@dclc{10150}{postscript}{\ding{"E6}}%
\uc@dclc{10151}{postscript}{\ding{"E7}}%
\uc@dclc{10152}{postscript}{\ding{"E8}}%
\uc@dclc{10153}{postscript}{\ding{"E9}}%
\uc@dclc{10154}{postscript}{\ding{"EA}}%
\uc@dclc{10155}{postscript}{\ding{"EB}}%
\uc@dclc{10156}{postscript}{\ding{"EC}}%
\uc@dclc{10157}{postscript}{\ding{"ED}}%
\uc@dclc{10158}{postscript}{\ding{"EE}}%
\uc@dclc{10159}{postscript}{\ding{"EF}}%
\uc@dclc{10161}{postscript}{\ding{"F1}}%
\uc@dclc{10162}{postscript}{\ding{"F2}}%
\uc@dclc{10163}{postscript}{\ding{"F3}}%
\uc@dclc{10164}{postscript}{\ding{"F4}}%
\uc@dclc{10165}{postscript}{\ding{"F5}}%
\uc@dclc{10166}{postscript}{\ding{"F6}}%
\uc@dclc{10167}{postscript}{\ding{"F7}}%
\uc@dclc{10168}{postscript}{\ding{"F8}}%
\uc@dclc{10169}{postscript}{\ding{"F9}}%
\uc@dclc{10170}{postscript}{\ding{"FA}}%
\uc@dclc{10171}{postscript}{\ding{"FB}}%
\uc@dclc{10172}{postscript}{\ding{"FC}}%
\uc@dclc{10173}{postscript}{\ding{"FD}}%
\uc@dclc{10174}{postscript}{\ding{"FE}}%
\uc@dclc{10214}{default}{\ensuremath{\llbracket}}%
\uc@dclc{10215}{default}{\ensuremath{\rrbracket}}%
\uc@dclc{10216}{default}{\ensuremath{\langle}}%
\uc@dclc{10217}{default}{\ensuremath{\rangle}}%
\uc@dclc{10229}{default}{\ensuremath{\longleftarrow}}%
\uc@dclc{10230}{default}{\ensuremath{\longrightarrow}}%
\uc@dclc{10231}{default}{\ensuremath{\longleftrightarrow}}%
\uc@dclc{10232}{default}{\ensuremath{\Longleftarrow}}%
\uc@dclc{10233}{default}{\ensuremath{\Longrightarrow}}%
\uc@dclc{10234}{default}{\ensuremath{\Longleftrightarrow}}%
\uc@dclc{10236}{default}{\ensuremath{\longmapsto}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
