%%
%% This is file `ltwenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ucs.dtx  (with options: `ltwenc.def')
%% 
%% Copyright 2001 Dominique Unruh  <unruh@ut.ee>
%% Copyright 2013 Wolfgang Jeltsch <wolfgang@cs.ioc.ee>
%% 
%% This program is provided under the terms of the LaTeX Project Public License with some
%% modifications. See the file LICENSE for information.
%% 
\ProvidesFile{ltwenc.def}[2001/10/17 Fontencoding LTW for Tengwar]
\DeclareFontEncoding{LTW}{}{}
\DeclareFontSubstitution{LTW}{dsque}{m}{n}
\DeclareTextSymbol{\tengwarTinco}{LTW}{"00}
\DeclareTextSymbol{\tengwarParma}{LTW}{"01}
\DeclareTextSymbol{\tengwarCalma}{LTW}{"02}
\DeclareTextSymbol{\tengwarQuesse}{LTW}{"03}
\DeclareTextSymbol{\tengwarAndo}{LTW}{"04}
\DeclareTextSymbol{\tengwarUmbar}{LTW}{"05}
\DeclareTextSymbol{\tengwarAnga}{LTW}{"06}
\DeclareTextSymbol{\tengwarUngwe}{LTW}{"07}
\DeclareTextSymbol{\tengwarThuule}{LTW}{"08}
\DeclareTextSymbol{\tengwarFormen}{LTW}{"09}
\DeclareTextSymbol{\tengwarHarma}{LTW}{"0A}
\DeclareTextSymbol{\tengwarHwesta}{LTW}{"0B}
\DeclareTextSymbol{\tengwarAnto}{LTW}{"0C}
\DeclareTextSymbol{\tengwarAmpa}{LTW}{"0D}
\DeclareTextSymbol{\tengwarAnca}{LTW}{"0E}
\DeclareTextSymbol{\tengwarUnque}{LTW}{"0F}
\DeclareTextSymbol{\tengwarNuumen}{LTW}{"10}
\DeclareTextSymbol{\tengwarMalta}{LTW}{"11}
\DeclareTextSymbol{\tengwarNoldo}{LTW}{"12}
\DeclareTextSymbol{\tengwarNwalme}{LTW}{"13}
\DeclareTextSymbol{\tengwarOore}{LTW}{"14}
\DeclareTextSymbol{\tengwarVala}{LTW}{"15}
\DeclareTextSymbol{\tengwarAnna}{LTW}{"16}
\DeclareTextSymbol{\tengwarVilya}{LTW}{"17}
\DeclareTextSymbol{\tengwarRoomen}{LTW}{"18}
\DeclareTextSymbol{\tengwarArda}{LTW}{"19}
\DeclareTextSymbol{\tengwarLambe}{LTW}{"1A}
\DeclareTextSymbol{\tengwarAlda}{LTW}{"1B}
\DeclareTextSymbol{\tengwarSilme}{LTW}{"1C}
\DeclareTextSymbol{\tengwarSilmeNuquerna}{LTW}{"1D}
\DeclareTextSymbol{\tengwarAare}{LTW}{"1E}
\DeclareTextSymbol{\tengwarAareNuquerna}{LTW}{"1F}
\DeclareTextSymbol{\tengwarHyarmen}{LTW}{"20}
\DeclareTextSymbol{\tengwarHwestaSindarinwa}{LTW}{"21}
\DeclareTextSymbol{\tengwarYanta}{LTW}{"22}
\DeclareTextSymbol{\tengwarUure}{LTW}{"23}
\DeclareTextSymbol{\tengwarHalla}{LTW}{"24}
\DeclareTextSymbol{\tengwarShortCarrier}{LTW}{"25}
\DeclareTextSymbol{\tengwarLongCarrier}{LTW}{"26}
\DeclareTextSymbol{\tengwarAnnaSindarinwa}{LTW}{"27}
\DeclareTextSymbol{\tengwarExtThuule}{LTW}{"28}
\DeclareTextSymbol{\tengwarExtFormen}{LTW}{"29}
\DeclareTextSymbol{\tengwarExtHarma}{LTW}{"2A}
\DeclareTextSymbol{\tengwarExtHwesta}{LTW}{"2B}
\DeclareTextSymbol{\tengwarExtAnto}{LTW}{"2C}
\DeclareTextSymbol{\tengwarExtAmpa}{LTW}{"2D}
\DeclareTextSymbol{\tengwarExtAnca}{LTW}{"2E}
\DeclareTextSymbol{\tengwarExtUnque}{LTW}{"2F}
\DeclareTextSymbol{\tengwarStemlessOore}{LTW}{"30}
\DeclareTextSymbol{\tengwarStemlessVala}{LTW}{"31}
\DeclareTextSymbol{\tengwarStemlessAnna}{LTW}{"32}
\DeclareTextSymbol{\tengwarStemlessVilya}{LTW}{"33}
\DeclareTextSymbol{\tengwarPusta}{LTW}{"50}
\DeclareTextSymbol{\tengwarDoublePusta}{LTW}{"51}
\DeclareTextSymbol{\tengwarExclam}{LTW}{"52}
\DeclareTextSymbol{\tengwarQuestion}{LTW}{"53}
\DeclareTextSymbol{\tengwarSection}{LTW}{"54}
\DeclareTextSymbol{\tengwarLongSection}{LTW}{"55}
\ProvideTextCommandDefault{\tengwarZero}{\tengwarStemlessOore}
\ProvideTextCommandDefault{\tengwarOne}{\tengwarStemlessVilya}
\DeclareTextSymbol{\tengwarTwo}{LTW}{"62}
\DeclareTextSymbol{\tengwarThree}{LTW}{"63}
\DeclareTextSymbol{\tengwarFour}{LTW}{"64}
\DeclareTextSymbol{\tengwarFive}{LTW}{"65}
\DeclareTextSymbol{\tengwarSix}{LTW}{"66}
\DeclareTextSymbol{\tengwarSeven}{LTW}{"67}
\DeclareTextSymbol{\tengwarEight}{LTW}{"68}
\DeclareTextSymbol{\tengwarNine}{LTW}{"69}
\DeclareTextSymbol{\tengwarTen}{LTW}{"6A}
\DeclareTextSymbol{\tengwarEleven}{LTW}{"6B}
\DeclareTextCommand{\tengwarThreeDotsAbove}{LTW}[1]{#1\char"40 }
\DeclareTextCommand{\tengwarThreeDotsBelow}{LTW}[1]{#1\char"41 }
\DeclareTextCommand{\tengwarTwoDotsAbove}{LTW}[1]{#1\char"42 }
\DeclareTextCommand{\tengwarTwoDotsBelow}{LTW}[1]{#1\char"43 }
\DeclareTextCommand{\tengwarAmaticse}{LTW}[1]{#1\char"44 }
\DeclareTextCommand{\tengwarNunticse}{LTW}[1]{#1\char"45 }
\DeclareTextCommand{\tengwarAcute}{LTW}[1]{#1\char"46 }
\DeclareTextCommand{\tengwarDoubleAcute}{LTW}[1]{#1\char"47 }
\DeclareTextCommand{\tengwarRightCurl}{LTW}[1]{#1\char"48 }
\DeclareTextCommand{\tengwarDoubleRightCurl}{LTW}[1]{#1\char"49 }
\DeclareTextCommand{\tengwarLeftCurl}{LTW}[1]{#1\char"4A }
\DeclareTextCommand{\tengwarDoubleLeftCurl}{LTW}[1]{#1\char"4B }
\DeclareTextCommand{\tengwarNasalizer}{LTW}[1]{#1\char"4C }
\DeclareTextCommand{\tengwarDoubler}{LTW}[1]{#1\char"4D }
\DeclareTextCommand{\tengwarTilde}{LTW}[1]{#1\char"4E }
\DeclareTextCommand{\tengwarBreve}{LTW}[1]{#1\char"4F }
\DeclareTextCommand{\tengwarLongCarrierBelow}{LTW}[1]{#1\char"56 }
\DeclareTextCommand{\tengwarDoubleAcuteBelow}{LTW}[1]{#1\char"57 }
\DeclareTextCommand{\tengwarRightCurlBelow}{LTW}[1]{#1\char"58 }
\DeclareTextCommand{\tengwarLeftCurlBelow}{LTW}[1]{#1\char"59 }

