%%% Unicode to TeX mapping, file uni-4.def, U+0400..U+04FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-4.def}[2013/05/13 UCS: Unicode data U+0400..U+04FF]%
\fi
\uc@dclc{1024}{default}{\@tabacckludge`\CYRE}%
\uc@dclc{1025}{default}{\CYRYO}%
\uc@dclc{1026}{default}{\CYRDJE}%
\uc@dclc{1027}{default}{\@tabacckludge'\CYRG}%
\uc@dclc{1028}{default}{\CYRIE}%
\uc@dclc{1029}{default}{\CYRDZE}%
\uc@dclc{1030}{default}{\CYRII}%
\uc@dclc{1031}{default}{\CYRYI}%
\uc@dclc{1032}{default}{\CYRJE}%
\uc@dclc{1033}{default}{\CYRLJE}%
\uc@dclc{1034}{default}{\CYRNJE}%
\uc@dclc{1035}{default}{\CYRTSHE}%
\uc@dclc{1036}{default}{\@tabacckludge'\CYRK}%
\uc@dclc{1037}{default}{\@tabacckludge`\CYRI}%
\uc@dclc{1038}{default}{\CYRUSHRT}%
\uc@dclc{1039}{default}{\CYRDZHE}%
\uc@dclc{1040}{default}{\CYRA}%
\uc@dclc{1041}{default}{\CYRB}%
\uc@dclc{1042}{default}{\CYRV}%
\uc@dclc{1043}{default}{\CYRG}%
\uc@dclc{1044}{default}{\CYRD}%
\uc@dclc{1045}{default}{\CYRE}%
\uc@dclc{1046}{default}{\CYRZH}%
\uc@dclc{1047}{default}{\CYRZ}%
\uc@dclc{1048}{default}{\CYRI}%
\uc@dclc{1049}{default}{\CYRISHRT}%
\uc@dclc{1050}{default}{\CYRK}%
\uc@dclc{1051}{default}{\CYRL}%
\uc@dclc{1052}{default}{\CYRM}%
\uc@dclc{1053}{default}{\CYRN}%
\uc@dclc{1054}{default}{\CYRO}%
\uc@dclc{1055}{default}{\CYRP}%
\uc@dclc{1056}{default}{\CYRR}%
\uc@dclc{1057}{default}{\CYRS}%
\uc@dclc{1058}{default}{\CYRT}%
\uc@dclc{1059}{default}{\CYRU}%
\uc@dclc{1060}{default}{\CYRF}%
\uc@dclc{1061}{default}{\CYRH}%
\uc@dclc{1062}{default}{\CYRC}%
\uc@dclc{1063}{default}{\CYRCH}%
\uc@dclc{1064}{default}{\CYRSH}%
\uc@dclc{1065}{default}{\CYRSHCH}%
\uc@dclc{1066}{default}{\CYRHRDSN}%
\uc@dclc{1067}{default}{\CYRERY}%
\uc@dclc{1068}{default}{\CYRSFTSN}%
\uc@dclc{1069}{default}{\CYREREV}%
\uc@dclc{1070}{default}{\CYRYU}%
\uc@dclc{1071}{default}{\CYRYA}%
\uc@dclc{1072}{default}{\cyra}%
\uc@dclc{1073}{default}{\cyrb}%
\uc@dclc{1074}{default}{\cyrv}%
\uc@dclc{1075}{default}{\cyrg}%
\uc@dclc{1076}{default}{\cyrd}%
\uc@dclc{1077}{default}{\cyre}%
\uc@dclc{1078}{default}{\cyrzh}%
\uc@dclc{1079}{default}{\cyrz}%
\uc@dclc{1080}{default}{\cyri}%
\uc@dclc{1081}{default}{\cyrishrt}%
\uc@dclc{1082}{default}{\cyrk}%
\uc@dclc{1083}{default}{\cyrl}%
\uc@dclc{1084}{default}{\cyrm}%
\uc@dclc{1085}{default}{\cyrn}%
\uc@dclc{1086}{default}{\cyro}%
\uc@dclc{1087}{default}{\cyrp}%
\uc@dclc{1088}{default}{\cyrr}%
\uc@dclc{1089}{default}{\cyrs}%
\uc@dclc{1090}{default}{\cyrt}%
\uc@dclc{1091}{default}{\cyru}%
\uc@dclc{1092}{default}{\cyrf}%
\uc@dclc{1093}{default}{\cyrh}%
\uc@dclc{1094}{default}{\cyrc}%
\uc@dclc{1095}{default}{\cyrch}%
\uc@dclc{1096}{default}{\cyrsh}%
\uc@dclc{1097}{default}{\cyrshch}%
\uc@dclc{1098}{default}{\cyrhrdsn}%
\uc@dclc{1099}{default}{\cyrery}%
\uc@dclc{1100}{default}{\cyrsftsn}%
\uc@dclc{1101}{default}{\cyrerev}%
\uc@dclc{1102}{default}{\cyryu}%
\uc@dclc{1103}{default}{\cyrya}%
\uc@dclc{1104}{default}{\@tabacckludge`\cyre}%
\uc@dclc{1105}{default}{\cyryo}%
\uc@dclc{1106}{default}{\cyrdje}%
\uc@dclc{1107}{default}{\@tabacckludge'\cyrg}%
\uc@dclc{1108}{default}{\cyrie}%
\uc@dclc{1109}{default}{\cyrdze}%
\uc@dclc{1110}{default}{\cyrii}%
\uc@dclc{1111}{default}{\cyryi}%
\uc@dclc{1112}{default}{\cyrje}%
\uc@dclc{1113}{default}{\cyrlje}%
\uc@dclc{1114}{default}{\cyrnje}%
\uc@dclc{1115}{default}{\cyrtshe}%
\uc@dclc{1116}{default}{\@tabacckludge'\cyrk}%
\uc@dclc{1117}{default}{\@tabacckludge`\cyri}%
\uc@dclc{1118}{default}{\cyrushrt}%
\uc@dclc{1119}{default}{\cyrdzhe}%
\uc@dclc{1120}{default}{\CYROMGA}%
\uc@dclc{1121}{default}{\cyromga}%
\uc@dclc{1122}{default}{\CYRYAT}%
\uc@dclc{1123}{default}{\cyryat}%
\uc@dclc{1124}{default}{\CYRIOTEST}%
\uc@dclc{1125}{default}{\cyriotest}%
\uc@dclc{1126}{default}{\CYRLYUS}%
\uc@dclc{1127}{default}{\cyrlyus}%
\uc@dclc{1128}{default}{\CYRIOTLYUS}%
\uc@dclc{1129}{default}{\cyriotlyus}%
\uc@dclc{1130}{default}{\CYRBYUS}%
\uc@dclc{1131}{default}{\cyrbyus}%
\uc@dclc{1132}{default}{\CYRIOTBYUS}%
\uc@dclc{1133}{default}{\cyriotbyus}%
\uc@dclc{1134}{default}{\CYRKSI}%
\uc@dclc{1135}{default}{\cyrksi}%
\uc@dclc{1136}{default}{\CYRPSI}%
\uc@dclc{1137}{default}{\cyrpsi}%
\uc@dclc{1138}{default}{\CYRFITA}%
\uc@dclc{1139}{default}{\cyrfita}%
\uc@dclc{1140}{default}{\CYRIZH}%
\uc@dclc{1141}{default}{\cyrizh}%
\uc@dclc{1142}{default}{\C\CYRIZH}%
\uc@dclc{1143}{default}{\C\cyrizh}%
\uc@dclc{1144}{default}{\CYRVARUK}%
\uc@dclc{1145}{default}{\cyrvaruk}%
\uc@dclc{1146}{default}{\CYROMRND}%
\uc@dclc{1147}{default}{\cyromrnd}%
\uc@dclc{1148}{default}{\CYROMTLO}%
\uc@dclc{1149}{default}{\cyromtlo}%
\uc@dclc{1150}{default}{\CYROT}%
\uc@dclc{1151}{default}{\cyrot}%
\uc@dclc{1152}{default}{\CYRKOPPA}%
\uc@dclc{1153}{default}{\cyrkoppa}%
\uc@dclc{1154}{default}{\CYRthousands{\empty}}%
\uc@dclc{1155}{default}{\uc@cmb\CYRtitlo{#1}}%
\uc@dclc{1156}{default}{\uc@cmb\CYRpalatal{#1}}%
\uc@dclc{1157}{default}{\uc@cmb\CYRdasia{#1}}%
\uc@dclc{1158}{default}{\uc@cmb\CYRpsili{#1}}%
\uc@dclc{1160}{default}{\uc@cmb\CYRlegion{#1}}%
\uc@dclc{1161}{default}{\uc@cmb\CYRleodr{#1}}%
\uc@dclc{1164}{default}{\CYRSEMISFTSN}%
\uc@dclc{1165}{default}{\cyrsemisftsn}%
\uc@dclc{1166}{default}{\CYRRTICK}%
\uc@dclc{1167}{default}{\cyrrtick}%
\uc@dclc{1168}{default}{\CYRGUP}%
\uc@dclc{1169}{default}{\cyrgup}%
\uc@dclc{1170}{default}{\CYRGHCRS}%
\uc@dclc{1171}{default}{\cyrghcrs}%
\uc@dclc{1172}{default}{\CYRGHK}%
\uc@dclc{1173}{default}{\cyrghk}%
\uc@dclc{1174}{default}{\CYRZHDSC}%
\uc@dclc{1175}{default}{\cyrzhdsc}%
\uc@dclc{1176}{default}{\CYRZDSC}%
\uc@dclc{1177}{default}{\cyrzdsc}%
\uc@dclc{1178}{default}{\CYRKDSC}%
\uc@dclc{1179}{default}{\cyrkdsc}%
\uc@dclc{1180}{default}{\CYRKVCRS}%
\uc@dclc{1181}{default}{\cyrkvcrs}%
\uc@dclc{1182}{default}{\CYRKHCRS}%
\uc@dclc{1183}{default}{\cyrkhcrs}%
\uc@dclc{1184}{default}{\CYRKBEAK}%
\uc@dclc{1185}{default}{\cyrkbeak}%
\uc@dclc{1186}{default}{\CYRNDSC}%
\uc@dclc{1187}{default}{\cyrndsc}%
\uc@dclc{1188}{default}{\CYRNG}%
\uc@dclc{1189}{default}{\cyrng}%
\uc@dclc{1190}{default}{\CYRPHK}%
\uc@dclc{1191}{default}{\cyrphk}%
\uc@dclc{1192}{default}{\CYRABHHA}%
\uc@dclc{1193}{default}{\cyrabhha}%
\uc@dclc{1194}{default}{\CYRSDSC}%
\uc@dclc{1195}{default}{\cyrsdsc}%
\uc@dclc{1196}{default}{\CYRTDSC}%
\uc@dclc{1197}{default}{\cyrtdsc}%
\uc@dclc{1198}{default}{\CYRY}%
\uc@dclc{1199}{default}{\cyry}%
\uc@dclc{1200}{default}{\CYRYHCRS}%
\uc@dclc{1201}{default}{\cyryhcrs}%
\uc@dclc{1202}{default}{\CYRHDSC}%
\uc@dclc{1203}{default}{\cyrhdsc}%
\uc@dclc{1204}{default}{\CYRTETSE}%
\uc@dclc{1205}{default}{\cyrtetse}%
\uc@dclc{1206}{default}{\CYRCHRDSC}%
\uc@dclc{1207}{default}{\cyrchrdsc}%
\uc@dclc{1208}{default}{\CYRCHVCRS}%
\uc@dclc{1209}{default}{\cyrchvcrs}%
\uc@dclc{1210}{default}{\CYRSHHA}%
\uc@dclc{1211}{default}{\cyrshha}%
\uc@dclc{1212}{default}{\CYRABHCH}%
\uc@dclc{1213}{default}{\cyrabhch}%
\uc@dclc{1214}{default}{\CYRABHCHDSC}%
\uc@dclc{1215}{default}{\cyrabhchdsc}%
\uc@dclc{1216}{default}{\CYRpalochka}%
\uc@dclc{1217}{default}{\U\CYRZH}%
\uc@dclc{1218}{default}{\U\cyrzh}%
\uc@dclc{1219}{default}{\CYRKHK}%
\uc@dclc{1220}{default}{\cyrkhk}%
\uc@dclc{1223}{default}{\CYRNHK}%
\uc@dclc{1224}{default}{\cyrnhk}%
\uc@dclc{1227}{default}{\CYRCHLDSC}%
\uc@dclc{1228}{default}{\cyrchldsc}%
\uc@dclc{1232}{default}{\U\CYRA}%
\uc@dclc{1233}{default}{\U\cyra}%
\uc@dclc{1234}{default}{\"\CYRA}%
\uc@dclc{1235}{default}{\"\cyra}%
\uc@dclc{1236}{default}{\CYRAE}%
\uc@dclc{1237}{default}{\cyrae}%
\uc@dclc{1238}{default}{\U\CYRE}%
\uc@dclc{1239}{default}{\U\cyre}%
\uc@dclc{1240}{default}{\CYRSCHWA}%
\uc@dclc{1241}{default}{\cyrschwa}%
\uc@dclc{1242}{default}{\"\CYRSCHWA}%
\uc@dclc{1243}{default}{\"\cyrschwa}%
\uc@dclc{1244}{default}{\"\CYRZH}%
\uc@dclc{1245}{default}{\"\cyrzh}%
\uc@dclc{1246}{default}{\"\CYRZ}%
\uc@dclc{1247}{default}{\"\cyrz}%
\uc@dclc{1248}{default}{\CYRABHDZE}%
\uc@dclc{1249}{default}{\cyrabhdze}%
\uc@dclc{1250}{default}{\@tabacckludge=\CYRI}%
\uc@dclc{1251}{default}{\@tabacckludge=\cyri}%
\uc@dclc{1252}{default}{\"\CYRI}%
\uc@dclc{1253}{default}{\"\cyri}%
\uc@dclc{1254}{default}{\"\CYRO}%
\uc@dclc{1255}{default}{\"\cyro}%
\uc@dclc{1256}{default}{\CYROTLD}%
\uc@dclc{1257}{default}{\cyrotld}%
\uc@dclc{1258}{default}{\"\CYROTLD}%
\uc@dclc{1259}{default}{\"\cyrotld}%
\uc@dclc{1260}{default}{\"\CYREREV}%
\uc@dclc{1261}{default}{\"\cyrerev}%
\uc@dclc{1262}{default}{\@tabacckludge=\CYRU}%
\uc@dclc{1263}{default}{\@tabacckludge=\cyru}%
\uc@dclc{1264}{default}{\"\CYRU}%
\uc@dclc{1265}{default}{\"\cyru}%
\uc@dclc{1266}{default}{\H\CYRU}%
\uc@dclc{1267}{default}{\H\cyru}%
\uc@dclc{1268}{default}{\"\CYRCH}%
\uc@dclc{1269}{default}{\"\cyrch}%
\uc@dclc{1272}{default}{\"\CYRERY}%
\uc@dclc{1273}{default}{\"\cyrery}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
