%%% Unicode to TeX mapping, file uni-32.def, U+2000..U+20FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-32.def}[2013/05/13 UCS: Unicode data U+2000..U+20FF]%
\fi
\uc@dclc{8192}{default}{\enskip}%
\gdef\uc@controlbox#1{{\fboxsep=1pt\fbox{\tabcolsep=0pt\ttfamily\tiny\begin{tabular}{c}#1\end{tabular}}}}%
\uc@dclc{8192}{ctrlglyphs}{\uc@controlbox{NQ\\SP}}%
\uc@dclc{8193}{default}{\quad}%
\uc@dclc{8193}{ctrlglyphs}{\uc@controlbox{MQ\\SP}}%
\uc@dclc{8194}{default}{\enskip}%
\uc@dclc{8194}{ctrlglyphs}{\uc@controlbox{EN\\SP}}%
\uc@dclc{8195}{default}{\quad}%
\uc@dclc{8195}{ctrlglyphs}{\uc@controlbox{EM\\SP}}%
\uc@dclc{8196}{default}{\kern.33333em\uc@spc}%
\uc@dclc{8196}{ctrlglyphs}{\uc@controlbox{3/M\\SP}}%
\uc@dclc{8197}{default}{\kern.25em\uc@spc}%
\uc@dclc{8197}{ctrlglyphs}{\uc@controlbox{4/M\\SP}}%
\uc@dclc{8198}{default}{\kern.16667em\uc@spc}%
\uc@dclc{8198}{ctrlglyphs}{\uc@controlbox{6/M\\SP}}%
\uc@dclc{8199}{autogenerated}{\unichar{32}}%
\uc@dclc{8200}{autogenerated}{\unichar{32}}%
\uc@dclc{8201}{default}{\thinspace}%
\uc@dclc{8201}{ctrlglyphs}{\uc@controlbox{TH\\SP}}%
\uc@dclc{8202}{autogenerated}{\unichar{32}}%
\uc@dclc{8203}{default}{\hskip\z@\relax}%
\uc@dclc{8203}{ctrlglyphs}{\uc@controlbox{ZW\\SP}}%
\uc@dclc{8204}{default}{{}}%
\uc@dclc{8204}{ctrlglyphs}{\uc@controlbox{ZW\\NJ}}%
\uc@dclc{8205}{default}{}%
\gdef\uc@lrmark{%
  \PackageWarning{ucs}{This text contains LRM/RLM/LRE/RLE
    characters.\MessageBreak Note that these are ignored because of
    incomplete\MessageBreak right-to-left capability. Try using
    LRO/RLO/PDF\MessageBreak characters instead to ensure correct
    order.\MessageBreak}%
  \gdef\uc@lrmark{}}%
\uc@dclc{8206}{default}{\uc@lrmark}%
\uc@dclc{8206}{ctrlglyphs}{\uc@controlbox{LRM}}%
\uc@dclc{8207}{default}{\uc@lrmark}%
\uc@dclc{8207}{ctrlglyphs}{\uc@controlbox{RLM}}%
\uc@dclc{8209}{default}{\nobreakdash-}%
\uc@dclc{8211}{default}{\textendash}%
\uc@dclc{8212}{default}{\textemdash}%
\uc@dclc{8216}{default}{\textquoteleft}%
\uc@dclc{8217}{default}{\textquoteright}%
\uc@dclc{8218}{default}{\quotesinglbase}%
\uc@dclc{8220}{default}{\textquotedblleft}%
\uc@dclc{8221}{default}{\textquotedblright}%
\uc@dclc{8222}{default}{\quotedblbase}%
\uc@dclc{8224}{default}{\dag}%
\uc@dclc{8225}{default}{\ddag}%
\uc@dclc{8226}{postscript}{\Pisymbol{psy}{"B7}}%
\uc@dclc{8226}{default}{\textbullet}%
\uc@dclc{8228}{autogenerated}{\unichar{46}}%
\uc@dclc{8229}{autogenerated}{\unichar{46}\unichar{46}}%
\uc@dclc{8230}{default}{\dots}%
\uc@dclc{8230}{postscript}{\Pisymbol{psy}{"BC}}%
\uc@dclc{8232}{default}{\leavevmode\newline}%
\uc@dclc{8232}{ctrlglyphs}{\uc@controlbox{L\\SEP}}%
\long\gdef\uc@par{\par}%
\uc@dclc{8233}{default}{\uc@par}%
\uc@dclc{8233}{ctrlglyphs}{\uc@controlbox{P\\SEP}}%
\uc@dclc{8234}{default}{\uc@lrmark}%
\uc@dclc{8234}{ctrlglyphs}{\uc@controlbox{LRE}}%
\uc@dclc{8235}{default}{\uc@lrmark}%
\uc@dclc{8235}{ctrlglyphs}{\uc@controlbox{RLE}}%
\gdef\uc@pdfstack{}%
\gdef\uc@rlengine{%
  \ifx\beginL\undefined
    \PackageError{ucs}{Need right-to-left
      engine}{Please use e.g. elatex instead of latex}%
    \let\beginL\relax\let\beginR\relax
    \let\endL\relax\let\endR\relax\else
    \ifnum\TeXXeTstate=0
      \PackageWarning{ucs}{Setting \protect\TeXXeTstate=1}%
      \TeXXeTstate=1\fi\fi
  \let\uc@pdfstack\empty
  \let\uc@rlengine\empty}%
\gdef\uc@pdf@#1#2\@nil{%
  #1\def\uc@pdfstack{#2}}%
\gdef\uc@pdferror{\PackageError{ucs}{PDF occurred without matching
    LRO/RLO}{Nest LRO/RLO and PDF properly with respect to
    TeX-groups}}%
\uc@dclc{8236}{default}{\ifx\uc@pdfstack\empty\uc@pdferror\else\expandafter\uc@pdf@\uc@pdfstack\@nil\fi}%
\uc@dclc{8236}{ctrlglyphs}{\uc@controlbox{PDF}}%
\uc@dclc{8237}{default}{\uc@rlengine\beginL\edef\uc@pdfstack{\endL\uc@pdfstack}}%
\uc@dclc{8237}{ctrlglyphs}{\uc@controlbox{LRO}}%
\uc@dclc{8238}{default}{\uc@rlengine\beginR\edef\uc@pdfstack{\endR\uc@pdfstack}}%
\uc@dclc{8238}{ctrlglyphs}{\uc@controlbox{RLO}}%
\uc@dclc{8239}{autogenerated}{\unichar{32}}%
\uc@dclc{8240}{default}{\textperthousand}%
\uc@dclc{8241}{default}{\textpertenthousand}%
\uc@dclc{8242}{default}{\ensuremath{^\prime}}%
\uc@dclc{8242}{postscript}{\Pisymbol{psy}{"A2}}%
\uc@dclc{8243}{default}{\ensuremath{^{\prime\prime}}}%
\uc@dclc{8243}{postscript}{\Pisymbol{psy}{"B2}}%
\uc@dclc{8244}{default}{\ensuremath{^{\prime\prime\prime}}}%
\uc@dclc{8249}{default}{\guilsinglleft}%
\uc@dclc{8250}{default}{\guilsinglright}%
\uc@dclc{8251}{default}{\textreferencemark}%
\uc@dclc{8252}{autogenerated}{\unichar{33}\unichar{33}}%
\uc@dclc{8253}{default}{\textinterrobang}%
\uc@dclc{8254}{postscript}{\Pisymbol{psy}{"60}}%
\uc@dclc{8260}{postscript}{\Pisymbol{psy}{"A4}}%
\uc@dclc{8263}{autogenerated}{\unichar{63}\unichar{63}}%
\uc@dclc{8264}{autogenerated}{\unichar{63}\unichar{33}}%
\uc@dclc{8265}{autogenerated}{\unichar{33}\unichar{63}}%
\uc@dclc{8279}{autogenerated}{\unichar{8242}\unichar{8242}\unichar{8242}\unichar{8242}}%
\uc@dclc{8287}{autogenerated}{\unichar{32}}%
\uc@dclc{8304}{mathletters}{\ensuremath{^0}}%
\uc@dclc{8304}{default}{\textsuperscript0}%
\uc@dclc{8305}{mathletters}{\ensuremath{^i}}%
\uc@dclc{8305}{default}{\textsuperscript i}%
\uc@dclc{8308}{mathletters}{\ensuremath{^4}}%
\uc@dclc{8308}{default}{\textsuperscript4}%
\uc@dclc{8309}{mathletters}{\ensuremath{^5}}%
\uc@dclc{8309}{default}{\textsuperscript5}%
\uc@dclc{8310}{mathletters}{\ensuremath{^6}}%
\uc@dclc{8310}{default}{\textsuperscript6}%
\uc@dclc{8311}{mathletters}{\ensuremath{^7}}%
\uc@dclc{8311}{default}{\textsuperscript7}%
\uc@dclc{8312}{mathletters}{\ensuremath{^8}}%
\uc@dclc{8312}{default}{\textsuperscript8}%
\uc@dclc{8313}{mathletters}{\ensuremath{^9}}%
\uc@dclc{8313}{default}{\textsuperscript9}%
\uc@dclc{8314}{mathletters}{\ensuremath{^+}}%
\uc@dclc{8314}{default}{\textsuperscript+}%
\uc@dclc{8315}{mathletters}{\ensuremath{^-}}%
\uc@dclc{8315}{default}{\textsuperscript-}%
\uc@dclc{8316}{mathletters}{\ensuremath{^=}}%
\uc@dclc{8316}{default}{\textsuperscript=}%
\uc@dclc{8317}{mathletters}{\ensuremath{^(}}%
\uc@dclc{8317}{default}{\textsuperscript(}%
\uc@dclc{8318}{mathletters}{\ensuremath{^)}}%
\uc@dclc{8318}{default}{\textsuperscript)}%
\uc@dclc{8319}{mathletters}{\ensuremath{^n}}%
\uc@dclc{8319}{default}{\textsuperscript n}%
\uc@dclc{8320}{default}{\ensuremath{_0}}%
\uc@dclc{8321}{default}{\ensuremath{_1}}%
\uc@dclc{8322}{default}{\ensuremath{_2}}%
\uc@dclc{8323}{default}{\ensuremath{_3}}%
\uc@dclc{8324}{default}{\ensuremath{_4}}%
\uc@dclc{8325}{default}{\ensuremath{_5}}%
\uc@dclc{8326}{default}{\ensuremath{_6}}%
\uc@dclc{8327}{default}{\ensuremath{_7}}%
\uc@dclc{8328}{default}{\ensuremath{_8}}%
\uc@dclc{8329}{default}{\ensuremath{_9}}%
\uc@dclc{8330}{default}{\ensuremath{_+}}%
\uc@dclc{8331}{default}{\ensuremath{_-}}%
\uc@dclc{8332}{default}{\ensuremath{_=}}%
\uc@dclc{8333}{default}{\ensuremath{_(}}%
\uc@dclc{8334}{default}{\ensuremath{_)}}%
\uc@dclc{8336}{autogenerated}{\unicodesub{\unichar{97}}}%
\uc@dclc{8337}{autogenerated}{\unicodesub{\unichar{101}}}%
\uc@dclc{8338}{autogenerated}{\unicodesub{\unichar{111}}}%
\uc@dclc{8339}{autogenerated}{\unicodesub{\unichar{120}}}%
\uc@dclc{8340}{autogenerated}{\unicodesub{\unichar{601}}}%
\uc@dclc{8341}{autogenerated}{\unicodesub{\unichar{104}}}%
\uc@dclc{8342}{autogenerated}{\unicodesub{\unichar{107}}}%
\uc@dclc{8343}{autogenerated}{\unicodesub{\unichar{108}}}%
\uc@dclc{8344}{autogenerated}{\unicodesub{\unichar{109}}}%
\uc@dclc{8345}{autogenerated}{\unicodesub{\unichar{110}}}%
\uc@dclc{8346}{autogenerated}{\unicodesub{\unichar{112}}}%
\uc@dclc{8347}{autogenerated}{\unicodesub{\unichar{115}}}%
\uc@dclc{8348}{autogenerated}{\unicodesub{\unichar{116}}}%
\uc@dclc{8353}{default}{\textcolonmonetary}%
\uc@dclc{8356}{default}{\textlira}%
\uc@dclc{8358}{default}{\textnaira}%
\uc@dclc{8360}{autogenerated}{\unichar{82}\unichar{115}}%
\uc@dclc{8361}{default}{\textwon}%
\uc@dclc{8363}{default}{\textdong}%
\uc@dclc{8364}{default}{\ifx\euro\undefined\texteuro\else\euro\fi}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
