%%% Unicode to TeX mapping, file uni-192.def, U+C000..U+C0FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-192.def}[2013/05/13 UCS: Unicode data U+C000..U+C0FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{49212}{cjkhangul}{\u@cjk@hangul10C3}%
\uc@dclc{49233}{cjkhangul}{\u@cjk@hangul10C4}%
\uc@dclc{49240}{cjkhangul}{\u@cjk@hangul10C5}%
\uc@dclc{49244}{cjkhangul}{\u@cjk@hangul10C6}%
\uc@dclc{49248}{cjkhangul}{\u@cjk@hangul10C7}%
\uc@dclc{49256}{cjkhangul}{\u@cjk@hangul10C8}%
\uc@dclc{49257}{cjkhangul}{\u@cjk@hangul10C9}%
\uc@dclc{49296}{cjkhangul}{\u@cjk@hangul10CA}%
\uc@dclc{49297}{cjkhangul}{\u@cjk@hangul10CB}%
\uc@dclc{49300}{cjkhangul}{\u@cjk@hangul10CC}%
\uc@dclc{49304}{cjkhangul}{\u@cjk@hangul10CD}%
\uc@dclc{49312}{cjkhangul}{\u@cjk@hangul10CE}%
\uc@dclc{49313}{cjkhangul}{\u@cjk@hangul10CF}%
\uc@dclc{49315}{cjkhangul}{\u@cjk@hangul10D0}%
\uc@dclc{49317}{cjkhangul}{\u@cjk@hangul10D1}%
\uc@dclc{49324}{cjkhangul}{\u@cjk@hangul10D2}%
\uc@dclc{49325}{cjkhangul}{\u@cjk@hangul10D3}%
\uc@dclc{49327}{cjkhangul}{\u@cjk@hangul10D4}%
\uc@dclc{49328}{cjkhangul}{\u@cjk@hangul10D5}%
\uc@dclc{49331}{cjkhangul}{\u@cjk@hangul10D6}%
\uc@dclc{49332}{cjkhangul}{\u@cjk@hangul10D7}%
\uc@dclc{49333}{cjkhangul}{\u@cjk@hangul10D8}%
\uc@dclc{49334}{cjkhangul}{\u@cjk@hangul10D9}%
\uc@dclc{49340}{cjkhangul}{\u@cjk@hangul10DA}%
\uc@dclc{49341}{cjkhangul}{\u@cjk@hangul10DB}%
\uc@dclc{49343}{cjkhangul}{\u@cjk@hangul10DC}%
\uc@dclc{49344}{cjkhangul}{\u@cjk@hangul10DD}%
\uc@dclc{49345}{cjkhangul}{\u@cjk@hangul10DE}%
\uc@dclc{49349}{cjkhangul}{\u@cjk@hangul10DF}%
\uc@dclc{49352}{cjkhangul}{\u@cjk@hangul10E0}%
\uc@dclc{49353}{cjkhangul}{\u@cjk@hangul10E1}%
\uc@dclc{49356}{cjkhangul}{\u@cjk@hangul10E2}%
\uc@dclc{49360}{cjkhangul}{\u@cjk@hangul10E3}%
\uc@dclc{49368}{cjkhangul}{\u@cjk@hangul10E4}%
\uc@dclc{49369}{cjkhangul}{\u@cjk@hangul10E5}%
\uc@dclc{49371}{cjkhangul}{\u@cjk@hangul10E6}%
\uc@dclc{49372}{cjkhangul}{\u@cjk@hangul10E7}%
\uc@dclc{49373}{cjkhangul}{\u@cjk@hangul10E8}%
\uc@dclc{49380}{cjkhangul}{\u@cjk@hangul10E9}%
\uc@dclc{49381}{cjkhangul}{\u@cjk@hangul10EA}%
\uc@dclc{49384}{cjkhangul}{\u@cjk@hangul10EB}%
\uc@dclc{49388}{cjkhangul}{\u@cjk@hangul10EC}%
\uc@dclc{49396}{cjkhangul}{\u@cjk@hangul10ED}%
\uc@dclc{49397}{cjkhangul}{\u@cjk@hangul10EE}%
\uc@dclc{49399}{cjkhangul}{\u@cjk@hangul10EF}%
\uc@dclc{49401}{cjkhangul}{\u@cjk@hangul10F0}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
