%%
%% This is file `letenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ucs.dtx  (with options: `letenc.def')
%% 
%% Copyright 2001 Dominique Unruh  <unruh@ut.ee>
%% Copyright 2013 Wolfgang Jeltsch <wolfgang@cs.ioc.ee>
%% 
%% This program is provided under the terms of the LaTeX Project Public License with some
%% modifications. See the file LICENSE for information.
%% 
\NeedsTeXFormat{LaTeX2e}[1998/12/01]
\ProvidesFile{letenc.def}[2004/10/17 Autogenerated encodings LET, Let]
\DeclareFontEncoding{LET}{}{}
\DeclareFontSubstitution{LET}{gfzem}{m}{n}
\DeclareFontEncoding{Let}{}{}
\DeclareFontSubstitution{Let}{gfzem}{m}{n}
\DeclareTextCommand{\textascii}{LET}[1]{\@textascii@switch{#1}}
\DeclareTextCommand{\textascii}{Let}[1]{\@textascii@switch{#1}}
\DeclareTextSymbol{\textethiopicha}{LET}{0}
\DeclareTextCommand{\textethiopicha}{Let}{\fontencoding{LET}\selectfont\textethiopicha}
\DeclareTextSymbol{\textethiopichu}{LET}{1}
\DeclareTextCommand{\textethiopichu}{Let}{\fontencoding{LET}\selectfont\textethiopichu}
\DeclareTextSymbol{\textethiopichi}{LET}{2}
\DeclareTextCommand{\textethiopichi}{Let}{\fontencoding{LET}\selectfont\textethiopichi}
\DeclareTextSymbol{\textethiopichaa}{LET}{3}
\DeclareTextCommand{\textethiopichaa}{Let}{\fontencoding{LET}\selectfont\textethiopichaa}
\DeclareTextSymbol{\textethiopichee}{LET}{4}
\DeclareTextCommand{\textethiopichee}{Let}{\fontencoding{LET}\selectfont\textethiopichee}
\DeclareTextSymbol{\textethiopiche}{LET}{5}
\DeclareTextCommand{\textethiopiche}{Let}{\fontencoding{LET}\selectfont\textethiopiche}
\DeclareTextSymbol{\textethiopicho}{LET}{6}
\DeclareTextCommand{\textethiopicho}{Let}{\fontencoding{LET}\selectfont\textethiopicho}
\DeclareTextSymbol{\textethiopicla}{LET}{8}
\DeclareTextCommand{\textethiopicla}{Let}{\fontencoding{LET}\selectfont\textethiopicla}
\DeclareTextSymbol{\textethiopiclu}{LET}{9}
\DeclareTextCommand{\textethiopiclu}{Let}{\fontencoding{LET}\selectfont\textethiopiclu}
\DeclareTextSymbol{\textethiopicli}{LET}{10}
\DeclareTextCommand{\textethiopicli}{Let}{\fontencoding{LET}\selectfont\textethiopicli}
\DeclareTextSymbol{\textethiopiclaa}{LET}{11}
\DeclareTextCommand{\textethiopiclaa}{Let}{\fontencoding{LET}\selectfont\textethiopiclaa}
\DeclareTextSymbol{\textethiopiclee}{LET}{12}
\DeclareTextCommand{\textethiopiclee}{Let}{\fontencoding{LET}\selectfont\textethiopiclee}
\DeclareTextSymbol{\textethiopicle}{LET}{13}
\DeclareTextCommand{\textethiopicle}{Let}{\fontencoding{LET}\selectfont\textethiopicle}
\DeclareTextSymbol{\textethiopiclo}{LET}{14}
\DeclareTextCommand{\textethiopiclo}{Let}{\fontencoding{LET}\selectfont\textethiopiclo}
\DeclareTextSymbol{\textethiopiclwa}{LET}{15}
\DeclareTextCommand{\textethiopiclwa}{Let}{\fontencoding{LET}\selectfont\textethiopiclwa}
\DeclareTextSymbol{\textethiopichha}{LET}{16}
\DeclareTextCommand{\textethiopichha}{Let}{\fontencoding{LET}\selectfont\textethiopichha}
\DeclareTextSymbol{\textethiopichhu}{LET}{17}
\DeclareTextCommand{\textethiopichhu}{Let}{\fontencoding{LET}\selectfont\textethiopichhu}
\DeclareTextSymbol{\textethiopichhi}{LET}{18}
\DeclareTextCommand{\textethiopichhi}{Let}{\fontencoding{LET}\selectfont\textethiopichhi}
\DeclareTextSymbol{\textethiopichhaa}{LET}{19}
\DeclareTextCommand{\textethiopichhaa}{Let}{\fontencoding{LET}\selectfont\textethiopichhaa}
\DeclareTextSymbol{\textethiopichhee}{LET}{20}
\DeclareTextCommand{\textethiopichhee}{Let}{\fontencoding{LET}\selectfont\textethiopichhee}
\DeclareTextSymbol{\textethiopichhe}{LET}{21}
\DeclareTextCommand{\textethiopichhe}{Let}{\fontencoding{LET}\selectfont\textethiopichhe}
\DeclareTextSymbol{\textethiopichho}{LET}{22}
\DeclareTextCommand{\textethiopichho}{Let}{\fontencoding{LET}\selectfont\textethiopichho}
\DeclareTextSymbol{\textethiopichhwa}{LET}{23}
\DeclareTextCommand{\textethiopichhwa}{Let}{\fontencoding{LET}\selectfont\textethiopichhwa}
\DeclareTextSymbol{\textethiopicma}{LET}{24}
\DeclareTextCommand{\textethiopicma}{Let}{\fontencoding{LET}\selectfont\textethiopicma}
\DeclareTextSymbol{\textethiopicmu}{LET}{25}
\DeclareTextCommand{\textethiopicmu}{Let}{\fontencoding{LET}\selectfont\textethiopicmu}
\DeclareTextSymbol{\textethiopicmi}{LET}{26}
\DeclareTextCommand{\textethiopicmi}{Let}{\fontencoding{LET}\selectfont\textethiopicmi}
\DeclareTextSymbol{\textethiopicmaa}{LET}{27}
\DeclareTextCommand{\textethiopicmaa}{Let}{\fontencoding{LET}\selectfont\textethiopicmaa}
\DeclareTextSymbol{\textethiopicmee}{LET}{28}
\DeclareTextCommand{\textethiopicmee}{Let}{\fontencoding{LET}\selectfont\textethiopicmee}
\DeclareTextSymbol{\textethiopicme}{LET}{29}
\DeclareTextCommand{\textethiopicme}{Let}{\fontencoding{LET}\selectfont\textethiopicme}
\DeclareTextSymbol{\textethiopicmo}{LET}{30}
\DeclareTextCommand{\textethiopicmo}{Let}{\fontencoding{LET}\selectfont\textethiopicmo}
\DeclareTextSymbol{\textethiopicmwa}{LET}{31}
\DeclareTextCommand{\textethiopicmwa}{Let}{\fontencoding{LET}\selectfont\textethiopicmwa}
\DeclareTextSymbol{\textethiopicsza}{LET}{32}
\DeclareTextCommand{\textethiopicsza}{Let}{\fontencoding{LET}\selectfont\textethiopicsza}
\DeclareTextSymbol{\textethiopicszu}{LET}{33}
\DeclareTextCommand{\textethiopicszu}{Let}{\fontencoding{LET}\selectfont\textethiopicszu}
\DeclareTextSymbol{\textethiopicszi}{LET}{34}
\DeclareTextCommand{\textethiopicszi}{Let}{\fontencoding{LET}\selectfont\textethiopicszi}
\DeclareTextSymbol{\textethiopicszaa}{LET}{35}
\DeclareTextCommand{\textethiopicszaa}{Let}{\fontencoding{LET}\selectfont\textethiopicszaa}
\DeclareTextSymbol{\textethiopicszee}{LET}{36}
\DeclareTextCommand{\textethiopicszee}{Let}{\fontencoding{LET}\selectfont\textethiopicszee}
\DeclareTextSymbol{\textethiopicsze}{LET}{37}
\DeclareTextCommand{\textethiopicsze}{Let}{\fontencoding{LET}\selectfont\textethiopicsze}
\DeclareTextSymbol{\textethiopicszo}{LET}{38}
\DeclareTextCommand{\textethiopicszo}{Let}{\fontencoding{LET}\selectfont\textethiopicszo}
\DeclareTextSymbol{\textethiopicszwa}{LET}{39}
\DeclareTextCommand{\textethiopicszwa}{Let}{\fontencoding{LET}\selectfont\textethiopicszwa}
\DeclareTextSymbol{\textethiopicra}{LET}{40}
\DeclareTextCommand{\textethiopicra}{Let}{\fontencoding{LET}\selectfont\textethiopicra}
\DeclareTextSymbol{\textethiopicru}{LET}{41}
\DeclareTextCommand{\textethiopicru}{Let}{\fontencoding{LET}\selectfont\textethiopicru}
\DeclareTextSymbol{\textethiopicri}{LET}{42}
\DeclareTextCommand{\textethiopicri}{Let}{\fontencoding{LET}\selectfont\textethiopicri}
\DeclareTextSymbol{\textethiopicraa}{LET}{43}
\DeclareTextCommand{\textethiopicraa}{Let}{\fontencoding{LET}\selectfont\textethiopicraa}
\DeclareTextSymbol{\textethiopicree}{LET}{44}
\DeclareTextCommand{\textethiopicree}{Let}{\fontencoding{LET}\selectfont\textethiopicree}
\DeclareTextSymbol{\textethiopicre}{LET}{45}
\DeclareTextCommand{\textethiopicre}{Let}{\fontencoding{LET}\selectfont\textethiopicre}
\DeclareTextSymbol{\textethiopicro}{LET}{46}
\DeclareTextCommand{\textethiopicro}{Let}{\fontencoding{LET}\selectfont\textethiopicro}
\DeclareTextSymbol{\textethiopicrwa}{LET}{47}
\DeclareTextCommand{\textethiopicrwa}{Let}{\fontencoding{LET}\selectfont\textethiopicrwa}
\DeclareTextSymbol{\textethiopicsa}{LET}{48}
\DeclareTextCommand{\textethiopicsa}{Let}{\fontencoding{LET}\selectfont\textethiopicsa}
\DeclareTextSymbol{\textethiopicsu}{LET}{49}
\DeclareTextCommand{\textethiopicsu}{Let}{\fontencoding{LET}\selectfont\textethiopicsu}
\DeclareTextSymbol{\textethiopicsi}{LET}{50}
\DeclareTextCommand{\textethiopicsi}{Let}{\fontencoding{LET}\selectfont\textethiopicsi}
\DeclareTextSymbol{\textethiopicsaa}{LET}{51}
\DeclareTextCommand{\textethiopicsaa}{Let}{\fontencoding{LET}\selectfont\textethiopicsaa}
\DeclareTextSymbol{\textethiopicsee}{LET}{52}
\DeclareTextCommand{\textethiopicsee}{Let}{\fontencoding{LET}\selectfont\textethiopicsee}
\DeclareTextSymbol{\textethiopicse}{LET}{53}
\DeclareTextCommand{\textethiopicse}{Let}{\fontencoding{LET}\selectfont\textethiopicse}
\DeclareTextSymbol{\textethiopicso}{LET}{54}
\DeclareTextCommand{\textethiopicso}{Let}{\fontencoding{LET}\selectfont\textethiopicso}
\DeclareTextSymbol{\textethiopicswa}{LET}{55}
\DeclareTextCommand{\textethiopicswa}{Let}{\fontencoding{LET}\selectfont\textethiopicswa}
\DeclareTextSymbol{\textethiopicsha}{LET}{56}
\DeclareTextCommand{\textethiopicsha}{Let}{\fontencoding{LET}\selectfont\textethiopicsha}
\DeclareTextSymbol{\textethiopicshu}{LET}{57}
\DeclareTextCommand{\textethiopicshu}{Let}{\fontencoding{LET}\selectfont\textethiopicshu}
\DeclareTextSymbol{\textethiopicshi}{LET}{58}
\DeclareTextCommand{\textethiopicshi}{Let}{\fontencoding{LET}\selectfont\textethiopicshi}
\DeclareTextSymbol{\textethiopicshaa}{LET}{59}
\DeclareTextCommand{\textethiopicshaa}{Let}{\fontencoding{LET}\selectfont\textethiopicshaa}
\DeclareTextSymbol{\textethiopicshee}{LET}{60}
\DeclareTextCommand{\textethiopicshee}{Let}{\fontencoding{LET}\selectfont\textethiopicshee}
\DeclareTextSymbol{\textethiopicshe}{LET}{61}
\DeclareTextCommand{\textethiopicshe}{Let}{\fontencoding{LET}\selectfont\textethiopicshe}
\DeclareTextSymbol{\textethiopicsho}{LET}{62}
\DeclareTextCommand{\textethiopicsho}{Let}{\fontencoding{LET}\selectfont\textethiopicsho}
\DeclareTextSymbol{\textethiopicshwa}{LET}{63}
\DeclareTextCommand{\textethiopicshwa}{Let}{\fontencoding{LET}\selectfont\textethiopicshwa}
\DeclareTextSymbol{\textethiopicqa}{LET}{64}
\DeclareTextCommand{\textethiopicqa}{Let}{\fontencoding{LET}\selectfont\textethiopicqa}
\DeclareTextSymbol{\textethiopicqu}{LET}{65}
\DeclareTextCommand{\textethiopicqu}{Let}{\fontencoding{LET}\selectfont\textethiopicqu}
\DeclareTextSymbol{\textethiopicqi}{LET}{66}
\DeclareTextCommand{\textethiopicqi}{Let}{\fontencoding{LET}\selectfont\textethiopicqi}
\DeclareTextSymbol{\textethiopicqaa}{LET}{67}
\DeclareTextCommand{\textethiopicqaa}{Let}{\fontencoding{LET}\selectfont\textethiopicqaa}
\DeclareTextSymbol{\textethiopicqee}{LET}{68}
\DeclareTextCommand{\textethiopicqee}{Let}{\fontencoding{LET}\selectfont\textethiopicqee}
\DeclareTextSymbol{\textethiopicqe}{LET}{69}
\DeclareTextCommand{\textethiopicqe}{Let}{\fontencoding{LET}\selectfont\textethiopicqe}
\DeclareTextSymbol{\textethiopicqo}{LET}{70}
\DeclareTextCommand{\textethiopicqo}{Let}{\fontencoding{LET}\selectfont\textethiopicqo}
\DeclareTextSymbol{\textethiopicqwa}{LET}{72}
\DeclareTextCommand{\textethiopicqwa}{Let}{\fontencoding{LET}\selectfont\textethiopicqwa}
\DeclareTextSymbol{\textethiopicqwi}{LET}{74}
\DeclareTextCommand{\textethiopicqwi}{Let}{\fontencoding{LET}\selectfont\textethiopicqwi}
\DeclareTextSymbol{\textethiopicqwaa}{LET}{75}
\DeclareTextCommand{\textethiopicqwaa}{Let}{\fontencoding{LET}\selectfont\textethiopicqwaa}
\DeclareTextSymbol{\textethiopicqwee}{LET}{76}
\DeclareTextCommand{\textethiopicqwee}{Let}{\fontencoding{LET}\selectfont\textethiopicqwee}
\DeclareTextSymbol{\textethiopicqwe}{LET}{77}
\DeclareTextCommand{\textethiopicqwe}{Let}{\fontencoding{LET}\selectfont\textethiopicqwe}
\DeclareTextSymbol{\textethiopicqha}{LET}{80}
\DeclareTextCommand{\textethiopicqha}{Let}{\fontencoding{LET}\selectfont\textethiopicqha}
\DeclareTextSymbol{\textethiopicqhu}{LET}{81}
\DeclareTextCommand{\textethiopicqhu}{Let}{\fontencoding{LET}\selectfont\textethiopicqhu}
\DeclareTextSymbol{\textethiopicqhi}{LET}{82}
\DeclareTextCommand{\textethiopicqhi}{Let}{\fontencoding{LET}\selectfont\textethiopicqhi}
\DeclareTextSymbol{\textethiopicqhaa}{LET}{83}
\DeclareTextCommand{\textethiopicqhaa}{Let}{\fontencoding{LET}\selectfont\textethiopicqhaa}
\DeclareTextSymbol{\textethiopicqhee}{LET}{84}
\DeclareTextCommand{\textethiopicqhee}{Let}{\fontencoding{LET}\selectfont\textethiopicqhee}
\DeclareTextSymbol{\textethiopicqhe}{LET}{85}
\DeclareTextCommand{\textethiopicqhe}{Let}{\fontencoding{LET}\selectfont\textethiopicqhe}
\DeclareTextSymbol{\textethiopicqho}{LET}{86}
\DeclareTextCommand{\textethiopicqho}{Let}{\fontencoding{LET}\selectfont\textethiopicqho}
\DeclareTextSymbol{\textethiopicqhwa}{LET}{88}
\DeclareTextCommand{\textethiopicqhwa}{Let}{\fontencoding{LET}\selectfont\textethiopicqhwa}
\DeclareTextSymbol{\textethiopicqhwi}{LET}{90}
\DeclareTextCommand{\textethiopicqhwi}{Let}{\fontencoding{LET}\selectfont\textethiopicqhwi}
\DeclareTextSymbol{\textethiopicqhwaa}{LET}{91}
\DeclareTextCommand{\textethiopicqhwaa}{Let}{\fontencoding{LET}\selectfont\textethiopicqhwaa}
\DeclareTextSymbol{\textethiopicqhwee}{LET}{92}
\DeclareTextCommand{\textethiopicqhwee}{Let}{\fontencoding{LET}\selectfont\textethiopicqhwee}
\DeclareTextSymbol{\textethiopicqhwe}{LET}{93}
\DeclareTextCommand{\textethiopicqhwe}{Let}{\fontencoding{LET}\selectfont\textethiopicqhwe}
\DeclareTextSymbol{\textethiopicba}{LET}{96}
\DeclareTextCommand{\textethiopicba}{Let}{\fontencoding{LET}\selectfont\textethiopicba}
\DeclareTextSymbol{\textethiopicbu}{LET}{97}
\DeclareTextCommand{\textethiopicbu}{Let}{\fontencoding{LET}\selectfont\textethiopicbu}
\DeclareTextSymbol{\textethiopicbi}{LET}{98}
\DeclareTextCommand{\textethiopicbi}{Let}{\fontencoding{LET}\selectfont\textethiopicbi}
\DeclareTextSymbol{\textethiopicbaa}{LET}{99}
\DeclareTextCommand{\textethiopicbaa}{Let}{\fontencoding{LET}\selectfont\textethiopicbaa}
\DeclareTextSymbol{\textethiopicbee}{LET}{100}
\DeclareTextCommand{\textethiopicbee}{Let}{\fontencoding{LET}\selectfont\textethiopicbee}
\DeclareTextSymbol{\textethiopicbe}{LET}{101}
\DeclareTextCommand{\textethiopicbe}{Let}{\fontencoding{LET}\selectfont\textethiopicbe}
\DeclareTextSymbol{\textethiopicbo}{LET}{102}
\DeclareTextCommand{\textethiopicbo}{Let}{\fontencoding{LET}\selectfont\textethiopicbo}
\DeclareTextSymbol{\textethiopicbwa}{LET}{103}
\DeclareTextCommand{\textethiopicbwa}{Let}{\fontencoding{LET}\selectfont\textethiopicbwa}
\DeclareTextSymbol{\textethiopicva}{LET}{104}
\DeclareTextCommand{\textethiopicva}{Let}{\fontencoding{LET}\selectfont\textethiopicva}
\DeclareTextSymbol{\textethiopicvu}{LET}{105}
\DeclareTextCommand{\textethiopicvu}{Let}{\fontencoding{LET}\selectfont\textethiopicvu}
\DeclareTextSymbol{\textethiopicvi}{LET}{106}
\DeclareTextCommand{\textethiopicvi}{Let}{\fontencoding{LET}\selectfont\textethiopicvi}
\DeclareTextSymbol{\textethiopicvaa}{LET}{107}
\DeclareTextCommand{\textethiopicvaa}{Let}{\fontencoding{LET}\selectfont\textethiopicvaa}
\DeclareTextSymbol{\textethiopicvee}{LET}{108}
\DeclareTextCommand{\textethiopicvee}{Let}{\fontencoding{LET}\selectfont\textethiopicvee}
\DeclareTextSymbol{\textethiopicve}{LET}{109}
\DeclareTextCommand{\textethiopicve}{Let}{\fontencoding{LET}\selectfont\textethiopicve}
\DeclareTextSymbol{\textethiopicvo}{LET}{110}
\DeclareTextCommand{\textethiopicvo}{Let}{\fontencoding{LET}\selectfont\textethiopicvo}
\DeclareTextSymbol{\textethiopicvwa}{LET}{111}
\DeclareTextCommand{\textethiopicvwa}{Let}{\fontencoding{LET}\selectfont\textethiopicvwa}
\DeclareTextSymbol{\textethiopicta}{LET}{112}
\DeclareTextCommand{\textethiopicta}{Let}{\fontencoding{LET}\selectfont\textethiopicta}
\DeclareTextSymbol{\textethiopictu}{LET}{113}
\DeclareTextCommand{\textethiopictu}{Let}{\fontencoding{LET}\selectfont\textethiopictu}
\DeclareTextSymbol{\textethiopicti}{LET}{114}
\DeclareTextCommand{\textethiopicti}{Let}{\fontencoding{LET}\selectfont\textethiopicti}
\DeclareTextSymbol{\textethiopictaa}{LET}{115}
\DeclareTextCommand{\textethiopictaa}{Let}{\fontencoding{LET}\selectfont\textethiopictaa}
\DeclareTextSymbol{\textethiopictee}{LET}{116}
\DeclareTextCommand{\textethiopictee}{Let}{\fontencoding{LET}\selectfont\textethiopictee}
\DeclareTextSymbol{\textethiopicte}{LET}{117}
\DeclareTextCommand{\textethiopicte}{Let}{\fontencoding{LET}\selectfont\textethiopicte}
\DeclareTextSymbol{\textethiopicto}{LET}{118}
\DeclareTextCommand{\textethiopicto}{Let}{\fontencoding{LET}\selectfont\textethiopicto}
\DeclareTextSymbol{\textethiopictwa}{LET}{119}
\DeclareTextCommand{\textethiopictwa}{Let}{\fontencoding{LET}\selectfont\textethiopictwa}
\DeclareTextSymbol{\textethiopicca}{LET}{120}
\DeclareTextCommand{\textethiopicca}{Let}{\fontencoding{LET}\selectfont\textethiopicca}
\DeclareTextSymbol{\textethiopiccu}{LET}{121}
\DeclareTextCommand{\textethiopiccu}{Let}{\fontencoding{LET}\selectfont\textethiopiccu}
\DeclareTextSymbol{\textethiopicci}{LET}{122}
\DeclareTextCommand{\textethiopicci}{Let}{\fontencoding{LET}\selectfont\textethiopicci}
\DeclareTextSymbol{\textethiopiccaa}{LET}{123}
\DeclareTextCommand{\textethiopiccaa}{Let}{\fontencoding{LET}\selectfont\textethiopiccaa}
\DeclareTextSymbol{\textethiopiccee}{LET}{124}
\DeclareTextCommand{\textethiopiccee}{Let}{\fontencoding{LET}\selectfont\textethiopiccee}
\DeclareTextSymbol{\textethiopicce}{LET}{125}
\DeclareTextCommand{\textethiopicce}{Let}{\fontencoding{LET}\selectfont\textethiopicce}
\DeclareTextSymbol{\textethiopicco}{LET}{126}
\DeclareTextCommand{\textethiopicco}{Let}{\fontencoding{LET}\selectfont\textethiopicco}
\DeclareTextSymbol{\textethiopiccwa}{LET}{127}
\DeclareTextCommand{\textethiopiccwa}{Let}{\fontencoding{LET}\selectfont\textethiopiccwa}
\DeclareTextSymbol{\textethiopicxa}{LET}{128}
\DeclareTextCommand{\textethiopicxa}{Let}{\fontencoding{LET}\selectfont\textethiopicxa}
\DeclareTextSymbol{\textethiopicxu}{LET}{129}
\DeclareTextCommand{\textethiopicxu}{Let}{\fontencoding{LET}\selectfont\textethiopicxu}
\DeclareTextSymbol{\textethiopicxi}{LET}{130}
\DeclareTextCommand{\textethiopicxi}{Let}{\fontencoding{LET}\selectfont\textethiopicxi}
\DeclareTextSymbol{\textethiopicxaa}{LET}{131}
\DeclareTextCommand{\textethiopicxaa}{Let}{\fontencoding{LET}\selectfont\textethiopicxaa}
\DeclareTextSymbol{\textethiopicxee}{LET}{132}
\DeclareTextCommand{\textethiopicxee}{Let}{\fontencoding{LET}\selectfont\textethiopicxee}
\DeclareTextSymbol{\textethiopicxe}{LET}{133}
\DeclareTextCommand{\textethiopicxe}{Let}{\fontencoding{LET}\selectfont\textethiopicxe}
\DeclareTextSymbol{\textethiopicxo}{LET}{134}
\DeclareTextCommand{\textethiopicxo}{Let}{\fontencoding{LET}\selectfont\textethiopicxo}
\DeclareTextSymbol{\textethiopicxwa}{LET}{136}
\DeclareTextCommand{\textethiopicxwa}{Let}{\fontencoding{LET}\selectfont\textethiopicxwa}
\DeclareTextSymbol{\textethiopicxwi}{LET}{138}
\DeclareTextCommand{\textethiopicxwi}{Let}{\fontencoding{LET}\selectfont\textethiopicxwi}
\DeclareTextSymbol{\textethiopicxwaa}{LET}{139}
\DeclareTextCommand{\textethiopicxwaa}{Let}{\fontencoding{LET}\selectfont\textethiopicxwaa}
\DeclareTextSymbol{\textethiopicxwee}{LET}{140}
\DeclareTextCommand{\textethiopicxwee}{Let}{\fontencoding{LET}\selectfont\textethiopicxwee}
\DeclareTextSymbol{\textethiopicxwe}{LET}{141}
\DeclareTextCommand{\textethiopicxwe}{Let}{\fontencoding{LET}\selectfont\textethiopicxwe}
\DeclareTextSymbol{\textethiopicna}{LET}{144}
\DeclareTextCommand{\textethiopicna}{Let}{\fontencoding{LET}\selectfont\textethiopicna}
\DeclareTextSymbol{\textethiopicnu}{LET}{145}
\DeclareTextCommand{\textethiopicnu}{Let}{\fontencoding{LET}\selectfont\textethiopicnu}
\DeclareTextSymbol{\textethiopicni}{LET}{146}
\DeclareTextCommand{\textethiopicni}{Let}{\fontencoding{LET}\selectfont\textethiopicni}
\DeclareTextSymbol{\textethiopicnaa}{LET}{147}
\DeclareTextCommand{\textethiopicnaa}{Let}{\fontencoding{LET}\selectfont\textethiopicnaa}
\DeclareTextSymbol{\textethiopicnee}{LET}{148}
\DeclareTextCommand{\textethiopicnee}{Let}{\fontencoding{LET}\selectfont\textethiopicnee}
\DeclareTextSymbol{\textethiopicne}{LET}{149}
\DeclareTextCommand{\textethiopicne}{Let}{\fontencoding{LET}\selectfont\textethiopicne}
\DeclareTextSymbol{\textethiopicno}{LET}{150}
\DeclareTextCommand{\textethiopicno}{Let}{\fontencoding{LET}\selectfont\textethiopicno}
\DeclareTextSymbol{\textethiopicnwa}{LET}{151}
\DeclareTextCommand{\textethiopicnwa}{Let}{\fontencoding{LET}\selectfont\textethiopicnwa}
\DeclareTextSymbol{\textethiopicnya}{LET}{152}
\DeclareTextCommand{\textethiopicnya}{Let}{\fontencoding{LET}\selectfont\textethiopicnya}
\DeclareTextSymbol{\textethiopicnyu}{LET}{153}
\DeclareTextCommand{\textethiopicnyu}{Let}{\fontencoding{LET}\selectfont\textethiopicnyu}
\DeclareTextSymbol{\textethiopicnyi}{LET}{154}
\DeclareTextCommand{\textethiopicnyi}{Let}{\fontencoding{LET}\selectfont\textethiopicnyi}
\DeclareTextSymbol{\textethiopicnyaa}{LET}{155}
\DeclareTextCommand{\textethiopicnyaa}{Let}{\fontencoding{LET}\selectfont\textethiopicnyaa}
\DeclareTextSymbol{\textethiopicnyee}{LET}{156}
\DeclareTextCommand{\textethiopicnyee}{Let}{\fontencoding{LET}\selectfont\textethiopicnyee}
\DeclareTextSymbol{\textethiopicnye}{LET}{157}
\DeclareTextCommand{\textethiopicnye}{Let}{\fontencoding{LET}\selectfont\textethiopicnye}
\DeclareTextSymbol{\textethiopicnyo}{LET}{158}
\DeclareTextCommand{\textethiopicnyo}{Let}{\fontencoding{LET}\selectfont\textethiopicnyo}
\DeclareTextSymbol{\textethiopicnywa}{LET}{159}
\DeclareTextCommand{\textethiopicnywa}{Let}{\fontencoding{LET}\selectfont\textethiopicnywa}
\DeclareTextSymbol{\textethiopicglottala}{LET}{160}
\DeclareTextCommand{\textethiopicglottala}{Let}{\fontencoding{LET}\selectfont\textethiopicglottala}
\DeclareTextSymbol{\textethiopicglottalu}{LET}{161}
\DeclareTextCommand{\textethiopicglottalu}{Let}{\fontencoding{LET}\selectfont\textethiopicglottalu}
\DeclareTextSymbol{\textethiopicglottali}{LET}{162}
\DeclareTextCommand{\textethiopicglottali}{Let}{\fontencoding{LET}\selectfont\textethiopicglottali}
\DeclareTextSymbol{\textethiopicglottalaa}{LET}{163}
\DeclareTextCommand{\textethiopicglottalaa}{Let}{\fontencoding{LET}\selectfont\textethiopicglottalaa}
\DeclareTextSymbol{\textethiopicglottalee}{LET}{164}
\DeclareTextCommand{\textethiopicglottalee}{Let}{\fontencoding{LET}\selectfont\textethiopicglottalee}
\DeclareTextSymbol{\textethiopicglottale}{LET}{165}
\DeclareTextCommand{\textethiopicglottale}{Let}{\fontencoding{LET}\selectfont\textethiopicglottale}
\DeclareTextSymbol{\textethiopicglottalo}{LET}{166}
\DeclareTextCommand{\textethiopicglottalo}{Let}{\fontencoding{LET}\selectfont\textethiopicglottalo}
\DeclareTextSymbol{\textethiopicglottalwa}{LET}{167}
\DeclareTextCommand{\textethiopicglottalwa}{Let}{\fontencoding{LET}\selectfont\textethiopicglottalwa}
\DeclareTextSymbol{\textethiopicka}{LET}{168}
\DeclareTextCommand{\textethiopicka}{Let}{\fontencoding{LET}\selectfont\textethiopicka}
\DeclareTextSymbol{\textethiopicku}{LET}{169}
\DeclareTextCommand{\textethiopicku}{Let}{\fontencoding{LET}\selectfont\textethiopicku}
\DeclareTextSymbol{\textethiopicki}{LET}{170}
\DeclareTextCommand{\textethiopicki}{Let}{\fontencoding{LET}\selectfont\textethiopicki}
\DeclareTextSymbol{\textethiopickaa}{LET}{171}
\DeclareTextCommand{\textethiopickaa}{Let}{\fontencoding{LET}\selectfont\textethiopickaa}
\DeclareTextSymbol{\textethiopickee}{LET}{172}
\DeclareTextCommand{\textethiopickee}{Let}{\fontencoding{LET}\selectfont\textethiopickee}
\DeclareTextSymbol{\textethiopicke}{LET}{173}
\DeclareTextCommand{\textethiopicke}{Let}{\fontencoding{LET}\selectfont\textethiopicke}
\DeclareTextSymbol{\textethiopicko}{LET}{174}
\DeclareTextCommand{\textethiopicko}{Let}{\fontencoding{LET}\selectfont\textethiopicko}
\DeclareTextSymbol{\textethiopickwa}{LET}{176}
\DeclareTextCommand{\textethiopickwa}{Let}{\fontencoding{LET}\selectfont\textethiopickwa}
\DeclareTextSymbol{\textethiopickwi}{LET}{178}
\DeclareTextCommand{\textethiopickwi}{Let}{\fontencoding{LET}\selectfont\textethiopickwi}
\DeclareTextSymbol{\textethiopickwaa}{LET}{179}
\DeclareTextCommand{\textethiopickwaa}{Let}{\fontencoding{LET}\selectfont\textethiopickwaa}
\DeclareTextSymbol{\textethiopickwee}{LET}{180}
\DeclareTextCommand{\textethiopickwee}{Let}{\fontencoding{LET}\selectfont\textethiopickwee}
\DeclareTextSymbol{\textethiopickwe}{LET}{181}
\DeclareTextCommand{\textethiopickwe}{Let}{\fontencoding{LET}\selectfont\textethiopickwe}
\DeclareTextSymbol{\textethiopickxa}{LET}{184}
\DeclareTextCommand{\textethiopickxa}{Let}{\fontencoding{LET}\selectfont\textethiopickxa}
\DeclareTextSymbol{\textethiopickxu}{LET}{185}
\DeclareTextCommand{\textethiopickxu}{Let}{\fontencoding{LET}\selectfont\textethiopickxu}
\DeclareTextSymbol{\textethiopickxi}{LET}{186}
\DeclareTextCommand{\textethiopickxi}{Let}{\fontencoding{LET}\selectfont\textethiopickxi}
\DeclareTextSymbol{\textethiopickxaa}{LET}{187}
\DeclareTextCommand{\textethiopickxaa}{Let}{\fontencoding{LET}\selectfont\textethiopickxaa}
\DeclareTextSymbol{\textethiopickxee}{LET}{188}
\DeclareTextCommand{\textethiopickxee}{Let}{\fontencoding{LET}\selectfont\textethiopickxee}
\DeclareTextSymbol{\textethiopickxe}{LET}{189}
\DeclareTextCommand{\textethiopickxe}{Let}{\fontencoding{LET}\selectfont\textethiopickxe}
\DeclareTextSymbol{\textethiopickxo}{LET}{190}
\DeclareTextCommand{\textethiopickxo}{Let}{\fontencoding{LET}\selectfont\textethiopickxo}
\DeclareTextSymbol{\textethiopickxwa}{LET}{192}
\DeclareTextCommand{\textethiopickxwa}{Let}{\fontencoding{LET}\selectfont\textethiopickxwa}
\DeclareTextSymbol{\textethiopickxwi}{LET}{194}
\DeclareTextCommand{\textethiopickxwi}{Let}{\fontencoding{LET}\selectfont\textethiopickxwi}
\DeclareTextSymbol{\textethiopickxwaa}{LET}{195}
\DeclareTextCommand{\textethiopickxwaa}{Let}{\fontencoding{LET}\selectfont\textethiopickxwaa}
\DeclareTextSymbol{\textethiopickxwee}{LET}{196}
\DeclareTextCommand{\textethiopickxwee}{Let}{\fontencoding{LET}\selectfont\textethiopickxwee}
\DeclareTextSymbol{\textethiopickxwe}{LET}{197}
\DeclareTextCommand{\textethiopickxwe}{Let}{\fontencoding{LET}\selectfont\textethiopickxwe}
\DeclareTextSymbol{\textethiopicwa}{LET}{200}
\DeclareTextCommand{\textethiopicwa}{Let}{\fontencoding{LET}\selectfont\textethiopicwa}
\DeclareTextSymbol{\textethiopicwu}{LET}{201}
\DeclareTextCommand{\textethiopicwu}{Let}{\fontencoding{LET}\selectfont\textethiopicwu}
\DeclareTextSymbol{\textethiopicwi}{LET}{202}
\DeclareTextCommand{\textethiopicwi}{Let}{\fontencoding{LET}\selectfont\textethiopicwi}
\DeclareTextSymbol{\textethiopicwaa}{LET}{203}
\DeclareTextCommand{\textethiopicwaa}{Let}{\fontencoding{LET}\selectfont\textethiopicwaa}
\DeclareTextSymbol{\textethiopicwee}{LET}{204}
\DeclareTextCommand{\textethiopicwee}{Let}{\fontencoding{LET}\selectfont\textethiopicwee}
\DeclareTextSymbol{\textethiopicwe}{LET}{205}
\DeclareTextCommand{\textethiopicwe}{Let}{\fontencoding{LET}\selectfont\textethiopicwe}
\DeclareTextSymbol{\textethiopicwo}{LET}{206}
\DeclareTextCommand{\textethiopicwo}{Let}{\fontencoding{LET}\selectfont\textethiopicwo}
\DeclareTextSymbol{\textethiopicpharyngeala}{LET}{208}
\DeclareTextCommand{\textethiopicpharyngeala}{Let}{\fontencoding{LET}\selectfont\textethiopicpharyngeala}
\DeclareTextSymbol{\textethiopicpharyngealu}{LET}{209}
\DeclareTextCommand{\textethiopicpharyngealu}{Let}{\fontencoding{LET}\selectfont\textethiopicpharyngealu}
\DeclareTextSymbol{\textethiopicpharyngeali}{LET}{210}
\DeclareTextCommand{\textethiopicpharyngeali}{Let}{\fontencoding{LET}\selectfont\textethiopicpharyngeali}
\DeclareTextSymbol{\textethiopicpharyngealaa}{LET}{211}
\DeclareTextCommand{\textethiopicpharyngealaa}{Let}{\fontencoding{LET}\selectfont\textethiopicpharyngealaa}
\DeclareTextSymbol{\textethiopicpharyngealee}{LET}{212}
\DeclareTextCommand{\textethiopicpharyngealee}{Let}{\fontencoding{LET}\selectfont\textethiopicpharyngealee}
\DeclareTextSymbol{\textethiopicpharyngeale}{LET}{213}
\DeclareTextCommand{\textethiopicpharyngeale}{Let}{\fontencoding{LET}\selectfont\textethiopicpharyngeale}
\DeclareTextSymbol{\textethiopicpharyngealo}{LET}{214}
\DeclareTextCommand{\textethiopicpharyngealo}{Let}{\fontencoding{LET}\selectfont\textethiopicpharyngealo}
\DeclareTextSymbol{\textethiopicza}{LET}{216}
\DeclareTextCommand{\textethiopicza}{Let}{\fontencoding{LET}\selectfont\textethiopicza}
\DeclareTextSymbol{\textethiopiczu}{LET}{217}
\DeclareTextCommand{\textethiopiczu}{Let}{\fontencoding{LET}\selectfont\textethiopiczu}
\DeclareTextSymbol{\textethiopiczi}{LET}{218}
\DeclareTextCommand{\textethiopiczi}{Let}{\fontencoding{LET}\selectfont\textethiopiczi}
\DeclareTextSymbol{\textethiopiczaa}{LET}{219}
\DeclareTextCommand{\textethiopiczaa}{Let}{\fontencoding{LET}\selectfont\textethiopiczaa}
\DeclareTextSymbol{\textethiopiczee}{LET}{220}
\DeclareTextCommand{\textethiopiczee}{Let}{\fontencoding{LET}\selectfont\textethiopiczee}
\DeclareTextSymbol{\textethiopicze}{LET}{221}
\DeclareTextCommand{\textethiopicze}{Let}{\fontencoding{LET}\selectfont\textethiopicze}
\DeclareTextSymbol{\textethiopiczo}{LET}{222}
\DeclareTextCommand{\textethiopiczo}{Let}{\fontencoding{LET}\selectfont\textethiopiczo}
\DeclareTextSymbol{\textethiopiczwa}{LET}{223}
\DeclareTextCommand{\textethiopiczwa}{Let}{\fontencoding{LET}\selectfont\textethiopiczwa}
\DeclareTextSymbol{\textethiopiczha}{LET}{224}
\DeclareTextCommand{\textethiopiczha}{Let}{\fontencoding{LET}\selectfont\textethiopiczha}
\DeclareTextSymbol{\textethiopiczhu}{LET}{225}
\DeclareTextCommand{\textethiopiczhu}{Let}{\fontencoding{LET}\selectfont\textethiopiczhu}
\DeclareTextSymbol{\textethiopiczhi}{LET}{226}
\DeclareTextCommand{\textethiopiczhi}{Let}{\fontencoding{LET}\selectfont\textethiopiczhi}
\DeclareTextSymbol{\textethiopiczhaa}{LET}{227}
\DeclareTextCommand{\textethiopiczhaa}{Let}{\fontencoding{LET}\selectfont\textethiopiczhaa}
\DeclareTextSymbol{\textethiopiczhee}{LET}{228}
\DeclareTextCommand{\textethiopiczhee}{Let}{\fontencoding{LET}\selectfont\textethiopiczhee}
\DeclareTextSymbol{\textethiopiczhe}{LET}{229}
\DeclareTextCommand{\textethiopiczhe}{Let}{\fontencoding{LET}\selectfont\textethiopiczhe}
\DeclareTextSymbol{\textethiopiczho}{LET}{230}
\DeclareTextCommand{\textethiopiczho}{Let}{\fontencoding{LET}\selectfont\textethiopiczho}
\DeclareTextSymbol{\textethiopiczhwa}{LET}{231}
\DeclareTextCommand{\textethiopiczhwa}{Let}{\fontencoding{LET}\selectfont\textethiopiczhwa}
\DeclareTextSymbol{\textethiopicya}{LET}{232}
\DeclareTextCommand{\textethiopicya}{Let}{\fontencoding{LET}\selectfont\textethiopicya}
\DeclareTextSymbol{\textethiopicyu}{LET}{233}
\DeclareTextCommand{\textethiopicyu}{Let}{\fontencoding{LET}\selectfont\textethiopicyu}
\DeclareTextSymbol{\textethiopicyi}{LET}{234}
\DeclareTextCommand{\textethiopicyi}{Let}{\fontencoding{LET}\selectfont\textethiopicyi}
\DeclareTextSymbol{\textethiopicyaa}{LET}{235}
\DeclareTextCommand{\textethiopicyaa}{Let}{\fontencoding{LET}\selectfont\textethiopicyaa}
\DeclareTextSymbol{\textethiopicyee}{LET}{236}
\DeclareTextCommand{\textethiopicyee}{Let}{\fontencoding{LET}\selectfont\textethiopicyee}
\DeclareTextSymbol{\textethiopicye}{LET}{237}
\DeclareTextCommand{\textethiopicye}{Let}{\fontencoding{LET}\selectfont\textethiopicye}
\DeclareTextSymbol{\textethiopicyo}{LET}{238}
\DeclareTextCommand{\textethiopicyo}{Let}{\fontencoding{LET}\selectfont\textethiopicyo}
\DeclareTextSymbol{\textethiopicda}{LET}{240}
\DeclareTextCommand{\textethiopicda}{Let}{\fontencoding{LET}\selectfont\textethiopicda}
\DeclareTextSymbol{\textethiopicdu}{LET}{241}
\DeclareTextCommand{\textethiopicdu}{Let}{\fontencoding{LET}\selectfont\textethiopicdu}
\DeclareTextSymbol{\textethiopicdi}{LET}{242}
\DeclareTextCommand{\textethiopicdi}{Let}{\fontencoding{LET}\selectfont\textethiopicdi}
\DeclareTextSymbol{\textethiopicdaa}{LET}{243}
\DeclareTextCommand{\textethiopicdaa}{Let}{\fontencoding{LET}\selectfont\textethiopicdaa}
\DeclareTextSymbol{\textethiopicdee}{LET}{244}
\DeclareTextCommand{\textethiopicdee}{Let}{\fontencoding{LET}\selectfont\textethiopicdee}
\DeclareTextSymbol{\textethiopicde}{LET}{245}
\DeclareTextCommand{\textethiopicde}{Let}{\fontencoding{LET}\selectfont\textethiopicde}
\DeclareTextSymbol{\textethiopicdo}{LET}{246}
\DeclareTextCommand{\textethiopicdo}{Let}{\fontencoding{LET}\selectfont\textethiopicdo}
\DeclareTextSymbol{\textethiopicdwa}{LET}{247}
\DeclareTextCommand{\textethiopicdwa}{Let}{\fontencoding{LET}\selectfont\textethiopicdwa}
\DeclareTextSymbol{\textethiopicdda}{LET}{248}
\DeclareTextCommand{\textethiopicdda}{Let}{\fontencoding{LET}\selectfont\textethiopicdda}
\DeclareTextSymbol{\textethiopicddu}{LET}{249}
\DeclareTextCommand{\textethiopicddu}{Let}{\fontencoding{LET}\selectfont\textethiopicddu}
\DeclareTextSymbol{\textethiopicddi}{LET}{250}
\DeclareTextCommand{\textethiopicddi}{Let}{\fontencoding{LET}\selectfont\textethiopicddi}
\DeclareTextSymbol{\textethiopicddaa}{LET}{251}
\DeclareTextCommand{\textethiopicddaa}{Let}{\fontencoding{LET}\selectfont\textethiopicddaa}
\DeclareTextSymbol{\textethiopicddee}{LET}{252}
\DeclareTextCommand{\textethiopicddee}{Let}{\fontencoding{LET}\selectfont\textethiopicddee}
\DeclareTextSymbol{\textethiopicdde}{LET}{253}
\DeclareTextCommand{\textethiopicdde}{Let}{\fontencoding{LET}\selectfont\textethiopicdde}
\DeclareTextSymbol{\textethiopicddo}{LET}{254}
\DeclareTextCommand{\textethiopicddo}{Let}{\fontencoding{LET}\selectfont\textethiopicddo}
\DeclareTextSymbol{\textethiopicddwa}{LET}{255}
\DeclareTextCommand{\textethiopicddwa}{Let}{\fontencoding{LET}\selectfont\textethiopicddwa}
\DeclareTextSymbol{\textethiopicja}{Let}{0}
\DeclareTextCommand{\textethiopicja}{LET}{\fontencoding{Let}\selectfont\textethiopicja}
\DeclareTextSymbol{\textethiopicju}{Let}{1}
\DeclareTextCommand{\textethiopicju}{LET}{\fontencoding{Let}\selectfont\textethiopicju}
\DeclareTextSymbol{\textethiopicji}{Let}{2}
\DeclareTextCommand{\textethiopicji}{LET}{\fontencoding{Let}\selectfont\textethiopicji}
\DeclareTextSymbol{\textethiopicjaa}{Let}{3}
\DeclareTextCommand{\textethiopicjaa}{LET}{\fontencoding{Let}\selectfont\textethiopicjaa}
\DeclareTextSymbol{\textethiopicjee}{Let}{4}
\DeclareTextCommand{\textethiopicjee}{LET}{\fontencoding{Let}\selectfont\textethiopicjee}
\DeclareTextSymbol{\textethiopicje}{Let}{5}
\DeclareTextCommand{\textethiopicje}{LET}{\fontencoding{Let}\selectfont\textethiopicje}
\DeclareTextSymbol{\textethiopicjo}{Let}{6}
\DeclareTextCommand{\textethiopicjo}{LET}{\fontencoding{Let}\selectfont\textethiopicjo}
\DeclareTextSymbol{\textethiopicjwa}{Let}{7}
\DeclareTextCommand{\textethiopicjwa}{LET}{\fontencoding{Let}\selectfont\textethiopicjwa}
\DeclareTextSymbol{\textethiopicga}{Let}{8}
\DeclareTextCommand{\textethiopicga}{LET}{\fontencoding{Let}\selectfont\textethiopicga}
\DeclareTextSymbol{\textethiopicgu}{Let}{9}
\DeclareTextCommand{\textethiopicgu}{LET}{\fontencoding{Let}\selectfont\textethiopicgu}
\DeclareTextSymbol{\textethiopicgi}{Let}{10}
\DeclareTextCommand{\textethiopicgi}{LET}{\fontencoding{Let}\selectfont\textethiopicgi}
\DeclareTextSymbol{\textethiopicgaa}{Let}{11}
\DeclareTextCommand{\textethiopicgaa}{LET}{\fontencoding{Let}\selectfont\textethiopicgaa}
\DeclareTextSymbol{\textethiopicgee}{Let}{12}
\DeclareTextCommand{\textethiopicgee}{LET}{\fontencoding{Let}\selectfont\textethiopicgee}
\DeclareTextSymbol{\textethiopicge}{Let}{13}
\DeclareTextCommand{\textethiopicge}{LET}{\fontencoding{Let}\selectfont\textethiopicge}
\DeclareTextSymbol{\textethiopicgo}{Let}{14}
\DeclareTextCommand{\textethiopicgo}{LET}{\fontencoding{Let}\selectfont\textethiopicgo}
\DeclareTextSymbol{\textethiopicgwa}{Let}{16}
\DeclareTextCommand{\textethiopicgwa}{LET}{\fontencoding{Let}\selectfont\textethiopicgwa}
\DeclareTextSymbol{\textethiopicgwi}{Let}{18}
\DeclareTextCommand{\textethiopicgwi}{LET}{\fontencoding{Let}\selectfont\textethiopicgwi}
\DeclareTextSymbol{\textethiopicgwaa}{Let}{19}
\DeclareTextCommand{\textethiopicgwaa}{LET}{\fontencoding{Let}\selectfont\textethiopicgwaa}
\DeclareTextSymbol{\textethiopicgwee}{Let}{20}
\DeclareTextCommand{\textethiopicgwee}{LET}{\fontencoding{Let}\selectfont\textethiopicgwee}
\DeclareTextSymbol{\textethiopicgwe}{Let}{21}
\DeclareTextCommand{\textethiopicgwe}{LET}{\fontencoding{Let}\selectfont\textethiopicgwe}
\DeclareTextSymbol{\textethiopicgga}{Let}{24}
\DeclareTextCommand{\textethiopicgga}{LET}{\fontencoding{Let}\selectfont\textethiopicgga}
\DeclareTextSymbol{\textethiopicggu}{Let}{25}
\DeclareTextCommand{\textethiopicggu}{LET}{\fontencoding{Let}\selectfont\textethiopicggu}
\DeclareTextSymbol{\textethiopicggi}{Let}{26}
\DeclareTextCommand{\textethiopicggi}{LET}{\fontencoding{Let}\selectfont\textethiopicggi}
\DeclareTextSymbol{\textethiopicggaa}{Let}{27}
\DeclareTextCommand{\textethiopicggaa}{LET}{\fontencoding{Let}\selectfont\textethiopicggaa}
\DeclareTextSymbol{\textethiopicggee}{Let}{28}
\DeclareTextCommand{\textethiopicggee}{LET}{\fontencoding{Let}\selectfont\textethiopicggee}
\DeclareTextSymbol{\textethiopicgge}{Let}{29}
\DeclareTextCommand{\textethiopicgge}{LET}{\fontencoding{Let}\selectfont\textethiopicgge}
\DeclareTextSymbol{\textethiopicggo}{Let}{30}
\DeclareTextCommand{\textethiopicggo}{LET}{\fontencoding{Let}\selectfont\textethiopicggo}
\DeclareTextSymbol{\textethiopictha}{Let}{32}
\DeclareTextCommand{\textethiopictha}{LET}{\fontencoding{Let}\selectfont\textethiopictha}
\DeclareTextSymbol{\textethiopicthu}{Let}{33}
\DeclareTextCommand{\textethiopicthu}{LET}{\fontencoding{Let}\selectfont\textethiopicthu}
\DeclareTextSymbol{\textethiopicthi}{Let}{34}
\DeclareTextCommand{\textethiopicthi}{LET}{\fontencoding{Let}\selectfont\textethiopicthi}
\DeclareTextSymbol{\textethiopicthaa}{Let}{35}
\DeclareTextCommand{\textethiopicthaa}{LET}{\fontencoding{Let}\selectfont\textethiopicthaa}
\DeclareTextSymbol{\textethiopicthee}{Let}{36}
\DeclareTextCommand{\textethiopicthee}{LET}{\fontencoding{Let}\selectfont\textethiopicthee}
\DeclareTextSymbol{\textethiopicthe}{Let}{37}
\DeclareTextCommand{\textethiopicthe}{LET}{\fontencoding{Let}\selectfont\textethiopicthe}
\DeclareTextSymbol{\textethiopictho}{Let}{38}
\DeclareTextCommand{\textethiopictho}{LET}{\fontencoding{Let}\selectfont\textethiopictho}
\DeclareTextSymbol{\textethiopicthwa}{Let}{39}
\DeclareTextCommand{\textethiopicthwa}{LET}{\fontencoding{Let}\selectfont\textethiopicthwa}
\DeclareTextSymbol{\textethiopiccha}{Let}{40}
\DeclareTextCommand{\textethiopiccha}{LET}{\fontencoding{Let}\selectfont\textethiopiccha}
\DeclareTextSymbol{\textethiopicchu}{Let}{41}
\DeclareTextCommand{\textethiopicchu}{LET}{\fontencoding{Let}\selectfont\textethiopicchu}
\DeclareTextSymbol{\textethiopicchi}{Let}{42}
\DeclareTextCommand{\textethiopicchi}{LET}{\fontencoding{Let}\selectfont\textethiopicchi}
\DeclareTextSymbol{\textethiopicchaa}{Let}{43}
\DeclareTextCommand{\textethiopicchaa}{LET}{\fontencoding{Let}\selectfont\textethiopicchaa}
\DeclareTextSymbol{\textethiopicchee}{Let}{44}
\DeclareTextCommand{\textethiopicchee}{LET}{\fontencoding{Let}\selectfont\textethiopicchee}
\DeclareTextSymbol{\textethiopicche}{Let}{45}
\DeclareTextCommand{\textethiopicche}{LET}{\fontencoding{Let}\selectfont\textethiopicche}
\DeclareTextSymbol{\textethiopiccho}{Let}{46}
\DeclareTextCommand{\textethiopiccho}{LET}{\fontencoding{Let}\selectfont\textethiopiccho}
\DeclareTextSymbol{\textethiopicchwa}{Let}{47}
\DeclareTextCommand{\textethiopicchwa}{LET}{\fontencoding{Let}\selectfont\textethiopicchwa}
\DeclareTextSymbol{\textethiopicpha}{Let}{48}
\DeclareTextCommand{\textethiopicpha}{LET}{\fontencoding{Let}\selectfont\textethiopicpha}
\DeclareTextSymbol{\textethiopicphu}{Let}{49}
\DeclareTextCommand{\textethiopicphu}{LET}{\fontencoding{Let}\selectfont\textethiopicphu}
\DeclareTextSymbol{\textethiopicphi}{Let}{50}
\DeclareTextCommand{\textethiopicphi}{LET}{\fontencoding{Let}\selectfont\textethiopicphi}
\DeclareTextSymbol{\textethiopicphaa}{Let}{51}
\DeclareTextCommand{\textethiopicphaa}{LET}{\fontencoding{Let}\selectfont\textethiopicphaa}
\DeclareTextSymbol{\textethiopicphee}{Let}{52}
\DeclareTextCommand{\textethiopicphee}{LET}{\fontencoding{Let}\selectfont\textethiopicphee}
\DeclareTextSymbol{\textethiopicphe}{Let}{53}
\DeclareTextCommand{\textethiopicphe}{LET}{\fontencoding{Let}\selectfont\textethiopicphe}
\DeclareTextSymbol{\textethiopicpho}{Let}{54}
\DeclareTextCommand{\textethiopicpho}{LET}{\fontencoding{Let}\selectfont\textethiopicpho}
\DeclareTextSymbol{\textethiopicphwa}{Let}{55}
\DeclareTextCommand{\textethiopicphwa}{LET}{\fontencoding{Let}\selectfont\textethiopicphwa}
\DeclareTextSymbol{\textethiopictsa}{Let}{56}
\DeclareTextCommand{\textethiopictsa}{LET}{\fontencoding{Let}\selectfont\textethiopictsa}
\DeclareTextSymbol{\textethiopictsu}{Let}{57}
\DeclareTextCommand{\textethiopictsu}{LET}{\fontencoding{Let}\selectfont\textethiopictsu}
\DeclareTextSymbol{\textethiopictsi}{Let}{58}
\DeclareTextCommand{\textethiopictsi}{LET}{\fontencoding{Let}\selectfont\textethiopictsi}
\DeclareTextSymbol{\textethiopictsaa}{Let}{59}
\DeclareTextCommand{\textethiopictsaa}{LET}{\fontencoding{Let}\selectfont\textethiopictsaa}
\DeclareTextSymbol{\textethiopictsee}{Let}{60}
\DeclareTextCommand{\textethiopictsee}{LET}{\fontencoding{Let}\selectfont\textethiopictsee}
\DeclareTextSymbol{\textethiopictse}{Let}{61}
\DeclareTextCommand{\textethiopictse}{LET}{\fontencoding{Let}\selectfont\textethiopictse}
\DeclareTextSymbol{\textethiopictso}{Let}{62}
\DeclareTextCommand{\textethiopictso}{LET}{\fontencoding{Let}\selectfont\textethiopictso}
\DeclareTextSymbol{\textethiopictswa}{Let}{63}
\DeclareTextCommand{\textethiopictswa}{LET}{\fontencoding{Let}\selectfont\textethiopictswa}
\DeclareTextSymbol{\textethiopictza}{Let}{64}
\DeclareTextCommand{\textethiopictza}{LET}{\fontencoding{Let}\selectfont\textethiopictza}
\DeclareTextSymbol{\textethiopictzu}{Let}{65}
\DeclareTextCommand{\textethiopictzu}{LET}{\fontencoding{Let}\selectfont\textethiopictzu}
\DeclareTextSymbol{\textethiopictzi}{Let}{66}
\DeclareTextCommand{\textethiopictzi}{LET}{\fontencoding{Let}\selectfont\textethiopictzi}
\DeclareTextSymbol{\textethiopictzaa}{Let}{67}
\DeclareTextCommand{\textethiopictzaa}{LET}{\fontencoding{Let}\selectfont\textethiopictzaa}
\DeclareTextSymbol{\textethiopictzee}{Let}{68}
\DeclareTextCommand{\textethiopictzee}{LET}{\fontencoding{Let}\selectfont\textethiopictzee}
\DeclareTextSymbol{\textethiopictze}{Let}{69}
\DeclareTextCommand{\textethiopictze}{LET}{\fontencoding{Let}\selectfont\textethiopictze}
\DeclareTextSymbol{\textethiopictzo}{Let}{70}
\DeclareTextCommand{\textethiopictzo}{LET}{\fontencoding{Let}\selectfont\textethiopictzo}
\DeclareTextSymbol{\textethiopicfa}{Let}{72}
\DeclareTextCommand{\textethiopicfa}{LET}{\fontencoding{Let}\selectfont\textethiopicfa}
\DeclareTextSymbol{\textethiopicfu}{Let}{73}
\DeclareTextCommand{\textethiopicfu}{LET}{\fontencoding{Let}\selectfont\textethiopicfu}
\DeclareTextSymbol{\textethiopicfi}{Let}{74}
\DeclareTextCommand{\textethiopicfi}{LET}{\fontencoding{Let}\selectfont\textethiopicfi}
\DeclareTextSymbol{\textethiopicfaa}{Let}{75}
\DeclareTextCommand{\textethiopicfaa}{LET}{\fontencoding{Let}\selectfont\textethiopicfaa}
\DeclareTextSymbol{\textethiopicfee}{Let}{76}
\DeclareTextCommand{\textethiopicfee}{LET}{\fontencoding{Let}\selectfont\textethiopicfee}
\DeclareTextSymbol{\textethiopicfe}{Let}{77}
\DeclareTextCommand{\textethiopicfe}{LET}{\fontencoding{Let}\selectfont\textethiopicfe}
\DeclareTextSymbol{\textethiopicfo}{Let}{78}
\DeclareTextCommand{\textethiopicfo}{LET}{\fontencoding{Let}\selectfont\textethiopicfo}
\DeclareTextSymbol{\textethiopicfwa}{Let}{79}
\DeclareTextCommand{\textethiopicfwa}{LET}{\fontencoding{Let}\selectfont\textethiopicfwa}
\DeclareTextSymbol{\textethiopicpa}{Let}{80}
\DeclareTextCommand{\textethiopicpa}{LET}{\fontencoding{Let}\selectfont\textethiopicpa}
\DeclareTextSymbol{\textethiopicpu}{Let}{81}
\DeclareTextCommand{\textethiopicpu}{LET}{\fontencoding{Let}\selectfont\textethiopicpu}
\DeclareTextSymbol{\textethiopicpi}{Let}{82}
\DeclareTextCommand{\textethiopicpi}{LET}{\fontencoding{Let}\selectfont\textethiopicpi}
\DeclareTextSymbol{\textethiopicpaa}{Let}{83}
\DeclareTextCommand{\textethiopicpaa}{LET}{\fontencoding{Let}\selectfont\textethiopicpaa}
\DeclareTextSymbol{\textethiopicpee}{Let}{84}
\DeclareTextCommand{\textethiopicpee}{LET}{\fontencoding{Let}\selectfont\textethiopicpee}
\DeclareTextSymbol{\textethiopicpe}{Let}{85}
\DeclareTextCommand{\textethiopicpe}{LET}{\fontencoding{Let}\selectfont\textethiopicpe}
\DeclareTextSymbol{\textethiopicpo}{Let}{86}
\DeclareTextCommand{\textethiopicpo}{LET}{\fontencoding{Let}\selectfont\textethiopicpo}
\DeclareTextSymbol{\textethiopicpwa}{Let}{87}
\DeclareTextCommand{\textethiopicpwa}{LET}{\fontencoding{Let}\selectfont\textethiopicpwa}
\DeclareTextSymbol{\textethiopicrya}{Let}{88}
\DeclareTextCommand{\textethiopicrya}{LET}{\fontencoding{Let}\selectfont\textethiopicrya}
\DeclareTextSymbol{\textethiopicmya}{Let}{89}
\DeclareTextCommand{\textethiopicmya}{LET}{\fontencoding{Let}\selectfont\textethiopicmya}
\DeclareTextSymbol{\textethiopicfya}{Let}{90}
\DeclareTextCommand{\textethiopicfya}{LET}{\fontencoding{Let}\selectfont\textethiopicfya}
\DeclareTextSymbol{\textethiopicwordspace}{Let}{97}
\DeclareTextCommand{\textethiopicwordspace}{LET}{\fontencoding{Let}\selectfont\textethiopicwordspace}
\DeclareTextSymbol{\textethiopicfullstop}{Let}{98}
\DeclareTextCommand{\textethiopicfullstop}{LET}{\fontencoding{Let}\selectfont\textethiopicfullstop}
\DeclareTextSymbol{\textethiopiccomma}{Let}{99}
\DeclareTextCommand{\textethiopiccomma}{LET}{\fontencoding{Let}\selectfont\textethiopiccomma}
\DeclareTextSymbol{\textethiopicsemicolon}{Let}{100}
\DeclareTextCommand{\textethiopicsemicolon}{LET}{\fontencoding{Let}\selectfont\textethiopicsemicolon}
\DeclareTextSymbol{\textethiopiccolon}{Let}{101}
\DeclareTextCommand{\textethiopiccolon}{LET}{\fontencoding{Let}\selectfont\textethiopiccolon}
\DeclareTextSymbol{\textethiopicprefacecolon}{Let}{102}
\DeclareTextCommand{\textethiopicprefacecolon}{LET}{\fontencoding{Let}\selectfont\textethiopicprefacecolon}
\DeclareTextSymbol{\textethiopicquestionmark}{Let}{103}
\DeclareTextCommand{\textethiopicquestionmark}{LET}{\fontencoding{Let}\selectfont\textethiopicquestionmark}
\DeclareTextSymbol{\textethiopicparagraph}{Let}{104}
\DeclareTextCommand{\textethiopicparagraph}{LET}{\fontencoding{Let}\selectfont\textethiopicparagraph}
\DeclareTextSymbol{\textethiopicone}{Let}{105}
\DeclareTextCommand{\textethiopicone}{LET}{\fontencoding{Let}\selectfont\textethiopicone}
\DeclareTextSymbol{\textethiopictwo}{Let}{106}
\DeclareTextCommand{\textethiopictwo}{LET}{\fontencoding{Let}\selectfont\textethiopictwo}
\DeclareTextSymbol{\textethiopicthree}{Let}{107}
\DeclareTextCommand{\textethiopicthree}{LET}{\fontencoding{Let}\selectfont\textethiopicthree}
\DeclareTextSymbol{\textethiopicfour}{Let}{108}
\DeclareTextCommand{\textethiopicfour}{LET}{\fontencoding{Let}\selectfont\textethiopicfour}
\DeclareTextSymbol{\textethiopicfive}{Let}{109}
\DeclareTextCommand{\textethiopicfive}{LET}{\fontencoding{Let}\selectfont\textethiopicfive}
\DeclareTextSymbol{\textethiopicsix}{Let}{110}
\DeclareTextCommand{\textethiopicsix}{LET}{\fontencoding{Let}\selectfont\textethiopicsix}
\DeclareTextSymbol{\textethiopicseven}{Let}{111}
\DeclareTextCommand{\textethiopicseven}{LET}{\fontencoding{Let}\selectfont\textethiopicseven}
\DeclareTextSymbol{\textethiopiceight}{Let}{112}
\DeclareTextCommand{\textethiopiceight}{LET}{\fontencoding{Let}\selectfont\textethiopiceight}
\DeclareTextSymbol{\textethiopicnine}{Let}{113}
\DeclareTextCommand{\textethiopicnine}{LET}{\fontencoding{Let}\selectfont\textethiopicnine}
\DeclareTextSymbol{\textethiopicten}{Let}{114}
\DeclareTextCommand{\textethiopicten}{LET}{\fontencoding{Let}\selectfont\textethiopicten}
\DeclareTextSymbol{\textethiopictwenty}{Let}{115}
\DeclareTextCommand{\textethiopictwenty}{LET}{\fontencoding{Let}\selectfont\textethiopictwenty}
\DeclareTextSymbol{\textethiopicthirty}{Let}{116}
\DeclareTextCommand{\textethiopicthirty}{LET}{\fontencoding{Let}\selectfont\textethiopicthirty}
\DeclareTextSymbol{\textethiopicforty}{Let}{117}
\DeclareTextCommand{\textethiopicforty}{LET}{\fontencoding{Let}\selectfont\textethiopicforty}
\DeclareTextSymbol{\textethiopicfifty}{Let}{118}
\DeclareTextCommand{\textethiopicfifty}{LET}{\fontencoding{Let}\selectfont\textethiopicfifty}
\DeclareTextSymbol{\textethiopicsixty}{Let}{119}
\DeclareTextCommand{\textethiopicsixty}{LET}{\fontencoding{Let}\selectfont\textethiopicsixty}
\DeclareTextSymbol{\textethiopicseventy}{Let}{120}
\DeclareTextCommand{\textethiopicseventy}{LET}{\fontencoding{Let}\selectfont\textethiopicseventy}
\DeclareTextSymbol{\textethiopiceighty}{Let}{121}
\DeclareTextCommand{\textethiopiceighty}{LET}{\fontencoding{Let}\selectfont\textethiopiceighty}
\DeclareTextSymbol{\textethiopicninety}{Let}{122}
\DeclareTextCommand{\textethiopicninety}{LET}{\fontencoding{Let}\selectfont\textethiopicninety}
\DeclareTextSymbol{\textethiopichundred}{Let}{123}
\DeclareTextCommand{\textethiopichundred}{LET}{\fontencoding{Let}\selectfont\textethiopichundred}
\DeclareTextSymbol{\textethiopictenthousand}{Let}{124}
\DeclareTextCommand{\textethiopictenthousand}{LET}{\fontencoding{Let}\selectfont\textethiopictenthousand}
