%%% Unicode to TeX mapping, file uni-40.def, U+2800..U+28FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-40.def}[2013/05/13 UCS: Unicode data U+2800..U+28FF]%
\fi
\uc@dclc{10240}{default}{\braillebox{}}%
\uc@dclc{10241}{default}{\braillebox{1}}%
\uc@dclc{10242}{default}{\braillebox{2}}%
\uc@dclc{10243}{default}{\braillebox{12}}%
\uc@dclc{10244}{default}{\braillebox{3}}%
\uc@dclc{10245}{default}{\braillebox{13}}%
\uc@dclc{10246}{default}{\braillebox{23}}%
\uc@dclc{10247}{default}{\braillebox{123}}%
\uc@dclc{10248}{default}{\braillebox{4}}%
\uc@dclc{10249}{default}{\braillebox{14}}%
\uc@dclc{10250}{default}{\braillebox{24}}%
\uc@dclc{10251}{default}{\braillebox{124}}%
\uc@dclc{10252}{default}{\braillebox{34}}%
\uc@dclc{10253}{default}{\braillebox{134}}%
\uc@dclc{10254}{default}{\braillebox{234}}%
\uc@dclc{10255}{default}{\braillebox{1234}}%
\uc@dclc{10256}{default}{\braillebox{5}}%
\uc@dclc{10257}{default}{\braillebox{15}}%
\uc@dclc{10258}{default}{\braillebox{25}}%
\uc@dclc{10259}{default}{\braillebox{125}}%
\uc@dclc{10260}{default}{\braillebox{35}}%
\uc@dclc{10261}{default}{\braillebox{135}}%
\uc@dclc{10262}{default}{\braillebox{235}}%
\uc@dclc{10263}{default}{\braillebox{1235}}%
\uc@dclc{10264}{default}{\braillebox{45}}%
\uc@dclc{10265}{default}{\braillebox{145}}%
\uc@dclc{10266}{default}{\braillebox{245}}%
\uc@dclc{10267}{default}{\braillebox{1245}}%
\uc@dclc{10268}{default}{\braillebox{345}}%
\uc@dclc{10269}{default}{\braillebox{1345}}%
\uc@dclc{10270}{default}{\braillebox{2345}}%
\uc@dclc{10271}{default}{\braillebox{12345}}%
\uc@dclc{10272}{default}{\braillebox{6}}%
\uc@dclc{10273}{default}{\braillebox{16}}%
\uc@dclc{10274}{default}{\braillebox{26}}%
\uc@dclc{10275}{default}{\braillebox{126}}%
\uc@dclc{10276}{default}{\braillebox{36}}%
\uc@dclc{10277}{default}{\braillebox{136}}%
\uc@dclc{10278}{default}{\braillebox{236}}%
\uc@dclc{10279}{default}{\braillebox{1236}}%
\uc@dclc{10280}{default}{\braillebox{46}}%
\uc@dclc{10281}{default}{\braillebox{146}}%
\uc@dclc{10282}{default}{\braillebox{246}}%
\uc@dclc{10283}{default}{\braillebox{1246}}%
\uc@dclc{10284}{default}{\braillebox{346}}%
\uc@dclc{10285}{default}{\braillebox{1346}}%
\uc@dclc{10286}{default}{\braillebox{2346}}%
\uc@dclc{10287}{default}{\braillebox{12346}}%
\uc@dclc{10288}{default}{\braillebox{56}}%
\uc@dclc{10289}{default}{\braillebox{156}}%
\uc@dclc{10290}{default}{\braillebox{256}}%
\uc@dclc{10291}{default}{\braillebox{1256}}%
\uc@dclc{10292}{default}{\braillebox{356}}%
\uc@dclc{10293}{default}{\braillebox{1356}}%
\uc@dclc{10294}{default}{\braillebox{2356}}%
\uc@dclc{10295}{default}{\braillebox{12356}}%
\uc@dclc{10296}{default}{\braillebox{456}}%
\uc@dclc{10297}{default}{\braillebox{1456}}%
\uc@dclc{10298}{default}{\braillebox{2456}}%
\uc@dclc{10299}{default}{\braillebox{12456}}%
\uc@dclc{10300}{default}{\braillebox{3456}}%
\uc@dclc{10301}{default}{\braillebox{13456}}%
\uc@dclc{10302}{default}{\braillebox{23456}}%
\uc@dclc{10303}{default}{\braillebox{123456}}%
\uc@dclc{10304}{default}{\braillebox{7}}%
\uc@dclc{10305}{default}{\braillebox{17}}%
\uc@dclc{10306}{default}{\braillebox{27}}%
\uc@dclc{10307}{default}{\braillebox{127}}%
\uc@dclc{10308}{default}{\braillebox{37}}%
\uc@dclc{10309}{default}{\braillebox{137}}%
\uc@dclc{10310}{default}{\braillebox{237}}%
\uc@dclc{10311}{default}{\braillebox{1237}}%
\uc@dclc{10312}{default}{\braillebox{47}}%
\uc@dclc{10313}{default}{\braillebox{147}}%
\uc@dclc{10314}{default}{\braillebox{247}}%
\uc@dclc{10315}{default}{\braillebox{1247}}%
\uc@dclc{10316}{default}{\braillebox{347}}%
\uc@dclc{10317}{default}{\braillebox{1347}}%
\uc@dclc{10318}{default}{\braillebox{2347}}%
\uc@dclc{10319}{default}{\braillebox{12347}}%
\uc@dclc{10320}{default}{\braillebox{57}}%
\uc@dclc{10321}{default}{\braillebox{157}}%
\uc@dclc{10322}{default}{\braillebox{257}}%
\uc@dclc{10323}{default}{\braillebox{1257}}%
\uc@dclc{10324}{default}{\braillebox{357}}%
\uc@dclc{10325}{default}{\braillebox{1357}}%
\uc@dclc{10326}{default}{\braillebox{2357}}%
\uc@dclc{10327}{default}{\braillebox{12357}}%
\uc@dclc{10328}{default}{\braillebox{457}}%
\uc@dclc{10329}{default}{\braillebox{1457}}%
\uc@dclc{10330}{default}{\braillebox{2457}}%
\uc@dclc{10331}{default}{\braillebox{12457}}%
\uc@dclc{10332}{default}{\braillebox{3457}}%
\uc@dclc{10333}{default}{\braillebox{13457}}%
\uc@dclc{10334}{default}{\braillebox{23457}}%
\uc@dclc{10335}{default}{\braillebox{123457}}%
\uc@dclc{10336}{default}{\braillebox{67}}%
\uc@dclc{10337}{default}{\braillebox{167}}%
\uc@dclc{10338}{default}{\braillebox{267}}%
\uc@dclc{10339}{default}{\braillebox{1267}}%
\uc@dclc{10340}{default}{\braillebox{367}}%
\uc@dclc{10341}{default}{\braillebox{1367}}%
\uc@dclc{10342}{default}{\braillebox{2367}}%
\uc@dclc{10343}{default}{\braillebox{12367}}%
\uc@dclc{10344}{default}{\braillebox{467}}%
\uc@dclc{10345}{default}{\braillebox{1467}}%
\uc@dclc{10346}{default}{\braillebox{2467}}%
\uc@dclc{10347}{default}{\braillebox{12467}}%
\uc@dclc{10348}{default}{\braillebox{3467}}%
\uc@dclc{10349}{default}{\braillebox{13467}}%
\uc@dclc{10350}{default}{\braillebox{23467}}%
\uc@dclc{10351}{default}{\braillebox{123467}}%
\uc@dclc{10352}{default}{\braillebox{567}}%
\uc@dclc{10353}{default}{\braillebox{1567}}%
\uc@dclc{10354}{default}{\braillebox{2567}}%
\uc@dclc{10355}{default}{\braillebox{12567}}%
\uc@dclc{10356}{default}{\braillebox{3567}}%
\uc@dclc{10357}{default}{\braillebox{13567}}%
\uc@dclc{10358}{default}{\braillebox{23567}}%
\uc@dclc{10359}{default}{\braillebox{123567}}%
\uc@dclc{10360}{default}{\braillebox{4567}}%
\uc@dclc{10361}{default}{\braillebox{14567}}%
\uc@dclc{10362}{default}{\braillebox{24567}}%
\uc@dclc{10363}{default}{\braillebox{124567}}%
\uc@dclc{10364}{default}{\braillebox{34567}}%
\uc@dclc{10365}{default}{\braillebox{134567}}%
\uc@dclc{10366}{default}{\braillebox{234567}}%
\uc@dclc{10367}{default}{\braillebox{1234567}}%
\uc@dclc{10368}{default}{\braillebox{8}}%
\uc@dclc{10369}{default}{\braillebox{18}}%
\uc@dclc{10370}{default}{\braillebox{28}}%
\uc@dclc{10371}{default}{\braillebox{128}}%
\uc@dclc{10372}{default}{\braillebox{38}}%
\uc@dclc{10373}{default}{\braillebox{138}}%
\uc@dclc{10374}{default}{\braillebox{238}}%
\uc@dclc{10375}{default}{\braillebox{1238}}%
\uc@dclc{10376}{default}{\braillebox{48}}%
\uc@dclc{10377}{default}{\braillebox{148}}%
\uc@dclc{10378}{default}{\braillebox{248}}%
\uc@dclc{10379}{default}{\braillebox{1248}}%
\uc@dclc{10380}{default}{\braillebox{348}}%
\uc@dclc{10381}{default}{\braillebox{1348}}%
\uc@dclc{10382}{default}{\braillebox{2348}}%
\uc@dclc{10383}{default}{\braillebox{12348}}%
\uc@dclc{10384}{default}{\braillebox{58}}%
\uc@dclc{10385}{default}{\braillebox{158}}%
\uc@dclc{10386}{default}{\braillebox{258}}%
\uc@dclc{10387}{default}{\braillebox{1258}}%
\uc@dclc{10388}{default}{\braillebox{358}}%
\uc@dclc{10389}{default}{\braillebox{1358}}%
\uc@dclc{10390}{default}{\braillebox{2358}}%
\uc@dclc{10391}{default}{\braillebox{12358}}%
\uc@dclc{10392}{default}{\braillebox{458}}%
\uc@dclc{10393}{default}{\braillebox{1458}}%
\uc@dclc{10394}{default}{\braillebox{2458}}%
\uc@dclc{10395}{default}{\braillebox{12458}}%
\uc@dclc{10396}{default}{\braillebox{3458}}%
\uc@dclc{10397}{default}{\braillebox{13458}}%
\uc@dclc{10398}{default}{\braillebox{23458}}%
\uc@dclc{10399}{default}{\braillebox{123458}}%
\uc@dclc{10400}{default}{\braillebox{68}}%
\uc@dclc{10401}{default}{\braillebox{168}}%
\uc@dclc{10402}{default}{\braillebox{268}}%
\uc@dclc{10403}{default}{\braillebox{1268}}%
\uc@dclc{10404}{default}{\braillebox{368}}%
\uc@dclc{10405}{default}{\braillebox{1368}}%
\uc@dclc{10406}{default}{\braillebox{2368}}%
\uc@dclc{10407}{default}{\braillebox{12368}}%
\uc@dclc{10408}{default}{\braillebox{468}}%
\uc@dclc{10409}{default}{\braillebox{1468}}%
\uc@dclc{10410}{default}{\braillebox{2468}}%
\uc@dclc{10411}{default}{\braillebox{12468}}%
\uc@dclc{10412}{default}{\braillebox{3468}}%
\uc@dclc{10413}{default}{\braillebox{13468}}%
\uc@dclc{10414}{default}{\braillebox{23468}}%
\uc@dclc{10415}{default}{\braillebox{123468}}%
\uc@dclc{10416}{default}{\braillebox{568}}%
\uc@dclc{10417}{default}{\braillebox{1568}}%
\uc@dclc{10418}{default}{\braillebox{2568}}%
\uc@dclc{10419}{default}{\braillebox{12568}}%
\uc@dclc{10420}{default}{\braillebox{3568}}%
\uc@dclc{10421}{default}{\braillebox{13568}}%
\uc@dclc{10422}{default}{\braillebox{23568}}%
\uc@dclc{10423}{default}{\braillebox{123568}}%
\uc@dclc{10424}{default}{\braillebox{4568}}%
\uc@dclc{10425}{default}{\braillebox{14568}}%
\uc@dclc{10426}{default}{\braillebox{24568}}%
\uc@dclc{10427}{default}{\braillebox{124568}}%
\uc@dclc{10428}{default}{\braillebox{34568}}%
\uc@dclc{10429}{default}{\braillebox{134568}}%
\uc@dclc{10430}{default}{\braillebox{234568}}%
\uc@dclc{10431}{default}{\braillebox{1234568}}%
\uc@dclc{10432}{default}{\braillebox{78}}%
\uc@dclc{10433}{default}{\braillebox{178}}%
\uc@dclc{10434}{default}{\braillebox{278}}%
\uc@dclc{10435}{default}{\braillebox{1278}}%
\uc@dclc{10436}{default}{\braillebox{378}}%
\uc@dclc{10437}{default}{\braillebox{1378}}%
\uc@dclc{10438}{default}{\braillebox{2378}}%
\uc@dclc{10439}{default}{\braillebox{12378}}%
\uc@dclc{10440}{default}{\braillebox{478}}%
\uc@dclc{10441}{default}{\braillebox{1478}}%
\uc@dclc{10442}{default}{\braillebox{2478}}%
\uc@dclc{10443}{default}{\braillebox{12478}}%
\uc@dclc{10444}{default}{\braillebox{3478}}%
\uc@dclc{10445}{default}{\braillebox{13478}}%
\uc@dclc{10446}{default}{\braillebox{23478}}%
\uc@dclc{10447}{default}{\braillebox{123478}}%
\uc@dclc{10448}{default}{\braillebox{578}}%
\uc@dclc{10449}{default}{\braillebox{1578}}%
\uc@dclc{10450}{default}{\braillebox{2578}}%
\uc@dclc{10451}{default}{\braillebox{12578}}%
\uc@dclc{10452}{default}{\braillebox{3578}}%
\uc@dclc{10453}{default}{\braillebox{13578}}%
\uc@dclc{10454}{default}{\braillebox{23578}}%
\uc@dclc{10455}{default}{\braillebox{123578}}%
\uc@dclc{10456}{default}{\braillebox{4578}}%
\uc@dclc{10457}{default}{\braillebox{14578}}%
\uc@dclc{10458}{default}{\braillebox{24578}}%
\uc@dclc{10459}{default}{\braillebox{124578}}%
\uc@dclc{10460}{default}{\braillebox{34578}}%
\uc@dclc{10461}{default}{\braillebox{134578}}%
\uc@dclc{10462}{default}{\braillebox{234578}}%
\uc@dclc{10463}{default}{\braillebox{1234578}}%
\uc@dclc{10464}{default}{\braillebox{678}}%
\uc@dclc{10465}{default}{\braillebox{1678}}%
\uc@dclc{10466}{default}{\braillebox{2678}}%
\uc@dclc{10467}{default}{\braillebox{12678}}%
\uc@dclc{10468}{default}{\braillebox{3678}}%
\uc@dclc{10469}{default}{\braillebox{13678}}%
\uc@dclc{10470}{default}{\braillebox{23678}}%
\uc@dclc{10471}{default}{\braillebox{123678}}%
\uc@dclc{10472}{default}{\braillebox{4678}}%
\uc@dclc{10473}{default}{\braillebox{14678}}%
\uc@dclc{10474}{default}{\braillebox{24678}}%
\uc@dclc{10475}{default}{\braillebox{124678}}%
\uc@dclc{10476}{default}{\braillebox{34678}}%
\uc@dclc{10477}{default}{\braillebox{134678}}%
\uc@dclc{10478}{default}{\braillebox{234678}}%
\uc@dclc{10479}{default}{\braillebox{1234678}}%
\uc@dclc{10480}{default}{\braillebox{5678}}%
\uc@dclc{10481}{default}{\braillebox{15678}}%
\uc@dclc{10482}{default}{\braillebox{25678}}%
\uc@dclc{10483}{default}{\braillebox{125678}}%
\uc@dclc{10484}{default}{\braillebox{35678}}%
\uc@dclc{10485}{default}{\braillebox{135678}}%
\uc@dclc{10486}{default}{\braillebox{235678}}%
\uc@dclc{10487}{default}{\braillebox{1235678}}%
\uc@dclc{10488}{default}{\braillebox{45678}}%
\uc@dclc{10489}{default}{\braillebox{145678}}%
\uc@dclc{10490}{default}{\braillebox{245678}}%
\uc@dclc{10491}{default}{\braillebox{1245678}}%
\uc@dclc{10492}{default}{\braillebox{345678}}%
\uc@dclc{10493}{default}{\braillebox{1345678}}%
\uc@dclc{10494}{default}{\braillebox{2345678}}%
\uc@dclc{10495}{default}{\braillebox{12345678}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
