%%% Unicode to TeX mapping, file uni-1.def, U+0100..U+01FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-1.def}[2013/05/13 UCS: Unicode data U+0100..U+01FF]%
\fi
\uc@dclc{256}{default}{\@tabacckludge=A}%
\uc@dclc{257}{default}{\@tabacckludge=a}%
\uc@dclc{258}{default}{\u A}%
\uc@dclc{259}{default}{\u a}%
\uc@dclc{260}{default}{\k A}%
\uc@dclc{261}{default}{\k a}%
\uc@dclc{262}{default}{\@tabacckludge'C}%
\uc@dclc{263}{default}{\@tabacckludge'c}%
\uc@dclc{264}{default}{\^C}%
\uc@dclc{265}{default}{\^c}%
\uc@dclc{266}{default}{\.C}%
\uc@dclc{267}{default}{\.c}%
\uc@dclc{268}{default}{\v C}%
\uc@dclc{269}{default}{\v c}%
\uc@dclc{270}{default}{\v D}%
\uc@dclc{271}{default}{\v d}%
\uc@dclc{272}{default}{\DJ}%
\uc@dclc{273}{default}{\dj}%
\uc@dclc{274}{default}{\@tabacckludge=E}%
\uc@dclc{275}{default}{\@tabacckludge=e}%
\uc@dclc{276}{default}{\u E}%
\uc@dclc{277}{default}{\u e}%
\uc@dclc{278}{default}{\.E}%
\uc@dclc{279}{default}{\.e}%
\uc@dclc{280}{default}{\k E}%
\uc@dclc{281}{default}{\k e}%
\uc@dclc{282}{default}{\v E}%
\uc@dclc{283}{default}{\v e}%
\uc@dclc{284}{default}{\^G}%
\uc@dclc{285}{default}{\^g}%
\uc@dclc{286}{default}{\u G}%
\uc@dclc{287}{default}{\u g}%
\uc@dclc{288}{default}{\.G}%
\uc@dclc{289}{default}{\.g}%
\uc@dclc{290}{default}{\c G}%
\uc@dclc{291}{dirty}{\leavevmode\vbox{\baselineskip\z@skip\ialign{\hss##\hss\crcr\vbox to.65ex{\hbox{\char"60}\vss}\crcr g\crcr}}}%
\uc@dclc{292}{default}{\^H}%
\uc@dclc{293}{default}{\^h}%
\uc@dclc{294}{default}{\textHbar}%
\uc@dclc{294}{dirty}{\leavevmode\rlap{\={\empty}}H\llap{\={\empty}}}%
\uc@dclc{295}{tipa}{\textcrh}%
\uc@dclc{295}{default}{\texthbar}%
\uc@dclc{295}{dirty}{\leavevmode\rlap{\={\empty}}h}%
\uc@dclc{296}{default}{\~I}%
\uc@dclc{297}{default}{\~\i}%
\uc@dclc{298}{default}{\@tabacckludge=I}%
\uc@dclc{299}{default}{\@tabacckludge=\i}%
\uc@dclc{300}{default}{\u I}%
\uc@dclc{301}{default}{\u\i}%
\uc@dclc{302}{default}{\k I}%
\uc@dclc{303}{default}{\k i}%
\uc@dclc{304}{default}{\.I}%
\uc@dclc{305}{default}{\i}%
\uc@dclc{306}{autogenerated}{\unichar{73}\unichar{74}}%
\uc@dclc{307}{autogenerated}{\unichar{105}\unichar{106}}%
\uc@dclc{308}{default}{\^J}%
\uc@dclc{309}{default}{\^\j}%
\uc@dclc{310}{default}{\c K}%
\uc@dclc{311}{default}{\c k}%
\uc@dclc{313}{default}{\@tabacckludge'L}%
\uc@dclc{314}{default}{\@tabacckludge'l}%
\uc@dclc{315}{default}{\c L}%
\uc@dclc{316}{default}{\c l}%
\uc@dclc{317}{default}{\v L}%
\uc@dclc{318}{default}{\v l}%
\uc@dclc{319}{autogenerated}{\unichar{76}\unichar{183}}%
\uc@dclc{320}{autogenerated}{\unichar{108}\unichar{183}}%
\uc@dclc{321}{default}{\L}%
\uc@dclc{322}{default}{\l}%
\uc@dclc{323}{default}{\@tabacckludge'N}%
\uc@dclc{324}{default}{\@tabacckludge'n}%
\uc@dclc{325}{default}{\c N}%
\uc@dclc{326}{default}{\c n}%
\uc@dclc{327}{default}{\v N}%
\uc@dclc{328}{default}{\v n}%
\uc@dclc{330}{default}{\NG}%
\uc@dclc{331}{default}{\ng}%
\uc@dclc{332}{default}{\@tabacckludge=O}%
\uc@dclc{333}{default}{\@tabacckludge=o}%
\uc@dclc{334}{default}{\u O}%
\uc@dclc{335}{default}{\u o}%
\uc@dclc{336}{default}{\H O}%
\uc@dclc{337}{default}{\H o}%
\uc@dclc{338}{default}{\OE}%
\uc@dclc{339}{default}{\oe}%
\uc@dclc{340}{default}{\@tabacckludge'R}%
\uc@dclc{341}{default}{\@tabacckludge'r}%
\uc@dclc{342}{default}{\c R}%
\uc@dclc{343}{default}{\c r}%
\uc@dclc{344}{default}{\v R}%
\uc@dclc{345}{default}{\v r}%
\uc@dclc{346}{default}{\@tabacckludge'S}%
\uc@dclc{347}{default}{\@tabacckludge's}%
\uc@dclc{348}{default}{\^S}%
\uc@dclc{349}{default}{\^s}%
\uc@dclc{350}{default}{\c S}%
\uc@dclc{351}{default}{\c s}%
\uc@dclc{352}{default}{\v S}%
\uc@dclc{353}{default}{\v s}%
\uc@dclc{354}{default}{\c T}%
\uc@dclc{355}{default}{\c t}%
\uc@dclc{356}{default}{\v T}%
\uc@dclc{357}{default}{\v t}%
\uc@dclc{358}{default}{\textTbar}%
\uc@dclc{359}{default}{\texttbar}%
\uc@dclc{360}{default}{\~U}%
\uc@dclc{361}{default}{\~u}%
\uc@dclc{362}{default}{\@tabacckludge=U}%
\uc@dclc{363}{default}{\@tabacckludge=u}%
\uc@dclc{364}{default}{\u U}%
\uc@dclc{365}{default}{\u u}%
\uc@dclc{366}{default}{\r U}%
\uc@dclc{367}{default}{\r u}%
\uc@dclc{368}{default}{\H U}%
\uc@dclc{369}{default}{\H u}%
\uc@dclc{370}{default}{\k U}%
\uc@dclc{371}{default}{\k u}%
\uc@dclc{372}{default}{\^W}%
\uc@dclc{373}{default}{\^w}%
\uc@dclc{374}{default}{\^Y}%
\uc@dclc{375}{default}{\^y}%
\uc@dclc{376}{default}{\"Y}%
\uc@dclc{377}{default}{\@tabacckludge'Z}%
\uc@dclc{378}{default}{\@tabacckludge'z}%
\uc@dclc{379}{default}{\.Z}%
\uc@dclc{380}{default}{\.z}%
\uc@dclc{381}{default}{\v Z}%
\uc@dclc{382}{default}{\v z}%
\uc@dclc{383}{autogenerated}{\unichar{115}}%
\uc@dclc{385}{default}{\textBhook}%
\uc@dclc{390}{default}{\textOopen}%
\uc@dclc{391}{default}{\textChook}%
\uc@dclc{392}{default}{\textchook}%
\uc@dclc{393}{default}{\textDafrican}%
\uc@dclc{394}{default}{\textDhook}%
\uc@dclc{398}{default}{\textEreversed}%
\uc@dclc{400}{default}{\textEopen}%
\uc@dclc{401}{default}{\textFhook}%
\uc@dclc{402}{default}{\textflorin}%
\uc@dclc{402}{postscript}{\Pisymbol{psy}{"A6}}%
\uc@dclc{404}{default}{\textGammaafrican}%
\uc@dclc{406}{default}{\textIotaafrican}%
\uc@dclc{408}{default}{\textKhook}%
\uc@dclc{409}{default}{\textkhook}%
\uc@dclc{413}{default}{\textNhookleft}%
\uc@dclc{416}{default}{\horn O}%
\uc@dclc{417}{default}{\horn o}%
\uc@dclc{420}{default}{\textPhook}%
\uc@dclc{421}{default}{\textphook}%
\uc@dclc{425}{default}{\textEsh}%
\uc@dclc{428}{default}{\textThook}%
\uc@dclc{429}{default}{\textthook}%
\uc@dclc{430}{default}{\textTretroflexhook}%
\uc@dclc{431}{default}{\horn U}%
\uc@dclc{432}{default}{\horn u}%
\uc@dclc{434}{default}{\textVhook}%
\uc@dclc{435}{default}{\textYhook}%
\uc@dclc{436}{default}{\textyhook}%
\uc@dclc{439}{default}{\textEzh}%
\uc@dclc{452}{autogenerated}{\unichar{68}\unichar{381}}%
\uc@dclc{453}{autogenerated}{\unichar{68}\unichar{382}}%
\uc@dclc{454}{autogenerated}{\unichar{100}\unichar{382}}%
\uc@dclc{455}{autogenerated}{\unichar{76}\unichar{74}}%
\uc@dclc{456}{autogenerated}{\unichar{76}\unichar{106}}%
\uc@dclc{457}{autogenerated}{\unichar{108}\unichar{106}}%
\uc@dclc{458}{autogenerated}{\unichar{78}\unichar{74}}%
\uc@dclc{459}{autogenerated}{\unichar{78}\unichar{106}}%
\uc@dclc{460}{autogenerated}{\unichar{110}\unichar{106}}%
\uc@dclc{461}{default}{\v A}%
\uc@dclc{462}{default}{\v a}%
\uc@dclc{463}{default}{\v I}%
\uc@dclc{464}{default}{\v\i}%
\uc@dclc{465}{default}{\v O}%
\uc@dclc{466}{default}{\v o}%
\uc@dclc{467}{default}{\v U}%
\uc@dclc{468}{default}{\v u}%
\uc@dclc{469}{default}{\@tabacckludge={\"U}}%
\uc@dclc{470}{default}{\@tabacckludge={\"u}}%
\uc@dclc{471}{default}{\@tabacckludge'{\"U}}%
\uc@dclc{472}{default}{\@tabacckludge'{\"u}}%
\uc@dclc{473}{default}{\v{\"U}}%
\uc@dclc{474}{default}{\v{\"u}}%
\uc@dclc{475}{default}{\@tabacckludge`{\"U}}%
\uc@dclc{476}{default}{\@tabacckludge`{\"u}}%
\uc@dclc{477}{default}{\texteturned}%
\uc@dclc{478}{default}{\@tabacckludge={\"A}}%
\uc@dclc{479}{default}{\@tabacckludge={\"a}}%
\uc@dclc{480}{autogenerated}{\unichar{550}\unichar{772}}%
\uc@dclc{481}{autogenerated}{\unichar{551}\unichar{772}}%
\uc@dclc{482}{default}{\@tabacckludge=\AE}%
\uc@dclc{483}{default}{\@tabacckludge=\ae}%
\uc@dclc{486}{default}{\v G}%
\uc@dclc{487}{default}{\v g}%
\uc@dclc{488}{default}{\v K}%
\uc@dclc{489}{default}{\v k}%
\uc@dclc{490}{default}{\k O}%
\uc@dclc{491}{default}{\k o}%
\uc@dclc{492}{autogenerated}{\unichar{490}\unichar{772}}%
\uc@dclc{493}{autogenerated}{\unichar{491}\unichar{772}}%
\uc@dclc{494}{default}{\v\textEzh}%
\uc@dclc{495}{default}{\v\textezh}%
\uc@dclc{496}{default}{\v\j}%
\uc@dclc{497}{autogenerated}{\unichar{68}\unichar{90}}%
\uc@dclc{498}{autogenerated}{\unichar{68}\unichar{122}}%
\uc@dclc{499}{autogenerated}{\unichar{100}\unichar{122}}%
\uc@dclc{500}{default}{\@tabacckludge'G}%
\uc@dclc{501}{default}{\@tabacckludge'g}%
\uc@dclc{504}{default}{\@tabacckludge`N}%
\uc@dclc{505}{default}{\@tabacckludge`n}%
\uc@dclc{506}{default}{\@tabacckludge'{\r A}}%
\uc@dclc{507}{default}{\@tabacckludge'{\r a}}%
\uc@dclc{508}{default}{\@tabacckludge'\AE}%
\uc@dclc{509}{default}{\@tabacckludge'\ae}%
\uc@dclc{510}{default}{\@tabacckludge'\O}%
\uc@dclc{511}{default}{\@tabacckludge'\o}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
