%%
%% This is file `ldvenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ucs.dtx  (with options: `ldvenc.def')
%% 
%% Copyright 2001 Dominique Unruh  <unruh@ut.ee>
%% Copyright 2013 Wolfgang Jeltsch <wolfgang@cs.ioc.ee>
%% 
%% This program is provided under the terms of the LaTeX Project Public License with some
%% modifications. See the file LICENSE for information.
%% 
\NeedsTeXFormat{LaTeX2e}[1998/12/01]
\ProvidesFile{ldvenc.def}[2004/10/17 Autogenerated encoding LDV]
\DeclareFontEncoding{LDV}{}{}
\DeclareFontSubstitution{LDV}{arial}{m}{n}
\DeclareTextSymbol{\guillemotleft}{LDV}{19}
\DeclareTextSymbol{\guillemotright}{LDV}{20}
\DeclareTextSymbol{\guilsinglleft}{LDV}{14}
\DeclareTextSymbol{\guilsinglright}{LDV}{15}
\DeclareTextSymbol{\i}{LDV}{25}
\DeclareTextSymbol{\quotedblbase}{LDV}{18}
\DeclareTextSymbol{\quotesinglbase}{LDV}{13}
\DeclareTextSymbol{\textasciicircum}{LDV}{`\^}
\DeclareTextSymbol{\textasciitilde}{LDV}{`\~}
\DeclareTextSymbol{\textbackslash}{LDV}{`\\}
\DeclareTextSymbol{\textbar}{LDV}{`\|}
\DeclareTextSymbol{\textbraceleft}{LDV}{`\{}
\DeclareTextSymbol{\textbraceright}{LDV}{`\}}
\DeclareTextSymbol{\textdollar}{LDV}{`\$}
\DeclareTextSymbol{\textemdash}{LDV}{22}
\DeclareTextSymbol{\textendash}{LDV}{21}
\DeclareTextSymbol{\textgreater}{LDV}{`\>}
\DeclareTextSymbol{\textless}{LDV}{`\<}
\DeclareTextSymbol{\textquotedblleft}{LDV}{16}
\DeclareTextSymbol{\textquotedblright}{LDV}{17}
\DeclareTextSymbol{\textquotedbl}{LDV}{`\"}
\DeclareTextSymbol{\textquoteleft}{LDV}{`\`}
\DeclareTextSymbol{\textquoteright}{LDV}{`\'}
\DeclareTextSymbol{\textunderscore}{LDV}{95}
\DeclareTextCommand{\textdevanagaricandrabindu}{LDV}[1]{#1\char129 }
\DeclareTextCommand{\textdevanagarianusvara}{LDV}[1]{#1\char130 }
\DeclareTextCommand{\textdevanagarivisarga}{LDV}[1]{#1\char131 }
\DeclareTextSymbol{\textdevanagaria}{LDV}{133}
\DeclareTextSymbol{\textdevanagariaa}{LDV}{134}
\DeclareTextSymbol{\textdevanagarii}{LDV}{135}
\DeclareTextSymbol{\textdevanagariii}{LDV}{136}
\DeclareTextSymbol{\textdevanagariu}{LDV}{137}
\DeclareTextSymbol{\textdevanagariuu}{LDV}{138}
\DeclareTextSymbol{\textdevanagarivocalicr}{LDV}{139}
\DeclareTextSymbol{\textdevanagarivocalicl}{LDV}{140}
\DeclareTextSymbol{\textdevanagaricandrae}{LDV}{141}
\DeclareTextSymbol{\textdevanagarishorte}{LDV}{142}
\DeclareTextSymbol{\textdevanagarie}{LDV}{143}
\DeclareTextSymbol{\textdevanagariai}{LDV}{144}
\DeclareTextSymbol{\textdevanagaricandrao}{LDV}{145}
\DeclareTextSymbol{\textdevanagarishorto}{LDV}{146}
\DeclareTextSymbol{\textdevanagario}{LDV}{147}
\DeclareTextSymbol{\textdevanagariau}{LDV}{148}
\DeclareTextSymbol{\textdevanagarika}{LDV}{149}
\DeclareTextSymbol{\textdevanagarikha}{LDV}{150}
\DeclareTextSymbol{\textdevanagariga}{LDV}{151}
\DeclareTextSymbol{\textdevanagarigha}{LDV}{152}
\DeclareTextSymbol{\textdevanagaringa}{LDV}{153}
\DeclareTextSymbol{\textdevanagarica}{LDV}{154}
\DeclareTextSymbol{\textdevanagaricha}{LDV}{155}
\DeclareTextSymbol{\textdevanagarija}{LDV}{156}
\DeclareTextSymbol{\textdevanagarijha}{LDV}{157}
\DeclareTextSymbol{\textdevanagarinya}{LDV}{158}
\DeclareTextSymbol{\textdevanagaritta}{LDV}{159}
\DeclareTextSymbol{\textdevanagarittha}{LDV}{160}
\DeclareTextSymbol{\textdevanagaridda}{LDV}{161}
\DeclareTextSymbol{\textdevanagariddha}{LDV}{162}
\DeclareTextSymbol{\textdevanagarinna}{LDV}{163}
\DeclareTextSymbol{\textdevanagarita}{LDV}{164}
\DeclareTextSymbol{\textdevanagaritha}{LDV}{165}
\DeclareTextSymbol{\textdevanagarida}{LDV}{166}
\DeclareTextSymbol{\textdevanagaridha}{LDV}{167}
\DeclareTextSymbol{\textdevanagarina}{LDV}{168}
\DeclareTextSymbol{\textdevanagarinnna}{LDV}{169}
\DeclareTextSymbol{\textdevanagaripa}{LDV}{170}
\DeclareTextSymbol{\textdevanagaripha}{LDV}{171}
\DeclareTextSymbol{\textdevanagariba}{LDV}{172}
\DeclareTextSymbol{\textdevanagaribha}{LDV}{173}
\DeclareTextSymbol{\textdevanagarima}{LDV}{174}
\DeclareTextSymbol{\textdevanagariya}{LDV}{175}
\DeclareTextSymbol{\textdevanagarira}{LDV}{176}
\DeclareTextSymbol{\textdevanagarirra}{LDV}{177}
\DeclareTextSymbol{\textdevanagarila}{LDV}{178}
\DeclareTextSymbol{\textdevanagarilla}{LDV}{179}
\DeclareTextSymbol{\textdevanagarillla}{LDV}{180}
\DeclareTextSymbol{\textdevanagariva}{LDV}{181}
\DeclareTextSymbol{\textdevanagarisha}{LDV}{182}
\DeclareTextSymbol{\textdevanagarissa}{LDV}{183}
\DeclareTextSymbol{\textdevanagarisa}{LDV}{184}
\DeclareTextSymbol{\textdevanagariha}{LDV}{185}
\DeclareTextCommand{\textdevanagarinukta}{LDV}[1]{#1\char188 }
\DeclareTextSymbol{\textdevanagariavagraha}{LDV}{189}
\DeclareTextCommand{\textdevanagarivowelaa}{LDV}[1]{#1\char190 }
\DeclareTextCommand{\textdevanagarivoweli}{LDV}[1]{\char191 #1}
\DeclareTextCommand{\textdevanagarivowelii}{LDV}[1]{#1\char192 }
\DeclareTextCommand{\textdevanagarivowelu}{LDV}[1]{#1\char193 }
\DeclareTextCommand{\textdevanagarivoweluu}{LDV}[1]{#1\char194 }
\DeclareTextCommand{\textdevanagarivowelvocalicr}{LDV}[1]{#1\char195 }
\DeclareTextCommand{\textdevanagarivowelvocalicrr}{LDV}[1]{#1\char196 }
\DeclareTextCommand{\textdevanagarivowelcandrae}{LDV}[1]{#1\char197 }
\DeclareTextCommand{\textdevanagarivowelshorte}{LDV}[1]{#1\char198 }
\DeclareTextCommand{\textdevanagarivowele}{LDV}[1]{#1\char199 }
\DeclareTextCommand{\textdevanagarivowelai}{LDV}[1]{#1\char200 }
\DeclareTextCommand{\textdevanagarivowelcandrao}{LDV}[1]{#1\char201 }
\DeclareTextCommand{\textdevanagarivowelshorto}{LDV}[1]{#1\char202 }
\DeclareTextCommand{\textdevanagarivowelo}{LDV}[1]{#1\char203 }
\DeclareTextCommand{\textdevanagarivowelau}{LDV}[1]{#1\char204 }
\DeclareTextCommand{\textdevanagarivirama}{LDV}[1]{#1\char205 }
\DeclareTextSymbol{\textdevanagariom}{LDV}{208}
\DeclareTextCommand{\textdevanagariudatta}{LDV}[1]{#1\char209 }
\DeclareTextCommand{\textdevanagarianudatta}{LDV}[1]{#1\char210 }
\DeclareTextCommand{\`}{LDV}[1]{#1\char211 }
\DeclareTextCommand{\'}{LDV}[1]{#1\char212 }
\DeclareTextSymbol{\textdevanagariqa}{LDV}{216}
\DeclareTextSymbol{\textdevanagarikhha}{LDV}{217}
\DeclareTextSymbol{\textdevanagarighha}{LDV}{218}
\DeclareTextSymbol{\textdevanagariza}{LDV}{219}
\DeclareTextSymbol{\textdevanagaridddha}{LDV}{220}
\DeclareTextSymbol{\textdevanagarirha}{LDV}{221}
\DeclareTextSymbol{\textdevanagarifa}{LDV}{222}
\DeclareTextSymbol{\textdevanagariyya}{LDV}{223}
\DeclareTextSymbol{\textdevanagarivocalicrr}{LDV}{224}
\DeclareTextSymbol{\textdevanagarivocalicll}{LDV}{225}
\DeclareTextCommand{\textdevanagarivowelvocalicl}{LDV}[1]{#1\char226 }
\DeclareTextCommand{\textdevanagarivowelvocalicll}{LDV}[1]{#1\char227 }
\DeclareTextSymbol{\textdevanagaridanda}{LDV}{228}
\DeclareTextSymbol{\textdevanagaridoubledanda}{LDV}{229}
\DeclareTextSymbol{\textdevanagarizero}{LDV}{230}
\DeclareTextSymbol{\textdevanagarione}{LDV}{231}
\DeclareTextSymbol{\textdevanagaritwo}{LDV}{232}
\DeclareTextSymbol{\textdevanagarithree}{LDV}{233}
\DeclareTextSymbol{\textdevanagarifour}{LDV}{234}
\DeclareTextSymbol{\textdevanagarifive}{LDV}{235}
\DeclareTextSymbol{\textdevanagarisix}{LDV}{236}
\DeclareTextSymbol{\textdevanagariseven}{LDV}{237}
\DeclareTextSymbol{\textdevanagarieight}{LDV}{238}
\DeclareTextSymbol{\textdevanagarinine}{LDV}{239}
\DeclareTextSymbol{\textdevanagariabbreviation}{LDV}{240}
