%%% Unicode to TeX mapping, file uni-469.def, U+1D500..U+1D5FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-469.def}[2013/05/13 UCS: Unicode data U+1D500..U+1D5FF]%
\fi
\uc@dclc{120064}{autogenerated}{\unichar{119}}%
\uc@dclc{120065}{autogenerated}{\unichar{120}}%
\uc@dclc{120066}{autogenerated}{\unichar{121}}%
\uc@dclc{120067}{autogenerated}{\unichar{122}}%
\uc@dclc{120068}{default}{\ensuremath{\mathfrak A}}%
\uc@dclc{120069}{default}{\ensuremath{\mathfrak B}}%
\uc@dclc{120071}{default}{\ensuremath{\mathfrak D}}%
\uc@dclc{120072}{default}{\ensuremath{\mathfrak E}}%
\uc@dclc{120073}{default}{\ensuremath{\mathfrak F}}%
\uc@dclc{120074}{default}{\ensuremath{\mathfrak G}}%
\uc@dclc{120077}{default}{\ensuremath{\mathfrak J}}%
\uc@dclc{120078}{default}{\ensuremath{\mathfrak K}}%
\uc@dclc{120079}{default}{\ensuremath{\mathfrak L}}%
\uc@dclc{120080}{default}{\ensuremath{\mathfrak M}}%
\uc@dclc{120081}{default}{\ensuremath{\mathfrak N}}%
\uc@dclc{120082}{default}{\ensuremath{\mathfrak O}}%
\uc@dclc{120083}{default}{\ensuremath{\mathfrak P}}%
\uc@dclc{120084}{default}{\ensuremath{\mathfrak Q}}%
\uc@dclc{120086}{default}{\ensuremath{\mathfrak S}}%
\uc@dclc{120087}{default}{\ensuremath{\mathfrak T}}%
\uc@dclc{120088}{default}{\ensuremath{\mathfrak U}}%
\uc@dclc{120089}{default}{\ensuremath{\mathfrak V}}%
\uc@dclc{120090}{default}{\ensuremath{\mathfrak W}}%
\uc@dclc{120091}{default}{\ensuremath{\mathfrak X}}%
\uc@dclc{120092}{default}{\ensuremath{\mathfrak Y}}%
\uc@dclc{120094}{default}{\ensuremath{\mathfrak a}}%
\uc@dclc{120095}{default}{\ensuremath{\mathfrak b}}%
\uc@dclc{120096}{default}{\ensuremath{\mathfrak c}}%
\uc@dclc{120097}{default}{\ensuremath{\mathfrak d}}%
\uc@dclc{120098}{default}{\ensuremath{\mathfrak e}}%
\uc@dclc{120099}{default}{\ensuremath{\mathfrak f}}%
\uc@dclc{120100}{default}{\ensuremath{\mathfrak g}}%
\uc@dclc{120101}{default}{\ensuremath{\mathfrak h}}%
\uc@dclc{120102}{default}{\ensuremath{\mathfrak i}}%
\uc@dclc{120103}{default}{\ensuremath{\mathfrak j}}%
\uc@dclc{120104}{default}{\ensuremath{\mathfrak k}}%
\uc@dclc{120105}{default}{\ensuremath{\mathfrak l}}%
\uc@dclc{120106}{default}{\ensuremath{\mathfrak m}}%
\uc@dclc{120107}{default}{\ensuremath{\mathfrak n}}%
\uc@dclc{120108}{default}{\ensuremath{\mathfrak o}}%
\uc@dclc{120109}{default}{\ensuremath{\mathfrak p}}%
\uc@dclc{120110}{default}{\ensuremath{\mathfrak q}}%
\uc@dclc{120111}{default}{\ensuremath{\mathfrak r}}%
\uc@dclc{120112}{default}{\ensuremath{\mathfrak s}}%
\uc@dclc{120113}{default}{\ensuremath{\mathfrak t}}%
\uc@dclc{120114}{default}{\ensuremath{\mathfrak u}}%
\uc@dclc{120115}{default}{\ensuremath{\mathfrak v}}%
\uc@dclc{120116}{default}{\ensuremath{\mathfrak w}}%
\uc@dclc{120117}{default}{\ensuremath{\mathfrak x}}%
\uc@dclc{120118}{default}{\ensuremath{\mathfrak y}}%
\uc@dclc{120119}{default}{\ensuremath{\mathfrak z}}%
\uc@dclc{120120}{default}{\ensuremath{\mathbb A}}%
\uc@dclc{120121}{default}{\ensuremath{\mathbb B}}%
\uc@dclc{120123}{default}{\ensuremath{\mathbb D}}%
\uc@dclc{120124}{default}{\ensuremath{\mathbb E}}%
\uc@dclc{120125}{default}{\ensuremath{\mathbb F}}%
\uc@dclc{120126}{default}{\ensuremath{\mathbb G}}%
\uc@dclc{120128}{default}{\ensuremath{\mathbb I}}%
\uc@dclc{120129}{default}{\ensuremath{\mathbb J}}%
\uc@dclc{120130}{default}{\ensuremath{\mathbb K}}%
\uc@dclc{120131}{default}{\ensuremath{\mathbb L}}%
\uc@dclc{120132}{default}{\ensuremath{\mathbb M}}%
\uc@dclc{120134}{default}{\ensuremath{\mathbb O}}%
\uc@dclc{120138}{default}{\ensuremath{\mathbb S}}%
\uc@dclc{120139}{default}{\ensuremath{\mathbb T}}%
\uc@dclc{120140}{default}{\ensuremath{\mathbb U}}%
\uc@dclc{120141}{default}{\ensuremath{\mathbb V}}%
\uc@dclc{120142}{default}{\ensuremath{\mathbb W}}%
\uc@dclc{120143}{default}{\ensuremath{\mathbb X}}%
\uc@dclc{120144}{default}{\ensuremath{\mathbb Y}}%
\uc@dclc{120146}{autogenerated}{\unichar{97}}%
\uc@dclc{120147}{autogenerated}{\unichar{98}}%
\uc@dclc{120148}{autogenerated}{\unichar{99}}%
\uc@dclc{120149}{autogenerated}{\unichar{100}}%
\uc@dclc{120150}{autogenerated}{\unichar{101}}%
\uc@dclc{120151}{autogenerated}{\unichar{102}}%
\uc@dclc{120152}{autogenerated}{\unichar{103}}%
\uc@dclc{120153}{autogenerated}{\unichar{104}}%
\uc@dclc{120154}{autogenerated}{\unichar{105}}%
\uc@dclc{120155}{autogenerated}{\unichar{106}}%
\uc@dclc{120156}{autogenerated}{\unichar{107}}%
\uc@dclc{120157}{autogenerated}{\unichar{108}}%
\uc@dclc{120158}{autogenerated}{\unichar{109}}%
\uc@dclc{120159}{autogenerated}{\unichar{110}}%
\uc@dclc{120160}{autogenerated}{\unichar{111}}%
\uc@dclc{120161}{autogenerated}{\unichar{112}}%
\uc@dclc{120162}{autogenerated}{\unichar{113}}%
\uc@dclc{120163}{autogenerated}{\unichar{114}}%
\uc@dclc{120164}{autogenerated}{\unichar{115}}%
\uc@dclc{120165}{autogenerated}{\unichar{116}}%
\uc@dclc{120166}{autogenerated}{\unichar{117}}%
\uc@dclc{120167}{autogenerated}{\unichar{118}}%
\uc@dclc{120168}{autogenerated}{\unichar{119}}%
\uc@dclc{120169}{autogenerated}{\unichar{120}}%
\uc@dclc{120170}{autogenerated}{\unichar{121}}%
\uc@dclc{120171}{autogenerated}{\unichar{122}}%
\uc@dclc{120172}{autogenerated}{\unichar{65}}%
\uc@dclc{120173}{autogenerated}{\unichar{66}}%
\uc@dclc{120174}{autogenerated}{\unichar{67}}%
\uc@dclc{120175}{autogenerated}{\unichar{68}}%
\uc@dclc{120176}{autogenerated}{\unichar{69}}%
\uc@dclc{120177}{autogenerated}{\unichar{70}}%
\uc@dclc{120178}{autogenerated}{\unichar{71}}%
\uc@dclc{120179}{autogenerated}{\unichar{72}}%
\uc@dclc{120180}{autogenerated}{\unichar{73}}%
\uc@dclc{120181}{autogenerated}{\unichar{74}}%
\uc@dclc{120182}{autogenerated}{\unichar{75}}%
\uc@dclc{120183}{autogenerated}{\unichar{76}}%
\uc@dclc{120184}{autogenerated}{\unichar{77}}%
\uc@dclc{120185}{autogenerated}{\unichar{78}}%
\uc@dclc{120186}{autogenerated}{\unichar{79}}%
\uc@dclc{120187}{autogenerated}{\unichar{80}}%
\uc@dclc{120188}{autogenerated}{\unichar{81}}%
\uc@dclc{120189}{autogenerated}{\unichar{82}}%
\uc@dclc{120190}{autogenerated}{\unichar{83}}%
\uc@dclc{120191}{autogenerated}{\unichar{84}}%
\uc@dclc{120192}{autogenerated}{\unichar{85}}%
\uc@dclc{120193}{autogenerated}{\unichar{86}}%
\uc@dclc{120194}{autogenerated}{\unichar{87}}%
\uc@dclc{120195}{autogenerated}{\unichar{88}}%
\uc@dclc{120196}{autogenerated}{\unichar{89}}%
\uc@dclc{120197}{autogenerated}{\unichar{90}}%
\uc@dclc{120198}{autogenerated}{\unichar{97}}%
\uc@dclc{120199}{autogenerated}{\unichar{98}}%
\uc@dclc{120200}{autogenerated}{\unichar{99}}%
\uc@dclc{120201}{autogenerated}{\unichar{100}}%
\uc@dclc{120202}{autogenerated}{\unichar{101}}%
\uc@dclc{120203}{autogenerated}{\unichar{102}}%
\uc@dclc{120204}{autogenerated}{\unichar{103}}%
\uc@dclc{120205}{autogenerated}{\unichar{104}}%
\uc@dclc{120206}{autogenerated}{\unichar{105}}%
\uc@dclc{120207}{autogenerated}{\unichar{106}}%
\uc@dclc{120208}{autogenerated}{\unichar{107}}%
\uc@dclc{120209}{autogenerated}{\unichar{108}}%
\uc@dclc{120210}{autogenerated}{\unichar{109}}%
\uc@dclc{120211}{autogenerated}{\unichar{110}}%
\uc@dclc{120212}{autogenerated}{\unichar{111}}%
\uc@dclc{120213}{autogenerated}{\unichar{112}}%
\uc@dclc{120214}{autogenerated}{\unichar{113}}%
\uc@dclc{120215}{autogenerated}{\unichar{114}}%
\uc@dclc{120216}{autogenerated}{\unichar{115}}%
\uc@dclc{120217}{autogenerated}{\unichar{116}}%
\uc@dclc{120218}{autogenerated}{\unichar{117}}%
\uc@dclc{120219}{autogenerated}{\unichar{118}}%
\uc@dclc{120220}{autogenerated}{\unichar{119}}%
\uc@dclc{120221}{autogenerated}{\unichar{120}}%
\uc@dclc{120222}{autogenerated}{\unichar{121}}%
\uc@dclc{120223}{autogenerated}{\unichar{122}}%
\uc@dclc{120224}{default}{\ensuremath{\mathsf A}}%
\uc@dclc{120225}{default}{\ensuremath{\mathsf B}}%
\uc@dclc{120226}{default}{\ensuremath{\mathsf C}}%
\uc@dclc{120227}{default}{\ensuremath{\mathsf D}}%
\uc@dclc{120228}{default}{\ensuremath{\mathsf E}}%
\uc@dclc{120229}{default}{\ensuremath{\mathsf F}}%
\uc@dclc{120230}{default}{\ensuremath{\mathsf G}}%
\uc@dclc{120231}{default}{\ensuremath{\mathsf H}}%
\uc@dclc{120232}{default}{\ensuremath{\mathsf I}}%
\uc@dclc{120233}{default}{\ensuremath{\mathsf J}}%
\uc@dclc{120234}{default}{\ensuremath{\mathsf K}}%
\uc@dclc{120235}{default}{\ensuremath{\mathsf L}}%
\uc@dclc{120236}{default}{\ensuremath{\mathsf M}}%
\uc@dclc{120237}{default}{\ensuremath{\mathsf N}}%
\uc@dclc{120238}{default}{\ensuremath{\mathsf O}}%
\uc@dclc{120239}{default}{\ensuremath{\mathsf P}}%
\uc@dclc{120240}{default}{\ensuremath{\mathsf Q}}%
\uc@dclc{120241}{default}{\ensuremath{\mathsf R}}%
\uc@dclc{120242}{default}{\ensuremath{\mathsf S}}%
\uc@dclc{120243}{default}{\ensuremath{\mathsf T}}%
\uc@dclc{120244}{default}{\ensuremath{\mathsf U}}%
\uc@dclc{120245}{default}{\ensuremath{\mathsf V}}%
\uc@dclc{120246}{default}{\ensuremath{\mathsf W}}%
\uc@dclc{120247}{default}{\ensuremath{\mathsf X}}%
\uc@dclc{120248}{default}{\ensuremath{\mathsf Y}}%
\uc@dclc{120249}{default}{\ensuremath{\mathsf Z}}%
\uc@dclc{120250}{default}{\ensuremath{\mathsf a}}%
\uc@dclc{120251}{default}{\ensuremath{\mathsf b}}%
\uc@dclc{120252}{default}{\ensuremath{\mathsf c}}%
\uc@dclc{120253}{default}{\ensuremath{\mathsf d}}%
\uc@dclc{120254}{default}{\ensuremath{\mathsf e}}%
\uc@dclc{120255}{default}{\ensuremath{\mathsf f}}%
\uc@dclc{120256}{default}{\ensuremath{\mathsf g}}%
\uc@dclc{120257}{default}{\ensuremath{\mathsf h}}%
\uc@dclc{120258}{default}{\ensuremath{\mathsf i}}%
\uc@dclc{120259}{default}{\ensuremath{\mathsf j}}%
\uc@dclc{120260}{default}{\ensuremath{\mathsf k}}%
\uc@dclc{120261}{default}{\ensuremath{\mathsf l}}%
\uc@dclc{120262}{default}{\ensuremath{\mathsf m}}%
\uc@dclc{120263}{default}{\ensuremath{\mathsf n}}%
\uc@dclc{120264}{default}{\ensuremath{\mathsf o}}%
\uc@dclc{120265}{default}{\ensuremath{\mathsf p}}%
\uc@dclc{120266}{default}{\ensuremath{\mathsf q}}%
\uc@dclc{120267}{default}{\ensuremath{\mathsf r}}%
\uc@dclc{120268}{default}{\ensuremath{\mathsf s}}%
\uc@dclc{120269}{default}{\ensuremath{\mathsf t}}%
\uc@dclc{120270}{default}{\ensuremath{\mathsf u}}%
\uc@dclc{120271}{default}{\ensuremath{\mathsf v}}%
\uc@dclc{120272}{default}{\ensuremath{\mathsf w}}%
\uc@dclc{120273}{default}{\ensuremath{\mathsf x}}%
\uc@dclc{120274}{default}{\ensuremath{\mathsf y}}%
\uc@dclc{120275}{default}{\ensuremath{\mathsf z}}%
\uc@dclc{120276}{autogenerated}{\unichar{65}}%
\uc@dclc{120277}{autogenerated}{\unichar{66}}%
\uc@dclc{120278}{autogenerated}{\unichar{67}}%
\uc@dclc{120279}{autogenerated}{\unichar{68}}%
\uc@dclc{120280}{autogenerated}{\unichar{69}}%
\uc@dclc{120281}{autogenerated}{\unichar{70}}%
\uc@dclc{120282}{autogenerated}{\unichar{71}}%
\uc@dclc{120283}{autogenerated}{\unichar{72}}%
\uc@dclc{120284}{autogenerated}{\unichar{73}}%
\uc@dclc{120285}{autogenerated}{\unichar{74}}%
\uc@dclc{120286}{autogenerated}{\unichar{75}}%
\uc@dclc{120287}{autogenerated}{\unichar{76}}%
\uc@dclc{120288}{autogenerated}{\unichar{77}}%
\uc@dclc{120289}{autogenerated}{\unichar{78}}%
\uc@dclc{120290}{autogenerated}{\unichar{79}}%
\uc@dclc{120291}{autogenerated}{\unichar{80}}%
\uc@dclc{120292}{autogenerated}{\unichar{81}}%
\uc@dclc{120293}{autogenerated}{\unichar{82}}%
\uc@dclc{120294}{autogenerated}{\unichar{83}}%
\uc@dclc{120295}{autogenerated}{\unichar{84}}%
\uc@dclc{120296}{autogenerated}{\unichar{85}}%
\uc@dclc{120297}{autogenerated}{\unichar{86}}%
\uc@dclc{120298}{autogenerated}{\unichar{87}}%
\uc@dclc{120299}{autogenerated}{\unichar{88}}%
\uc@dclc{120300}{autogenerated}{\unichar{89}}%
\uc@dclc{120301}{autogenerated}{\unichar{90}}%
\uc@dclc{120302}{autogenerated}{\unichar{97}}%
\uc@dclc{120303}{autogenerated}{\unichar{98}}%
\uc@dclc{120304}{autogenerated}{\unichar{99}}%
\uc@dclc{120305}{autogenerated}{\unichar{100}}%
\uc@dclc{120306}{autogenerated}{\unichar{101}}%
\uc@dclc{120307}{autogenerated}{\unichar{102}}%
\uc@dclc{120308}{autogenerated}{\unichar{103}}%
\uc@dclc{120309}{autogenerated}{\unichar{104}}%
\uc@dclc{120310}{autogenerated}{\unichar{105}}%
\uc@dclc{120311}{autogenerated}{\unichar{106}}%
\uc@dclc{120312}{autogenerated}{\unichar{107}}%
\uc@dclc{120313}{autogenerated}{\unichar{108}}%
\uc@dclc{120314}{autogenerated}{\unichar{109}}%
\uc@dclc{120315}{autogenerated}{\unichar{110}}%
\uc@dclc{120316}{autogenerated}{\unichar{111}}%
\uc@dclc{120317}{autogenerated}{\unichar{112}}%
\uc@dclc{120318}{autogenerated}{\unichar{113}}%
\uc@dclc{120319}{autogenerated}{\unichar{114}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
