%%% Unicode to TeX mapping, file uni-206.def, U+CE00..U+CEFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-206.def}[2013/05/13 UCS: Unicode data U+CE00..U+CEFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{52740}{cjkhangul}{\u@cjk@hangul13CD}%
\uc@dclc{52744}{cjkhangul}{\u@cjk@hangul13CE}%
\uc@dclc{52748}{cjkhangul}{\u@cjk@hangul13CF}%
\uc@dclc{52756}{cjkhangul}{\u@cjk@hangul13D0}%
\uc@dclc{52761}{cjkhangul}{\u@cjk@hangul13D1}%
\uc@dclc{52768}{cjkhangul}{\u@cjk@hangul13D2}%
\uc@dclc{52769}{cjkhangul}{\u@cjk@hangul13D3}%
\uc@dclc{52772}{cjkhangul}{\u@cjk@hangul13D4}%
\uc@dclc{52776}{cjkhangul}{\u@cjk@hangul13D5}%
\uc@dclc{52784}{cjkhangul}{\u@cjk@hangul13D6}%
\uc@dclc{52785}{cjkhangul}{\u@cjk@hangul13D7}%
\uc@dclc{52787}{cjkhangul}{\u@cjk@hangul13D8}%
\uc@dclc{52789}{cjkhangul}{\u@cjk@hangul13D9}%
\uc@dclc{52824}{cjkhangul}{\u@cjk@hangul13DA}%
\uc@dclc{52825}{cjkhangul}{\u@cjk@hangul13DB}%
\uc@dclc{52828}{cjkhangul}{\u@cjk@hangul13DC}%
\uc@dclc{52831}{cjkhangul}{\u@cjk@hangul13DD}%
\uc@dclc{52832}{cjkhangul}{\u@cjk@hangul13DE}%
\uc@dclc{52833}{cjkhangul}{\u@cjk@hangul13DF}%
\uc@dclc{52840}{cjkhangul}{\u@cjk@hangul13E0}%
\uc@dclc{52841}{cjkhangul}{\u@cjk@hangul13E1}%
\uc@dclc{52843}{cjkhangul}{\u@cjk@hangul13E2}%
\uc@dclc{52845}{cjkhangul}{\u@cjk@hangul13E3}%
\uc@dclc{52852}{cjkhangul}{\u@cjk@hangul13E4}%
\uc@dclc{52853}{cjkhangul}{\u@cjk@hangul13E5}%
\uc@dclc{52856}{cjkhangul}{\u@cjk@hangul13E6}%
\uc@dclc{52860}{cjkhangul}{\u@cjk@hangul13E7}%
\uc@dclc{52868}{cjkhangul}{\u@cjk@hangul13E8}%
\uc@dclc{52869}{cjkhangul}{\u@cjk@hangul13E9}%
\uc@dclc{52871}{cjkhangul}{\u@cjk@hangul13EA}%
\uc@dclc{52873}{cjkhangul}{\u@cjk@hangul13EB}%
\uc@dclc{52880}{cjkhangul}{\u@cjk@hangul13EC}%
\uc@dclc{52881}{cjkhangul}{\u@cjk@hangul13ED}%
\uc@dclc{52884}{cjkhangul}{\u@cjk@hangul13EE}%
\uc@dclc{52888}{cjkhangul}{\u@cjk@hangul13EF}%
\uc@dclc{52896}{cjkhangul}{\u@cjk@hangul13F0}%
\uc@dclc{52897}{cjkhangul}{\u@cjk@hangul13F1}%
\uc@dclc{52899}{cjkhangul}{\u@cjk@hangul13F2}%
\uc@dclc{52900}{cjkhangul}{\u@cjk@hangul13F3}%
\uc@dclc{52901}{cjkhangul}{\u@cjk@hangul13F4}%
\uc@dclc{52908}{cjkhangul}{\u@cjk@hangul13F5}%
\uc@dclc{52909}{cjkhangul}{\u@cjk@hangul13F6}%
\uc@dclc{52929}{cjkhangul}{\u@cjk@hangul13F7}%
\uc@dclc{52964}{cjkhangul}{\u@cjk@hangul13F8}%
\uc@dclc{52965}{cjkhangul}{\u@cjk@hangul13F9}%
\uc@dclc{52968}{cjkhangul}{\u@cjk@hangul13FA}%
\uc@dclc{52971}{cjkhangul}{\u@cjk@hangul13FB}%
\uc@dclc{52972}{cjkhangul}{\u@cjk@hangul13FC}%
\uc@dclc{52980}{cjkhangul}{\u@cjk@hangul13FD}%
\uc@dclc{52981}{cjkhangul}{\u@cjk@hangul13FE}%
\uc@dclc{52983}{cjkhangul}{\u@cjk@hangul13FF}%
\uc@dclc{52984}{cjkhangul}{\u@cjk@hangul1400}%
\uc@dclc{52985}{cjkhangul}{\u@cjk@hangul1401}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
