%%% Unicode to TeX mapping, file uni-5.def, U+0500..U+05FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-5.def}[2013/05/13 UCS: Unicode data U+0500..U+05FF]%
\fi
\uc@dclc{1456}{default}{\uc@cmb\sheva{#1}}%
\uc@dclc{1457}{default}{\uc@cmb\hatafsegol{#1}}%
\uc@dclc{1458}{default}{\uc@cmb\hatafpatah{#1}}%
\uc@dclc{1459}{default}{\uc@cmb\hatafqamats{#1}}%
\uc@dclc{1460}{default}{\uc@cmb\hiriq{#1}}%
\uc@dclc{1461}{default}{\uc@cmb\tsere{#1}}%
\uc@dclc{1462}{default}{\uc@cmb\segol{#1}}%
\uc@dclc{1463}{default}{\uc@cmb\patah{#1}}%
\uc@dclc{1464}{default}{\uc@cmb\qamats{#1}}%
\uc@dclc{1465}{default}{\uc@cmb\holam{#1}}%
\uc@dclc{1467}{default}{\uc@cmb\qubuts{#1}}%
\uc@dclc{1468}{default}{\uc@cmb\dagesh{#1}}%
\uc@dclc{1469}{default}{\uc@cmb\meteg{#1}}%
\uc@dclc{1470}{default}{\maqaf}%
\uc@dclc{1473}{default}{\uc@cmb\shindot{#1}}%
\uc@dclc{1474}{default}{\uc@cmb\sindot{#1}}%
\uc@dclc{1475}{default}{\sofpasuq}%
\uc@dclc{1488}{default}{\hebalef}%
\uc@dclc{1488}{mathletters}{\ensuremath\aleph}%
\uc@dclc{1489}{default}{\hebbet}%
\uc@dclc{1489}{mathletters}{\ensuremath\beth}%
\uc@dclc{1490}{default}{\hebgimel}%
\uc@dclc{1490}{mathletters}{\ensuremath\gimel}%
\uc@dclc{1491}{default}{\hebdalet}%
\uc@dclc{1491}{mathletters}{\ensuremath\daleth}%
\uc@dclc{1492}{default}{\hebhe}%
\uc@dclc{1493}{default}{\hebvav}%
\uc@dclc{1494}{default}{\hebzayin}%
\uc@dclc{1495}{default}{\hebhet}%
\uc@dclc{1496}{default}{\hebtet}%
\uc@dclc{1497}{default}{\hebyod}%
\uc@dclc{1498}{default}{\hebfinalkaf}%
\uc@dclc{1499}{default}{\hebkaf}%
\uc@dclc{1500}{default}{\heblamed}%
\uc@dclc{1501}{default}{\hebfinalmem}%
\uc@dclc{1502}{default}{\hebmem}%
\uc@dclc{1503}{default}{\hebfinalnun}%
\uc@dclc{1504}{default}{\hebnun}%
\uc@dclc{1505}{default}{\hebsamekh}%
\uc@dclc{1506}{default}{\hebayin}%
\uc@dclc{1507}{default}{\hebfinalpe}%
\uc@dclc{1508}{default}{\hebpe}%
\uc@dclc{1509}{default}{\hebfinaltsadi}%
\uc@dclc{1510}{default}{\hebtsadi}%
\uc@dclc{1511}{default}{\hebqof}%
\uc@dclc{1512}{default}{\hebresh}%
\uc@dclc{1513}{default}{\hebshin}%
\uc@dclc{1514}{default}{\hebtav}%
\uc@dclc{1520}{default}{\doublevav}%
\uc@dclc{1521}{default}{\vavyod}%
\uc@dclc{1522}{default}{\doubleyod}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
