%%% Unicode to TeX mapping, file uni-180.def, U+B400..U+B4FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-180.def}[2013/05/13 UCS: Unicode data U+B400..U+B4FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{46096}{cjkhangul}{\u@cjk@hangul087D}%
\uc@dclc{46104}{cjkhangul}{\u@cjk@hangul087E}%
\uc@dclc{46108}{cjkhangul}{\u@cjk@hangul087F}%
\uc@dclc{46112}{cjkhangul}{\u@cjk@hangul0880}%
\uc@dclc{46120}{cjkhangul}{\u@cjk@hangul0881}%
\uc@dclc{46121}{cjkhangul}{\u@cjk@hangul0882}%
\uc@dclc{46123}{cjkhangul}{\u@cjk@hangul0883}%
\uc@dclc{46132}{cjkhangul}{\u@cjk@hangul0884}%
\uc@dclc{46160}{cjkhangul}{\u@cjk@hangul0885}%
\uc@dclc{46161}{cjkhangul}{\u@cjk@hangul0886}%
\uc@dclc{46164}{cjkhangul}{\u@cjk@hangul0887}%
\uc@dclc{46168}{cjkhangul}{\u@cjk@hangul0888}%
\uc@dclc{46176}{cjkhangul}{\u@cjk@hangul0889}%
\uc@dclc{46177}{cjkhangul}{\u@cjk@hangul088A}%
\uc@dclc{46179}{cjkhangul}{\u@cjk@hangul088B}%
\uc@dclc{46181}{cjkhangul}{\u@cjk@hangul088C}%
\uc@dclc{46188}{cjkhangul}{\u@cjk@hangul088D}%
\uc@dclc{46208}{cjkhangul}{\u@cjk@hangul088E}%
\uc@dclc{46216}{cjkhangul}{\u@cjk@hangul088F}%
\uc@dclc{46237}{cjkhangul}{\u@cjk@hangul0890}%
\uc@dclc{46244}{cjkhangul}{\u@cjk@hangul0891}%
\uc@dclc{46248}{cjkhangul}{\u@cjk@hangul0892}%
\uc@dclc{46252}{cjkhangul}{\u@cjk@hangul0893}%
\uc@dclc{46261}{cjkhangul}{\u@cjk@hangul0894}%
\uc@dclc{46263}{cjkhangul}{\u@cjk@hangul0895}%
\uc@dclc{46265}{cjkhangul}{\u@cjk@hangul0896}%
\uc@dclc{46272}{cjkhangul}{\u@cjk@hangul0897}%
\uc@dclc{46276}{cjkhangul}{\u@cjk@hangul0898}%
\uc@dclc{46280}{cjkhangul}{\u@cjk@hangul0899}%
\uc@dclc{46288}{cjkhangul}{\u@cjk@hangul089A}%
\uc@dclc{46293}{cjkhangul}{\u@cjk@hangul089B}%
\uc@dclc{46300}{cjkhangul}{\u@cjk@hangul089C}%
\uc@dclc{46301}{cjkhangul}{\u@cjk@hangul089D}%
\uc@dclc{46304}{cjkhangul}{\u@cjk@hangul089E}%
\uc@dclc{46307}{cjkhangul}{\u@cjk@hangul089F}%
\uc@dclc{46308}{cjkhangul}{\u@cjk@hangul08A0}%
\uc@dclc{46310}{cjkhangul}{\u@cjk@hangul08A1}%
\uc@dclc{46316}{cjkhangul}{\u@cjk@hangul08A2}%
\uc@dclc{46317}{cjkhangul}{\u@cjk@hangul08A3}%
\uc@dclc{46319}{cjkhangul}{\u@cjk@hangul08A4}%
\uc@dclc{46321}{cjkhangul}{\u@cjk@hangul08A5}%
\uc@dclc{46328}{cjkhangul}{\u@cjk@hangul08A6}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
