%%% Unicode to TeX mapping, file uni-187.def, U+BB00..U+BBFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-187.def}[2013/05/13 UCS: Unicode data U+BB00..U+BBFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{47872}{cjkhangul}{\u@cjk@hangul09D0}%
\uc@dclc{47876}{cjkhangul}{\u@cjk@hangul09D1}%
\uc@dclc{47885}{cjkhangul}{\u@cjk@hangul09D2}%
\uc@dclc{47887}{cjkhangul}{\u@cjk@hangul09D3}%
\uc@dclc{47889}{cjkhangul}{\u@cjk@hangul09D4}%
\uc@dclc{47896}{cjkhangul}{\u@cjk@hangul09D5}%
\uc@dclc{47900}{cjkhangul}{\u@cjk@hangul09D6}%
\uc@dclc{47904}{cjkhangul}{\u@cjk@hangul09D7}%
\uc@dclc{47913}{cjkhangul}{\u@cjk@hangul09D8}%
\uc@dclc{47915}{cjkhangul}{\u@cjk@hangul09D9}%
\uc@dclc{47924}{cjkhangul}{\u@cjk@hangul09DA}%
\uc@dclc{47925}{cjkhangul}{\u@cjk@hangul09DB}%
\uc@dclc{47926}{cjkhangul}{\u@cjk@hangul09DC}%
\uc@dclc{47928}{cjkhangul}{\u@cjk@hangul09DD}%
\uc@dclc{47931}{cjkhangul}{\u@cjk@hangul09DE}%
\uc@dclc{47932}{cjkhangul}{\u@cjk@hangul09DF}%
\uc@dclc{47933}{cjkhangul}{\u@cjk@hangul09E0}%
\uc@dclc{47934}{cjkhangul}{\u@cjk@hangul09E1}%
\uc@dclc{47940}{cjkhangul}{\u@cjk@hangul09E2}%
\uc@dclc{47941}{cjkhangul}{\u@cjk@hangul09E3}%
\uc@dclc{47943}{cjkhangul}{\u@cjk@hangul09E4}%
\uc@dclc{47945}{cjkhangul}{\u@cjk@hangul09E5}%
\uc@dclc{47949}{cjkhangul}{\u@cjk@hangul09E6}%
\uc@dclc{47951}{cjkhangul}{\u@cjk@hangul09E7}%
\uc@dclc{47952}{cjkhangul}{\u@cjk@hangul09E8}%
\uc@dclc{47956}{cjkhangul}{\u@cjk@hangul09E9}%
\uc@dclc{47960}{cjkhangul}{\u@cjk@hangul09EA}%
\uc@dclc{47969}{cjkhangul}{\u@cjk@hangul09EB}%
\uc@dclc{47971}{cjkhangul}{\u@cjk@hangul09EC}%
\uc@dclc{47980}{cjkhangul}{\u@cjk@hangul09ED}%
\uc@dclc{48008}{cjkhangul}{\u@cjk@hangul09EE}%
\uc@dclc{48012}{cjkhangul}{\u@cjk@hangul09EF}%
\uc@dclc{48016}{cjkhangul}{\u@cjk@hangul09F0}%
\uc@dclc{48036}{cjkhangul}{\u@cjk@hangul09F1}%
\uc@dclc{48040}{cjkhangul}{\u@cjk@hangul09F2}%
\uc@dclc{48044}{cjkhangul}{\u@cjk@hangul09F3}%
\uc@dclc{48052}{cjkhangul}{\u@cjk@hangul09F4}%
\uc@dclc{48055}{cjkhangul}{\u@cjk@hangul09F5}%
\uc@dclc{48064}{cjkhangul}{\u@cjk@hangul09F6}%
\uc@dclc{48068}{cjkhangul}{\u@cjk@hangul09F7}%
\uc@dclc{48072}{cjkhangul}{\u@cjk@hangul09F8}%
\uc@dclc{48080}{cjkhangul}{\u@cjk@hangul09F9}%
\uc@dclc{48083}{cjkhangul}{\u@cjk@hangul09FA}%
\uc@dclc{48120}{cjkhangul}{\u@cjk@hangul09FB}%
\uc@dclc{48121}{cjkhangul}{\u@cjk@hangul09FC}%
\uc@dclc{48124}{cjkhangul}{\u@cjk@hangul09FD}%
\uc@dclc{48127}{cjkhangul}{\u@cjk@hangul09FE}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
