%%% Unicode to TeX mapping, file uni-197.def, U+C500..U+C5FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-197.def}[2013/05/13 UCS: Unicode data U+C500..U+C5FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{50432}{cjkhangul}{\u@cjk@hangul11BD}%
\uc@dclc{50433}{cjkhangul}{\u@cjk@hangul11BE}%
\uc@dclc{50444}{cjkhangul}{\u@cjk@hangul11BF}%
\uc@dclc{50448}{cjkhangul}{\u@cjk@hangul11C0}%
\uc@dclc{50452}{cjkhangul}{\u@cjk@hangul11C1}%
\uc@dclc{50460}{cjkhangul}{\u@cjk@hangul11C2}%
\uc@dclc{50472}{cjkhangul}{\u@cjk@hangul11C3}%
\uc@dclc{50473}{cjkhangul}{\u@cjk@hangul11C4}%
\uc@dclc{50476}{cjkhangul}{\u@cjk@hangul11C5}%
\uc@dclc{50480}{cjkhangul}{\u@cjk@hangul11C6}%
\uc@dclc{50488}{cjkhangul}{\u@cjk@hangul11C7}%
\uc@dclc{50489}{cjkhangul}{\u@cjk@hangul11C8}%
\uc@dclc{50491}{cjkhangul}{\u@cjk@hangul11C9}%
\uc@dclc{50493}{cjkhangul}{\u@cjk@hangul11CA}%
\uc@dclc{50500}{cjkhangul}{\u@cjk@hangul11CB}%
\uc@dclc{50501}{cjkhangul}{\u@cjk@hangul11CC}%
\uc@dclc{50504}{cjkhangul}{\u@cjk@hangul11CD}%
\uc@dclc{50505}{cjkhangul}{\u@cjk@hangul11CE}%
\uc@dclc{50506}{cjkhangul}{\u@cjk@hangul11CF}%
\uc@dclc{50508}{cjkhangul}{\u@cjk@hangul11D0}%
\uc@dclc{50509}{cjkhangul}{\u@cjk@hangul11D1}%
\uc@dclc{50510}{cjkhangul}{\u@cjk@hangul11D2}%
\uc@dclc{50515}{cjkhangul}{\u@cjk@hangul11D3}%
\uc@dclc{50516}{cjkhangul}{\u@cjk@hangul11D4}%
\uc@dclc{50517}{cjkhangul}{\u@cjk@hangul11D5}%
\uc@dclc{50519}{cjkhangul}{\u@cjk@hangul11D6}%
\uc@dclc{50520}{cjkhangul}{\u@cjk@hangul11D7}%
\uc@dclc{50521}{cjkhangul}{\u@cjk@hangul11D8}%
\uc@dclc{50525}{cjkhangul}{\u@cjk@hangul11D9}%
\uc@dclc{50526}{cjkhangul}{\u@cjk@hangul11DA}%
\uc@dclc{50528}{cjkhangul}{\u@cjk@hangul11DB}%
\uc@dclc{50529}{cjkhangul}{\u@cjk@hangul11DC}%
\uc@dclc{50532}{cjkhangul}{\u@cjk@hangul11DD}%
\uc@dclc{50536}{cjkhangul}{\u@cjk@hangul11DE}%
\uc@dclc{50544}{cjkhangul}{\u@cjk@hangul11DF}%
\uc@dclc{50545}{cjkhangul}{\u@cjk@hangul11E0}%
\uc@dclc{50547}{cjkhangul}{\u@cjk@hangul11E1}%
\uc@dclc{50548}{cjkhangul}{\u@cjk@hangul11E2}%
\uc@dclc{50549}{cjkhangul}{\u@cjk@hangul11E3}%
\uc@dclc{50556}{cjkhangul}{\u@cjk@hangul11E4}%
\uc@dclc{50557}{cjkhangul}{\u@cjk@hangul11E5}%
\uc@dclc{50560}{cjkhangul}{\u@cjk@hangul11E6}%
\uc@dclc{50564}{cjkhangul}{\u@cjk@hangul11E7}%
\uc@dclc{50567}{cjkhangul}{\u@cjk@hangul11E8}%
\uc@dclc{50572}{cjkhangul}{\u@cjk@hangul11E9}%
\uc@dclc{50573}{cjkhangul}{\u@cjk@hangul11EA}%
\uc@dclc{50575}{cjkhangul}{\u@cjk@hangul11EB}%
\uc@dclc{50577}{cjkhangul}{\u@cjk@hangul11EC}%
\uc@dclc{50581}{cjkhangul}{\u@cjk@hangul11ED}%
\uc@dclc{50583}{cjkhangul}{\u@cjk@hangul11EE}%
\uc@dclc{50584}{cjkhangul}{\u@cjk@hangul11EF}%
\uc@dclc{50588}{cjkhangul}{\u@cjk@hangul11F0}%
\uc@dclc{50592}{cjkhangul}{\u@cjk@hangul11F1}%
\uc@dclc{50601}{cjkhangul}{\u@cjk@hangul11F2}%
\uc@dclc{50612}{cjkhangul}{\u@cjk@hangul11F3}%
\uc@dclc{50613}{cjkhangul}{\u@cjk@hangul11F4}%
\uc@dclc{50616}{cjkhangul}{\u@cjk@hangul11F5}%
\uc@dclc{50617}{cjkhangul}{\u@cjk@hangul11F6}%
\uc@dclc{50619}{cjkhangul}{\u@cjk@hangul11F7}%
\uc@dclc{50620}{cjkhangul}{\u@cjk@hangul11F8}%
\uc@dclc{50621}{cjkhangul}{\u@cjk@hangul11F9}%
\uc@dclc{50622}{cjkhangul}{\u@cjk@hangul11FA}%
\uc@dclc{50628}{cjkhangul}{\u@cjk@hangul11FB}%
\uc@dclc{50629}{cjkhangul}{\u@cjk@hangul11FC}%
\uc@dclc{50630}{cjkhangul}{\u@cjk@hangul11FD}%
\uc@dclc{50631}{cjkhangul}{\u@cjk@hangul11FE}%
\uc@dclc{50632}{cjkhangul}{\u@cjk@hangul11FF}%
\uc@dclc{50633}{cjkhangul}{\u@cjk@hangul1200}%
\uc@dclc{50634}{cjkhangul}{\u@cjk@hangul1201}%
\uc@dclc{50636}{cjkhangul}{\u@cjk@hangul1202}%
\uc@dclc{50638}{cjkhangul}{\u@cjk@hangul1203}%
\uc@dclc{50640}{cjkhangul}{\u@cjk@hangul1204}%
\uc@dclc{50641}{cjkhangul}{\u@cjk@hangul1205}%
\uc@dclc{50644}{cjkhangul}{\u@cjk@hangul1206}%
\uc@dclc{50648}{cjkhangul}{\u@cjk@hangul1207}%
\uc@dclc{50656}{cjkhangul}{\u@cjk@hangul1208}%
\uc@dclc{50657}{cjkhangul}{\u@cjk@hangul1209}%
\uc@dclc{50659}{cjkhangul}{\u@cjk@hangul120A}%
\uc@dclc{50661}{cjkhangul}{\u@cjk@hangul120B}%
\uc@dclc{50668}{cjkhangul}{\u@cjk@hangul120C}%
\uc@dclc{50669}{cjkhangul}{\u@cjk@hangul120D}%
\uc@dclc{50670}{cjkhangul}{\u@cjk@hangul120E}%
\uc@dclc{50672}{cjkhangul}{\u@cjk@hangul120F}%
\uc@dclc{50676}{cjkhangul}{\u@cjk@hangul1210}%
\uc@dclc{50678}{cjkhangul}{\u@cjk@hangul1211}%
\uc@dclc{50679}{cjkhangul}{\u@cjk@hangul1212}%
\uc@dclc{50684}{cjkhangul}{\u@cjk@hangul1213}%
\uc@dclc{50685}{cjkhangul}{\u@cjk@hangul1214}%
\uc@dclc{50686}{cjkhangul}{\u@cjk@hangul1215}%
\uc@dclc{50687}{cjkhangul}{\u@cjk@hangul1216}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
