%%% Unicode to TeX mapping, file uni-179.def, U+B300..U+B3FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-179.def}[2013/05/13 UCS: Unicode data U+B300..U+B3FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{45824}{cjkhangul}{\u@cjk@hangul0844}%
\uc@dclc{45825}{cjkhangul}{\u@cjk@hangul0845}%
\uc@dclc{45828}{cjkhangul}{\u@cjk@hangul0846}%
\uc@dclc{45832}{cjkhangul}{\u@cjk@hangul0847}%
\uc@dclc{45840}{cjkhangul}{\u@cjk@hangul0848}%
\uc@dclc{45841}{cjkhangul}{\u@cjk@hangul0849}%
\uc@dclc{45843}{cjkhangul}{\u@cjk@hangul084A}%
\uc@dclc{45844}{cjkhangul}{\u@cjk@hangul084B}%
\uc@dclc{45845}{cjkhangul}{\u@cjk@hangul084C}%
\uc@dclc{45852}{cjkhangul}{\u@cjk@hangul084D}%
\uc@dclc{45908}{cjkhangul}{\u@cjk@hangul084E}%
\uc@dclc{45909}{cjkhangul}{\u@cjk@hangul084F}%
\uc@dclc{45910}{cjkhangul}{\u@cjk@hangul0850}%
\uc@dclc{45912}{cjkhangul}{\u@cjk@hangul0851}%
\uc@dclc{45915}{cjkhangul}{\u@cjk@hangul0852}%
\uc@dclc{45916}{cjkhangul}{\u@cjk@hangul0853}%
\uc@dclc{45918}{cjkhangul}{\u@cjk@hangul0854}%
\uc@dclc{45919}{cjkhangul}{\u@cjk@hangul0855}%
\uc@dclc{45924}{cjkhangul}{\u@cjk@hangul0856}%
\uc@dclc{45925}{cjkhangul}{\u@cjk@hangul0857}%
\uc@dclc{45927}{cjkhangul}{\u@cjk@hangul0858}%
\uc@dclc{45929}{cjkhangul}{\u@cjk@hangul0859}%
\uc@dclc{45931}{cjkhangul}{\u@cjk@hangul085A}%
\uc@dclc{45934}{cjkhangul}{\u@cjk@hangul085B}%
\uc@dclc{45936}{cjkhangul}{\u@cjk@hangul085C}%
\uc@dclc{45937}{cjkhangul}{\u@cjk@hangul085D}%
\uc@dclc{45940}{cjkhangul}{\u@cjk@hangul085E}%
\uc@dclc{45944}{cjkhangul}{\u@cjk@hangul085F}%
\uc@dclc{45952}{cjkhangul}{\u@cjk@hangul0860}%
\uc@dclc{45953}{cjkhangul}{\u@cjk@hangul0861}%
\uc@dclc{45955}{cjkhangul}{\u@cjk@hangul0862}%
\uc@dclc{45956}{cjkhangul}{\u@cjk@hangul0863}%
\uc@dclc{45957}{cjkhangul}{\u@cjk@hangul0864}%
\uc@dclc{45964}{cjkhangul}{\u@cjk@hangul0865}%
\uc@dclc{45968}{cjkhangul}{\u@cjk@hangul0866}%
\uc@dclc{45972}{cjkhangul}{\u@cjk@hangul0867}%
\uc@dclc{45984}{cjkhangul}{\u@cjk@hangul0868}%
\uc@dclc{45985}{cjkhangul}{\u@cjk@hangul0869}%
\uc@dclc{45992}{cjkhangul}{\u@cjk@hangul086A}%
\uc@dclc{45996}{cjkhangul}{\u@cjk@hangul086B}%
\uc@dclc{46020}{cjkhangul}{\u@cjk@hangul086C}%
\uc@dclc{46021}{cjkhangul}{\u@cjk@hangul086D}%
\uc@dclc{46024}{cjkhangul}{\u@cjk@hangul086E}%
\uc@dclc{46027}{cjkhangul}{\u@cjk@hangul086F}%
\uc@dclc{46028}{cjkhangul}{\u@cjk@hangul0870}%
\uc@dclc{46030}{cjkhangul}{\u@cjk@hangul0871}%
\uc@dclc{46032}{cjkhangul}{\u@cjk@hangul0872}%
\uc@dclc{46036}{cjkhangul}{\u@cjk@hangul0873}%
\uc@dclc{46037}{cjkhangul}{\u@cjk@hangul0874}%
\uc@dclc{46039}{cjkhangul}{\u@cjk@hangul0875}%
\uc@dclc{46041}{cjkhangul}{\u@cjk@hangul0876}%
\uc@dclc{46043}{cjkhangul}{\u@cjk@hangul0877}%
\uc@dclc{46045}{cjkhangul}{\u@cjk@hangul0878}%
\uc@dclc{46048}{cjkhangul}{\u@cjk@hangul0879}%
\uc@dclc{46052}{cjkhangul}{\u@cjk@hangul087A}%
\uc@dclc{46056}{cjkhangul}{\u@cjk@hangul087B}%
\uc@dclc{46076}{cjkhangul}{\u@cjk@hangul087C}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
