%%% Unicode to TeX mapping, file uni-249.def, U+F900..U+F9FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-249.def}[2013/05/13 UCS: Unicode data U+F900..U+F9FF]%
\fi
\uc@dclc{63744}{autogenerated}{\unichar{35912}}%
\uc@dclc{63745}{autogenerated}{\unichar{26356}}%
\uc@dclc{63746}{autogenerated}{\unichar{36554}}%
\uc@dclc{63747}{autogenerated}{\unichar{36040}}%
\uc@dclc{63748}{autogenerated}{\unichar{28369}}%
\uc@dclc{63749}{autogenerated}{\unichar{20018}}%
\uc@dclc{63750}{autogenerated}{\unichar{21477}}%
\uc@dclc{63751}{autogenerated}{\unichar{40860}}%
\uc@dclc{63752}{autogenerated}{\unichar{40860}}%
\uc@dclc{63753}{autogenerated}{\unichar{22865}}%
\uc@dclc{63754}{autogenerated}{\unichar{37329}}%
\uc@dclc{63755}{autogenerated}{\unichar{21895}}%
\uc@dclc{63756}{autogenerated}{\unichar{22856}}%
\uc@dclc{63757}{autogenerated}{\unichar{25078}}%
\uc@dclc{63758}{autogenerated}{\unichar{30313}}%
\uc@dclc{63759}{autogenerated}{\unichar{32645}}%
\uc@dclc{63760}{autogenerated}{\unichar{34367}}%
\uc@dclc{63761}{autogenerated}{\unichar{34746}}%
\uc@dclc{63762}{autogenerated}{\unichar{35064}}%
\uc@dclc{63763}{autogenerated}{\unichar{37007}}%
\uc@dclc{63764}{autogenerated}{\unichar{27138}}%
\uc@dclc{63765}{autogenerated}{\unichar{27931}}%
\uc@dclc{63766}{autogenerated}{\unichar{28889}}%
\uc@dclc{63767}{autogenerated}{\unichar{29662}}%
\uc@dclc{63768}{autogenerated}{\unichar{33853}}%
\uc@dclc{63769}{autogenerated}{\unichar{37226}}%
\uc@dclc{63770}{autogenerated}{\unichar{39409}}%
\uc@dclc{63771}{autogenerated}{\unichar{20098}}%
\uc@dclc{63772}{autogenerated}{\unichar{21365}}%
\uc@dclc{63773}{autogenerated}{\unichar{27396}}%
\uc@dclc{63774}{autogenerated}{\unichar{29211}}%
\uc@dclc{63775}{autogenerated}{\unichar{34349}}%
\uc@dclc{63776}{autogenerated}{\unichar{40478}}%
\uc@dclc{63777}{autogenerated}{\unichar{23888}}%
\uc@dclc{63778}{autogenerated}{\unichar{28651}}%
\uc@dclc{63779}{autogenerated}{\unichar{34253}}%
\uc@dclc{63780}{autogenerated}{\unichar{35172}}%
\uc@dclc{63781}{autogenerated}{\unichar{25289}}%
\uc@dclc{63782}{autogenerated}{\unichar{33240}}%
\uc@dclc{63783}{autogenerated}{\unichar{34847}}%
\uc@dclc{63784}{autogenerated}{\unichar{24266}}%
\uc@dclc{63785}{autogenerated}{\unichar{26391}}%
\uc@dclc{63786}{autogenerated}{\unichar{28010}}%
\uc@dclc{63787}{autogenerated}{\unichar{29436}}%
\uc@dclc{63788}{autogenerated}{\unichar{37070}}%
\uc@dclc{63789}{autogenerated}{\unichar{20358}}%
\uc@dclc{63790}{autogenerated}{\unichar{20919}}%
\uc@dclc{63791}{autogenerated}{\unichar{21214}}%
\uc@dclc{63792}{autogenerated}{\unichar{25796}}%
\uc@dclc{63793}{autogenerated}{\unichar{27347}}%
\uc@dclc{63794}{autogenerated}{\unichar{29200}}%
\uc@dclc{63795}{autogenerated}{\unichar{30439}}%
\uc@dclc{63796}{autogenerated}{\unichar{32769}}%
\uc@dclc{63797}{autogenerated}{\unichar{34310}}%
\uc@dclc{63798}{autogenerated}{\unichar{34396}}%
\uc@dclc{63799}{autogenerated}{\unichar{36335}}%
\uc@dclc{63800}{autogenerated}{\unichar{38706}}%
\uc@dclc{63801}{autogenerated}{\unichar{39791}}%
\uc@dclc{63802}{autogenerated}{\unichar{40442}}%
\uc@dclc{63803}{autogenerated}{\unichar{30860}}%
\uc@dclc{63804}{autogenerated}{\unichar{31103}}%
\uc@dclc{63805}{autogenerated}{\unichar{32160}}%
\uc@dclc{63806}{autogenerated}{\unichar{33737}}%
\uc@dclc{63807}{autogenerated}{\unichar{37636}}%
\uc@dclc{63808}{autogenerated}{\unichar{40575}}%
\uc@dclc{63809}{autogenerated}{\unichar{35542}}%
\uc@dclc{63810}{autogenerated}{\unichar{22751}}%
\uc@dclc{63811}{autogenerated}{\unichar{24324}}%
\uc@dclc{63812}{autogenerated}{\unichar{31840}}%
\uc@dclc{63813}{autogenerated}{\unichar{32894}}%
\uc@dclc{63814}{autogenerated}{\unichar{29282}}%
\uc@dclc{63815}{autogenerated}{\unichar{30922}}%
\uc@dclc{63816}{autogenerated}{\unichar{36034}}%
\uc@dclc{63817}{autogenerated}{\unichar{38647}}%
\uc@dclc{63818}{autogenerated}{\unichar{22744}}%
\uc@dclc{63819}{autogenerated}{\unichar{23650}}%
\uc@dclc{63820}{autogenerated}{\unichar{27155}}%
\uc@dclc{63821}{autogenerated}{\unichar{28122}}%
\uc@dclc{63822}{autogenerated}{\unichar{28431}}%
\uc@dclc{63823}{autogenerated}{\unichar{32047}}%
\uc@dclc{63824}{autogenerated}{\unichar{32311}}%
\uc@dclc{63825}{autogenerated}{\unichar{38475}}%
\uc@dclc{63826}{autogenerated}{\unichar{21202}}%
\uc@dclc{63827}{autogenerated}{\unichar{32907}}%
\uc@dclc{63828}{autogenerated}{\unichar{20956}}%
\uc@dclc{63829}{autogenerated}{\unichar{20940}}%
\uc@dclc{63830}{autogenerated}{\unichar{31260}}%
\uc@dclc{63831}{autogenerated}{\unichar{32190}}%
\uc@dclc{63832}{autogenerated}{\unichar{33777}}%
\uc@dclc{63833}{autogenerated}{\unichar{38517}}%
\uc@dclc{63834}{autogenerated}{\unichar{35712}}%
\uc@dclc{63835}{autogenerated}{\unichar{25295}}%
\uc@dclc{63836}{autogenerated}{\unichar{27138}}%
\uc@dclc{63837}{autogenerated}{\unichar{35582}}%
\uc@dclc{63838}{autogenerated}{\unichar{20025}}%
\uc@dclc{63839}{autogenerated}{\unichar{23527}}%
\uc@dclc{63840}{autogenerated}{\unichar{24594}}%
\uc@dclc{63841}{autogenerated}{\unichar{29575}}%
\uc@dclc{63842}{autogenerated}{\unichar{30064}}%
\uc@dclc{63843}{autogenerated}{\unichar{21271}}%
\uc@dclc{63844}{autogenerated}{\unichar{30971}}%
\uc@dclc{63845}{autogenerated}{\unichar{20415}}%
\uc@dclc{63846}{autogenerated}{\unichar{24489}}%
\uc@dclc{63847}{autogenerated}{\unichar{19981}}%
\uc@dclc{63848}{autogenerated}{\unichar{27852}}%
\uc@dclc{63849}{autogenerated}{\unichar{25976}}%
\uc@dclc{63850}{autogenerated}{\unichar{32034}}%
\uc@dclc{63851}{autogenerated}{\unichar{21443}}%
\uc@dclc{63852}{autogenerated}{\unichar{22622}}%
\uc@dclc{63853}{autogenerated}{\unichar{30465}}%
\uc@dclc{63854}{autogenerated}{\unichar{33865}}%
\uc@dclc{63855}{autogenerated}{\unichar{35498}}%
\uc@dclc{63856}{autogenerated}{\unichar{27578}}%
\uc@dclc{63857}{autogenerated}{\unichar{36784}}%
\uc@dclc{63858}{autogenerated}{\unichar{27784}}%
\uc@dclc{63859}{autogenerated}{\unichar{25342}}%
\uc@dclc{63860}{autogenerated}{\unichar{33509}}%
\uc@dclc{63861}{autogenerated}{\unichar{25504}}%
\uc@dclc{63862}{autogenerated}{\unichar{30053}}%
\uc@dclc{63863}{autogenerated}{\unichar{20142}}%
\uc@dclc{63864}{autogenerated}{\unichar{20841}}%
\uc@dclc{63865}{autogenerated}{\unichar{20937}}%
\uc@dclc{63866}{autogenerated}{\unichar{26753}}%
\uc@dclc{63867}{autogenerated}{\unichar{31975}}%
\uc@dclc{63868}{autogenerated}{\unichar{33391}}%
\uc@dclc{63869}{autogenerated}{\unichar{35538}}%
\uc@dclc{63870}{autogenerated}{\unichar{37327}}%
\uc@dclc{63871}{autogenerated}{\unichar{21237}}%
\uc@dclc{63872}{autogenerated}{\unichar{21570}}%
\uc@dclc{63873}{autogenerated}{\unichar{22899}}%
\uc@dclc{63874}{autogenerated}{\unichar{24300}}%
\uc@dclc{63875}{autogenerated}{\unichar{26053}}%
\uc@dclc{63876}{autogenerated}{\unichar{28670}}%
\uc@dclc{63877}{autogenerated}{\unichar{31018}}%
\uc@dclc{63878}{autogenerated}{\unichar{38317}}%
\uc@dclc{63879}{autogenerated}{\unichar{39530}}%
\uc@dclc{63880}{autogenerated}{\unichar{40599}}%
\uc@dclc{63881}{autogenerated}{\unichar{40654}}%
\uc@dclc{63882}{autogenerated}{\unichar{21147}}%
\uc@dclc{63883}{autogenerated}{\unichar{26310}}%
\uc@dclc{63884}{autogenerated}{\unichar{27511}}%
\uc@dclc{63885}{autogenerated}{\unichar{36706}}%
\uc@dclc{63886}{autogenerated}{\unichar{24180}}%
\uc@dclc{63887}{autogenerated}{\unichar{24976}}%
\uc@dclc{63888}{autogenerated}{\unichar{25088}}%
\uc@dclc{63889}{autogenerated}{\unichar{25754}}%
\uc@dclc{63890}{autogenerated}{\unichar{28451}}%
\uc@dclc{63891}{autogenerated}{\unichar{29001}}%
\uc@dclc{63892}{autogenerated}{\unichar{29833}}%
\uc@dclc{63894}{autogenerated}{\unichar{32244}}%
\uc@dclc{63895}{autogenerated}{\unichar{32879}}%
\uc@dclc{63896}{autogenerated}{\unichar{36646}}%
\uc@dclc{63897}{autogenerated}{\unichar{34030}}%
\uc@dclc{63898}{autogenerated}{\unichar{36899}}%
\uc@dclc{63899}{autogenerated}{\unichar{37706}}%
\uc@dclc{63900}{autogenerated}{\unichar{21015}}%
\uc@dclc{63901}{autogenerated}{\unichar{21155}}%
\uc@dclc{63902}{autogenerated}{\unichar{21693}}%
\uc@dclc{63903}{autogenerated}{\unichar{28872}}%
\uc@dclc{63904}{autogenerated}{\unichar{35010}}%
\uc@dclc{63905}{autogenerated}{\unichar{35498}}%
\uc@dclc{63906}{autogenerated}{\unichar{24265}}%
\uc@dclc{63907}{autogenerated}{\unichar{24565}}%
\uc@dclc{63908}{autogenerated}{\unichar{25467}}%
\uc@dclc{63909}{autogenerated}{\unichar{27566}}%
\uc@dclc{63910}{autogenerated}{\unichar{31806}}%
\uc@dclc{63911}{autogenerated}{\unichar{29557}}%
\uc@dclc{63912}{autogenerated}{\unichar{20196}}%
\uc@dclc{63913}{autogenerated}{\unichar{22265}}%
\uc@dclc{63914}{autogenerated}{\unichar{23527}}%
\uc@dclc{63915}{autogenerated}{\unichar{23994}}%
\uc@dclc{63916}{autogenerated}{\unichar{24604}}%
\uc@dclc{63917}{autogenerated}{\unichar{29618}}%
\uc@dclc{63918}{autogenerated}{\unichar{29801}}%
\uc@dclc{63919}{autogenerated}{\unichar{32666}}%
\uc@dclc{63920}{autogenerated}{\unichar{32838}}%
\uc@dclc{63921}{autogenerated}{\unichar{37428}}%
\uc@dclc{63922}{autogenerated}{\unichar{38646}}%
\uc@dclc{63923}{autogenerated}{\unichar{38728}}%
\uc@dclc{63924}{autogenerated}{\unichar{38936}}%
\uc@dclc{63925}{autogenerated}{\unichar{20363}}%
\uc@dclc{63926}{autogenerated}{\unichar{31150}}%
\uc@dclc{63927}{autogenerated}{\unichar{37300}}%
\uc@dclc{63928}{autogenerated}{\unichar{38584}}%
\uc@dclc{63929}{autogenerated}{\unichar{24801}}%
\uc@dclc{63930}{autogenerated}{\unichar{20102}}%
\uc@dclc{63931}{autogenerated}{\unichar{20698}}%
\uc@dclc{63932}{autogenerated}{\unichar{23534}}%
\uc@dclc{63933}{autogenerated}{\unichar{23615}}%
\uc@dclc{63934}{autogenerated}{\unichar{26009}}%
\uc@dclc{63935}{autogenerated}{\unichar{27138}}%
\uc@dclc{63936}{autogenerated}{\unichar{29134}}%
\uc@dclc{63937}{autogenerated}{\unichar{30274}}%
\uc@dclc{63938}{autogenerated}{\unichar{34044}}%
\uc@dclc{63939}{autogenerated}{\unichar{36988}}%
\uc@dclc{63940}{autogenerated}{\unichar{40845}}%
\uc@dclc{63941}{autogenerated}{\unichar{26248}}%
\uc@dclc{63942}{autogenerated}{\unichar{38446}}%
\uc@dclc{63943}{autogenerated}{\unichar{21129}}%
\uc@dclc{63944}{autogenerated}{\unichar{26491}}%
\uc@dclc{63945}{autogenerated}{\unichar{26611}}%
\uc@dclc{63946}{autogenerated}{\unichar{27969}}%
\uc@dclc{63947}{autogenerated}{\unichar{28316}}%
\uc@dclc{63948}{autogenerated}{\unichar{29705}}%
\uc@dclc{63949}{autogenerated}{\unichar{30041}}%
\uc@dclc{63950}{autogenerated}{\unichar{30827}}%
\uc@dclc{63951}{autogenerated}{\unichar{32016}}%
\uc@dclc{63952}{autogenerated}{\unichar{39006}}%
\uc@dclc{63953}{autogenerated}{\unichar{20845}}%
\uc@dclc{63954}{autogenerated}{\unichar{25134}}%
\uc@dclc{63955}{autogenerated}{\unichar{38520}}%
\uc@dclc{63956}{autogenerated}{\unichar{20523}}%
\uc@dclc{63957}{autogenerated}{\unichar{23833}}%
\uc@dclc{63958}{autogenerated}{\unichar{28138}}%
\uc@dclc{63959}{autogenerated}{\unichar{36650}}%
\uc@dclc{63960}{autogenerated}{\unichar{24459}}%
\uc@dclc{63961}{autogenerated}{\unichar{24900}}%
\uc@dclc{63962}{autogenerated}{\unichar{26647}}%
\uc@dclc{63963}{autogenerated}{\unichar{29575}}%
\uc@dclc{63964}{autogenerated}{\unichar{38534}}%
\uc@dclc{63965}{autogenerated}{\unichar{21033}}%
\uc@dclc{63966}{autogenerated}{\unichar{21519}}%
\uc@dclc{63967}{autogenerated}{\unichar{23653}}%
\uc@dclc{63968}{autogenerated}{\unichar{26131}}%
\uc@dclc{63969}{autogenerated}{\unichar{26446}}%
\uc@dclc{63970}{autogenerated}{\unichar{26792}}%
\uc@dclc{63971}{autogenerated}{\unichar{27877}}%
\uc@dclc{63972}{autogenerated}{\unichar{29702}}%
\uc@dclc{63973}{autogenerated}{\unichar{30178}}%
\uc@dclc{63974}{autogenerated}{\unichar{32633}}%
\uc@dclc{63975}{autogenerated}{\unichar{35023}}%
\uc@dclc{63976}{autogenerated}{\unichar{35041}}%
\uc@dclc{63977}{autogenerated}{\unichar{37324}}%
\uc@dclc{63978}{autogenerated}{\unichar{38626}}%
\uc@dclc{63979}{autogenerated}{\unichar{21311}}%
\uc@dclc{63980}{autogenerated}{\unichar{28346}}%
\uc@dclc{63981}{autogenerated}{\unichar{21533}}%
\uc@dclc{63982}{autogenerated}{\unichar{29136}}%
\uc@dclc{63983}{autogenerated}{\unichar{29848}}%
\uc@dclc{63984}{autogenerated}{\unichar{34298}}%
\uc@dclc{63985}{autogenerated}{\unichar{38563}}%
\uc@dclc{63986}{autogenerated}{\unichar{40023}}%
\uc@dclc{63987}{autogenerated}{\unichar{40607}}%
\uc@dclc{63988}{autogenerated}{\unichar{26519}}%
\uc@dclc{63989}{autogenerated}{\unichar{28107}}%
\uc@dclc{63990}{autogenerated}{\unichar{33256}}%
\uc@dclc{63991}{autogenerated}{\unichar{31435}}%
\uc@dclc{63992}{autogenerated}{\unichar{31520}}%
\uc@dclc{63993}{autogenerated}{\unichar{31890}}%
\uc@dclc{63994}{autogenerated}{\unichar{29376}}%
\uc@dclc{63995}{autogenerated}{\unichar{28825}}%
\uc@dclc{63996}{autogenerated}{\unichar{35672}}%
\uc@dclc{63997}{autogenerated}{\unichar{20160}}%
\uc@dclc{63998}{autogenerated}{\unichar{33590}}%
\uc@dclc{63999}{autogenerated}{\unichar{21050}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
