%%% Unicode to TeX mapping, file uni-209.def, U+D100..U+D1FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-209.def}[2013/05/13 UCS: Unicode data U+D100..U+D1FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{53517}{cjkhangul}{\u@cjk@hangul1463}%
\uc@dclc{53552}{cjkhangul}{\u@cjk@hangul1464}%
\uc@dclc{53553}{cjkhangul}{\u@cjk@hangul1465}%
\uc@dclc{53556}{cjkhangul}{\u@cjk@hangul1466}%
\uc@dclc{53560}{cjkhangul}{\u@cjk@hangul1467}%
\uc@dclc{53562}{cjkhangul}{\u@cjk@hangul1468}%
\uc@dclc{53568}{cjkhangul}{\u@cjk@hangul1469}%
\uc@dclc{53569}{cjkhangul}{\u@cjk@hangul146A}%
\uc@dclc{53571}{cjkhangul}{\u@cjk@hangul146B}%
\uc@dclc{53572}{cjkhangul}{\u@cjk@hangul146C}%
\uc@dclc{53573}{cjkhangul}{\u@cjk@hangul146D}%
\uc@dclc{53580}{cjkhangul}{\u@cjk@hangul146E}%
\uc@dclc{53581}{cjkhangul}{\u@cjk@hangul146F}%
\uc@dclc{53584}{cjkhangul}{\u@cjk@hangul1470}%
\uc@dclc{53588}{cjkhangul}{\u@cjk@hangul1471}%
\uc@dclc{53596}{cjkhangul}{\u@cjk@hangul1472}%
\uc@dclc{53597}{cjkhangul}{\u@cjk@hangul1473}%
\uc@dclc{53599}{cjkhangul}{\u@cjk@hangul1474}%
\uc@dclc{53601}{cjkhangul}{\u@cjk@hangul1475}%
\uc@dclc{53608}{cjkhangul}{\u@cjk@hangul1476}%
\uc@dclc{53612}{cjkhangul}{\u@cjk@hangul1477}%
\uc@dclc{53628}{cjkhangul}{\u@cjk@hangul1478}%
\uc@dclc{53636}{cjkhangul}{\u@cjk@hangul1479}%
\uc@dclc{53640}{cjkhangul}{\u@cjk@hangul147A}%
\uc@dclc{53664}{cjkhangul}{\u@cjk@hangul147B}%
\uc@dclc{53665}{cjkhangul}{\u@cjk@hangul147C}%
\uc@dclc{53668}{cjkhangul}{\u@cjk@hangul147D}%
\uc@dclc{53672}{cjkhangul}{\u@cjk@hangul147E}%
\uc@dclc{53680}{cjkhangul}{\u@cjk@hangul147F}%
\uc@dclc{53681}{cjkhangul}{\u@cjk@hangul1480}%
\uc@dclc{53683}{cjkhangul}{\u@cjk@hangul1481}%
\uc@dclc{53685}{cjkhangul}{\u@cjk@hangul1482}%
\uc@dclc{53690}{cjkhangul}{\u@cjk@hangul1483}%
\uc@dclc{53692}{cjkhangul}{\u@cjk@hangul1484}%
\uc@dclc{53696}{cjkhangul}{\u@cjk@hangul1485}%
\uc@dclc{53720}{cjkhangul}{\u@cjk@hangul1486}%
\uc@dclc{53748}{cjkhangul}{\u@cjk@hangul1487}%
\uc@dclc{53752}{cjkhangul}{\u@cjk@hangul1488}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
