%%% Unicode to TeX mapping, file uni-498.def, U+1F200..U+1F2FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-498.def}[2013/05/13 UCS: Unicode data U+1F200..U+1F2FF]%
\fi
\uc@dclc{127488}{autogenerated}{\unicodesquare{\unichar{12411}\unichar{12363}}}%
\uc@dclc{127489}{autogenerated}{\unicodesquare{\unichar{12467}\unichar{12467}}}%
\uc@dclc{127490}{autogenerated}{\unicodesquare{\unichar{12469}}}%
\uc@dclc{127504}{autogenerated}{\unicodesquare{\unichar{25163}}}%
\uc@dclc{127505}{autogenerated}{\unicodesquare{\unichar{23383}}}%
\uc@dclc{127506}{autogenerated}{\unicodesquare{\unichar{21452}}}%
\uc@dclc{127507}{autogenerated}{\unicodesquare{\unichar{12487}}}%
\uc@dclc{127508}{autogenerated}{\unicodesquare{\unichar{20108}}}%
\uc@dclc{127509}{autogenerated}{\unicodesquare{\unichar{22810}}}%
\uc@dclc{127510}{autogenerated}{\unicodesquare{\unichar{35299}}}%
\uc@dclc{127511}{autogenerated}{\unicodesquare{\unichar{22825}}}%
\uc@dclc{127512}{autogenerated}{\unicodesquare{\unichar{20132}}}%
\uc@dclc{127513}{autogenerated}{\unicodesquare{\unichar{26144}}}%
\uc@dclc{127514}{autogenerated}{\unicodesquare{\unichar{28961}}}%
\uc@dclc{127515}{autogenerated}{\unicodesquare{\unichar{26009}}}%
\uc@dclc{127516}{autogenerated}{\unicodesquare{\unichar{21069}}}%
\uc@dclc{127517}{autogenerated}{\unicodesquare{\unichar{24460}}}%
\uc@dclc{127518}{autogenerated}{\unicodesquare{\unichar{20877}}}%
\uc@dclc{127519}{autogenerated}{\unicodesquare{\unichar{26032}}}%
\uc@dclc{127520}{autogenerated}{\unicodesquare{\unichar{21021}}}%
\uc@dclc{127521}{autogenerated}{\unicodesquare{\unichar{32066}}}%
\uc@dclc{127522}{autogenerated}{\unicodesquare{\unichar{29983}}}%
\uc@dclc{127523}{autogenerated}{\unicodesquare{\unichar{36009}}}%
\uc@dclc{127524}{autogenerated}{\unicodesquare{\unichar{22768}}}%
\uc@dclc{127525}{autogenerated}{\unicodesquare{\unichar{21561}}}%
\uc@dclc{127526}{autogenerated}{\unicodesquare{\unichar{28436}}}%
\uc@dclc{127527}{autogenerated}{\unicodesquare{\unichar{25237}}}%
\uc@dclc{127528}{autogenerated}{\unicodesquare{\unichar{25429}}}%
\uc@dclc{127529}{autogenerated}{\unicodesquare{\unichar{19968}}}%
\uc@dclc{127530}{autogenerated}{\unicodesquare{\unichar{19977}}}%
\uc@dclc{127531}{autogenerated}{\unicodesquare{\unichar{36938}}}%
\uc@dclc{127532}{autogenerated}{\unicodesquare{\unichar{24038}}}%
\uc@dclc{127533}{autogenerated}{\unicodesquare{\unichar{20013}}}%
\uc@dclc{127534}{autogenerated}{\unicodesquare{\unichar{21491}}}%
\uc@dclc{127535}{autogenerated}{\unicodesquare{\unichar{25351}}}%
\uc@dclc{127536}{autogenerated}{\unicodesquare{\unichar{36208}}}%
\uc@dclc{127537}{autogenerated}{\unicodesquare{\unichar{25171}}}%
\uc@dclc{127538}{autogenerated}{\unicodesquare{\unichar{31105}}}%
\uc@dclc{127539}{autogenerated}{\unicodesquare{\unichar{31354}}}%
\uc@dclc{127540}{autogenerated}{\unicodesquare{\unichar{21512}}}%
\uc@dclc{127541}{autogenerated}{\unicodesquare{\unichar{28288}}}%
\uc@dclc{127542}{autogenerated}{\unicodesquare{\unichar{26377}}}%
\uc@dclc{127543}{autogenerated}{\unicodesquare{\unichar{26376}}}%
\uc@dclc{127544}{autogenerated}{\unicodesquare{\unichar{30003}}}%
\uc@dclc{127545}{autogenerated}{\unicodesquare{\unichar{21106}}}%
\uc@dclc{127546}{autogenerated}{\unicodesquare{\unichar{21942}}}%
\uc@dclc{127552}{autogenerated}{\unichar{12308}\unichar{26412}\unichar{12309}}%
\uc@dclc{127553}{autogenerated}{\unichar{12308}\unichar{19977}\unichar{12309}}%
\uc@dclc{127554}{autogenerated}{\unichar{12308}\unichar{20108}\unichar{12309}}%
\uc@dclc{127555}{autogenerated}{\unichar{12308}\unichar{23433}\unichar{12309}}%
\uc@dclc{127556}{autogenerated}{\unichar{12308}\unichar{28857}\unichar{12309}}%
\uc@dclc{127557}{autogenerated}{\unichar{12308}\unichar{25171}\unichar{12309}}%
\uc@dclc{127558}{autogenerated}{\unichar{12308}\unichar{30423}\unichar{12309}}%
\uc@dclc{127559}{autogenerated}{\unichar{12308}\unichar{21213}\unichar{12309}}%
\uc@dclc{127560}{autogenerated}{\unichar{12308}\unichar{25943}\unichar{12309}}%
\uc@dclc{127568}{autogenerated}{\unicodecircle{\unichar{24471}}}%
\uc@dclc{127569}{autogenerated}{\unicodecircle{\unichar{21487}}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
