%%% Unicode to TeX mapping, file uni-255.def, U+FF00..U+FFFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-255.def}[2013/05/13 UCS: Unicode data U+FF00..U+FFFF]%
\fi
\uc@dclc{65281}{autogenerated}{\unicodewide{\unichar{33}}}%
\uc@dclc{65282}{autogenerated}{\unicodewide{\unichar{34}}}%
\uc@dclc{65283}{autogenerated}{\unicodewide{\unichar{35}}}%
\uc@dclc{65284}{autogenerated}{\unicodewide{\unichar{36}}}%
\uc@dclc{65285}{autogenerated}{\unicodewide{\unichar{37}}}%
\uc@dclc{65286}{autogenerated}{\unicodewide{\unichar{38}}}%
\uc@dclc{65287}{autogenerated}{\unicodewide{\unichar{39}}}%
\uc@dclc{65288}{autogenerated}{\unicodewide{\unichar{40}}}%
\uc@dclc{65289}{autogenerated}{\unicodewide{\unichar{41}}}%
\uc@dclc{65290}{autogenerated}{\unicodewide{\unichar{42}}}%
\uc@dclc{65291}{autogenerated}{\unicodewide{\unichar{43}}}%
\uc@dclc{65292}{autogenerated}{\unicodewide{\unichar{44}}}%
\uc@dclc{65293}{autogenerated}{\unicodewide{\unichar{45}}}%
\uc@dclc{65294}{autogenerated}{\unicodewide{\unichar{46}}}%
\uc@dclc{65295}{autogenerated}{\unicodewide{\unichar{47}}}%
\uc@dclc{65296}{autogenerated}{\unicodewide{\unichar{48}}}%
\uc@dclc{65297}{autogenerated}{\unicodewide{\unichar{49}}}%
\uc@dclc{65298}{autogenerated}{\unicodewide{\unichar{50}}}%
\uc@dclc{65299}{autogenerated}{\unicodewide{\unichar{51}}}%
\uc@dclc{65300}{autogenerated}{\unicodewide{\unichar{52}}}%
\uc@dclc{65301}{autogenerated}{\unicodewide{\unichar{53}}}%
\uc@dclc{65302}{autogenerated}{\unicodewide{\unichar{54}}}%
\uc@dclc{65303}{autogenerated}{\unicodewide{\unichar{55}}}%
\uc@dclc{65304}{autogenerated}{\unicodewide{\unichar{56}}}%
\uc@dclc{65305}{autogenerated}{\unicodewide{\unichar{57}}}%
\uc@dclc{65306}{autogenerated}{\unicodewide{\unichar{58}}}%
\uc@dclc{65307}{autogenerated}{\unicodewide{\unichar{59}}}%
\uc@dclc{65308}{autogenerated}{\unicodewide{\unichar{60}}}%
\uc@dclc{65309}{autogenerated}{\unicodewide{\unichar{61}}}%
\uc@dclc{65310}{autogenerated}{\unicodewide{\unichar{62}}}%
\uc@dclc{65311}{autogenerated}{\unicodewide{\unichar{63}}}%
\uc@dclc{65312}{autogenerated}{\unicodewide{\unichar{64}}}%
\uc@dclc{65313}{autogenerated}{\unicodewide{\unichar{65}}}%
\uc@dclc{65314}{autogenerated}{\unicodewide{\unichar{66}}}%
\uc@dclc{65315}{autogenerated}{\unicodewide{\unichar{67}}}%
\uc@dclc{65316}{autogenerated}{\unicodewide{\unichar{68}}}%
\uc@dclc{65317}{autogenerated}{\unicodewide{\unichar{69}}}%
\uc@dclc{65318}{autogenerated}{\unicodewide{\unichar{70}}}%
\uc@dclc{65319}{autogenerated}{\unicodewide{\unichar{71}}}%
\uc@dclc{65320}{autogenerated}{\unicodewide{\unichar{72}}}%
\uc@dclc{65321}{autogenerated}{\unicodewide{\unichar{73}}}%
\uc@dclc{65322}{autogenerated}{\unicodewide{\unichar{74}}}%
\uc@dclc{65323}{autogenerated}{\unicodewide{\unichar{75}}}%
\uc@dclc{65324}{autogenerated}{\unicodewide{\unichar{76}}}%
\uc@dclc{65325}{autogenerated}{\unicodewide{\unichar{77}}}%
\uc@dclc{65326}{autogenerated}{\unicodewide{\unichar{78}}}%
\uc@dclc{65327}{autogenerated}{\unicodewide{\unichar{79}}}%
\uc@dclc{65328}{autogenerated}{\unicodewide{\unichar{80}}}%
\uc@dclc{65329}{autogenerated}{\unicodewide{\unichar{81}}}%
\uc@dclc{65330}{autogenerated}{\unicodewide{\unichar{82}}}%
\uc@dclc{65331}{autogenerated}{\unicodewide{\unichar{83}}}%
\uc@dclc{65332}{autogenerated}{\unicodewide{\unichar{84}}}%
\uc@dclc{65333}{autogenerated}{\unicodewide{\unichar{85}}}%
\uc@dclc{65334}{autogenerated}{\unicodewide{\unichar{86}}}%
\uc@dclc{65335}{autogenerated}{\unicodewide{\unichar{87}}}%
\uc@dclc{65336}{autogenerated}{\unicodewide{\unichar{88}}}%
\uc@dclc{65337}{autogenerated}{\unicodewide{\unichar{89}}}%
\uc@dclc{65338}{autogenerated}{\unicodewide{\unichar{90}}}%
\uc@dclc{65339}{autogenerated}{\unicodewide{\unichar{91}}}%
\uc@dclc{65340}{autogenerated}{\unicodewide{\unichar{92}}}%
\uc@dclc{65341}{autogenerated}{\unicodewide{\unichar{93}}}%
\uc@dclc{65342}{autogenerated}{\unicodewide{\unichar{94}}}%
\uc@dclc{65343}{autogenerated}{\unicodewide{\unichar{95}}}%
\uc@dclc{65344}{autogenerated}{\unicodewide{\unichar{96}}}%
\uc@dclc{65345}{autogenerated}{\unicodewide{\unichar{97}}}%
\uc@dclc{65346}{autogenerated}{\unicodewide{\unichar{98}}}%
\uc@dclc{65347}{autogenerated}{\unicodewide{\unichar{99}}}%
\uc@dclc{65348}{autogenerated}{\unicodewide{\unichar{100}}}%
\uc@dclc{65349}{autogenerated}{\unicodewide{\unichar{101}}}%
\uc@dclc{65350}{autogenerated}{\unicodewide{\unichar{102}}}%
\uc@dclc{65351}{autogenerated}{\unicodewide{\unichar{103}}}%
\uc@dclc{65352}{autogenerated}{\unicodewide{\unichar{104}}}%
\uc@dclc{65353}{autogenerated}{\unicodewide{\unichar{105}}}%
\uc@dclc{65354}{autogenerated}{\unicodewide{\unichar{106}}}%
\uc@dclc{65355}{autogenerated}{\unicodewide{\unichar{107}}}%
\uc@dclc{65356}{autogenerated}{\unicodewide{\unichar{108}}}%
\uc@dclc{65357}{autogenerated}{\unicodewide{\unichar{109}}}%
\uc@dclc{65358}{autogenerated}{\unicodewide{\unichar{110}}}%
\uc@dclc{65359}{autogenerated}{\unicodewide{\unichar{111}}}%
\uc@dclc{65360}{autogenerated}{\unicodewide{\unichar{112}}}%
\uc@dclc{65361}{autogenerated}{\unicodewide{\unichar{113}}}%
\uc@dclc{65362}{autogenerated}{\unicodewide{\unichar{114}}}%
\uc@dclc{65363}{autogenerated}{\unicodewide{\unichar{115}}}%
\uc@dclc{65364}{autogenerated}{\unicodewide{\unichar{116}}}%
\uc@dclc{65365}{autogenerated}{\unicodewide{\unichar{117}}}%
\uc@dclc{65366}{autogenerated}{\unicodewide{\unichar{118}}}%
\uc@dclc{65367}{autogenerated}{\unicodewide{\unichar{119}}}%
\uc@dclc{65368}{autogenerated}{\unicodewide{\unichar{120}}}%
\uc@dclc{65369}{autogenerated}{\unicodewide{\unichar{121}}}%
\uc@dclc{65370}{autogenerated}{\unicodewide{\unichar{122}}}%
\uc@dclc{65371}{autogenerated}{\unicodewide{\unichar{123}}}%
\uc@dclc{65372}{autogenerated}{\unicodewide{\unichar{124}}}%
\uc@dclc{65373}{autogenerated}{\unicodewide{\unichar{125}}}%
\uc@dclc{65374}{autogenerated}{\unicodewide{\unichar{126}}}%
\uc@dclc{65377}{autogenerated}{\unicodenarrow{\unichar{12290}}}%
\uc@dclc{65378}{autogenerated}{\unicodenarrow{\unichar{12300}}}%
\uc@dclc{65379}{autogenerated}{\unicodenarrow{\unichar{12301}}}%
\uc@dclc{65380}{autogenerated}{\unicodenarrow{\unichar{12289}}}%
\uc@dclc{65381}{autogenerated}{\unicodenarrow{\unichar{12539}}}%
\uc@dclc{65382}{autogenerated}{\unicodenarrow{\unichar{12530}}}%
\uc@dclc{65383}{autogenerated}{\unicodenarrow{\unichar{12449}}}%
\uc@dclc{65384}{autogenerated}{\unicodenarrow{\unichar{12451}}}%
\uc@dclc{65385}{autogenerated}{\unicodenarrow{\unichar{12453}}}%
\uc@dclc{65386}{autogenerated}{\unicodenarrow{\unichar{12455}}}%
\uc@dclc{65387}{autogenerated}{\unicodenarrow{\unichar{12457}}}%
\uc@dclc{65388}{autogenerated}{\unicodenarrow{\unichar{12515}}}%
\uc@dclc{65389}{autogenerated}{\unicodenarrow{\unichar{12517}}}%
\uc@dclc{65390}{autogenerated}{\unicodenarrow{\unichar{12519}}}%
\uc@dclc{65391}{autogenerated}{\unicodenarrow{\unichar{12483}}}%
\uc@dclc{65392}{autogenerated}{\unicodenarrow{\unichar{12540}}}%
\uc@dclc{65393}{autogenerated}{\unicodenarrow{\unichar{12450}}}%
\uc@dclc{65394}{autogenerated}{\unicodenarrow{\unichar{12452}}}%
\uc@dclc{65395}{autogenerated}{\unicodenarrow{\unichar{12454}}}%
\uc@dclc{65396}{autogenerated}{\unicodenarrow{\unichar{12456}}}%
\uc@dclc{65397}{autogenerated}{\unicodenarrow{\unichar{12458}}}%
\uc@dclc{65398}{autogenerated}{\unicodenarrow{\unichar{12459}}}%
\uc@dclc{65399}{autogenerated}{\unicodenarrow{\unichar{12461}}}%
\uc@dclc{65400}{autogenerated}{\unicodenarrow{\unichar{12463}}}%
\uc@dclc{65401}{autogenerated}{\unicodenarrow{\unichar{12465}}}%
\uc@dclc{65402}{autogenerated}{\unicodenarrow{\unichar{12467}}}%
\uc@dclc{65403}{autogenerated}{\unicodenarrow{\unichar{12469}}}%
\uc@dclc{65404}{autogenerated}{\unicodenarrow{\unichar{12471}}}%
\uc@dclc{65405}{autogenerated}{\unicodenarrow{\unichar{12473}}}%
\uc@dclc{65406}{autogenerated}{\unicodenarrow{\unichar{12475}}}%
\uc@dclc{65407}{autogenerated}{\unicodenarrow{\unichar{12477}}}%
\uc@dclc{65408}{autogenerated}{\unicodenarrow{\unichar{12479}}}%
\uc@dclc{65409}{autogenerated}{\unicodenarrow{\unichar{12481}}}%
\uc@dclc{65410}{autogenerated}{\unicodenarrow{\unichar{12484}}}%
\uc@dclc{65411}{autogenerated}{\unicodenarrow{\unichar{12486}}}%
\uc@dclc{65412}{autogenerated}{\unicodenarrow{\unichar{12488}}}%
\uc@dclc{65413}{autogenerated}{\unicodenarrow{\unichar{12490}}}%
\uc@dclc{65414}{autogenerated}{\unicodenarrow{\unichar{12491}}}%
\uc@dclc{65415}{autogenerated}{\unicodenarrow{\unichar{12492}}}%
\uc@dclc{65416}{autogenerated}{\unicodenarrow{\unichar{12493}}}%
\uc@dclc{65417}{autogenerated}{\unicodenarrow{\unichar{12494}}}%
\uc@dclc{65418}{autogenerated}{\unicodenarrow{\unichar{12495}}}%
\uc@dclc{65419}{autogenerated}{\unicodenarrow{\unichar{12498}}}%
\uc@dclc{65420}{autogenerated}{\unicodenarrow{\unichar{12501}}}%
\uc@dclc{65421}{autogenerated}{\unicodenarrow{\unichar{12504}}}%
\uc@dclc{65422}{autogenerated}{\unicodenarrow{\unichar{12507}}}%
\uc@dclc{65423}{autogenerated}{\unicodenarrow{\unichar{12510}}}%
\uc@dclc{65424}{autogenerated}{\unicodenarrow{\unichar{12511}}}%
\uc@dclc{65425}{autogenerated}{\unicodenarrow{\unichar{12512}}}%
\uc@dclc{65426}{autogenerated}{\unicodenarrow{\unichar{12513}}}%
\uc@dclc{65427}{autogenerated}{\unicodenarrow{\unichar{12514}}}%
\uc@dclc{65428}{autogenerated}{\unicodenarrow{\unichar{12516}}}%
\uc@dclc{65429}{autogenerated}{\unicodenarrow{\unichar{12518}}}%
\uc@dclc{65430}{autogenerated}{\unicodenarrow{\unichar{12520}}}%
\uc@dclc{65431}{autogenerated}{\unicodenarrow{\unichar{12521}}}%
\uc@dclc{65432}{autogenerated}{\unicodenarrow{\unichar{12522}}}%
\uc@dclc{65433}{autogenerated}{\unicodenarrow{\unichar{12523}}}%
\uc@dclc{65434}{autogenerated}{\unicodenarrow{\unichar{12524}}}%
\uc@dclc{65435}{autogenerated}{\unicodenarrow{\unichar{12525}}}%
\uc@dclc{65436}{autogenerated}{\unicodenarrow{\unichar{12527}}}%
\uc@dclc{65437}{autogenerated}{\unicodenarrow{\unichar{12531}}}%
\uc@dclc{65440}{autogenerated}{\unicodenarrow{\unichar{12644}}}%
\uc@dclc{65441}{autogenerated}{\unicodenarrow{\unichar{12593}}}%
\uc@dclc{65442}{autogenerated}{\unicodenarrow{\unichar{12594}}}%
\uc@dclc{65443}{autogenerated}{\unicodenarrow{\unichar{12595}}}%
\uc@dclc{65444}{autogenerated}{\unicodenarrow{\unichar{12596}}}%
\uc@dclc{65445}{autogenerated}{\unicodenarrow{\unichar{12597}}}%
\uc@dclc{65446}{autogenerated}{\unicodenarrow{\unichar{12598}}}%
\uc@dclc{65447}{autogenerated}{\unicodenarrow{\unichar{12599}}}%
\uc@dclc{65448}{autogenerated}{\unicodenarrow{\unichar{12600}}}%
\uc@dclc{65449}{autogenerated}{\unicodenarrow{\unichar{12601}}}%
\uc@dclc{65450}{autogenerated}{\unicodenarrow{\unichar{12602}}}%
\uc@dclc{65451}{autogenerated}{\unicodenarrow{\unichar{12603}}}%
\uc@dclc{65452}{autogenerated}{\unicodenarrow{\unichar{12604}}}%
\uc@dclc{65453}{autogenerated}{\unicodenarrow{\unichar{12605}}}%
\uc@dclc{65454}{autogenerated}{\unicodenarrow{\unichar{12606}}}%
\uc@dclc{65455}{autogenerated}{\unicodenarrow{\unichar{12607}}}%
\uc@dclc{65456}{autogenerated}{\unicodenarrow{\unichar{12608}}}%
\uc@dclc{65457}{autogenerated}{\unicodenarrow{\unichar{12609}}}%
\uc@dclc{65458}{autogenerated}{\unicodenarrow{\unichar{12610}}}%
\uc@dclc{65459}{autogenerated}{\unicodenarrow{\unichar{12611}}}%
\uc@dclc{65460}{autogenerated}{\unicodenarrow{\unichar{12612}}}%
\uc@dclc{65461}{autogenerated}{\unicodenarrow{\unichar{12613}}}%
\uc@dclc{65462}{autogenerated}{\unicodenarrow{\unichar{12614}}}%
\uc@dclc{65463}{autogenerated}{\unicodenarrow{\unichar{12615}}}%
\uc@dclc{65464}{autogenerated}{\unicodenarrow{\unichar{12616}}}%
\uc@dclc{65465}{autogenerated}{\unicodenarrow{\unichar{12617}}}%
\uc@dclc{65466}{autogenerated}{\unicodenarrow{\unichar{12618}}}%
\uc@dclc{65467}{autogenerated}{\unicodenarrow{\unichar{12619}}}%
\uc@dclc{65468}{autogenerated}{\unicodenarrow{\unichar{12620}}}%
\uc@dclc{65469}{autogenerated}{\unicodenarrow{\unichar{12621}}}%
\uc@dclc{65470}{autogenerated}{\unicodenarrow{\unichar{12622}}}%
\uc@dclc{65474}{autogenerated}{\unicodenarrow{\unichar{12623}}}%
\uc@dclc{65475}{autogenerated}{\unicodenarrow{\unichar{12624}}}%
\uc@dclc{65476}{autogenerated}{\unicodenarrow{\unichar{12625}}}%
\uc@dclc{65477}{autogenerated}{\unicodenarrow{\unichar{12626}}}%
\uc@dclc{65478}{autogenerated}{\unicodenarrow{\unichar{12627}}}%
\uc@dclc{65479}{autogenerated}{\unicodenarrow{\unichar{12628}}}%
\uc@dclc{65482}{autogenerated}{\unicodenarrow{\unichar{12629}}}%
\uc@dclc{65483}{autogenerated}{\unicodenarrow{\unichar{12630}}}%
\uc@dclc{65484}{autogenerated}{\unicodenarrow{\unichar{12631}}}%
\uc@dclc{65485}{autogenerated}{\unicodenarrow{\unichar{12632}}}%
\uc@dclc{65486}{autogenerated}{\unicodenarrow{\unichar{12633}}}%
\uc@dclc{65487}{autogenerated}{\unicodenarrow{\unichar{12634}}}%
\uc@dclc{65490}{autogenerated}{\unicodenarrow{\unichar{12635}}}%
\uc@dclc{65491}{autogenerated}{\unicodenarrow{\unichar{12636}}}%
\uc@dclc{65492}{autogenerated}{\unicodenarrow{\unichar{12637}}}%
\uc@dclc{65493}{autogenerated}{\unicodenarrow{\unichar{12638}}}%
\uc@dclc{65494}{autogenerated}{\unicodenarrow{\unichar{12639}}}%
\uc@dclc{65495}{autogenerated}{\unicodenarrow{\unichar{12640}}}%
\uc@dclc{65498}{autogenerated}{\unicodenarrow{\unichar{12641}}}%
\uc@dclc{65499}{autogenerated}{\unicodenarrow{\unichar{12642}}}%
\uc@dclc{65500}{autogenerated}{\unicodenarrow{\unichar{12643}}}%
\uc@dclc{65504}{autogenerated}{\unicodewide{\unichar{162}}}%
\uc@dclc{65505}{autogenerated}{\unicodewide{\unichar{163}}}%
\uc@dclc{65506}{autogenerated}{\unicodewide{\unichar{172}}}%
\uc@dclc{65507}{autogenerated}{\unicodewide{\unichar{175}}}%
\uc@dclc{65508}{autogenerated}{\unicodewide{\unichar{166}}}%
\uc@dclc{65509}{autogenerated}{\unicodewide{\unichar{165}}}%
\uc@dclc{65510}{autogenerated}{\unicodewide{\unichar{8361}}}%
\uc@dclc{65512}{autogenerated}{\unicodenarrow{\unichar{9474}}}%
\uc@dclc{65513}{autogenerated}{\unicodenarrow{\unichar{8592}}}%
\uc@dclc{65514}{autogenerated}{\unicodenarrow{\unichar{8593}}}%
\uc@dclc{65515}{autogenerated}{\unicodenarrow{\unichar{8594}}}%
\uc@dclc{65516}{autogenerated}{\unicodenarrow{\unichar{8595}}}%
\uc@dclc{65517}{autogenerated}{\unicodenarrow{\unichar{9632}}}%
\uc@dclc{65534}{default}{\PackageError{ucs}{U+FFFE occured.}{Probably some byte order problem occured during some conversion step.}}%
\gdef\uc@controlbox#1{{\fboxsep=1pt\fbox{\tabcolsep=0pt\ttfamily\tiny\begin{tabular}{c}#1\end{tabular}}}}%
\uc@dclc{65534}{ctrlglyphs}{\uc@controlbox{N/A}}%
\uc@dclc{65535}{default}{\PackageError{ucs}{U+FFFF occured.}{This is no Unicode character.}}%
\uc@dclc{65535}{ctrlglyphs}{\uc@controlbox{N/A}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
