%%% Unicode to TeX mapping, file uni-189.def, U+BD00..U+BDFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-189.def}[2013/05/13 UCS: Unicode data U+BD00..U+BDFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{48388}{cjkhangul}{\u@cjk@hangul104A}%
\uc@dclc{48389}{cjkhangul}{\u@cjk@hangul104B}%
\uc@dclc{48391}{cjkhangul}{\u@cjk@hangul104C}%
\uc@dclc{48393}{cjkhangul}{\u@cjk@hangul104D}%
\uc@dclc{48400}{cjkhangul}{\u@cjk@hangul104E}%
\uc@dclc{48404}{cjkhangul}{\u@cjk@hangul104F}%
\uc@dclc{48420}{cjkhangul}{\u@cjk@hangul1050}%
\uc@dclc{48428}{cjkhangul}{\u@cjk@hangul1051}%
\uc@dclc{48448}{cjkhangul}{\u@cjk@hangul1052}%
\uc@dclc{48456}{cjkhangul}{\u@cjk@hangul1053}%
\uc@dclc{48457}{cjkhangul}{\u@cjk@hangul1054}%
\uc@dclc{48460}{cjkhangul}{\u@cjk@hangul1055}%
\uc@dclc{48464}{cjkhangul}{\u@cjk@hangul1056}%
\uc@dclc{48472}{cjkhangul}{\u@cjk@hangul1057}%
\uc@dclc{48473}{cjkhangul}{\u@cjk@hangul1058}%
\uc@dclc{48484}{cjkhangul}{\u@cjk@hangul1059}%
\uc@dclc{48488}{cjkhangul}{\u@cjk@hangul105A}%
\uc@dclc{48512}{cjkhangul}{\u@cjk@hangul105B}%
\uc@dclc{48513}{cjkhangul}{\u@cjk@hangul105C}%
\uc@dclc{48516}{cjkhangul}{\u@cjk@hangul105D}%
\uc@dclc{48519}{cjkhangul}{\u@cjk@hangul105E}%
\uc@dclc{48520}{cjkhangul}{\u@cjk@hangul105F}%
\uc@dclc{48521}{cjkhangul}{\u@cjk@hangul1060}%
\uc@dclc{48522}{cjkhangul}{\u@cjk@hangul1061}%
\uc@dclc{48528}{cjkhangul}{\u@cjk@hangul1062}%
\uc@dclc{48529}{cjkhangul}{\u@cjk@hangul1063}%
\uc@dclc{48531}{cjkhangul}{\u@cjk@hangul1064}%
\uc@dclc{48533}{cjkhangul}{\u@cjk@hangul1065}%
\uc@dclc{48537}{cjkhangul}{\u@cjk@hangul1066}%
\uc@dclc{48538}{cjkhangul}{\u@cjk@hangul1067}%
\uc@dclc{48540}{cjkhangul}{\u@cjk@hangul1068}%
\uc@dclc{48548}{cjkhangul}{\u@cjk@hangul1069}%
\uc@dclc{48560}{cjkhangul}{\u@cjk@hangul106A}%
\uc@dclc{48568}{cjkhangul}{\u@cjk@hangul106B}%
\uc@dclc{48596}{cjkhangul}{\u@cjk@hangul106C}%
\uc@dclc{48597}{cjkhangul}{\u@cjk@hangul106D}%
\uc@dclc{48600}{cjkhangul}{\u@cjk@hangul106E}%
\uc@dclc{48604}{cjkhangul}{\u@cjk@hangul106F}%
\uc@dclc{48617}{cjkhangul}{\u@cjk@hangul1070}%
\uc@dclc{48624}{cjkhangul}{\u@cjk@hangul1071}%
\uc@dclc{48628}{cjkhangul}{\u@cjk@hangul1072}%
\uc@dclc{48632}{cjkhangul}{\u@cjk@hangul1073}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
