%%% Unicode to TeX mapping, file uni-172.def, U+AC00..U+ACFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-172.def}[2013/05/13 UCS: Unicode data U+AC00..U+ACFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{44032}{cjkhangul}{\u@cjk@hangul0682}%
\uc@dclc{44033}{cjkhangul}{\u@cjk@hangul0683}%
\uc@dclc{44036}{cjkhangul}{\u@cjk@hangul0684}%
\uc@dclc{44039}{cjkhangul}{\u@cjk@hangul0685}%
\uc@dclc{44040}{cjkhangul}{\u@cjk@hangul0686}%
\uc@dclc{44041}{cjkhangul}{\u@cjk@hangul0687}%
\uc@dclc{44042}{cjkhangul}{\u@cjk@hangul0688}%
\uc@dclc{44048}{cjkhangul}{\u@cjk@hangul0689}%
\uc@dclc{44049}{cjkhangul}{\u@cjk@hangul068A}%
\uc@dclc{44050}{cjkhangul}{\u@cjk@hangul068B}%
\uc@dclc{44051}{cjkhangul}{\u@cjk@hangul068C}%
\uc@dclc{44052}{cjkhangul}{\u@cjk@hangul068D}%
\uc@dclc{44053}{cjkhangul}{\u@cjk@hangul068E}%
\uc@dclc{44054}{cjkhangul}{\u@cjk@hangul068F}%
\uc@dclc{44055}{cjkhangul}{\u@cjk@hangul0690}%
\uc@dclc{44057}{cjkhangul}{\u@cjk@hangul0691}%
\uc@dclc{44058}{cjkhangul}{\u@cjk@hangul0692}%
\uc@dclc{44059}{cjkhangul}{\u@cjk@hangul0693}%
\uc@dclc{44060}{cjkhangul}{\u@cjk@hangul0694}%
\uc@dclc{44061}{cjkhangul}{\u@cjk@hangul0695}%
\uc@dclc{44064}{cjkhangul}{\u@cjk@hangul0696}%
\uc@dclc{44068}{cjkhangul}{\u@cjk@hangul0697}%
\uc@dclc{44076}{cjkhangul}{\u@cjk@hangul0698}%
\uc@dclc{44077}{cjkhangul}{\u@cjk@hangul0699}%
\uc@dclc{44079}{cjkhangul}{\u@cjk@hangul069A}%
\uc@dclc{44080}{cjkhangul}{\u@cjk@hangul069B}%
\uc@dclc{44081}{cjkhangul}{\u@cjk@hangul069C}%
\uc@dclc{44088}{cjkhangul}{\u@cjk@hangul069D}%
\uc@dclc{44089}{cjkhangul}{\u@cjk@hangul069E}%
\uc@dclc{44092}{cjkhangul}{\u@cjk@hangul069F}%
\uc@dclc{44096}{cjkhangul}{\u@cjk@hangul06A0}%
\uc@dclc{44107}{cjkhangul}{\u@cjk@hangul06A1}%
\uc@dclc{44109}{cjkhangul}{\u@cjk@hangul06A2}%
\uc@dclc{44116}{cjkhangul}{\u@cjk@hangul06A3}%
\uc@dclc{44120}{cjkhangul}{\u@cjk@hangul06A4}%
\uc@dclc{44124}{cjkhangul}{\u@cjk@hangul06A5}%
\uc@dclc{44144}{cjkhangul}{\u@cjk@hangul06A6}%
\uc@dclc{44145}{cjkhangul}{\u@cjk@hangul06A7}%
\uc@dclc{44148}{cjkhangul}{\u@cjk@hangul06A8}%
\uc@dclc{44151}{cjkhangul}{\u@cjk@hangul06A9}%
\uc@dclc{44152}{cjkhangul}{\u@cjk@hangul06AA}%
\uc@dclc{44154}{cjkhangul}{\u@cjk@hangul06AB}%
\uc@dclc{44160}{cjkhangul}{\u@cjk@hangul06AC}%
\uc@dclc{44161}{cjkhangul}{\u@cjk@hangul06AD}%
\uc@dclc{44163}{cjkhangul}{\u@cjk@hangul06AE}%
\uc@dclc{44164}{cjkhangul}{\u@cjk@hangul06AF}%
\uc@dclc{44165}{cjkhangul}{\u@cjk@hangul06B0}%
\uc@dclc{44166}{cjkhangul}{\u@cjk@hangul06B1}%
\uc@dclc{44169}{cjkhangul}{\u@cjk@hangul06B2}%
\uc@dclc{44170}{cjkhangul}{\u@cjk@hangul06B3}%
\uc@dclc{44171}{cjkhangul}{\u@cjk@hangul06B4}%
\uc@dclc{44172}{cjkhangul}{\u@cjk@hangul06B5}%
\uc@dclc{44176}{cjkhangul}{\u@cjk@hangul06B6}%
\uc@dclc{44180}{cjkhangul}{\u@cjk@hangul06B7}%
\uc@dclc{44188}{cjkhangul}{\u@cjk@hangul06B8}%
\uc@dclc{44189}{cjkhangul}{\u@cjk@hangul06B9}%
\uc@dclc{44191}{cjkhangul}{\u@cjk@hangul06BA}%
\uc@dclc{44192}{cjkhangul}{\u@cjk@hangul06BB}%
\uc@dclc{44193}{cjkhangul}{\u@cjk@hangul06BC}%
\uc@dclc{44200}{cjkhangul}{\u@cjk@hangul06BD}%
\uc@dclc{44201}{cjkhangul}{\u@cjk@hangul06BE}%
\uc@dclc{44202}{cjkhangul}{\u@cjk@hangul06BF}%
\uc@dclc{44204}{cjkhangul}{\u@cjk@hangul06C0}%
\uc@dclc{44207}{cjkhangul}{\u@cjk@hangul06C1}%
\uc@dclc{44208}{cjkhangul}{\u@cjk@hangul06C2}%
\uc@dclc{44216}{cjkhangul}{\u@cjk@hangul06C3}%
\uc@dclc{44217}{cjkhangul}{\u@cjk@hangul06C4}%
\uc@dclc{44219}{cjkhangul}{\u@cjk@hangul06C5}%
\uc@dclc{44220}{cjkhangul}{\u@cjk@hangul06C6}%
\uc@dclc{44221}{cjkhangul}{\u@cjk@hangul06C7}%
\uc@dclc{44225}{cjkhangul}{\u@cjk@hangul06C8}%
\uc@dclc{44228}{cjkhangul}{\u@cjk@hangul06C9}%
\uc@dclc{44232}{cjkhangul}{\u@cjk@hangul06CA}%
\uc@dclc{44236}{cjkhangul}{\u@cjk@hangul06CB}%
\uc@dclc{44245}{cjkhangul}{\u@cjk@hangul06CC}%
\uc@dclc{44247}{cjkhangul}{\u@cjk@hangul06CD}%
\uc@dclc{44256}{cjkhangul}{\u@cjk@hangul06CE}%
\uc@dclc{44257}{cjkhangul}{\u@cjk@hangul06CF}%
\uc@dclc{44260}{cjkhangul}{\u@cjk@hangul06D0}%
\uc@dclc{44263}{cjkhangul}{\u@cjk@hangul06D1}%
\uc@dclc{44264}{cjkhangul}{\u@cjk@hangul06D2}%
\uc@dclc{44266}{cjkhangul}{\u@cjk@hangul06D3}%
\uc@dclc{44268}{cjkhangul}{\u@cjk@hangul06D4}%
\uc@dclc{44271}{cjkhangul}{\u@cjk@hangul06D5}%
\uc@dclc{44272}{cjkhangul}{\u@cjk@hangul06D6}%
\uc@dclc{44273}{cjkhangul}{\u@cjk@hangul06D7}%
\uc@dclc{44275}{cjkhangul}{\u@cjk@hangul06D8}%
\uc@dclc{44277}{cjkhangul}{\u@cjk@hangul06D9}%
\uc@dclc{44278}{cjkhangul}{\u@cjk@hangul06DA}%
\uc@dclc{44284}{cjkhangul}{\u@cjk@hangul06DB}%
\uc@dclc{44285}{cjkhangul}{\u@cjk@hangul06DC}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
