%%% Unicode to TeX mapping, file uni-14.def, U+0E00..U+0EFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-14.def}[2013/05/13 UCS: Unicode data U+0E00..U+0EFF]%
\fi
\uc@dclc{3585}{default}{\thaiKoKai}%
\uc@dclc{3586}{default}{\thaiKhoKhai}%
\uc@dclc{3587}{default}{\thaiKhoKhuat}%
\uc@dclc{3588}{default}{\thaiKhoKhwai}%
\uc@dclc{3589}{default}{\thaiKhoKhon}%
\uc@dclc{3590}{default}{\thaiKhoRakhang}%
\uc@dclc{3591}{default}{\thaiNgoNgu}%
\uc@dclc{3592}{default}{\thaiChoChan}%
\uc@dclc{3593}{default}{\thaiChoChing}%
\uc@dclc{3594}{default}{\thaiChoChang}%
\uc@dclc{3595}{default}{\thaiSoSo}%
\uc@dclc{3596}{default}{\thaiChoChoe}%
\uc@dclc{3597}{default}{\thaiYoYing}%
\uc@dclc{3598}{default}{\thaiDoChada}%
\uc@dclc{3599}{default}{\thaiToPatak}%
\uc@dclc{3600}{default}{\thaiThoThan}%
\uc@dclc{3601}{default}{\thaiThoNangmontho}%
\uc@dclc{3602}{default}{\thaiThoPhuthao}%
\uc@dclc{3603}{default}{\thaiNoNen}%
\uc@dclc{3604}{default}{\thaiDoDek}%
\uc@dclc{3605}{default}{\thaiToTao}%
\uc@dclc{3606}{default}{\thaiThoThung}%
\uc@dclc{3607}{default}{\thaiThoThahan}%
\uc@dclc{3608}{default}{\thaiThoThong}%
\uc@dclc{3609}{default}{\thaiNoNu}%
\uc@dclc{3610}{default}{\thaiBoBaimai}%
\uc@dclc{3611}{default}{\thaiPoPla}%
\uc@dclc{3612}{default}{\thaiPhoPhung}%
\uc@dclc{3613}{default}{\thaiFoFa}%
\uc@dclc{3614}{default}{\thaiPhoPhan}%
\uc@dclc{3615}{default}{\thaiFoFan}%
\uc@dclc{3616}{default}{\thaiPhoSamphao}%
\uc@dclc{3617}{default}{\thaiMoMa}%
\uc@dclc{3618}{default}{\thaiYoYak}%
\uc@dclc{3619}{default}{\thaiRoRua}%
\uc@dclc{3620}{default}{\thaiRu}%
\uc@dclc{3621}{default}{\thaiLoLing}%
\uc@dclc{3622}{default}{\thaiLu}%
\uc@dclc{3623}{default}{\thaiWoWaen}%
\uc@dclc{3624}{default}{\thaiSoSala}%
\uc@dclc{3625}{default}{\thaiSoRusi}%
\uc@dclc{3626}{default}{\thaiSoSua}%
\uc@dclc{3627}{default}{\thaiHoHip}%
\uc@dclc{3628}{default}{\thaiLoChula}%
\uc@dclc{3629}{default}{\thaiOAng}%
\uc@dclc{3630}{default}{\thaiHoNokhuk}%
\uc@dclc{3631}{default}{\thaiPaiyannoi}%
\uc@dclc{3632}{default}{\thaiSaraA}%
\uc@dclc{3633}{default}{\thaiMaiHanakat}%
\uc@dclc{3634}{default}{\thaiSaraAa}%
\uc@dclc{3635}{default}{\thaiSaraAm}%
\uc@dclc{3636}{default}{\thaiSaraI}%
\uc@dclc{3637}{default}{\thaiSaraIi}%
\uc@dclc{3638}{default}{\thaiSaraUe}%
\uc@dclc{3639}{default}{\thaiSaraUee}%
\uc@dclc{3640}{default}{\thaiSaraU}%
\uc@dclc{3641}{default}{\thaiSaraUu}%
\uc@dclc{3642}{default}{\thaiPhinthu}%
\uc@dclc{3647}{default}{\textbaht}%
\uc@dclc{3648}{default}{\thaiSaraE}%
\uc@dclc{3649}{default}{\thaiSaraAe}%
\uc@dclc{3650}{default}{\thaiSaraO}%
\uc@dclc{3651}{default}{\thaiSaraAiMaimuan}%
\uc@dclc{3652}{default}{\thaiSaraAiMaimalai}%
\uc@dclc{3653}{default}{\thaiLakkhangyao}%
\uc@dclc{3654}{default}{\thaiMaiyamok}%
\uc@dclc{3655}{default}{\thaiMaitaikhu}%
\uc@dclc{3656}{default}{\thaiMaiEk}%
\uc@dclc{3657}{default}{\thaiMaiTho}%
\uc@dclc{3658}{default}{\thaiMaiTri}%
\uc@dclc{3659}{default}{\thaiMaiChattawa}%
\uc@dclc{3660}{default}{\thaiThanthakhat}%
\uc@dclc{3661}{default}{\thaiNikhahit}%
\uc@dclc{3662}{default}{\thaiYamakkan}%
\uc@dclc{3663}{default}{\thaiFongman}%
\uc@dclc{3664}{default}{\thaizero}%
\uc@dclc{3665}{default}{\thaione}%
\uc@dclc{3666}{default}{\thaitwo}%
\uc@dclc{3667}{default}{\thaithree}%
\uc@dclc{3668}{default}{\thaifour}%
\uc@dclc{3669}{default}{\thaifive}%
\uc@dclc{3670}{default}{\thaisix}%
\uc@dclc{3671}{default}{\thaiseven}%
\uc@dclc{3672}{default}{\thaieight}%
\uc@dclc{3673}{default}{\thainine}%
\uc@dclc{3674}{default}{\thaiAngkhankhu}%
\uc@dclc{3675}{default}{\thaiKhomut}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
