%%
%% This is file `ltaenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ucs.dtx  (with options: `ltaenc.def')
%% 
%% Copyright 2001 Dominique Unruh  <unruh@ut.ee>
%% Copyright 2013 Wolfgang Jeltsch <wolfgang@cs.ioc.ee>
%% 
%% This program is provided under the terms of the LaTeX Project Public License with some
%% modifications. See the file LICENSE for information.
%% 
\NeedsTeXFormat{LaTeX2e}[1998/12/01]
\ProvidesFile{ltaenc.def}[2004/10/17 Autogenerated encoding LTA]
\DeclareFontEncoding{LTA}{}{}
\DeclareFontSubstitution{LTA}{arial}{m}{n}
\DeclareTextSymbol{\guillemotleft}{LTA}{19}
\DeclareTextSymbol{\guillemotright}{LTA}{20}
\DeclareTextSymbol{\guilsinglleft}{LTA}{14}
\DeclareTextSymbol{\guilsinglright}{LTA}{15}
\DeclareTextSymbol{\i}{LTA}{25}
\DeclareTextSymbol{\quotedblbase}{LTA}{18}
\DeclareTextSymbol{\quotesinglbase}{LTA}{13}
\DeclareTextSymbol{\textasciicircum}{LTA}{`\^}
\DeclareTextSymbol{\textasciitilde}{LTA}{`\~}
\DeclareTextSymbol{\textbackslash}{LTA}{`\\}
\DeclareTextSymbol{\textbar}{LTA}{`\|}
\DeclareTextSymbol{\textbraceleft}{LTA}{`\{}
\DeclareTextSymbol{\textbraceright}{LTA}{`\}}
\DeclareTextSymbol{\textdollar}{LTA}{`\$}
\DeclareTextSymbol{\textemdash}{LTA}{22}
\DeclareTextSymbol{\textendash}{LTA}{21}
\DeclareTextSymbol{\textgreater}{LTA}{`\>}
\DeclareTextSymbol{\textless}{LTA}{`\<}
\DeclareTextSymbol{\textquotedblleft}{LTA}{16}
\DeclareTextSymbol{\textquotedblright}{LTA}{17}
\DeclareTextSymbol{\textquotedbl}{LTA}{`\"}
\DeclareTextSymbol{\textquoteleft}{LTA}{`\`}
\DeclareTextSymbol{\textquoteright}{LTA}{`\'}
\DeclareTextSymbol{\textunderscore}{LTA}{95}
\DeclareTextSymbol{\thaiKoKai}{LTA}{129}
\DeclareTextSymbol{\thaiKhoKhai}{LTA}{130}
\DeclareTextSymbol{\thaiKhoKhuat}{LTA}{131}
\DeclareTextSymbol{\thaiKhoKhwai}{LTA}{132}
\DeclareTextSymbol{\thaiKhoKhon}{LTA}{133}
\DeclareTextSymbol{\thaiKhoRakhang}{LTA}{134}
\DeclareTextSymbol{\thaiNgoNgu}{LTA}{135}
\DeclareTextSymbol{\thaiChoChan}{LTA}{136}
\DeclareTextSymbol{\thaiChoChing}{LTA}{137}
\DeclareTextSymbol{\thaiChoChang}{LTA}{138}
\DeclareTextSymbol{\thaiSoSo}{LTA}{139}
\DeclareTextSymbol{\thaiChoChoe}{LTA}{140}
\DeclareTextSymbol{\thaiYoYing}{LTA}{141}
\DeclareTextSymbol{\thaiDoChada}{LTA}{142}
\DeclareTextSymbol{\thaiToPatak}{LTA}{143}
\DeclareTextSymbol{\thaiThoThan}{LTA}{144}
\DeclareTextSymbol{\thaiThoNangmontho}{LTA}{145}
\DeclareTextSymbol{\thaiThoPhuthao}{LTA}{146}
\DeclareTextSymbol{\thaiNoNen}{LTA}{147}
\DeclareTextSymbol{\thaiDoDek}{LTA}{148}
\DeclareTextSymbol{\thaiToTao}{LTA}{149}
\DeclareTextSymbol{\thaiThoThung}{LTA}{150}
\DeclareTextSymbol{\thaiThoThahan}{LTA}{151}
\DeclareTextSymbol{\thaiThoThong}{LTA}{152}
\DeclareTextSymbol{\thaiNoNu}{LTA}{153}
\DeclareTextSymbol{\thaiBoBaimai}{LTA}{154}
\DeclareTextSymbol{\thaiPoPla}{LTA}{155}
\DeclareTextSymbol{\thaiPhoPhung}{LTA}{156}
\DeclareTextSymbol{\thaiFoFa}{LTA}{157}
\DeclareTextSymbol{\thaiPhoPhan}{LTA}{158}
\DeclareTextSymbol{\thaiFoFan}{LTA}{159}
\DeclareTextSymbol{\thaiPhoSamphao}{LTA}{160}
\DeclareTextSymbol{\thaiMoMa}{LTA}{161}
\DeclareTextSymbol{\thaiYoYak}{LTA}{162}
\DeclareTextSymbol{\thaiRoRua}{LTA}{163}
\DeclareTextSymbol{\thaiRu}{LTA}{164}
\DeclareTextSymbol{\thaiLoLing}{LTA}{165}
\DeclareTextSymbol{\thaiLu}{LTA}{166}
\DeclareTextSymbol{\thaiWoWaen}{LTA}{167}
\DeclareTextSymbol{\thaiSoSala}{LTA}{168}
\DeclareTextSymbol{\thaiSoRusi}{LTA}{169}
\DeclareTextSymbol{\thaiSoSua}{LTA}{170}
\DeclareTextSymbol{\thaiHoHip}{LTA}{171}
\DeclareTextSymbol{\thaiLoChula}{LTA}{172}
\DeclareTextSymbol{\thaiOAng}{LTA}{173}
\DeclareTextSymbol{\thaiHoNokhuk}{LTA}{174}
\DeclareTextSymbol{\thaiPaiyannoi}{LTA}{175}
\DeclareTextSymbol{\thaiSaraA}{LTA}{176}
\DeclareTextSymbol{\thaiMaiHanakat}{LTA}{177}
\DeclareTextSymbol{\thaiSaraAa}{LTA}{178}
\DeclareTextSymbol{\thaiSaraAm}{LTA}{179}
\DeclareTextSymbol{\thaiSaraI}{LTA}{180}
\DeclareTextSymbol{\thaiSaraIi}{LTA}{181}
\DeclareTextSymbol{\thaiSaraUe}{LTA}{182}
\DeclareTextSymbol{\thaiSaraUee}{LTA}{183}
\DeclareTextSymbol{\thaiSaraU}{LTA}{184}
\DeclareTextSymbol{\thaiSaraUu}{LTA}{185}
\DeclareTextSymbol{\thaiPhinthu}{LTA}{186}
\DeclareTextSymbol{\textbaht}{LTA}{191}
\DeclareTextSymbol{\thaiSaraE}{LTA}{192}
\DeclareTextSymbol{\thaiSaraAe}{LTA}{193}
\DeclareTextSymbol{\thaiSaraO}{LTA}{194}
\DeclareTextSymbol{\thaiSaraAiMaimuan}{LTA}{195}
\DeclareTextSymbol{\thaiSaraAiMaimalai}{LTA}{196}
\DeclareTextSymbol{\thaiLakkhangyao}{LTA}{197}
\DeclareTextSymbol{\thaiMaiyamok}{LTA}{198}
\DeclareTextSymbol{\thaiMaitaikhu}{LTA}{199}
\DeclareTextSymbol{\thaiMaiEk}{LTA}{200}
\DeclareTextSymbol{\thaiMaiTho}{LTA}{201}
\DeclareTextSymbol{\thaiMaiTri}{LTA}{202}
\DeclareTextSymbol{\thaiMaiChattawa}{LTA}{203}
\DeclareTextSymbol{\thaiThanthakhat}{LTA}{204}
\DeclareTextSymbol{\thaiNikhahit}{LTA}{205}
\DeclareTextSymbol{\thaiYamakkan}{LTA}{206}
\DeclareTextSymbol{\thaiFongman}{LTA}{207}
\DeclareTextSymbol{\thaizero}{LTA}{208}
\DeclareTextSymbol{\thaione}{LTA}{209}
\DeclareTextSymbol{\thaitwo}{LTA}{210}
\DeclareTextSymbol{\thaithree}{LTA}{211}
\DeclareTextSymbol{\thaifour}{LTA}{212}
\DeclareTextSymbol{\thaifive}{LTA}{213}
\DeclareTextSymbol{\thaisix}{LTA}{214}
\DeclareTextSymbol{\thaiseven}{LTA}{215}
\DeclareTextSymbol{\thaieight}{LTA}{216}
\DeclareTextSymbol{\thainine}{LTA}{217}
\DeclareTextSymbol{\thaiAngkhankhu}{LTA}{218}
\DeclareTextSymbol{\thaiKhomut}{LTA}{219}
