%%% Unicode to TeX mapping, file uni-167.def, U+A700..U+A7FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-167.def}[2013/05/13 UCS: Unicode data U+A700..U+A7FF]%
\fi
\uc@dclc{43000}{autogenerated}{\unicodesuper{\unichar{294}}}%
\uc@dclc{43001}{autogenerated}{\unicodesuper{\unichar{339}}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
