%%
%% This is file `mkrenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ucs.dtx  (with options: `mkrenc.def')
%% 
%% Copyright 2001 Dominique Unruh  <unruh@ut.ee>
%% Copyright 2013 Wolfgang Jeltsch <wolfgang@cs.ioc.ee>
%% 
%% This program is provided under the terms of the LaTeX Project Public License with some
%% modifications. See the file LICENSE for information.
%% 
\ProvidesFile{mkrenc.def}[2003/11/29 Fontencoding MKR for use with package makor]
\makeatletter
\AtBeginDocument{%
  \let\mkr@quote\"
  \RequirePackage{makor}%
  \let\"\mkr@quote
  \expandafter\ifx\csname !hdefaultfont\endcsname\relax
    \expandafter\def\csname !hdefaultfont\endcsname{NFSS}\fi
  }%
\expandafter\g@addto@macro\csname selectfont \endcsname{\protect\@hfontadapt}
\begingroup
\escapechar=-1
\edef\temp@a{%
  \gdef\noexpand\@hfontadapt@
  \expandafter\string\csname select font \endcsname##1 ##2%
  \noexpand\@nil{%
    \edef\noexpand\temp@a{%
      \noexpand\noexpand\noexpand\hfontdef{\noexpand\mkr@font}{##1}{\noexpand\f@size pt}}\noexpand\temp@a}}\temp@a
\xdef\mkr@at{\expandafter\string\csname\space at \endcsname}%
\endgroup
\def\@hfont@enc{MKR}
\def\@hfontadapt{%
  \ifx\f@encoding\@hfont@enc%
    \edef\mkr@font{mkr@\f@family\f@series\f@shape-\f@size}%
    %\typeout{HFONTADAPT: ID:\mkr@font, SIZE: \f@size}%
    \@ifundefined{\mkr@font}{%
      %\typeout{Needs adapting. (\expandafter\meaning\the\font)}%
      \edef\temp@a{\noexpand\@hfontadapt@\expandafter\meaning\the\font\space\noexpand\@nil}\temp@a%
      }{}%
    \expandafter\hfont\expandafter{\mkr@font}%
  \fi
}
\DeclareFontEncoding{MKR}{}{}
\DeclareFontSubstitution{MKR}{omega}{m}{n}
\DeclareTextCommand\hebalef{MKR}{`}
\DeclareTextCommand\hebbet{MKR}{v}
\DeclareTextCommand\hebgimel{MKR}{g}
\DeclareTextCommand\hebdalet{MKR}{d}
\DeclareTextCommand\hebhe{MKR}{h}
\DeclareTextCommand\hebvav{MKR}{w}
\DeclareTextCommand\hebzayin{MKR}{z}
\DeclareTextCommand\hebhet{MKR}{x}
\DeclareTextCommand\hebtet{MKR}{t}
\DeclareTextCommand\hebyod{MKR}{y}
\DeclareTextCommand\hebfinalkaf{MKR}{K\char94 }
\DeclareTextCommand\hebkaf{MKR}{K\NOBOUNDARY}
\DeclareTextCommand\heblamed{MKR}{l}
\DeclareTextCommand\hebfinalmem{MKR}{m\char94 }
\DeclareTextCommand\hebmem{MKR}{m\NOBOUNDARY}
\DeclareTextCommand\hebfinalnun{MKR}{n\char94 }
\DeclareTextCommand\hebnun{MKR}{n\NOBOUNDARY}
\DeclareTextCommand\hebsamekh{MKR}{s}
\DeclareTextCommand\hebayin{MKR}{``}
\DeclareTextCommand\hebfinalpe{MKR}{f\char94 }
\DeclareTextCommand\hebpe{MKR}{f\NOBOUNDARY}
\DeclareTextCommand\hebfinaltsadi{MKR}{ts\char94 }
\DeclareTextCommand\hebtsadi{MKR}{ts\NOBOUNDARY}
\DeclareTextCommand\hebqof{MKR}{q}
\DeclareTextCommand\hebresh{MKR}{r}
\DeclareTextCommand\hebshin{MKR}{sh}
\DeclareTextCommand\hebtav{MKR}{s\char94 }
\DeclareTextSymbol\doublevav{MKR}{"83}
\DeclareTextSymbol\vavyod{MKR}{"84}
\DeclareTextSymbol\doubleyod{MKR}{"81}
\DeclareTextCommand\maqaf{MKR}{-{}}
\DeclareTextCommand\sofpasuq{MKR}{:}
\DeclareTextSymbol\geresh{MKR}{251}
\DeclareTextSymbol\gershayim{MKR}{"22}
\DeclareTextSymbol\hebaleflamed{MKR}{"A4}
\DeclareTextCommand\dagesh{MKR}[1]{#1*}
\DeclareTextCommand\sheva{MKR}[1]{#1\vwlSHEVA}
\DeclareTextCommand\hatafsegol{MKR}[1]{#1\vwlCOLON\vwlE}
\DeclareTextCommand\hatafpatah{MKR}[1]{#1\vwlCOLON\vwlA}
\DeclareTextCommand\hatafqamats{MKR}[1]{#1\vwlCOLON\vwlPLUS}
\DeclareTextCommand\hiriq{MKR}[1]{#1\vwlI}
\DeclareTextCommand\tsere{MKR}[1]{#1\vwlE\vwlI}
\DeclareTextCommand\segol{MKR}[1]{#1\vwlE}
\DeclareTextCommand\patah{MKR}[1]{#1\vwlA}
\DeclareTextCommand\qamats{MKR}[1]{#1\vwlPLUS}
\DeclareTextCommand\qubuts{MKR}[1]{#1\vwlU}
\DeclareTextCommand\meteg{MKR}[1]{#1\vwlVERT}
\DeclareTextCommand\holam{MKR}[1]{#1o}
\DeclareTextCommand\shindot{MKR}[1]{sh\char94 }% Only useful as \shindot\shin
\DeclareTextCommand\sindot{MKR}[1]{\char94s}% Only useful as \sindot\shin
\DeclareTextCommand{\textascii}{MKR}[1]{\@textascii@switch{#1}}
\DeclareTextComposite\patach{MKR}\doubleyod{"82}
\DeclareTextCompositeCommand\dagesh{MKR}\finalkaf{K*\char94 }
\DeclareTextCompositeCommand\dagesh{MKR}\kaf{K*\NOBOUNDARY}
\DeclareTextCompositeCommand\dagesh{MKR}\finalmem{m*{}}
\DeclareTextCompositeCommand\dagesh{MKR}\mem{m*\NOBOUNDARY}
\DeclareTextCompositeCommand\dagesh{MKR}\finalnun{n*{}}
\DeclareTextCompositeCommand\dagesh{MKR}\nun{n*\NOBOUNDARY}
\DeclareTextCompositeCommand\dagesh{MKR}\pe{f*\NOBOUNDARY}
\DeclareTextCompositeCommand\dagesh{MKR}\tsadi{ts*\NOBOUNDARY}
