%%% Unicode to TeX mapping, file uni-31.def, U+1F00..U+1FFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-31.def}[2013/05/13 UCS: Unicode data U+1F00..U+1FFF]%
\fi
\uc@dclc{7936}{default}{\textpsili\textalpha}%
\uc@dclc{7937}{default}{\textdasia\textalpha}%
\uc@dclc{7938}{default}{\textpsilivaria\textalpha}%
\uc@dclc{7939}{default}{\textdasiavaria\textalpha}%
\uc@dclc{7940}{default}{\textpsilioxia\textalpha}%
\uc@dclc{7941}{default}{\textdasiaoxia\textalpha}%
\uc@dclc{7942}{default}{\textpsiliperispomeni\textalpha}%
\uc@dclc{7943}{default}{\textdasiaperispomeni\textalpha}%
\uc@dclc{7944}{default}{\textpsili\textAlpha}%
\uc@dclc{7945}{default}{\textdasia\textAlpha}%
\uc@dclc{7946}{default}{\textpsilivaria\textAlpha}%
\uc@dclc{7947}{default}{\textdasiavaria\textAlpha}%
\uc@dclc{7948}{default}{\textpsilioxia\textAlpha}%
\uc@dclc{7949}{default}{\textdasiaoxia\textAlpha}%
\uc@dclc{7950}{default}{\textpsiliperispomeni\textAlpha}%
\uc@dclc{7951}{default}{\textdasiaperispomeni\textAlpha}%
\uc@dclc{7952}{default}{\textpsili\textepsilon}%
\uc@dclc{7953}{default}{\textdasia\textepsilon}%
\uc@dclc{7954}{default}{\textpsilivaria\textepsilon}%
\uc@dclc{7955}{default}{\textdasiavaria\textepsilon}%
\uc@dclc{7956}{default}{\textpsilioxia\textepsilon}%
\uc@dclc{7957}{default}{\textdasiaoxia\textepsilon}%
\uc@dclc{7960}{default}{\textpsili\textEpsilon}%
\uc@dclc{7961}{default}{\textdasia\textEpsilon}%
\uc@dclc{7962}{default}{\textpsilivaria\textEpsilon}%
\uc@dclc{7963}{default}{\textdasiavaria\textEpsilon}%
\uc@dclc{7964}{default}{\textpsilioxia\textEpsilon}%
\uc@dclc{7965}{default}{\textdasiaoxia\textEpsilon}%
\uc@dclc{7968}{default}{\textpsili\texteta}%
\uc@dclc{7969}{default}{\textdasia\texteta}%
\uc@dclc{7970}{default}{\textpsilivaria\texteta}%
\uc@dclc{7971}{default}{\textdasiavaria\texteta}%
\uc@dclc{7972}{default}{\textpsilioxia\texteta}%
\uc@dclc{7973}{default}{\textdasiaoxia\texteta}%
\uc@dclc{7974}{default}{\textpsiliperispomeni\texteta}%
\uc@dclc{7975}{default}{\textdasiaperispomeni\texteta}%
\uc@dclc{7976}{default}{\textpsili\textEta}%
\uc@dclc{7977}{default}{\textdasia\textEta}%
\uc@dclc{7978}{default}{\textpsilivaria\textEta}%
\uc@dclc{7979}{default}{\textdasiavaria\textEta}%
\uc@dclc{7980}{default}{\textpsilioxia\textEta}%
\uc@dclc{7981}{default}{\textdasiaoxia\textEta}%
\uc@dclc{7982}{default}{\textpsiliperispomeni\textEta}%
\uc@dclc{7983}{default}{\textdasiaperispomeni\textEta}%
\uc@dclc{7984}{default}{\textpsili\textiota}%
\uc@dclc{7985}{default}{\textdasia\textiota}%
\uc@dclc{7986}{default}{\textpsilivaria\textiota}%
\uc@dclc{7987}{default}{\textdasiavaria\textiota}%
\uc@dclc{7988}{default}{\textpsilioxia\textiota}%
\uc@dclc{7989}{default}{\textdasiaoxia\textiota}%
\uc@dclc{7990}{default}{\textpsiliperispomeni\textiota}%
\uc@dclc{7991}{default}{\textdasiaperispomeni\textiota}%
\uc@dclc{7992}{default}{\textpsili\textIota}%
\uc@dclc{7993}{default}{\textdasia\textIota}%
\uc@dclc{7994}{default}{\textpsilivaria\textIota}%
\uc@dclc{7995}{default}{\textdasiavaria\textIota}%
\uc@dclc{7996}{default}{\textpsilioxia\textIota}%
\uc@dclc{7997}{default}{\textdasiaoxia\textIota}%
\uc@dclc{7998}{default}{\textpsiliperispomeni\textIota}%
\uc@dclc{7999}{default}{\textdasiaperispomeni\textIota}%
\uc@dclc{8000}{default}{\textpsili\textomicron}%
\uc@dclc{8001}{default}{\textdasia\textomicron}%
\uc@dclc{8002}{default}{\textpsilivaria\textomicron}%
\uc@dclc{8003}{default}{\textdasiavaria\textomicron}%
\uc@dclc{8004}{default}{\textpsilioxia\textomicron}%
\uc@dclc{8005}{default}{\textdasiaoxia\textomicron}%
\uc@dclc{8008}{default}{\textpsili\textOmicron}%
\uc@dclc{8009}{default}{\textdasia\textOmicron}%
\uc@dclc{8010}{default}{\textpsilivaria\textOmicron}%
\uc@dclc{8011}{default}{\textdasiavaria\textOmicron}%
\uc@dclc{8012}{default}{\textpsilioxia\textOmicron}%
\uc@dclc{8013}{default}{\textdasiaoxia\textOmicron}%
\uc@dclc{8016}{default}{\textpsili\textupsilon}%
\uc@dclc{8017}{default}{\textdasia\textupsilon}%
\uc@dclc{8018}{default}{\textpsilivaria\textupsilon}%
\uc@dclc{8019}{default}{\textdasiavaria\textupsilon}%
\uc@dclc{8020}{default}{\textpsilioxia\textupsilon}%
\uc@dclc{8021}{default}{\textdasiaoxia\textupsilon}%
\uc@dclc{8022}{default}{\textpsiliperispomeni\textupsilon}%
\uc@dclc{8023}{default}{\textdasiaperispomeni\textupsilon}%
\uc@dclc{8025}{default}{\textdasia\textUpsilon}%
\uc@dclc{8027}{default}{\textdasiavaria\textUpsilon}%
\uc@dclc{8029}{default}{\textdasiaoxia\textUpsilon}%
\uc@dclc{8031}{default}{\textdasiaperispomeni\textUpsilon}%
\uc@dclc{8032}{default}{\textpsili\textomega}%
\uc@dclc{8033}{default}{\textdasia\textomega}%
\uc@dclc{8034}{default}{\textpsilivaria\textomega}%
\uc@dclc{8035}{default}{\textdasiavaria\textomega}%
\uc@dclc{8036}{default}{\textpsilioxia\textomega}%
\uc@dclc{8037}{default}{\textdasiaoxia\textomega}%
\uc@dclc{8038}{default}{\textpsiliperispomeni\textomega}%
\uc@dclc{8039}{default}{\textdasiaperispomeni\textomega}%
\uc@dclc{8040}{default}{\textpsili\textOmega}%
\uc@dclc{8041}{default}{\textdasia\textOmega}%
\uc@dclc{8042}{default}{\textpsilivaria\textOmega}%
\uc@dclc{8043}{default}{\textdasiavaria\textOmega}%
\uc@dclc{8044}{default}{\textpsilioxia\textOmega}%
\uc@dclc{8045}{default}{\textdasiaoxia\textOmega}%
\uc@dclc{8046}{default}{\textpsiliperispomeni\textOmega}%
\uc@dclc{8047}{default}{\textdasiaperispomeni\textOmega}%
\uc@dclc{8048}{default}{\@tabacckludge`\textalpha}%
\uc@dclc{8049}{default}{\textoxia\textalpha}%
\uc@dclc{8050}{default}{\@tabacckludge`\textepsilon}%
\uc@dclc{8051}{default}{\textoxia\textepsilon}%
\uc@dclc{8052}{default}{\@tabacckludge`\texteta}%
\uc@dclc{8053}{default}{\textoxia\texteta}%
\uc@dclc{8054}{default}{\@tabacckludge`\textiota}%
\uc@dclc{8055}{default}{\textoxia\textiota}%
\uc@dclc{8056}{default}{\@tabacckludge`\textomicron}%
\uc@dclc{8057}{default}{\textoxia\textomicron}%
\uc@dclc{8058}{default}{\@tabacckludge`\textupsilon}%
\uc@dclc{8059}{default}{\textoxia\textupsilon}%
\uc@dclc{8060}{default}{\@tabacckludge`\textomega}%
\uc@dclc{8061}{default}{\textoxia\textomega}%
\uc@dclc{8064}{default}{\textpsiliiota\textalpha}%
\uc@dclc{8065}{default}{\textdasiaiota\textalpha}%
\uc@dclc{8066}{default}{\textpsilivariaiota\textalpha}%
\uc@dclc{8067}{default}{\textdasiavariaiota\textalpha}%
\uc@dclc{8068}{default}{\textpsilioxiaiota\textalpha}%
\uc@dclc{8069}{default}{\textdasiaoxiaiota\textalpha}%
\uc@dclc{8070}{default}{\textpsiliperispomeniiota\textalpha}%
\uc@dclc{8071}{default}{\textdasiaperispomeniiota\textalpha}%
\uc@dclc{8072}{default}{\textpsiliiota\textAlpha}%
\uc@dclc{8073}{default}{\textdasiaiota\textAlpha}%
\uc@dclc{8074}{default}{\textpsilivariaiota\textAlpha}%
\uc@dclc{8075}{default}{\textdasiavariaiota\textAlpha}%
\uc@dclc{8076}{default}{\textpsilioxiaiota\textAlpha}%
\uc@dclc{8077}{default}{\textdasiaoxiaiota\textAlpha}%
\uc@dclc{8078}{default}{\textpsiliperispomeniiota\textAlpha}%
\uc@dclc{8079}{default}{\textdasiaperispomeniiota\textAlpha}%
\uc@dclc{8080}{default}{\textpsiliiota\texteta}%
\uc@dclc{8081}{default}{\textdasiaiota\texteta}%
\uc@dclc{8082}{default}{\textpsilivariaiota\texteta}%
\uc@dclc{8083}{default}{\textdasiavariaiota\texteta}%
\uc@dclc{8084}{default}{\textpsilioxiaiota\texteta}%
\uc@dclc{8085}{default}{\textdasiaoxiaiota\texteta}%
\uc@dclc{8086}{default}{\textpsiliperispomeniiota\texteta}%
\uc@dclc{8087}{default}{\textdasiaperispomeniiota\texteta}%
\uc@dclc{8088}{default}{\textpsiliiota\textEta}%
\uc@dclc{8089}{default}{\textdasiaiota\textEta}%
\uc@dclc{8090}{default}{\textpsilivariaiota\textEta}%
\uc@dclc{8091}{default}{\textdasiavariaiota\textEta}%
\uc@dclc{8092}{default}{\textpsilioxiaiota\textEta}%
\uc@dclc{8093}{default}{\textdasiaoxiaiota\textEta}%
\uc@dclc{8094}{default}{\textpsiliperispomeniiota\textEta}%
\uc@dclc{8095}{default}{\textdasiaperispomeniiota\textEta}%
\uc@dclc{8096}{default}{\textpsiliiota\textomega}%
\uc@dclc{8097}{default}{\textdasiaiota\textomega}%
\uc@dclc{8098}{default}{\textpsilivariaiota\textomega}%
\uc@dclc{8099}{default}{\textdasiavariaiota\textomega}%
\uc@dclc{8100}{default}{\textpsilioxiaiota\textomega}%
\uc@dclc{8101}{default}{\textdasiaoxiaiota\textomega}%
\uc@dclc{8102}{default}{\textpsiliperispomeniiota\textomega}%
\uc@dclc{8103}{default}{\textdasiaperispomeniiota\textomega}%
\uc@dclc{8104}{default}{\textpsiliiota\textOmega}%
\uc@dclc{8105}{default}{\textdasiaiota\textOmega}%
\uc@dclc{8106}{default}{\textpsilivariaiota\textOmega}%
\uc@dclc{8107}{default}{\textdasiavariaiota\textOmega}%
\uc@dclc{8108}{default}{\textpsilioxiaiota\textOmega}%
\uc@dclc{8109}{default}{\textdasiaoxiaiota\textOmega}%
\uc@dclc{8110}{default}{\textpsiliperispomeniiota\textOmega}%
\uc@dclc{8111}{default}{\textdasiaperispomeniiota\textOmega}%
\uc@dclc{8112}{default}{\u\textalpha}%
\uc@dclc{8113}{default}{\@tabacckludge=\textalpha}%
\uc@dclc{8114}{default}{\textvariaiota\textalpha}%
\uc@dclc{8115}{default}{\textsubiota\textalpha}%
\uc@dclc{8116}{default}{\textoxiaiota\textalpha}%
\uc@dclc{8118}{default}{\~\textalpha}%
\uc@dclc{8119}{default}{\textperispomeniiota\textalpha}%
\uc@dclc{8120}{default}{\u\textAlpha}%
\uc@dclc{8121}{default}{\@tabacckludge=\textAlpha}%
\uc@dclc{8122}{default}{\@tabacckludge`\textAlpha}%
\uc@dclc{8123}{default}{\textoxia\textAlpha}%
\uc@dclc{8124}{default}{\textsubiota\textAlpha}%
\uc@dclc{8125}{default}{\textpsili{\empty}}%
\uc@dclc{8126}{default}{\textsubiota{\empty}}%
\uc@dclc{8127}{default}{\textpsili{\empty}}%
\uc@dclc{8128}{default}{\~{\empty}}%
\uc@dclc{8129}{default}{\textdialytikaperispomeni{\empty}}%
\uc@dclc{8130}{default}{\textvariaiota\texteta}%
\uc@dclc{8131}{default}{\textsubiota\texteta}%
\uc@dclc{8132}{default}{\textoxiaiota\texteta}%
\uc@dclc{8134}{default}{\~\texteta}%
\uc@dclc{8135}{default}{\textperispomeniiota\texteta}%
\uc@dclc{8136}{default}{\@tabacckludge`\textEpsilon}%
\uc@dclc{8137}{default}{\textoxia\textEpsilon}%
\uc@dclc{8138}{default}{\@tabacckludge`\textEta}%
\uc@dclc{8139}{default}{\textoxia\textEta}%
\uc@dclc{8140}{default}{\textsubiota\textEta}%
\uc@dclc{8141}{default}{\textpsilivaria{\empty}}%
\uc@dclc{8142}{default}{\textpsilioxia{\empty}}%
\uc@dclc{8143}{default}{\textpsiliperispomeni{\empty}}%
\uc@dclc{8144}{default}{\u\textiota}%
\uc@dclc{8145}{default}{\@tabacckludge=\textiota}%
\uc@dclc{8146}{default}{\textdialytikavaria\textiota}%
\uc@dclc{8147}{default}{\textdialytikaoxia\textiota}%
\uc@dclc{8150}{default}{\~\textiota}%
\uc@dclc{8151}{default}{\textdialytikaperispomeni\textiota}%
\uc@dclc{8152}{default}{\u\textIota}%
\uc@dclc{8153}{default}{\@tabacckludge=\textIota}%
\uc@dclc{8154}{default}{\@tabacckludge`\textIota}%
\uc@dclc{8155}{default}{\textoxia\textIota}%
\uc@dclc{8157}{default}{\textdasiavaria{\empty}}%
\uc@dclc{8158}{default}{\textdasiaoxia{\empty}}%
\uc@dclc{8159}{default}{\textdasiaperispomeni{\empty}}%
\uc@dclc{8160}{default}{\u\textupsilon}%
\uc@dclc{8161}{default}{\@tabacckludge=\textupsilon}%
\uc@dclc{8162}{default}{\textdialytikavaria\textupsilon}%
\uc@dclc{8163}{default}{\textdialytikaoxia\textupsilon}%
\uc@dclc{8164}{default}{\textpsili\textrho}%
\uc@dclc{8165}{default}{\textdasia\textrho}%
\uc@dclc{8166}{default}{\~\textupsilon}%
\uc@dclc{8167}{default}{\textdialytikaperispomeni\textupsilon}%
\uc@dclc{8168}{default}{\u\textUpsilon}%
\uc@dclc{8169}{default}{\@tabacckludge=\textUpsilon}%
\uc@dclc{8170}{default}{\@tabacckludge`\textUpsilon}%
\uc@dclc{8171}{default}{\textoxia\textUpsilon}%
\uc@dclc{8172}{default}{\textdasia\textRho}%
\uc@dclc{8173}{default}{\textdialytikavaria{\empty}}%
\uc@dclc{8174}{default}{\textdialytikaoxia{\empty}}%
\uc@dclc{8175}{default}{\@tabacckludge`{\empty}}%
\uc@dclc{8178}{default}{\textvariaiota\textomega}%
\uc@dclc{8179}{default}{\textsubiota\textomega}%
\uc@dclc{8180}{default}{\textoxiaiota\textomega}%
\uc@dclc{8182}{default}{\~\textomega}%
\uc@dclc{8183}{default}{\textperispomeniiota\textomega}%
\uc@dclc{8184}{default}{\@tabacckludge`\textOmicron}%
\uc@dclc{8185}{default}{\textoxia\textOmicron}%
\uc@dclc{8186}{default}{\@tabacckludge`\textOmega}%
\uc@dclc{8187}{default}{\textoxia\textOmega}%
\uc@dclc{8188}{default}{\textsubiota\textOmega}%
\uc@dclc{8189}{default}{\textoxia{\empty}}%
\uc@dclc{8190}{default}{\textdasia{\empty}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
