%%% Unicode to TeX mapping, file uni-42.def, U+2A00..U+2AFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-42.def}[2013/05/13 UCS: Unicode data U+2A00..U+2AFF]%
\fi
\uc@dclc{10764}{autogenerated}{\unichar{8747}\unichar{8747}\unichar{8747}\unichar{8747}}%
\uc@dclc{10868}{autogenerated}{\unichar{58}\unichar{58}\unichar{61}}%
\uc@dclc{10869}{autogenerated}{\unichar{61}\unichar{61}}%
\uc@dclc{10870}{autogenerated}{\unichar{61}\unichar{61}\unichar{61}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
