%%% Unicode to TeX mapping, file uni-2.def, U+0200..U+02FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-2.def}[2013/05/13 UCS: Unicode data U+0200..U+02FF]%
\fi
\uc@dclc{512}{default}{\textdblgravecmb A}%
\uc@dclc{513}{default}{\textdblgravecmb a}%
\uc@dclc{514}{autogenerated}{\unichar{65}\unichar{785}}%
\uc@dclc{515}{autogenerated}{\unichar{97}\unichar{785}}%
\uc@dclc{516}{default}{\textdblgravecmb E}%
\uc@dclc{517}{default}{\textdblgravecmb e}%
\uc@dclc{518}{autogenerated}{\unichar{69}\unichar{785}}%
\uc@dclc{519}{autogenerated}{\unichar{101}\unichar{785}}%
\uc@dclc{520}{default}{\textdblgravecmb I}%
\uc@dclc{521}{default}{\textdblgravecmb i}%
\uc@dclc{522}{autogenerated}{\unichar{73}\unichar{785}}%
\uc@dclc{523}{autogenerated}{\unichar{105}\unichar{785}}%
\uc@dclc{524}{default}{\textdblgravecmb O}%
\uc@dclc{525}{default}{\textdblgravecmb o}%
\uc@dclc{526}{autogenerated}{\unichar{79}\unichar{785}}%
\uc@dclc{527}{autogenerated}{\unichar{111}\unichar{785}}%
\uc@dclc{528}{default}{\textdblgravecmb R}%
\uc@dclc{529}{default}{\textdblgravecmb r}%
\uc@dclc{530}{autogenerated}{\unichar{82}\unichar{785}}%
\uc@dclc{531}{autogenerated}{\unichar{114}\unichar{785}}%
\uc@dclc{532}{default}{\textdblgravecmb U}%
\uc@dclc{533}{default}{\textdblgravecmb u}%
\uc@dclc{534}{autogenerated}{\unichar{85}\unichar{785}}%
\uc@dclc{535}{autogenerated}{\unichar{117}\unichar{785}}%
\uc@dclc{536}{default}{{\textcommabelow S}}%
\uc@dclc{537}{default}{{\textcommabelow s}}%
\uc@dclc{538}{default}{{\textcommabelow T}}%
\uc@dclc{539}{default}{{\textcommabelow t}}%
\uc@dclc{542}{default}{\v H}%
\uc@dclc{543}{default}{\v h}%
\uc@dclc{550}{default}{\.A}%
\uc@dclc{551}{default}{\.a}%
\uc@dclc{552}{default}{\c E}%
\uc@dclc{553}{default}{\c e}%
\uc@dclc{554}{default}{\@tabacckludge={\"O}}%
\uc@dclc{555}{default}{\@tabacckludge={\"o}}%
\uc@dclc{556}{default}{\@tabacckludge={\~O}}%
\uc@dclc{557}{default}{\@tabacckludge={\~o}}%
\uc@dclc{558}{default}{\.O}%
\uc@dclc{559}{default}{\.o}%
\uc@dclc{560}{autogenerated}{\unichar{558}\unichar{772}}%
\uc@dclc{561}{autogenerated}{\unichar{559}\unichar{772}}%
\uc@dclc{562}{default}{\@tabacckludge=Y}%
\uc@dclc{563}{default}{\@tabacckludge=y}%
\uc@dclc{592}{tipa}{\textturna}%
\uc@dclc{593}{tipa}{\textscripta}%
\uc@dclc{594}{tipa}{\textturnscripta}%
\uc@dclc{595}{default}{\textbhook}%
\uc@dclc{595}{tipa}{\texthtb}%
\uc@dclc{596}{default}{\textoopen}%
\uc@dclc{596}{tipa}{\textopeno}%
\uc@dclc{597}{tipa}{\textctc}%
\uc@dclc{598}{default}{\textdtail}%
\uc@dclc{598}{tipa}{\textrtaild}%
\uc@dclc{599}{default}{\textdhook}%
\uc@dclc{599}{tipa}{\texthtd}%
\uc@dclc{600}{tipa}{\textreve}%
\uc@dclc{601}{default}{\textschwa}%
\uc@dclc{602}{tipa}{\textrhookschwa}%
\uc@dclc{603}{default}{\texteopen}%
\uc@dclc{603}{tipa}{\textepsilon}%
\uc@dclc{604}{tipa}{\textrevepsilon}%
\uc@dclc{605}{tipa}{\textrhookrevepsilon}%
\uc@dclc{606}{tipa}{\textcloserevepsilon}%
\uc@dclc{607}{tipa}{\textbardotlessj}%
\uc@dclc{608}{tipa}{\texthtg}%
\uc@dclc{609}{tipa}{\textscriptg}%
\uc@dclc{610}{tipa}{\textscg}%
\uc@dclc{611}{default}{\textgammalatinsmall}%
\uc@dclc{611}{tipa}{\textgamma}%
\uc@dclc{612}{tipa}{\textramshorns}%
\uc@dclc{613}{tipa}{\textturnh}%
\uc@dclc{614}{tipa}{\texthth}%
\uc@dclc{615}{tipa}{\texththeng}%
\uc@dclc{616}{tipa}{\textbari}%
\uc@dclc{617}{default}{\textiotalatin}%
\uc@dclc{617}{tipa}{\textiota}%
\uc@dclc{618}{tipa}{\textsci}%
\uc@dclc{619}{tipa}{\textltilde}%
\uc@dclc{620}{tipa}{\textbeltl}%
\uc@dclc{621}{tipa}{\textrtaill}%
\uc@dclc{622}{tipa}{\textlyoghlig}%
\uc@dclc{623}{tipa}{\textturnm}%
\uc@dclc{624}{tipa}{\textturnmrleg}%
\uc@dclc{625}{tipa}{\textltailm}%
\uc@dclc{626}{default}{\textnhookleft}%
\uc@dclc{626}{tipa}{\textltailn}%
\uc@dclc{627}{tipa}{\textrtailn}%
\uc@dclc{628}{tipa}{\textscn}%
\uc@dclc{629}{tipa}{\textbaro}%
\uc@dclc{630}{tipa}{\textscoelig}%
\uc@dclc{631}{tipa}{\textcloseomega}%
\uc@dclc{632}{tipa}{\textphi}%
\uc@dclc{633}{tipa}{\textturnr}%
\uc@dclc{634}{tipa}{\textturnlonglegr}%
\uc@dclc{635}{tipa}{\textturnrrtail}%
\uc@dclc{636}{tipa}{\textlonglegr}%
\uc@dclc{637}{tipa}{\textrtailr}%
\uc@dclc{638}{tipa}{\textfishhookr}%
\uc@dclc{639}{tipa}{\textlhti}%
\uc@dclc{640}{tipa}{\textscr}%
\uc@dclc{641}{tipa}{\textinvscr}%
\uc@dclc{642}{tipa}{\textrtails}%
\uc@dclc{643}{default}{\textesh}%
\uc@dclc{644}{tipa}{\texthtbardotlessj}%
\uc@dclc{645}{tipa}{\textraisevibyi}%
\uc@dclc{646}{tipa}{\textctesh}%
\uc@dclc{647}{tipa}{\textturnt}%
\uc@dclc{648}{default}{\texttretroflexhook}%
\uc@dclc{648}{tipa}{\textrtailt}%
\uc@dclc{649}{tipa}{\textbaru}%
\uc@dclc{650}{tipa}{\textupsilon}%
\uc@dclc{651}{default}{\textvhook}%
\uc@dclc{651}{tipa}{\textscriptv}%
\uc@dclc{652}{tipa}{\textturnv}%
\uc@dclc{653}{tipa}{\textturnw}%
\uc@dclc{654}{tipa}{\textturny}%
\uc@dclc{655}{tipa}{\textscy}%
\uc@dclc{656}{tipa}{\textrtailz}%
\uc@dclc{657}{tipa}{\textctz}%
\uc@dclc{658}{default}{\textezh}%
\uc@dclc{658}{tipa}{\textyogh}%
\uc@dclc{659}{tipa}{\textctyogh}%
\uc@dclc{660}{tipa}{\textglotstop}%
\uc@dclc{661}{tipa}{\textrevglotstop}%
\uc@dclc{662}{tipa}{\textinvglotstop}%
\uc@dclc{663}{tipa}{\textstretchc}%
\uc@dclc{664}{tipa}{\textbullseye}%
\uc@dclc{665}{tipa}{\textscb}%
\uc@dclc{666}{tipa}{\textcloseepsilon}%
\uc@dclc{667}{tipa}{\texthtscg}%
\uc@dclc{668}{tipa}{\textsch}%
\uc@dclc{669}{tipa}{\textctj}%
\uc@dclc{670}{tipa}{\textturnk}%
\uc@dclc{671}{tipa}{\textscl}%
\uc@dclc{672}{tipa}{\texthtq}%
\uc@dclc{673}{tipa}{\textbarglotstop}%
\uc@dclc{674}{tipa}{\textbarrevglotstop}%
\uc@dclc{675}{tipa}{\textdzlig}%
\uc@dclc{676}{tipa}{\textdyoghlig}%
\uc@dclc{677}{tipa}{\textdctzlig}%
\uc@dclc{678}{tipa}{\texttslig}%
\uc@dclc{679}{default}{\texttesh}%
\uc@dclc{679}{tipa}{\textteshlig}%
\uc@dclc{680}{tipa}{\texttctclig}%
\uc@dclc{688}{default}{\textsuperscript h}%
\uc@dclc{689}{tipa}{\textsuperscript\texthth}%
\uc@dclc{690}{default}{\textsuperscript j}%
\uc@dclc{691}{default}{\textsuperscript r}%
\uc@dclc{692}{tipa}{\textsuperscript\textturnr}%
\uc@dclc{693}{tipa}{\textsuperscript\textturnrrtail}%
\uc@dclc{694}{tipa}{\textsuperscript\textinvscr}%
\uc@dclc{695}{default}{\textsuperscript w}%
\uc@dclc{696}{default}{\textsuperscript y}%
\uc@dclc{702}{default}{\ifnum\fontdimen1\font=0\protect\raisebox{0.4ex}{$\rhook$}\else\protect\raisebox{0.4ex}{\kern.05em$\rhook$\kern-.1em}\fi}%
\uc@dclc{703}{default}{\ifnum\fontdimen1\font=0\protect\raisebox{0.4ex}{$\lhook$}\else\protect\raisebox{0.4ex}{\kern.05em$\lhook$\kern-.1em}\fi}%
\uc@dclc{710}{default}{\^{\empty}}%
\uc@dclc{711}{default}{\v{\empty}}%
\uc@dclc{712}{tipa}{\textprimstress}%
\uc@dclc{713}{default}{\@tabacckludge={\empty}}%
\uc@dclc{714}{default}{\@tabacckludge'{\empty}}%
\uc@dclc{715}{default}{\@tabacckludge`{\empty}}%
\uc@dclc{717}{default}{\b{\empty}}%
\uc@dclc{720}{tipa}{\textlengthmark}%
\uc@dclc{728}{default}{\u{\empty}}%
\uc@dclc{729}{default}{\.{\empty}}%
\uc@dclc{730}{default}{\r{\empty}}%
\uc@dclc{731}{default}{\k{\empty}}%
\uc@dclc{732}{default}{\~{\empty}}%
\uc@dclc{733}{default}{\H{\empty}}%
\uc@dclc{736}{autogenerated}{\unicodesuper{\unichar{611}}}%
\uc@dclc{737}{autogenerated}{\unicodesuper{\unichar{108}}}%
\uc@dclc{738}{autogenerated}{\unicodesuper{\unichar{115}}}%
\uc@dclc{739}{autogenerated}{\unicodesuper{\unichar{120}}}%
\uc@dclc{740}{autogenerated}{\unicodesuper{\unichar{661}}}%
\uc@dclc{741}{tipa}{\tone5}%
\uc@dclc{742}{tipa}{\tone4}%
\uc@dclc{743}{tipa}{\tone3}%
\uc@dclc{744}{tipa}{\tone2}%
\uc@dclc{745}{tipa}{\tone1}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
