%%% Unicode to TeX mapping, file uni-178.def, U+B200..U+B2FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-178.def}[2013/05/13 UCS: Unicode data U+B200..U+B2FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{45572}{cjkhangul}{\u@cjk@hangul0802}%
\uc@dclc{45573}{cjkhangul}{\u@cjk@hangul0803}%
\uc@dclc{45576}{cjkhangul}{\u@cjk@hangul0804}%
\uc@dclc{45579}{cjkhangul}{\u@cjk@hangul0805}%
\uc@dclc{45580}{cjkhangul}{\u@cjk@hangul0806}%
\uc@dclc{45588}{cjkhangul}{\u@cjk@hangul0807}%
\uc@dclc{45589}{cjkhangul}{\u@cjk@hangul0808}%
\uc@dclc{45591}{cjkhangul}{\u@cjk@hangul0809}%
\uc@dclc{45593}{cjkhangul}{\u@cjk@hangul080A}%
\uc@dclc{45600}{cjkhangul}{\u@cjk@hangul080B}%
\uc@dclc{45620}{cjkhangul}{\u@cjk@hangul080C}%
\uc@dclc{45628}{cjkhangul}{\u@cjk@hangul080D}%
\uc@dclc{45656}{cjkhangul}{\u@cjk@hangul080E}%
\uc@dclc{45660}{cjkhangul}{\u@cjk@hangul080F}%
\uc@dclc{45664}{cjkhangul}{\u@cjk@hangul0810}%
\uc@dclc{45672}{cjkhangul}{\u@cjk@hangul0811}%
\uc@dclc{45673}{cjkhangul}{\u@cjk@hangul0812}%
\uc@dclc{45684}{cjkhangul}{\u@cjk@hangul0813}%
\uc@dclc{45685}{cjkhangul}{\u@cjk@hangul0814}%
\uc@dclc{45692}{cjkhangul}{\u@cjk@hangul0815}%
\uc@dclc{45700}{cjkhangul}{\u@cjk@hangul0816}%
\uc@dclc{45701}{cjkhangul}{\u@cjk@hangul0817}%
\uc@dclc{45705}{cjkhangul}{\u@cjk@hangul0818}%
\uc@dclc{45712}{cjkhangul}{\u@cjk@hangul0819}%
\uc@dclc{45713}{cjkhangul}{\u@cjk@hangul081A}%
\uc@dclc{45716}{cjkhangul}{\u@cjk@hangul081B}%
\uc@dclc{45720}{cjkhangul}{\u@cjk@hangul081C}%
\uc@dclc{45721}{cjkhangul}{\u@cjk@hangul081D}%
\uc@dclc{45722}{cjkhangul}{\u@cjk@hangul081E}%
\uc@dclc{45728}{cjkhangul}{\u@cjk@hangul081F}%
\uc@dclc{45729}{cjkhangul}{\u@cjk@hangul0820}%
\uc@dclc{45731}{cjkhangul}{\u@cjk@hangul0821}%
\uc@dclc{45733}{cjkhangul}{\u@cjk@hangul0822}%
\uc@dclc{45734}{cjkhangul}{\u@cjk@hangul0823}%
\uc@dclc{45738}{cjkhangul}{\u@cjk@hangul0824}%
\uc@dclc{45740}{cjkhangul}{\u@cjk@hangul0825}%
\uc@dclc{45744}{cjkhangul}{\u@cjk@hangul0826}%
\uc@dclc{45748}{cjkhangul}{\u@cjk@hangul0827}%
\uc@dclc{45768}{cjkhangul}{\u@cjk@hangul0828}%
\uc@dclc{45769}{cjkhangul}{\u@cjk@hangul0829}%
\uc@dclc{45772}{cjkhangul}{\u@cjk@hangul082A}%
\uc@dclc{45776}{cjkhangul}{\u@cjk@hangul082B}%
\uc@dclc{45778}{cjkhangul}{\u@cjk@hangul082C}%
\uc@dclc{45784}{cjkhangul}{\u@cjk@hangul082D}%
\uc@dclc{45785}{cjkhangul}{\u@cjk@hangul082E}%
\uc@dclc{45787}{cjkhangul}{\u@cjk@hangul082F}%
\uc@dclc{45789}{cjkhangul}{\u@cjk@hangul0830}%
\uc@dclc{45794}{cjkhangul}{\u@cjk@hangul0831}%
\uc@dclc{45796}{cjkhangul}{\u@cjk@hangul0832}%
\uc@dclc{45797}{cjkhangul}{\u@cjk@hangul0833}%
\uc@dclc{45798}{cjkhangul}{\u@cjk@hangul0834}%
\uc@dclc{45800}{cjkhangul}{\u@cjk@hangul0835}%
\uc@dclc{45803}{cjkhangul}{\u@cjk@hangul0836}%
\uc@dclc{45804}{cjkhangul}{\u@cjk@hangul0837}%
\uc@dclc{45805}{cjkhangul}{\u@cjk@hangul0838}%
\uc@dclc{45806}{cjkhangul}{\u@cjk@hangul0839}%
\uc@dclc{45807}{cjkhangul}{\u@cjk@hangul083A}%
\uc@dclc{45811}{cjkhangul}{\u@cjk@hangul083B}%
\uc@dclc{45812}{cjkhangul}{\u@cjk@hangul083C}%
\uc@dclc{45813}{cjkhangul}{\u@cjk@hangul083D}%
\uc@dclc{45815}{cjkhangul}{\u@cjk@hangul083E}%
\uc@dclc{45816}{cjkhangul}{\u@cjk@hangul083F}%
\uc@dclc{45817}{cjkhangul}{\u@cjk@hangul0840}%
\uc@dclc{45818}{cjkhangul}{\u@cjk@hangul0841}%
\uc@dclc{45819}{cjkhangul}{\u@cjk@hangul0842}%
\uc@dclc{45823}{cjkhangul}{\u@cjk@hangul0843}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
