%%% Unicode to TeX mapping, file uni-208.def, U+D000..U+D0FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-208.def}[2013/05/13 UCS: Unicode data U+D000..U+D0FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{53248}{cjkhangul}{\u@cjk@hangul142F}%
\uc@dclc{53252}{cjkhangul}{\u@cjk@hangul1430}%
\uc@dclc{53265}{cjkhangul}{\u@cjk@hangul1431}%
\uc@dclc{53272}{cjkhangul}{\u@cjk@hangul1432}%
\uc@dclc{53293}{cjkhangul}{\u@cjk@hangul1433}%
\uc@dclc{53300}{cjkhangul}{\u@cjk@hangul1434}%
\uc@dclc{53301}{cjkhangul}{\u@cjk@hangul1435}%
\uc@dclc{53304}{cjkhangul}{\u@cjk@hangul1436}%
\uc@dclc{53308}{cjkhangul}{\u@cjk@hangul1437}%
\uc@dclc{53316}{cjkhangul}{\u@cjk@hangul1438}%
\uc@dclc{53317}{cjkhangul}{\u@cjk@hangul1439}%
\uc@dclc{53319}{cjkhangul}{\u@cjk@hangul143A}%
\uc@dclc{53321}{cjkhangul}{\u@cjk@hangul143B}%
\uc@dclc{53328}{cjkhangul}{\u@cjk@hangul143C}%
\uc@dclc{53332}{cjkhangul}{\u@cjk@hangul143D}%
\uc@dclc{53336}{cjkhangul}{\u@cjk@hangul143E}%
\uc@dclc{53344}{cjkhangul}{\u@cjk@hangul143F}%
\uc@dclc{53356}{cjkhangul}{\u@cjk@hangul1440}%
\uc@dclc{53357}{cjkhangul}{\u@cjk@hangul1441}%
\uc@dclc{53360}{cjkhangul}{\u@cjk@hangul1442}%
\uc@dclc{53364}{cjkhangul}{\u@cjk@hangul1443}%
\uc@dclc{53372}{cjkhangul}{\u@cjk@hangul1444}%
\uc@dclc{53373}{cjkhangul}{\u@cjk@hangul1445}%
\uc@dclc{53377}{cjkhangul}{\u@cjk@hangul1446}%
\uc@dclc{53412}{cjkhangul}{\u@cjk@hangul1447}%
\uc@dclc{53413}{cjkhangul}{\u@cjk@hangul1448}%
\uc@dclc{53416}{cjkhangul}{\u@cjk@hangul1449}%
\uc@dclc{53420}{cjkhangul}{\u@cjk@hangul144A}%
\uc@dclc{53428}{cjkhangul}{\u@cjk@hangul144B}%
\uc@dclc{53429}{cjkhangul}{\u@cjk@hangul144C}%
\uc@dclc{53431}{cjkhangul}{\u@cjk@hangul144D}%
\uc@dclc{53433}{cjkhangul}{\u@cjk@hangul144E}%
\uc@dclc{53440}{cjkhangul}{\u@cjk@hangul144F}%
\uc@dclc{53441}{cjkhangul}{\u@cjk@hangul1450}%
\uc@dclc{53444}{cjkhangul}{\u@cjk@hangul1451}%
\uc@dclc{53448}{cjkhangul}{\u@cjk@hangul1452}%
\uc@dclc{53449}{cjkhangul}{\u@cjk@hangul1453}%
\uc@dclc{53456}{cjkhangul}{\u@cjk@hangul1454}%
\uc@dclc{53457}{cjkhangul}{\u@cjk@hangul1455}%
\uc@dclc{53459}{cjkhangul}{\u@cjk@hangul1456}%
\uc@dclc{53460}{cjkhangul}{\u@cjk@hangul1457}%
\uc@dclc{53461}{cjkhangul}{\u@cjk@hangul1458}%
\uc@dclc{53468}{cjkhangul}{\u@cjk@hangul1459}%
\uc@dclc{53469}{cjkhangul}{\u@cjk@hangul145A}%
\uc@dclc{53472}{cjkhangul}{\u@cjk@hangul145B}%
\uc@dclc{53476}{cjkhangul}{\u@cjk@hangul145C}%
\uc@dclc{53484}{cjkhangul}{\u@cjk@hangul145D}%
\uc@dclc{53485}{cjkhangul}{\u@cjk@hangul145E}%
\uc@dclc{53487}{cjkhangul}{\u@cjk@hangul145F}%
\uc@dclc{53488}{cjkhangul}{\u@cjk@hangul1460}%
\uc@dclc{53489}{cjkhangul}{\u@cjk@hangul1461}%
\uc@dclc{53496}{cjkhangul}{\u@cjk@hangul1462}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
